/*= Rohde&Schwarz UP300/UP350 Audio Analyzer & Generator ====================*/
/* LabWindows/CVI 8.0 VXIpnp style Instrument Driver
/* Original Release: June 2005
/* By: Martin Koutny
/*
/* Should you have any technical questions please contact the hotline of
/* Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
/*
/* e-mail: CustomerSupport@rsd.rohde-schwarz.com
/*
/* Modification History:
/*
/*  Rev 1.6.3, 09/2008, CVI 8.1 by Martin Krcmar
/*      - Windows Vista support added in installer
/*
/*  Rev 1.6.2, 07/2008, CVI 8.1 by Martin Krcmar
/*      - Changed functions:
/*            rssiup_AnalyzerRMSDCMeasurement (function description modified)
/*
/*  Rev 1.6.1, 05/2008, CVI 8.1 by Martin Krcmar
/*      - Added functions:
/*            rssiup_AnalyzerTHDSweepMeasurementResults2
/*      - Changed functions:
/*            rssiup_SetGeneratorFunctionRMSSweepAmplitude (recalculation of amplitudes)
/*            rssiup_GetGeneratorFunctionRMSSweepAmplitude (recalculation of amplitudes)
/*            rssiup_SetGeneratorFunctionRMSSelectiveSweepAmplitude (recalculation of amplitudes)
/*            rssiup_GetGeneratorFunctionRMSSelectiveSweepAmplitude (recalculation of amplitudes)
/*            rssiup_SetGeneratorAllParamChanRMSSelectiveSweep (recalculation of amplitudes)
/*            rssiup_GetGeneratorAllParamChanRMSSelectiveSweep (recalculation of amplitudes)
/*            rssiup_SetGeneratorFunctionTHDSweepAmplitude (recalculation of amplitudes)
/*            rssiup_GetGeneratorFunctionTHDSweepAmplitude (recalculation of amplitudes)
/*            rssiup_AnalyzerRMSSweepMeasurement (recalculation of SweepParam and RMS values)
/*            rssiup_AnalyzerRMSSelectiveSweepMeasurement (recalculation of SweepParam)
/*            rssiup_AnalyzerTHDSweepMeasurement (recalculation of SweepParam)
/*
/*  Rev 1.6, 03/2008, CVI 8.1 by Martin Krcmar
/*      - Added functions:
/*            rssiup_AnalyzerTHDSweepMeasurementResultsExt
/*            rssiup_AnalyzerTHDNMeasurementResultsExt
/*
/*  Rev 1.5, 12/2007, CVI 8.0 by Martin Krcmar
/*      - Added functions:
/*          - RMS Sweep:
/*            rssiup_SetGeneratorFunctionRMSSweepFrequency
/*            rssiup_GetGeneratorFunctionRMSSweepFrequency
/*            rssiup_SetGeneratorFunctionRMSSweepAmplitude
/*            rssiup_GetGeneratorFunctionRMSSweepAmplitude
/*            rssiup_AnalyzerRMSSweepMeasurement
/*          - RMS Selective Sweep:
/*            rssiup_GetGeneratorFunctionRMSSelectiveFrequencyLimits
/*            rssiup_SetGeneratorFunctionRMSSelectiveSweepFrequency
/*            rssiup_GetGeneratorFunctionRMSSelectiveSweepFrequency
/*            rssiup_SetGeneratorFunctionRMSSelectiveSweepBandwidth
/*            rssiup_GetGeneratorFunctionRMSSelectiveSweepBandwidth
/*            rssiup_SetGeneratorFunctionRMSSelectiveSweepAmplitude
/*            rssiup_GetGeneratorFunctionRMSSelectiveSweepAmplitude
/*            rssiup_SetGeneratorAllParamChanRMSSelectiveSweep
/*            rssiup_GetGeneratorAllParamChanRMSSelectiveSweep
/*            rssiup_SetGeneratorAllParamRMSSelectiveSweep
/*            rssiup_GetGeneratorAllParamRMSSelectiveSweep
/*            rssiup_SetGeneratorAllParamRMSSelectiveSweepSettings
/*            rssiup_GetGeneratorAllParamRMSSelectiveSweepSettings
/*            rssiup_AnalyzerRMSSelectiveSweepMeasurement
/*          - THD Sweep:
/*            rssiup_SetGeneratorFunctionTHDSweepFrequency
/*            rssiup_GetGeneratorFunctionTHDSweepFrequency
/*            rssiup_SetGeneratorFunctionTHDSweepAmplitude
/*            rssiup_GetGeneratorFunctionTHDSweepAmplitude
/*            rssiup_AnalyzerTHDSweepMeasurement
/*          - New units (dB, %) in THD, DFD and ModDist measurements:
/*            rssiup_AnalyzerTHDSweepMeasurementResults
/*            rssiup_AnalyzerTHDNMeasurementResults
/*            rssiup_AnalyzerDFDMeasurementResults
/*            rssiup_AnalyzerModDistMeasurementResults
/*          - RMS Selective Variable Bandwidth:
/*            rssiup_SetAnalyzerFunctionRMSSelectiveVariableBWSettings
/*            rssiup_GetAnalyzerFunctionRMSSelectiveVariableBWSettings
/*            rssiup_SetAnalyzerFunctionRMSSelVariableBWFFTSettings
/*            rssiup_GetAnalyzerFunctionRMSSelVariableBWFFTSettings
/*            rssiup_SetAnalyzerFunctionRMSSelectiveVariableBWFrequencySettings
/*            rssiup_GetAnalyzerFunctionRMSSelectiveVariableBWFrequencySettings
/*            rssiup_SetAnalyzerFunctionAllParamsRMSSelectiveVariableBWSettings
/*            rssiup_GetAnalyzerFunctionAllParamsRMSSelectiveVariableBWSettings
/*            rssiup_SetAnalyzerFunctionAllParamsRMSSelVariableBWFFTSettings
/*            rssiup_GetAnalyzerFunctionAllParamsRMSSelVariableBWFFTSettings
/*            rssiup_AnalyzerRMSSelectiveVariableBWMainMeasurement
/*            rssiup_AnalyzerRMSSelectiveVariableBWPostFFTMeasurement
/*      - Changed functions:
/*          rssiup_SetAnalyzerFunctionState (added new values to parameters)
/*          rssiup_GetAnalyzerFunctionState (added new values to parameters)
/*          rssiup_GetTriggerState (added new values to parameters)
/*          rssiup_SetTriggerSource (added new values to parameters)
/*          rssiup_SetSweepControl (added new values to parameters)
/*          rssiup_checkStatus (added new error message)
/*          rssiup_parseAnalyzerFunctionData
/*          rssiup_StartMeasurementWaitOPC
/*
/*  Rev 1.4.2, 06/2007, CVI 8.0 by Martin Krcmar
/*      - Added C# wrapper to installer
/*      - Bug fixed in function rssiup_AnalyzerPeakResponseData
/*      - rssiup_SetGeneratorFunctionState function panel help updated
/*
/*  Rev 1.4.1, 03/2007, CVI 8.0 by Martin Koutny
/*      - Code performance improvements
/*
/*  Rev 1.4, 11/2006, CVI 8.0 by Martin Krcmar
/*      - Added functions:
/*          rssiup_GetTriggerState
/*          rssiup_SetTriggerSource
/*          rssiup_GetTriggerSource
/*          rssiup_SetSweepControl
/*      - Changed functions:
/*          rssiup_SetMeasurementMode (trigger system added, added firmware number checking)
/*          rssiup_GetMeasurementMode (trigger system added)
/*          rssiup_StartMeasurement (trigger system added, added firmware number checking)
/*          rssiup_StartMeasurementWaitOPC (OPC checking and caching added)
/*          rssiup_checkStatus (three new error messages)
/*          rssiup_AbortMeasurement (added checking for CONT MODE, added firmware number checking)
/*          rssiup_defaultInstrSetup (added firmware number checking)
/*          rssiup_AnalyzerPeakResponseData (cache checking added)
/*          rssiup_AnalyzerRMSDCMeasurement (cache checking added)
/*          rssiup_AnalyzerQpeakMeasurement (cache checking added)
/*          rssiup_AnalyzerRMSSelectiveMeasurement (cache checking added)
/*          rssiup_AnalyzerTHDNMainMeasurement (cache checking added)
/*          rssiup_AnalyzerTHDNPostFFTMeasurement (cache checking added)
/*          rssiup_AnalyzerPhaseMainMeasurement (cache checking added)
/*          rssiup_AnalyzerDFDMainMeasurement (cache checking added)
/*          rssiup_AnalyzerDFDPostFFTMeasurement (cache checking added)
/*          rssiup_AnalyzerModDistMainMeasurement (cache checking added)
/*          rssiup_AnalyzerModDistPostFFTMeasurement (cache checking added)
/*          rssiup_AnalyzerFFTSpectrumMainMeasurement (cache checking added)
/*          rssiup_DigitalAnalyzerSampleRateMeasurement (cache checking added)
/*          rssiup_DigitalAnalyzerProtocolMeasurement (cache checking added)
/*          rssiup_SetGeneratorFunctionArbitrary (removed - not exported)
/*          rssiup_GetGeneratorFunctionArbitrary (removed - not exported)
/*          rssiup_SetGeneratorFunctionArbitraryDimension (removed - not exported)
/*          rssiup_GetGeneratorFunctionArbitraryDimension (removed - not exported)
/*
/*  Rev 1.3, 05/2006, CVI 8.0 by Martin Koutny
/*      - Code maintenance and testing (UP350 functionality - digital analyzer & generator)
/*          rssiup_SetGeneratorFunctionSineDimension (value conversion)
/*          rssiup_GetGeneratorFunctionSineDimension (value conversion)
/*          rssiup_SetGeneratorFunctionNoiseDimension (value conversion)
/*          rssiup_GetGeneratorFunctionNoiseDimension (value conversion)
/*          rssiup_SetGeneratorFunctionMultisineShape (values recalculated, frequency parameter retyped)
/*          rssiup_GetGeneratorFunctionMultisineShape (values recalculated, frequency parameter retyped)
/*          rssiup_SetGeneratorFunctionMultisineDimension (values recalculated)
/*          rssiup_GetGeneratorFunctionMultisineDimension (values recalculated)
/*          rssiup_SetGeneratorFunctionArbitrary (code improvement, predefined FFT noise signals are accessible)
/*          rssiup_GetGeneratorFunctionArbitrary (code improvement)
/*          rssiup_SetGeneratorFunctionArbitraryDimension (values recalculated)
/*          rssiup_SetGeneratorFunctionArbitraryDimension (values recalculated)
/*          rssiup_SetGeneratorGlobalDCOffset (support for digital generator)
/*          rssiup_GetGeneratorGlobalDCOffset (support for digital generator)
/*          rssiup_SetAnalogGeneratorRangeValue (value conversion)
/*          rssiup_GetAnalogGeneratorRange (value conversion)
/*          rssiup_SetDigitalGeneratorSamplingFrequencyOffset (description changed)
/*          rssiup_GetDigitalGeneratorSamplingFrequencyOffset (description changed)
/*          rssiup_SetGeneratorDeviceSelector (all running functions are stopped before device change)
/*          rssiup_AnalyzerFFTSpectrumMainMeasurement (post processing of results, reads also reduced FFT due to MMI)
/*          rssiup_SetAnalyzerFunctionFFTSettings (limited to RSSIUP_CHAB only)
/*          rssiup_GetAnalyzerFunctionFFTSettings (limited to RSSIUP_CHAB only)
/*          rssiup_SetAnalyzerFunctionFFTAveraging (limited to RSSIUP_CHAB only)
/*          rssiup_GetAnalyzerFunctionFFTAveraging (limited to RSSIUP_CHAB only)
/*          rssiup_GetAnalyzerDigitalFilter (device data structure changed)
/*          rssiup_SetAnalyzerFunctionPeakSettings (valid range changed)
/*          rssiup_AnalyzerPeakResponseData (values recalculated)
/*          rssiup_AnalyzerRMSDCMeasurement (values recalculated)
/*          rssiup_AnalyzerQpeakMeasurement (values recalculated)
/*          rssiup_AnalyzerRMSSelectiveMeasurement (values recalculated)
/*          rssiup_AnalyzerTHDNMainMeasurement (values recalculated)
/*          rssiup_AnalyzerDFDMainMeasurement (values recalculated)
/*          rssiup_AnalyzerModDistMainMeasurement (values recalculated)
/*
/*  Rev 1.2, 03/2006, CVI 8.0 by Martin Koutny
/*      - Added support for UP350, description changed
/*      - Code maintenance
/*      - Post processing of measurement results (recalculation)
/*      - Name(s) of function groups changed when the functions apply
/*          for either analog or also digital analyzer mode
/*      - Changed functions:
/*          rssiup_SetAnalogAnalyzerRangeNumber (removed - not exported)
/*          rssiup_GetAnalogAnalyzerRangeNumber (removed - not exported)
/*          rssiup_SetAnalogGeneratorRangeNumber (removed - not exported)
/*          rssiup_GetAnalogGeneratorRangeNumber (removed - not exported)
/*
/*  Rev 1.1, 01/2006, CVI 7.1 by Martin Koutny
/*      - Instrument driver structure modification and code maintenance
/*          - Changed functions:
/*              rssiup_AnalyzerDFDDataReductionFFTMeasurement (removed - not exported)
/*              rssiup_AnalyzerDFDMainMeasurement (parameters changed)
/*              rssiup_AnalyzerDFDPostFFTMeasurement (parameter values changed)
/*              rssiup_AnalyzerFFTSpectrumDataReductionMeasurement (removed - not exported)
/*              rssiup_AnalyzerFFTSpectrumMainMeasurement (parameters changed)
/*              rssiup_AnalyzerFunctionQpeakReset (removed - not exported)
/*              rssiup_AnalyzerModDistDataReductionFFTMeasurement (removed - not exported)
/*              rssiup_AnalyzerModDistMainMeasurement (parameters changed)
/*              rssiup_AnalyzerModDistPostFFTMeasurement (parameter values changed)
/*              rssiup_AnalyzerPeakResponseData (description changed)
/*              rssiup_AnalyzerPhaseDataReductionFFTMeasurement (removed - not exported)
/*              rssiup_AnalyzerPhaseMainMeasurement (parameters changed)
/*              rssiup_AnalyzerPhasePostFFTMeasurement (removed - not exported)
/*              rssiup_AnalyzerQpeakMeasurement (description changed)
/*              rssiup_AnalyzerRMSDCMeasurement (parameters changed)
/*              rssiup_AnalyzerRMSSelectiveMeasurement (parameters changed)
/*              rssiup_AnalyzerTHDNDataReductionFFTMeasurement (removed - not exported)
/*              rssiup_AnalyzerTHDNMainMeasurement (parameters changed)
/*              rssiup_configureRefOscillator (parameter values changed)
/*              rssiup_GetAnalogAnalyzerCoupling (channel removed)
/*              rssiup_GetAnalogAnalyzerFloatGround (FW version checking)
/*              rssiup_GetAnalogAnalyzerHighPassFilter (removed - not exported)
/*              rssiup_GetAnalogAnalyzerInput (description changed)
/*              rssiup_GetAnalogAnalyzerRange (parameters changed)
/*              rssiup_GetAnalogGeneratorRangeNumber (parameter values changed)
/*              rssiup_GetAnalogGeneratorRange (parameters changed)
/*              rssiup_GetAnalyzerDigitalFilter (parameters changed)
/*              rssiup_GetAnalyzerFunctionDFDFFTSettings (parameters changed)
/*              rssiup_GetAnalyzerFunctionDistFFTSettings (parameters changed)
/*              rssiup_GetAnalyzerFunctionFFTSettings (parameters changed)
/*              rssiup_GetAnalyzerFunctionPeakAveraging (removed - not exported)
/*              rssiup_GetAnalyzerFunctionPhaseFFTSettings (removed - not exported)
/*              rssiup_GetAnalyzerFunctionQpeakSettings (parameter changed)
/*              rssiup_GetAnalyzerFunctionRMSDCSettings (parameters changed)
/*              rssiup_GetAnalyzerFunctionRMSSelectiveAveraging (parameter values changed)
/*              rssiup_GetAnalyzerFunctionTHDNFFTSettings (parameters changed)
/*              rssiup_GetAnalyzerFunctionTHDNSettings (parameters changed)
/*              rssiup_GetAnalyzerUserFilter (removed - not exported)
/*              rssiup_GetAudioMonitorAttenuation (not changed)
/*              rssiup_GetDigitalAnalyzerInput (description changed)
/*              rssiup_GetDigitalAnalyzerSampleRateAveraging (parameter values changed)
/*              rssiup_GetDigitalGeneratorNoofBits (channel removed)
/*              rssiup_GetDigitalGeneratorProtocol (description changed)
/*              rssiup_GetGeneratorGlobalDCOffset (description changed)
/*              rssiup_getRefOscillatorParameters (parameter values changed)
/*              rssiup_SetAnalogAnalyzerCoupling (channel removed)
/*              rssiup_SetAnalogAnalyzerFloatGround (FW version checking)
/*              rssiup_SetAnalogAnalyzerHighPassFilter (removed - not exported)
/*              rssiup_SetAnalogAnalyzerInput (description changed)
/*              rssiup_SetAnalogAnalyzerRangeNumber (description changed)
/*              rssiup_SetAnalogAnalyzerRangeValue (parameter changed)
/*              rssiup_SetAnalogGeneratorRangeDependency (description changed)
/*              rssiup_SetAnalogGeneratorRangeNumber (parameter values changed)
/*              rssiup_SetAnalogGeneratorRangeValue (description changed)
/*              rssiup_SetAnalyzerDigitalFilter (parameter values changed)
/*              rssiup_SetAnalyzerFunctionDFDFFTSettings (parameters changed)
/*              rssiup_SetAnalyzerFunctionModDistFFTSettings (parameters changed)
/*              rssiup_SetAnalyzerFunctionFFTSettings (parameters changed)
/*              rssiup_SetAnalyzerFunctionPeakAveraging (removed - not exported)
/*              rssiup_SetAnalyzerFunctionPhaseFFTSettings (removed - not exported)
/*              rssiup_SetAnalyzerFunctionQpeakSettings (parameter changed)
/*              rssiup_SetAnalyzerFunctionRMSDCSettings (parameters changed)
/*              rssiup_SetAnalyzerFunctionRMSSelectiveAveraging (parameter values changed)
/*              rssiup_SetAnalyzerFunctionRMSSelectiveSettings (parameters changed)
/*              rssiup_SetAnalyzerFunctionState (function changed)
/*              rssiup_SetAnalyzerFunctionTHDNFFTSettings (parameters changed)
/*              rssiup_SetAnalyzerFunctionTHDNSettings (parameter changed)
/*              rssiup_SetAnalyzerUserFilter (removed - not exported)
/*              rssiup_SetAudioMonitorAttenuation (not changed)
/*              rssiup_SetAudioMonitorSource (description changed)
/*              rssiup_SetDigitalAnalyzerInput (parameter value changed)
/*              rssiup_SetDigitalAnalyzerSampleRateAveraging (parameter value changed)
/*              rssiup_SetDigitalGeneratorNoofBits (channel removed)
/*              rssiup_SetDigitalGeneratorProtocol (channel removed)
/*              rssiup_SetGeneratorGlobalDCOffset (description changed)
/*              rssiup_SetGeneratorFunctionState (function code fixed)
/*          - For all functions where units applies is fixed description
/*            to present the only basic and/or desired units. These functions
/*            need not to be listed here. Current revision supports only basic
/*            units anyway.
/*          - Included additional support files for SiControl Library (Lite)
/*
/*===========================================================================*/
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <math.h>
#include <float.h>
//#include <userint.h>
#include <SiControl.h>
#include "rssiup.h"

/*- Instrument driver revision ----------------------------------------------*/

#define RSSIUP_REVISION                         "Rev 1.6.3, 09/2008, CVI 8.1"

/*= Constants & Macros ======================================================*/

#define BUFFER_SIZE                             4095L   /* I/O buffer size */
#define RSSIUP_DEFAULT_TIMEOUT                  10000   /* Timeout value in msec */
#define MAX_ERROR_QUEUE_LENGTH                  512     /* Maximum number of queued errors */
#define NUMERIC_PRECISION                       1e-12   /* Precision of compare operations */

#define RSSIUP_ANALYZER_MODE_ANALOG             0       /* Analyzer is in analog mode */
#define RSSIUP_ANALYZER_MODE_DIGITAL            1       /* Analyzer is in digital mode */

#define RSSIUP_GENERATOR_MODE_ANALOG            0       /* Generator is in analog mode */
#define RSSIUP_GENERATOR_MODE_DIGITAL           1       /* Generator is in digital mode */

/*- Debuging mode & operations ----------------------------------------------*/

#define RSSIUP_HANDSHAKE_GDI_ACKNOWLEDGE        VI_FALSE    /* Check result of handshaking operation (ACK/NAK) */
#define IGNORE_OS_INTERNAL_ERROR_0xC01B         VI_TRUE     /* Ignore (VI_TRUE) error message - this error can be ignored */

#define IGNORE_MSG_DIGITAL_BOARD_OVERDETECTOR   VI_TRUE     /* Ignore (VI_TRUE) error message MSG_DIGITAL_BOARD_OVERDETECTOR - Workaround for damaged module */

/*- Device States -----------------------------------------------------------*/

#define RSSIUP_BUSY                             0       /* Device is working (module process internal operation). */
#define RSSIUP_READY                            1       /* Device is up and waiting for commands. */

/*- Applicable Product IDs --------------------------------------------------*/

#define RSSIUP_PID_UP300                        0x0008  /* Audio Analyzer & Generator */
#define RSSIUP_PID_PS_OLD                       0x0009  /* Power Supply (old) */
#define RSSIUP_PID_PS                           0x0010  /* Power Supply */

/*- Applicable Vendor ID ----------------------------------------------------*/

#define RSSIUP_VID_ROHDE_SCHWARZ                0x0AAD  /* Rohde&Schwarz */

/*- General Purpose Constants -----------------------------------------------*/

/* Channels */

#define ChAB                                    0
#define ChA                                     1
#define ChB                                     2

/* Number of channels */

#define GEN_CHANNEL_CNT                         2
#define ANL_CHANNEL_CNT                         2

/* On & Off Constants */

#define OFF                                     0
#define ON                                      1

typedef ViUInt16                                TOnOff;

/* Number of the generator functions & ranges */

#define GENFUN_CNT                              6
#define GEN_RANGE_CNT                           10
#define GEN_MULTISINE_HARMONIC                  17
#define GEN_MAX_ARB_SAMPLES                     16384

#define ANLFUN_CNT                              32
#define ANL_RANGE_CNT                           9

/* Generator status */

#define dsBussy                                 0
#define dsReady                                 1

typedef ViUInt16                                TDevStatus;

/* Device Selector */

#define deDisabled                              0
#define deEnabled                               1

typedef ViUInt16                                TDevEnabled;

/* Analyzer Results */

#define FFT_MAGIC_CONST                         0.4535
#define FFT_NOSL_MAX                            7430
#define FFT_DISPLAY_SIZE_MAX                    310
#define RMS_SWEEP_MAX_SAMPLES                   2000
#define RMS_SEL_SWEEP_MAX_SAMPLES               796
#define THD_SWEEP_MAX_SAMPLES                   200

/*- GDI Commands ------------------------------------------------------------*/

/* Generator DSI Tables - Generator Description (Get table) */

#define DSI_GET_GEN_DESCRIPTION                 0xA000  /* Gets pack informations about generator. */
#define DSI_GET_AGEN_RANGETABLE                 0xA001  /* Gets analog generator range table. */

/* Generator DSI Tables - Generator Init Function (Get Table) */

#define DSI_GET_GENFUN_SINE_SHAPE               0xA101  /* Gets frequencies & phases for sinus generator. */
#define DSI_GET_GENFUN_NOISE_SHAPE              0xA102  /* Gets PDF parameters. */
#define DSI_GET_GENFUN_MULTISINE_SHAPE          0xA103  /* Gets multisine shape parameters. */
#define DSI_GET_GENFUN_ARBITRARY_SHAPE          0xA104  /* Gets Data for arbitrary generator. */
#define DSI_GET_GENFUN_BURST_SHAPE              0xA105  /* Gets frequency & times for sine burst generator. */

/* Generator DSI Tables - Generator Init Function (Cmd Table) */

#define DSI_CMD_GENFUN_SINE_SHAPE               0xA181  /* Sets frequencies & phases for sinus generator. */
#define DSI_CMD_GENFUN_NOISE_SHAPE              0xA182  /* Sets PDF parameters. */
#define DSI_CMD_GENFUN_MULTISINE_SHAPE          0xA183  /* Sets multisine shape parameters. */
#define DSI_CMD_GENFUN_ARBITRARY_SHAPE          0xA184  /* Sets Data for arbitrary generator. */
#define DSI_CMD_GENFUN_BURST_SHAPE              0xA185  /* Sets frequency & times for sine burst generator. */

/* Generator DSI Tables - Generator Reinit Functions (Get Table) */

#define DSI_GET_GENFUN_SINE_DIMENSION           0xA201  /* Gets amplitudes & offsets for sinus generator. */
#define DSI_GET_GENFUN_NOISE_DIMENSION          0xA202  /* Gets amplitudes & offsets for noise generator. */
#define DSI_GET_GENFUN_MULTISINE_DIMENSION      0xA203  /* Gets amplitudes & offsets for multisine generator. */
#define DSI_GET_GENFUN_ARBITRARY_DIMENSION      0xA204  /* Gets amplitudes & offsets for arbitrary generator. */
#define DSI_GET_GENFUN_BURST_DIMENSION          0xA205  /* Gets amplitudes & offsets for sine burst  generator. */
#define DSI_GET_GENFUN_POLARITY_DIMENSION       0xA206  /* Gets amplitudes & offsets for polarity generator. */
#define DSI_GET_GENFUN_GlobDCOffset             0xA207  /* Gets global DC  offset for  generator. */

/* Generator DSI Tables - Generator Reinit Functions (Cmd Table) */

#define DSI_CMD_GENFUN_SINE_DIMENSION           0xA281  /* Sets amplitudes & offsets for sinus generator. */
#define DSI_CMD_GENFUN_NOISE_DIMENSION          0xA282  /* Sets amplitudes & offsets for noise generator. */
#define DSI_CMD_GENFUN_MULTISINE_DIMENSION      0xA283  /* Sets amplitudes & offsets for multisine generator. */
#define DSI_CMD_GENFUN_ARBITRARY_DIMENSION      0xA284  /* Sets amplitudes & offsets for arbitrary generator. */
#define DSI_CMD_GENFUN_BURST_DIMENSION          0xA285  /* Sets amplitudes & offsets for sine burst  generator. */
#define DSI_CMD_GENFUN_POLARITY_DIMENSION       0xA286  /* Sets amplitudes & offsets for polarity generator. */
#define DSI_CMD_GENFUN_GlobDCOffset             0xA287  /* Sets global DC offset for generator. */

/* Generator DSI Tables - Generator hardware setting (Get table) */

#define DSI_GET_GENHW_DEVICE_SELECTOR           0xA301  /* Gets actual device and sampling frequency on witch works generator. */
#define DSI_GET_AGENHW_OUTPUT                   0xA302  /* Gets actual status of analog generator output. */
#define DSI_GET_AGENHW_RANGE_NUM                0xA303  /* Gets parameters range and mode for generator. */
#define DSI_GET_AGENHW_RANGE_DEPENDENCY         0xA304  /* Gets parameter range dependency for generator. */
#define DSI_GET_AGENHW_RANGE_VOLT               0xA305  /* Gets parameters range and mode for generator by value in volts. */
#define DSI_GET_AGENHW_FLOAT_GND                0xA306  /* Gets actual status of generator floating ground. */

#define DSI_GET_ANLHW_DAI_SAMPL_FREQ_OFFSET     0xA310
#define DSI_GET_DGENHW_NUM_OF_BITS              0xA311
#define DSI_GET_GENFUN_DAIPROTOCOL              0xA312

/* Generator DSI Tables - Generator hardware setting (Cmd table) */

#define DSI_CMD_GENHW_DEVICE_SELECTOR           0xA381  /* Sets new device and sampling frequency for generator. */
#define DSI_CMD_AGENHW_OUTPUT                   0xA382  /* Sets analog generator output to ON or OFF. */
#define DSI_CMD_AGENHW_RANGE_NUM                0xA383  /* Sets parameters range and mode for generator. */
#define DSI_CMD_AGENHW_RANGE_DEPENDENCY         0xA384  /* Sets parameter range dependency for generator. */
#define DSI_CMD_AGENHW_RANGE_VOLT               0xA385  /* Sets parameters range and mode for generator by value in volts. */
#define DSI_CMD_AGENHW_FLOAT_GND                0xA386  /* Sets generator floating ground to ON or OFF. */

#define DSI_CMD_ANLHW_DAI_SAMPL_FREQ_OFFSET     0xA390
#define DSI_CMD_DGENHW_NUM_OF_BITS              0xA391
#define DSI_CMD_GENFUN_DAIPROTOCOL              0xA392

/* Generator DSI Tables - Generator functions controlling (Cmd table) */

#define DSI_CMD_GENFUN_FUNCTION_ON              0xB100  /* Funcion switch-on/switch-off. */

/* Analyzer DSI Tables - Analyzer Description (Get table) */

#define DSI_GET_ANL_DESCRIPTION                 0xAB00  /* Gets pack informations about analyzer. */
#define DSI_GET_AANL_RANGETABLE                 0xAB01  /* Gets analog analyzer range table. */

/* Analyzer DSI Tables - Analyzer Function (Get Table) */

#define DSI_GET_ANLFUN_PEAK_SETTING             0xAC00
#define DSI_GET_ANLFUN_PEAK_AVERAGING           0xAC01
#define DSI_GET_ANLFUN_RMSDC_MEASTIMES_WIDESET  0xAC10
#define DSI_GET_ANLFUN_RMSDC_WIDEBAND_AVERAGING 0xAC11
#define DSI_GET_ANLFUN_QPEAK_SETTING            0xAC20
#define DSI_GET_ANLFUN_RMSSEL_SETTING           0xAC30
#define DSI_GET_ANLFUN_RMSSEL_AVERANGING        0xAC31
#define DSI_GET_ANLFUN_RMSSEL_MuTsk_CHAN_SETTING      0xAC33
#define DSI_GET_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING   0xAC34
#define DSI_GET_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING 0xAC35
#define DSI_GET_ANLFUN_THDN_MEASUREMENT_TIMES   0xAC40
#define DSI_GET_ANLFUN_THDN_SETTINGS            0xAC41
#define DSI_GET_ANLFUN_THDN_AVERANGING          0xAC42
#define DSI_GET_ANLFUN_INTSYNCHRO_SETTING       0xAC60
#define DSI_GET_ANLFUN_INTSYNCHRO_DIGFILTERON   0xAC61
#define DSI_GET_ANLFUN_EXTSYNCHRO_SETTING       0xAC70
#define DSI_GET_ANLFUN_DIGITALFILTER_SETTING    0xAC80
#define DSI_GET_ANLFUN_USERFILTER_SETTING       0xAC90
#define DSI_GET_ANLFUN_SinRmsSweep_NoChSet      0xACA0
#define DSI_GET_ANLFUN_SinRmsSweep_ChanSet      0xACA1
#define DSI_GET_ANLFUN_SinThdSweep_NoChSet      0xACA4
#define DSI_GET_ANLFUN_SinThdSweep_ChanSet      0xACA5
#define DSI_GET_ANLFUN_SinRSmSweep_NoChSet      0xACB4
#define DSI_GET_ANLFUN_SinRSmSweep_ChanSet      0xACB5
#define DSI_GET_ANLFUN_SinRSmSweep_AllPSet      0xACB8
#define DSI_GET_ANLFUN_WF_MEASUREMENTSETTING    0xACC1
#define DSI_GET_ANLFUN_WF_SETTING               0xACC2
#define DSI_GET_ANLFUN_WF_OVERSAMPLINGMODE      0xACC3
#define DSI_GET_ANLFUN_WF_POSTFILTERTRIGERSET   0xACC4
#define DSI_GET_ANLFUN_WF_DATAREDUCTIONSETTING  0xACC5
#define DSI_GET_ANLFUN_THDpmN_SETTING           0xACD0
#define DSI_GET_ANLFUN_PHASEMuTsk_SETTING       0xACE0
#define DSI_GET_ANLFUN_DFDMuTsk_SETTING         0xACF0
#define DSI_GET_ANLFUN_ModDist_SETTING          0xACF8
#define DSI_GET_ANLFUN_FFTMuTsk_SETTING         0xACF9

/* Analyzer DSI Tables - Analyzer Function (Cmd table) */

#define DSI_CMD_ANLFUN_PEAK_SETTING             0xAD00
#define DSI_CMD_ANLFUN_PEAK_AVERAGING           0xAD01
#define DSI_CMD_ANLFUN_RMSDC_MEASTIMES_WIDESET  0xAD10
#define DSI_CMD_ANLFUN_RMSDC_WIDEBAND_AVERAGING 0xAD11
#define DSI_CMD_ANLFUN_QPEAK_SETTING            0xAD20
#define DSI_CMD_ANLFUN_QPEAK_MINMAXRESET        0xAD21
#define DSI_CMD_ANLFUN_RMSSEL_SETTING           0xAD30
#define DSI_CMD_ANLFUN_RMSSEL_AVERANGING        0xAD31
#define DSI_CMD_ANLFUN_RMSSEL_MuTsk_CHAN_SETTING      0xAD33
#define DSI_CMD_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING   0xAD34
#define DSI_CMD_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING 0xAD35
#define DSI_CMD_ANLFUN_THDN_MEASUREMENT_TIMES   0xAD40
#define DSI_CMD_ANLFUN_THDN_SETTINGS            0xAD41
#define DSI_CMD_ANLFUN_THDN_AVERANGING          0xAD42
#define DSI_CMD_ANLFUN_INTSYNCHRO_SETTING       0xAD60
#define DSI_CMD_ANLFUN_INTSYNCHRO_DIGFILTERON   0xAD61
#define DSI_CMD_ANLFUN_EXTSYNCHRO_SETTING       0xAD70
#define DSI_CMD_ANLFUN_DIGITALFILTER_SETTING    0xAD80
#define DSI_CMD_ANLFUN_USERFILTER_SETTING       0xAD90
#define DSI_CMD_ANLFUN_SinRmsSweep_NoChSet		0xADA0
#define DSI_CMD_ANLFUN_SinRmsSweep_ChanSet      0xADA1
#define DSI_CMD_ANLFUN_SinThdSweep_NoChSet      0xADA4
#define DSI_CMD_ANLFUN_SinThdSweep_ChanSet      0xADA5
#define DSI_CMD_ANLFUN_SinRSmSweep_NoChSet      0xADB4
#define DSI_CMD_ANLFUN_SinRSmSweep_ChanSet      0xADB5
#define DSI_CMD_ANLFUN_SinRSmSweep_AllPSet      0xADB8
#define DSI_CMD_ANLFUN_WF_MEASUREMENTSETTING    0xADC1
#define DSI_CMD_ANLFUN_WF_SETTING               0xADC2
#define DSI_CMD_ANLFUN_WF_OVERSAMPLINGMODE      0xADC3
#define DSI_CMD_ANLFUN_WF_POSTFILTERTRIGERSET   0xADC4
#define DSI_CMD_ANLFUN_WF_DATAREDUCTIONSETTING  0xADC5
#define DSI_CMD_ANLFUN_THDpmN_SETTING           0xADD0
#define DSI_CMD_ANLFUN_PHASEMuTsk_SETTING       0xADE0
#define DSI_CMD_ANLFUN_DFDMuTsk_SETTING         0xADF0
#define DSI_CMD_ANLFUN_ModDist_SETTING          0xADF8
#define DSI_CMD_ANLFUN_FFTMuTsk_SETTING         0xADF9

/* Analyzer DSI Tables - Analyzer hardware setting (Get table) */

#define DSI_GET_ANLHW_DEVICE_SELECTOR           0xAE01  /* Gets actual device and sampling frequency on witch works analyzer. */
#define DSI_GET_AANLHW_INPUT                    0xAE02  /* Gets actual status of analog analyzer input. */
#define DSI_GET_AANLHW_RANGE_NUM                0xAE03  /* Gets parameters range and mode for analyzer. */
#define DSI_GET_AANLHW_RANGE_DEPENDENCY         0xAE04  /* Gets parameter range dependency for analyzer. */
#define DSI_GET_AANLHW_RANGE_VOLT               0xAE05  /* Gets parameters range and mode for analyzer by value in volts. */
#define DSI_GET_AANLHW_COUPLING                 0xAE06
#define DSI_GET_AANLHW_DIGITAL_HPF              0xAE07
#define DSI_GET_AANLHW_FLOAT_GND                0xAE08

#define DSI_GET_ANLFUN_DAISAMPLERATE_SETTING    0xACFA
#define DSI_GET_ANLFUN_DAISAMPLERATE_AVERAGING  0xACFB
#define DSI_GET_ANLFUN_DAIPROTOCOL_SETTING      0xACFC
#define DSI_GET_DANLHW_INPUT_SELECTOR           0xAE10
#define DSI_GET_DANLHW_NUM_OF_BITS              0xAE12
#define DSI_GET_AANLHW_MEAS_MODE                0xAE13
#define DSI_GET_AANLHW_FUN_TRIG_MEAS_STATE      0xAE14

/* Analyzer DSI Tables - Analyzer hardware setting (Cmd table) */

#define DSI_CMD_ANLHW_DEVICE_SELECTOR           0xAE81  /* Sets new device and sampling frequency for analyzer. */
#define DSI_CMD_AANLHW_INPUT                    0xAE82  /* Sets analog analyzer output to ON or OFF. */
#define DSI_CMD_AANLHW_RANGE_NUM                0xAE83  /* Sets parameters range and mode for analyzer. */
#define DSI_CMD_AANLHW_RANGE_DEPENDENCY         0xAE84  /* Sets parameter range dependency for analyzer. */
#define DSI_CMD_AANLHW_RANGE_VOLT               0xAE85  /* Sets parameters range and mode for analyzer by value in volts. */
#define DSI_CMD_AANLHW_COUPLING                 0xAE86  /* Sets analyzer floating ground to ON or OFF. */
#define DSI_CMD_AANLHW_DIGITAL_HPF              0xAE87
#define DSI_CMD_AANLHW_FLOAT_GND                0xAE88

#define DSI_CMD_ANLFUN_DAISAMPLERATE_SETTING    0xADFA
#define DSI_CMD_ANLFUN_DAISAMPLERATE_AVERAGING  0xADFB
#define DSI_CMD_ANLFUN_DAIPROTOCOL_SETTING      0xADFC
#define DSI_CMD_DANLHW_INPUT_SELECTOR           0xAE90
#define DSI_CMD_DANLHW_NUM_OF_BITS              0xAE92
#define DSI_CMD_AANLHW_MEAS_MODE                0xAE93

/* Analyzer DSI Tables - Analyzer functions controlling (Cmd table) */

#define DSI_CMD_ANLFUN_FUNCTION_ON              0xBB00  /* Funcion switch-on/switch-off. */
#define DSI_CMD_ANLFUN_FUNCTION_CntReset        0xBB01
#define DSI_CMD_ANLFUN_FUNCTION_SendNextResults 0xBB02
#define DSI_CMD_ANLFUN_FUNCTION_IncChangeCnt    0xBB03
#define DSI_CMD_ANLFUN_FUNCTION_CtrlStep        0xBB04

/* Audio Monitor DSI Commands Summary */

#define DSI_GET_MONHW_OUTPUT                    0xA701
#define DSI_CMD_MONHW_OUTPUT                    0xA781
#define DSI_GET_MONHW_ATTENUATION               0xA702
#define DSI_CMD_MONHW_ATTENUATION               0xA782
#define DSI_GET_MONHW_SOURCE                    0xA703
#define DSI_CMD_MONHW_SOURCE                    0xA783

/* Reference Oscillator Settings */

#define DSI_CMD_DEV_ROSC_SETTING                0xE8A0
#define DSI_GET_DEV_ROSC_SETTING                0xF060

/* Enable Tests */

#define ENABLE_RESULT_LOOP                      0x8029  /* Enable flag for reading of results from device. */
#define ENABLE_RESULTS_READING                  0x802A  /* Enable flag for reading of results from DSP. */

/*- GDI Events & Messages ---------------------------------------------------*/

#define MSG_HANDSHAKE                           0x67FF

/* Messages */

#define MSG_OSE_INTERNAL_ERROR                  0x6010
#define MSG_DEVICE_ERROR                        0x6011
#define MSG_USB_ENUMERATION_STATUS              0x6012
#define MSG_SELFTEST                            0x6100
#define MSG_SELFCALIBRATION                     0x6101
#define MSG_BOOT_STATUS                         0x6102
#define MSG_BAUGRUPPENDATA_ACTION               0x6103
#define MSG_DEVICE_STATUS                       0x6104
#define MSG_NOT_IMPLEMENTED_ID                  0x6110
#define MSG_INVALID_REQUEST_ID                  0x6120
#define MSG_INVALID_CHANNEL                     0x6125
#define MSG_INVALID_SIZE                        0x6130
#define MSG_INVALID_VALUE                       0x6140
#define MSG_INVALID_COMMAND                     0x6160
#define MSG_INVALID_RANGE                       0x6170
#define MSG_UNKNOW_NAME                         0x6180
#define MSG_GENERATOR_ERROR                     0x6190
#define MSG_SYSTEM_ERROR                        0x61A0
#define MSG_INVALID_PRECONDITION                0x61B0
#define MSG_GENERATOR_AMPLITUDE                 0x6200
#define MSG_GENERATOR_AMPLITUDE_NO_CHANNEL      0x6201
#define MSG_GENERATOR_AMPLITUDE_CHANNEL_B       0x6202
#define MSG_GENERATOR_AMPLITUDE_CHANNEL_A       0x6203
#define MSG_GENERATOR_AMPLITUDE_CHANNEL_AB      0x6204
#define MSG_GENERATOR_RANGE_SET                 0x6210
#define MSG_ANALYZER_RANGE_SET                  0x6211
#define MSG_PLL_LOCK                            0x6230
#define MSG_INTERRUPT_EVENT                     0x6240
#define MSG_ANALYZER_OVERDETECTOR               0x6241
#define MSG_GENERATOR_OVERDETECTOR              0x6242
#define MSG_DIGITAL_BOARD_OVERDETECTOR          0x6244
#define MSG_CENTRAL_DEBUGGING_TRAP              0x6270
#define MSG_DSPTASK                             0x6300
#define MSG_ANALYZER_DSP_TASK                   0x6301
#define MSG_GENERATOR_DSP_TASK                  0x6302
#define MSG_ANALYZER_BAD_PARAMETER              0x6310
#define MSG_ANALYZER_BAD_STATUS                 0x6311
#define MSG_FLUSH_BUFFER_POOL                   0x6312
#define MSG_ANALYZER_OVERRANGE                  0x6313
#define MSG_FPGA_ARBITER                        0x6320
#define MSG_SWEEP_EVENTS                        0x6414
#define MSG_INVALID_TRIG_STATE					0x6415
#define MSG_OPERATION_COMPLETE					0x6416
#define MSG_INVALID_MEAS_MODE                   0x6417
#define MSG_DAI_MESSAGE                         0x6500
#define MSG_DATA                                0x6F00
#define MSG_INVALID_DSP_TASK                    0x8070

/*- Functions results data stream -------------------------------------------*/

#define CLASS_ID_UP300_ANL_FUN                  0x5200

/*- Measurement task IDs ----------------------------------------------------*/

#define MEAS_PEAK                               0x0102
#define MEAS_QPEAK                              0x010B
#define MEAS_RMSDC                              0x210E
#define MEAS_RMSSEL                             0x0107
#define MEAS_RMSSEL_MUTSK                       0x3355
#define MEAS_RMSSEL_MUTSK_FFT                   0x1355
#define MEAS_RMSSEL_MUTSK_REDUCED_FFT           0x2355
#define MEAS_THDN                               0x3350
#define MEAS_THDN_POST_FFT                      0x1350
#define MEAS_THDN_REDUCED_FFT                   0x2350
#define MEAS_PHASE                              0x3351
#define MEAS_PHASE_POST_FFT                     0x1351
#define MEAS_PHASE_REDUCED_FFT                  0x2351
#define MEAS_DFD                                0x3352
#define MEAS_DFD_POST_FFT                       0x1352
#define MEAS_DFD_REDUCED_FFT                    0x2352
#define MEAS_MOD_DIST                           0x3353
#define MEAS_MOD_DIST_POST_FFT                  0x1353
#define MEAS_MOD_DIST_REDUCED_FFT               0x2353
#define MEAS_FFT                                0x1354
#define MEAS_FFT_REDUCED                        0x2354
#define MEAS_DAI_SAMPLING_FREQUENCY             0x0401
#define MEAS_DAI_PROTOCOL                       0x0402
#define MEAS_RMS_SWEEP                          0x220F
#define MEAS_RMS_SELECTIVE_SWEEP                0x220A
#define MEAS_THD_SWEEP                          0x220D

/*- DSP Task state ----------------------------------------------------------*/

#define TASK_ERROR                              0x0000
#define TASK_OK                                 0x0001
#define TASK_BAD_STATUS                         0x0002
#define TASK_HANDSHAKE                          0x0003
#define TASK_ALREADY                            0x0004
#define TASK_INT_MEM                            0x0005
#define TASK_EXT_MEM                            0x0006
#define TASK_MISMATCH                           0x0008
#define TASK_REPAIR                             0x0009
#define DSP_TASK_LOAD                           0x0010
#define DSP_TASK_INIT                           0x0020
#define DSP_TASK_REINIT                         0x0030
#define DSP_TASK_STOP                           0x0040
#define DSP_TASK_UNLOAD                         0x0050
#define DSP_TASK_SETPARAM                       0x0060
#define DSP_TASK_INCLUDE                        0x0080
#define DSP_TASK_FREE                           0x0090
#define DSP_TASK_CONNECT                        0x00A0
#define DSP_TASK_DISCONNECT                     0x00B0
#define DSP_TASK_RESULT                         0x00C0
#define DSP_TASK_DELETE_FROM_INIT_TABLE         0x00D0
#define DSP_TASK_ADD_TO_INIT_TABLE              0x00E0

/*- Central debugging trap --------------------------------------------------*/

#define MSG_CENTRAL_DEBUGGING_TRAP_BUFFER_POOL  0x0001
#define MSG_CENTRAL_DEBUGGING_TRAP_FPGA         0x0002
#define MSG_CENTRAL_DEBUGGING_TRAP_I2C          0x0003
#define MSG_CENTRAL_DEBUGGING_TRAP_DEVICE       0x0004
#define MSG_CENTRAL_DEBUGGING_TRAP_BUFFER_DSP   0x0005
#define MSG_CENTRAL_DEBUGGING_TRAP_ANL_FUNCTION 0x0006
#define MSG_CENTRAL_DEBUGGING_TRAP_MSG_BUFFER   0x0007

/*- Data type identifiers used in the data structures -----------------------*/

#define DBL                                     0       /* double (8bytes) */
#define FLT                                     1       /* float (4bytes) */
#define I32                                     2       /* long (4bytes) */
#define U32                                     3       /* unsigned long (4bytes) */
#define I16                                     4       /* short (2bytes) */
#define U16                                     5       /* unsigned short (2bytes) */

/*- Macros ------------------------------------------------------------------*/

#define CHECKERR(fCal) if (rssiup_status = (fCal), rssiup_status < VI_SUCCESS) \
    return rssiup_status; else

#define CHECKERR_CU(fCal) if (rssiup_status = (fCal), rssiup_status < VI_SUCCESS) \
    return rssiup_initCleanUp (instrSession, rssiup_status); else

#define DBL2FLT(dblVal, fltVal) \
    fltVal = FLT_EPSILON * ceil (dblVal / FLT_EPSILON);

#define GOCHECKERR(fCal) if (rssiup_status = (fCal), rssiup_status < VI_SUCCESS) \
    goto ERROR; else

#define CHECKSESSION(instrSession) \
    if (!instrPtr) \
        return SI_ERROR_INV_OBJECT; \
    if (instrPtr -> instrSession != instrSession) \
        return SI_ERROR_INV_OBJECT;

#define DEBUG( fCal ) \
    { \
        ViStatus    e_r_r_o_r           = VI_SUCCESS;\
        clock_t     fCalTime            = 0,\
                    fCalStartTime       = 0;\
        ViChar      error_message[256];\
        fCalStartTime = clock();\
        e_r_r_o_r = (fCal);\
        rssiup_status = e_r_r_o_r;\
        printf(" Line %ld (%ld ms): %s\n", __LINE__,\
            (fCalTime = (clock() - fCalStartTime)), #fCal);\
        if (e_r_r_o_r != VI_SUCCESS)\
            {\
            rssiup_error_message (instrSession, e_r_r_o_r, error_message);\
            printf("\tFunction Call Status: 0x%08X, %s\n", e_r_r_o_r, error_message);\
            rssiup_error_query(instrSession, &e_r_r_o_r, error_message);\
            printf("\tInstrument Error: 0x%X, %s\n", e_r_r_o_r, error_message);\
            }\
        GOCHECKERR (rssiup_status);\
    }


/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE/DATA STRUCTURES =======================*/
/*****************************************************************************/

#pragma pack(1) /* Set maximum alignment to 1byte */

/* TIntValPair is used in the rssiup_error_message function */
typedef struct
{
   ViStatus                     intVal;
   ViUInt16                     intName;
}  TIntValPair;

/* TStringValPair is used in the rssiup_error_message function */
typedef struct
{
   ViStatus                     stringVal;
   ViString                     stringName;
}  TStringValPair;

/* TStringErrorPair is used for error queue handling */
typedef struct
{
   ViStatus                     stringVal;
   ViChar                       stringName[256];
}  TStringErrorPair;

/* Define range table data type */
typedef union
{
    ViReal64                    dbl; /* Must be always as first item! */
    ViReal32                    flt;
    ViInt32                     i32;
    ViUInt32                    u32;
    ViInt16                     i16;
    ViUInt16                    u16;
/*  ViConstString               string; */
} TUValue;

/*
    Defines discrete elements of range table
     - parameter: parameter constant
     - value: discrete value attached to the parameter
     - type: data type
     - opt: optional string value, set NULL for last item
*/
typedef struct
{
    ViInt32                     parameter;
    ViInt32                     value;
    ViUInt16                    type;
    ViConstString               opt;
} TSDiscreteValue;

/*
    TSMixedValPair is indexed value pair
    - constant
    - index
    - value
*/
typedef struct
{
   ViInt32                      constant;
   ViInt32                      index;
   ViReal64                     value;
}  TSMixedValPair;

/*****************************************************************************/
/*= Global data =============================================================*/
/*****************************************************************************/

/*- Generator DSI Tables - Generator Init Function (Get & Cmd Table) --------*/

/* DSI_GET_GENFUN_SINE_SHAPE (ChAB), DSI_CMD_GENFUN_SINE_SHAPE (ChAB) */

typedef struct {
    ViReal32                    Frequency1;
    ViReal32                    Frequency2;
    ViReal32                    InitialPhase1;
    ViReal32                    InitialPhase2;
    ViUInt16                    Sender;
} TSine_SHAPE;

/* DSI_GET_GENFUN_NOISE_SHAPE (ChAB), DSI_CMD_GENFUN_NOISE_SHAPE (ChAB) */

typedef struct {
    ViInt16                     PDF;
    ViUInt16                    GaussianFactor;
    ViUInt16                    Sender;
} TNoise_SHAPE;

#define gaussian                -1
#define rectangular             0
#define triangular              1

static TSDiscreteValue          SNoisePDFDiscVals[] =
{
    {RSSIUP_PDF_GAUSSIAN,       gaussian,       I16, ""},
    {RSSIUP_PDF_RECTANGULAR,    rectangular,    U16, ""},
    {RSSIUP_PDF_TRIANGULAR,     triangular,     U16, ""},
    {0, 0, 0, NULL}
};

/* DSI_GET_GENFUN_MULTISINE_SHAPE (ChAB), DSI_CMD_GENFUN_MULTISINE_SHAPE (ChAB) */

typedef struct {
    ViUInt16                    ComponentNumber;
    ViUInt16                    BufferLen;
    ViUInt16                    Frequency[GEN_MULTISINE_HARMONIC];
    ViReal32                    Phase[GEN_MULTISINE_HARMONIC];
    ViReal32                    RelativeAmplitude[GEN_MULTISINE_HARMONIC];
    ViReal32                    AMFrequency;
    ViUInt16                    Sender;
} TMultisine_SHAPE;

/* DSI_GET_GENFUN_ARBITRARY_SHAPE (ChA, ChB), DSI_CMD_GENFUN_ARBITRARY_SHAPE (ChAB, ChA, ChB) */

typedef struct {
    ViUInt16                    PartyID;
    ViUInt16                    PartyMax;
    ViUInt16                    ShapeDataSzInSa;
    ViUInt16                    PartySzInSa;
    ViReal32                    TransferedData[1000]; // 1000 is max block size
    ViUInt16                    Sender;
} TArbitrary_SHAPE;

/* DSI_GET_GENFUN_BURST_SHAPE (ChAB), DSI_CMD_GENFUN_BURST_SHAPE (ChAB) */

typedef struct {
    ViReal32                    GenFrequency;
    ViReal32                    BurstOnDelay;
    ViReal32                    HighLevelTime;
    ViReal32                    LowLevelTime;
    ViUInt16                    SignalType;
    ViUInt16                    Sender;
} TBurst_SHAPE;

#define Single                  0
#define Quadrat                 1

static TSDiscreteValue          SBurstSignalTypeDiscVals[] =
{
    {RSSIUP_BURST_SIGNAL_SINGLE,    Single,     U16, ""},
    {RSSIUP_BURST_SIGNAL_QUADRANT,  Quadrat,    U16, ""},
    {0, 0, 0, NULL}
};

/*- Generator DSI Tables - Generator Reinit Functions (Get & Cmd Table) -----*/

/* DSI_GET_GENFUN_SINE_DIMENSION (ChA, ChB), DSI_CMD_GENFUN_SINE_DIMENSION (ChAB, ChA, ChB) */

typedef struct {
    ViReal32                    DCOffset;
    ViReal32                    Amplitude1;
    ViReal32                    Amplitude2;
    ViUInt16                    Sender;
} TSine_DIMENSION;

/* DSI_GET_GENFUN_NOISE_DIMENSION (ChA, ChB), DSI_CMD_GENFUN_NOISE_DIMENSION  (ChAB, ChA, ChB) */

typedef struct {
    ViReal32                    DCOffset;
    ViReal32                    Amplitude1;
    ViReal32                    Amplitude2;
    ViUInt16                    Sender;
} TNoise_DIMENSION;

/* DSI_GET_GENFUN_MULTISINE_DIMENSION (ChA, ChB), DSI_CMD_GENFUN_MULTISINE_DIMENSION  (ChAB, ChA, ChB) */

typedef struct {
    ViReal32                    DCOffset;
    ViReal32                    Amplitude1;
    ViReal32                    Amplitude2;
    ViReal32                    AMModDepth;
    ViUInt16                    Sender;
} TMultisine_DIMENSION;

/* DSI_GET_GENFUN_ARBITRARY_DIMENSION (ChA, ChB), DSI_CMD_GENFUN_ARBITRARY_DIMENSION (ChAB, ChA, ChB) */

typedef struct {
    ViReal32                    DCOffset;
    ViReal32                    Amplitude1;
    ViReal32                    Amplitude2;
    ViUInt16                    Sender;
} TArbitrary_DIMENSION;

/* DSI_GET_GENFUN_BURST_DIMENSION (ChA, ChB), DSI_CMD_GENFUN_BURST_DIMENSION (ChAB, ChA, ChB) */

typedef struct {
    ViReal32                    DCOffset;
    ViReal32                    Amplitude1;
    ViReal32                    Amplitude2;
    ViReal32                    LowLevelAmpl;
    ViUInt16                    Sender;
} TBurst_DIMENSION;

/* DSI_GET_GENFUN_POLARITY_DIMENSION (ChA, ChB), DSI_CMD_GENFUN_POLARITY_DIMENSION (ChAB, ChA, ChB) */

typedef struct {
    ViReal32                    DCOffset;
    ViReal32                    Amplitude1;
    ViReal32                    Amplitude2;
    ViUInt16                    Sender;
} TPolarity_DIMENSION;

/* DSI_GET_GENFUN_GlobDCOffset (ChA, ChB), DSI_CMD_GENFUN_GlobDCOffset (ChAB, ChA, ChB) */

typedef struct {
    ViReal32                    DCOffset;
    ViUInt16                    Sender;
} TGlobDCOffset;

/*- Generator DSI Tables - Generator hardware setting (Get & Cmd table) -----*/

/* DSI_GET_GENHW_DEVICE_SELECTOR (ChAB), DSI_CMD_GENHW_DEVICE_SELECTOR (ChAB) */

#define dsA49                   0
#define dsA98                   1
#define dsA195                  2
#define dsD32                   3
#define dsD44                   4
#define dsD48                   5
#define dsD96                   6
#define dsD192                  7

typedef ViUInt16                TGenDevSelector;

static TSDiscreteValue          SGenDevSelectorDiscVals[] =
{
    {RSSIUP_GEN_A49,            dsA49,  U16, ""},
    {RSSIUP_GEN_A98,            dsA98,  U16, ""},
    {RSSIUP_GEN_A195,           dsA195, U16, ""},
    {RSSIUP_GEN_D32,            dsD32,  U16, ""},
    {RSSIUP_GEN_D44,            dsD44,  U16, ""},
    {RSSIUP_GEN_D48,            dsD48,  U16, ""},
    {RSSIUP_GEN_D96,            dsD96,  U16, ""},
    {RSSIUP_GEN_D192,           dsD192, U16, ""},
    {0, 0, 0, NULL}
};

/* DSI_GET_AGENHW_OUTPUT (ChA, ChB), DSI_CMD_AGENHW_OUTPUT (ChAB, ChA, ChB) */

typedef TOnOff                  TAGenOutput;

/* DSI_GET_AGENHW_RANGE_NUM, DSI_CMD_AGENHW_RANGE_NUM */

#define rtAuto                  0
#define rtFixed                 1
#define rtMinimal               2

typedef ViUInt16                TAGenRangeMode;

static TSDiscreteValue          SAGenRangeModeDiscVals[] =
{
    {RSSIUP_RANGE_MODE_AUTO,    rtAuto,     U16, ""},
    {RSSIUP_RANGE_MODE_FIXED,   rtFixed,    U16, ""},
    {RSSIUP_RANGE_MODE_MINIMAL, rtMinimal,  U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    TAGenRangeMode              RangeMode;
    ViUInt16                    RangeNum;
} TAGenRange;

/* DSI_GET_AGENHW_RANGE_DEPENDENCY, DSI_CMD_AGENHW_RANGE_DEPENDENCY */

typedef TOnOff                  TAGenRangeDependency;

/* DSI_GET_AGENHW_RANGE_VOLT (ChA, ChB) */

typedef struct {
    ViUInt16                    Mode;
    ViReal32                    DnLimit;
    ViReal32                    UpLimit;
} TAGenRangeModeGetVolt;

/* DSI_CMD_AGENHW_RANGE_VOLT (ChAB, ChA, ChB) */

typedef struct {
    ViUInt16                    Mode;
    ViReal32                    RangeValue;
} TAGenRangeModeSetVolt;

/* DSI_GET_AGENHW_FLOAT_GND (ChA, ChB), DSI_CMD_AGENHW_FLOAT_GND (ChAB, ChA, ChB) */

typedef TOnOff                  TAGenFloatGnd;

/* DSI_GET_GENFUN_DAIPROTOCOL (ChAB), DSI_CMD_GENFUN_DAIPROTOCOL (ChAB) */

typedef struct {
    ViUInt8                     ChannelStatus [24];
    ViUInt8                     UserData[24];
    ViUInt16                    ValidityBit;
    ViUInt16                    Sender;
} TDGenDaiProtocol;

/* DSI_GET_ANLHW_DAI_SAMPL_FREQ_OFFSET (ChAB), DSI_CMD_ANLHW_DAI_SAMPL_FREQ_OFFSET (ChAB) */


/* DSI_GET_DGENHW_NUM_OF_BITS (ChA, ChB), DSI_CMD_DGENHW_NUM_OF_BITS (ChAB, ChA, ChB) */

#define nb16bits                0
#define nb17bits                1
#define nb18bits                2
#define nb19bits                3
#define nb20bits                4
#define nb21bits                5
#define nb22bits                6
#define nb23bits                7
#define nb24bits                8

typedef ViUInt16                TDDevNoOfBits;

static TSDiscreteValue          SDDevNoOfBitsDiscVals[] =
{
    {RSSIUP_DAI_BITS_16, nb16bits,  U16, ""},
    {RSSIUP_DAI_BITS_17, nb17bits,  U16, ""},
    {RSSIUP_DAI_BITS_18, nb18bits,  U16, ""},
    {RSSIUP_DAI_BITS_19, nb19bits,  U16, ""},
    {RSSIUP_DAI_BITS_20, nb20bits,  U16, ""},
    {RSSIUP_DAI_BITS_21, nb21bits,  U16, ""},
    {RSSIUP_DAI_BITS_22, nb22bits,  U16, ""},
    {RSSIUP_DAI_BITS_23, nb23bits,  U16, ""},
    {RSSIUP_DAI_BITS_24, nb24bits,  U16, ""},
    {0, 0, 0, NULL}
};

/* DSI_GET_DGENHW_CHANNELSTATUSBLOCK (ChA, ChB), DSI_CMD_DGENHW_CHANNELSTATUSBLOCK (ChAB, ChA, ChB) */

typedef ViUInt8                 TDGenChannelStatusBlock[24];

/* Generator DSI Tables - Generator functions controlling (Cmd table) */

/* DSI_CMD_GENFUN_FUNCTION_ON */

#define gfSine                  0
#define gfArbitrary             1
#define gfNoise                 2
#define gfMultiSine             3
#define gfBurst                 4
#define gfPolarity              5
#define gfGlobalDCOffset        6
#define gfAllGenFuns            0xFFFF /* Valid only for a function switch-off (-1) */

static TSDiscreteValue          SGenFunIDDiscVals[] =
{
    {RSSIUP_GEN_FUNC_ALL,       gfAllGenFuns,       U16, ""},
    {RSSIUP_GEN_FUNC_SINE,      gfSine,             U16, ""},
    {RSSIUP_GEN_FUNC_ARB,       gfArbitrary,        U16, ""},
    {RSSIUP_GEN_FUNC_NOISE,     gfNoise,            U16, ""},
    {RSSIUP_GEN_FUNC_MULTISINE, gfMultiSine,        U16, ""},
    {RSSIUP_GEN_FUNC_BURST,     gfBurst,            U16, ""},
    {RSSIUP_GEN_FUNC_POLARITY,  gfPolarity,         U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    GenFunID;
    ViUInt16                    FunctionStatus;
    ViUInt16                    Sender;
} TGenFun;

/*- Generator DSI Tables - Generator Description (Get table) ----------------*/

/* DSI_GET_GEN_DESCRIPTION (ChAB) */

typedef struct {
    TDevStatus                  Status;
    TGenDevSelector             DevSelector;
    ViReal32                    ActualMaxPeakAmpl;
    ViReal32                    SampleFreq;
    ViReal32                    ActualPeakAmpl[GEN_CHANNEL_CNT];
    ViReal32                    GlobalDCOffset[GEN_CHANNEL_CNT];
    ViInt16                     IsRunning;
    ViInt16                     FunctionIsOn[GENFUN_CNT][GEN_CHANNEL_CNT];
    ViUInt16                    Sender[GENFUN_CNT];
} TGenGenerally;

typedef struct {
    TAGenFloatGnd               FloatGnd[GEN_CHANNEL_CNT];
    TAGenOutput                 Output[GEN_CHANNEL_CNT];
    TAGenRange                  Range[GEN_CHANNEL_CNT];
    TAGenRangeDependency        Dependency;
} TAGenHW;

typedef struct {
    TDevEnabled                 Enabled;
    ViReal32                    MaxPeakAmpl;
    TAGenHW                     AGenHW;
} TAGen;

#if 1
typedef struct {
    ViUInt8                     ubData[24];
} TChanStatBlock;

typedef struct {
    ViUInt8                     ubData[24];
} TUserData;

typedef struct {
    TChanStatBlock              ChanStatBlock;
    TUserData                   UserData;
    ViUInt16                    Sender;
} TDGenDAIProtocol_DtSet;

typedef ViUInt16                TtxDaiValidityBit;

#define vbDataIsValid           0
#define vbDataIsInvalid         1

//static TSDiscreteValue          STtxDaiValidityBitDiscVals[] =
//{
//    {RSSIUP_DAI_DATA_VALID,     vbDataIsValid,       U16, ""},
//    {RSSIUP_DAI_DATA_INVALID,   vbDataIsInvalid,     U16, ""},
//    {0, 0, 0, NULL}
//};

typedef struct {
    TtxDaiValidityBit           ValidityBit;
    ViUInt16                    Sender;
} TDGenDAIProtocol_ValSet;
#endif

typedef struct {
    ViInt16                     SamplFrqOffs[GEN_CHANNEL_CNT];
    TDGenChannelStatusBlock     ChannelStatusBlock[GEN_CHANNEL_CNT];
    TDDevNoOfBits               NoOfBits[GEN_CHANNEL_CNT];
} TDGenHW;

typedef struct {
    TDevEnabled                 Enabled;
    ViReal32                    MaxPeakAmpl;
    TDGenHW                     DGenHW;
} TDGen;

typedef struct {
    TGenGenerally               GenGenerally;
    TAGen                       AGen;
    TDGen                       DGen;

    /* --- TODO: Describe remaining bytes --- */

    ViUInt16                    unknown[34];

} TGenDescription;

/* DSI_GET_AGEN_RANGETABLE (ChAB) */

typedef struct {
    ViReal32                    DnLimit;
    ViReal32                    UpLimit;
} TLimitLine;

typedef struct {
    ViUInt16                    CntOfLines;
    TLimitLine                  Line[GEN_RANGE_CNT];
} TAGenRangeTable;

/*- Analyzer Shared Constants -----------------------------------------------*/

/* TAnlFunID */

#define afDigLoop               0
#define afPeak                  1
#define afRMSDC                 2
#define afRMSSel                3
#define afTHD_N                 4
#define afPolarity              5
#define afWaveform              6
#define afFFTMuTsk              7
#define afTHDpmN                8
#define afPhaseMuTsk            9
#define afQPeak                 10
#define afDSPLoad               11
#define afDFDMuTsk              12
#define afModDist               13
#define afRMSSelMuTsk           14
#define afSinRmsSweep           15
#define afSinThdSweep           17
#define afSinRSmSweep           25
#define afDAISamplRate          30
#define afDAIProtocol           31
#define afAllAnlFuns            0xFFFF /* -1 */

typedef ViUInt16                TAnlFunID;

/* TAverageMode */

#define amOff                   0
#define amNormal                1
#define amExponencial           2
#define amFlat                  3

typedef ViUInt16                TAverageMode;

static TSDiscreteValue          SAverageModeDiscVals[] =
{
    {RSSIUP_AVERAGING_MODE_OFF,         amOff,          U16, ""},
    {RSSIUP_AVERAGING_MODE_NORMAL,      amNormal,       U16, ""},
    {RSSIUP_AVERAGING_MODE_EXPONENCIAL, amExponencial,  U16, ""},
    {RSSIUP_AVERAGING_MODE_FLAT,        amFlat,         U16, ""},
    {0, 0, 0, NULL}
};

/* TSynchroMode */

#define smSynchroMeasurement    0
#define smAsynchroMeasurement   1

typedef ViUInt16                TSynchroMode;

static TSDiscreteValue          SSynchroModeDiscVals[] =
{
    {RSSIUP_SYNC_MODE_SYNC,     smSynchroMeasurement,   U16, ""},
    {RSSIUP_SYNC_MODE_ASYNC,    smAsynchroMeasurement,  U16, ""},
    {0, 0, 0, NULL}
};

/* TSynchroSources */

#define ssGenTrack_chA_RisingEdge           0
#define ssGenTrack_chA_FallingEdge          1
#define ssGenTrack_chB_RisingRdge           2
#define ssGenTrack_chB_FallingEdge          3
#define ssSignalSynchro_chA_RisingEdge      4
#define ssSignalSynchro_chA_FallingEdge     5
#define ssSignalSynchro_chB_RisingEdge      6
#define ssSignalSynchro_chB_FallingEdge     7
#define ssArbitraryGen_chA                  8
#define ssArbitraryGen_chB                  9
#define ssBurstSineGen                      10
#define ssMultisineGen                      11
#define ssNoSynchro                         12
#define ssExternalSource                    13

typedef ViUInt16                TSynchroSource;

static TSDiscreteValue          SSynchroSourceDiscVals[] =
{
    {RSSIUP_SYNC_SOURCE_SIN_GEN_A_RISE,     ssGenTrack_chA_RisingEdge,          U16, ""},
    {RSSIUP_SYNC_SOURCE_SIN_GEN_A_FALL,     ssGenTrack_chA_FallingEdge,         U16, ""},
    {RSSIUP_SYNC_SOURCE_SIN_GEN_B_RISE,     ssGenTrack_chB_RisingRdge,          U16, ""},
    {RSSIUP_SYNC_SOURCE_SIN_GEN_B_FALL,     ssGenTrack_chB_FallingEdge,         U16, ""},
    {RSSIUP_SYNC_SOURCE_SIGNAL_A_RISE,      ssSignalSynchro_chA_RisingEdge,     U16, ""},
    {RSSIUP_SYNC_SOURCE_SIGNAL_A_FALL,      ssSignalSynchro_chA_FallingEdge,    U16, ""},
    {RSSIUP_SYNC_SOURCE_SIGNAL_B_RISE,      ssSignalSynchro_chB_RisingEdge,     U16, ""},
    {RSSIUP_SYNC_SOURCE_SIGNAL_B_FALL,      ssSignalSynchro_chB_FallingEdge,    U16, ""},
/*  {RSSIUP_SYNC_SOURCE_ARB_GEN_A,          ssArbitraryGen_chA,                 U16, ""}, */
/*  {RSSIUP_SYNC_SOURCE_ARB_GEN_B,          ssArbitraryGen_chB,                 U16, ""}, */
/*  {RSSIUP_SYNC_SOURCE_BURST_SINE_GEN,     ssBurstSineGen,                     U16, ""}, */
/*  {RSSIUP_SYNC_SOURCE_MULTISINE_GEN,      ssMultisineGen,                     U16, ""}, */
/*  {RSSIUP_SYNC_SOURCE_NO_SYNC,            ssNoSynchro,                        U16, ""}, */
/*  {RSSIUP_SYNC_SOURCE_EXT_SYNC,           ssExternalSource,                   U16, ""}, */
    {0, 0, 0, NULL}
};

/* TLevelMode */

#define lmAutoLevel             0
#define lmFixedLevel            1

typedef ViUInt16                TSynchroLevelMode;
/*
static TSDiscreteValue          SSynchroLevelModDiscVals[] =
{
    {RSSIUP_SYNC_LEVEL_MODE_AUTO,   lmAutoLevel,    U16, ""},
    {RSSIUP_SYNC_LEVEL_MODE_FIXED,  lmFixedLevel,   U16, ""},
    {0, 0, 0, NULL}
};
*/
/* TFreqMode */

#define fmGenTrack_chA          4
#define fmGenTrack_chB          1
#define fmSignal_chA            2
#define fmSignal_chB            3
#define fmFixedValue            0

typedef ViUInt16                TFreqMode;

static TSDiscreteValue          SFreqModeDiscVals[] =
{
    {RSSIUP_FREQ_MODE_RMS_GEN_TRACK_CHA,    fmGenTrack_chA, U16, ""},
    {RSSIUP_FREQ_MODE_RMS_GEN_TRACK_CHB,    fmGenTrack_chB, U16, ""},
    {RSSIUP_FREQ_MODE_RMS_SIGNAL_CHA,       fmSignal_chA,   U16, ""},
    {RSSIUP_FREQ_MODE_RMS_SIGNAL_CHB,       fmSignal_chB,   U16, ""},
    {RSSIUP_FREQ_MODE_RMS_FIXED_VALUE,      fmFixedValue,   U16, ""},
    {0, 0, 0, NULL}
};

/* TBandwidth */

#define b_0_3_Hz                0
#define b_1_10_Hz               1
#define b_2_30_Hz               2
#define b_3_100_Hz              3
#define b_4_300_Hz              4

typedef ViUInt16                TBandwidth;

static TSDiscreteValue          SBandwidthDiscVals[] =
{
    {RSSIUP_RMS_BANDWIDTH_3HZ,      b_0_3_Hz,   U16, ""},
    {RSSIUP_RMS_BANDWIDTH_10HZ,     b_1_10_Hz,  U16, ""},
    {RSSIUP_RMS_BANDWIDTH_30HZ,     b_2_30_Hz,  U16, ""},
    {RSSIUP_RMS_BANDWIDTH_100HZ,    b_3_100_Hz, U16, ""},
    {RSSIUP_RMS_BANDWIDTH_300HZ,    b_4_300_Hz, U16, ""},
    {0, 0, 0, NULL}
};

/*- Analyzer DSI Tables - Analyzer Function (Get & Cmd Table) ---------------*/

/* DSI_GET_ANLFUN_PEAK_SETTING (ChAB) */

typedef struct {
    ViReal32                    MeasureTime;
} TGetPeakSetting;

/* DSI_CMD_ANLFUN_PEAK_SETTING (ChAB) */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    MeasurTime;
} TCmdPeakSetting;

/* DSI_GET_ANLFUN_PEAK_AVERAGING (ChAB) */

typedef struct {
    TAverageMode                AverageMode;
    ViUInt16                    AverageFactor;
} TGetPeakAveraging;

/* DSI_CMD_ANLFUN_PEAK_AVERAGING (ChAB) */

typedef struct {
    ViUInt16                    Reserve;
    TAverageMode                AverageMode;
    ViUInt16                    AverageFactor;
} TCmdPeakAveraging;

/* DSI_GET_ANLFUN_RMSDC_MEASTIMES_WIDESET (ChA, ChB) */

typedef struct {
  ViReal32                      MeasureTime;
  ViReal32                      TimeOut;
  TSynchroMode                  SynchroMode;
  TSynchroSource                SynchroSource;
  TSynchroLevelMode             SynchroLevelMode;
  ViReal32                      FixedLevel;
  ViReal32                      FixedHysteresis;
  ViReal32                      AutoHysteresis;
  ViReal32                      SynchroFilterTau;
} TGetRMSWidebandSettingAndTimes;

/* DSI_CMD_ANLFUN_RMSDC_MEASTIMES_WIDESET (ChA, ChB, ChAB) */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    MeasureTime;
    ViReal32                    TimeOut;
    TSynchroMode                SynchroMode;
    TSynchroSource              SynchroSource;
    TSynchroLevelMode           SynchroLevelMode;
    ViReal32                    FixedLevel;
    ViReal32                    FixedHysteresis;
    ViReal32                    AutoHysteresis;
    ViReal32                    SynchroFilterTau;
} TCmdRMSWidebandSettingAndTimes;

/* DSI_GET_ANLFUN_RMSDC_WIDEBAND_AVERAGING (ChA, ChB) */

typedef struct {
    TAverageMode                AverMode_DC;
    ViUInt16                    AverFactor_DC;
    TAverageMode                AverMode_RMS;
    ViUInt16                    AverFactor_RMS;
    TAverageMode                AverMode_Freq;
    ViUInt16                    AverFactor_Freq;
} TGetRMSWidebandAveraging;

/* DSI_CMD_ANLFUN_RMSDC_WIDEBAND_AVERAGING (ChA, ChB, ChAB) */

typedef struct {
    ViUInt16                    Reserve;
    TAverageMode                AverMode_DC;
    ViUInt16                    AverFactor_DC;
    TAverageMode                AverMode_RMS;
    ViUInt16                    AverFactor_RMS;
    TAverageMode                AverMode_Freq;
    ViUInt16                    AverFactor_Freq;
} TCmdRMSWidebandAveraging;

/* DSI_CMD_ANLFUN_QPEAK_SETTING (ChAB) */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    InitDelay;
} TCmdQPeakSetting;

/* DSI_CMD_ANLFUN_QPEAK_MINMAXRESET (ChAB) */

typedef struct {
    ViUInt16                    Sender;
} TCmdQPeakMinMaxReset;

/* DSI_GET_ANLFUN_QPEAK_SETTING (ChAB) */

typedef struct {
    ViReal32                    InitDelay;
} TGetQPeakSetting;

/* DSI_CMD_ANLFUN_RMSSEL_SETTING (ChAB) */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    MeasTime;
    ViReal32                    CenterFrequency;
    TFreqMode                   FrequencyMode;
    TBandwidth                  Bandwidth;
} TCmdRMSSelSetting;

/* DSI_CMD_ANLFUN_RMSSEL_AVERANGING (ChAB) */

typedef struct {
    ViUInt16                    Reserve;
    TAverageMode                AverageMode;
    ViUInt16                    AverageFactor;
} TCmdRMSSelAveraging;

/* DSI_GET_ANLFUN_RMSSEL_SETTING (ChAB) */

typedef struct {
    ViReal32                    MeasTime;
    ViReal32                    CenterFrequency;
    TFreqMode                   FrequencyMode;
    TBandwidth                  Bandwidth;
} TGetRMSSelSetting;

/* DSI_GET_ANLFUN_RMSSEL_AVERANGING (ChAB) */

typedef struct {
    TAverageMode                AverageMode;
    ViUInt16                    AverageFactor;
} TGetRMSSelAveraging;

/* DSI_CMD_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING (ChAB) */

typedef ViUInt16                TFilterBandwidthType;

static TSDiscreteValue          STFilterBandwidthTypeDiscVals[] =
{
    {RSSIUP_FILTER_BWID_TYPE_CONST,   0, U16, ""},
    {RSSIUP_FILTER_BWID_TYPE_RELAT,   1, U16, ""},
    {0, 0, 0, NULL}
};

typedef ViUInt16                TAutoFrqMode;

static TSDiscreteValue          STAutoFrqModeDiscVals[] =
{
    {RSSIUP_FREQ_MODE_AUTO,       0, U16, ""},
    {RSSIUP_FREQ_MODE_FIXED,      1, U16, ""},
    {0, 0, 0, NULL}
};

/* TFFTSize */

#define fs1024                  0
#define fs2048                  1
#define fs4096                  2
#define fs8192                  3
#define fs16384                 4

typedef ViUInt16                TFFTSize;

static TSDiscreteValue          SFFTSizeDiscVals[] =
{
    {RSSIUP_FFT_SIZE_1024,  fs1024,     U16, ""},
    {RSSIUP_FFT_SIZE_2048,  fs2048,     U16, ""},
    {RSSIUP_FFT_SIZE_4096,  fs4096,     U16, ""},
    {RSSIUP_FFT_SIZE_8192,  fs8192,     U16, ""},
    {RSSIUP_FFT_SIZE_16384, fs16384,    U16, ""},
    {0, 0, 0, NULL}
};

/* TPostFFTWindow */

#define pwRectangular           0
#define pwHamming               1
#define pwHanning               2
#define pwBlackmanHarris        3
#define pwRifeVincent1          4
#define pwRifeVincent2          5
#define pwRifeVincent3          6
#define pwFlatTop               7

typedef ViUInt16                TPostFFTWindow;

static TSDiscreteValue          SPostFFTWindowDiscVals[] =
{
    {RSSIUP_FFT_WINDOW_RECTANGULAR,         pwRectangular,      U16, ""},
    {RSSIUP_FFT_WINDOW_HAMMING,             pwHamming,          U16, ""},
    {RSSIUP_FFT_WINDOW_HANNING,             pwHanning,          U16, ""},
    {RSSIUP_FFT_WINDOW_BLACKMANN_HARRIS,    pwBlackmanHarris,   U16, ""},
    {RSSIUP_FFT_WINDOW_RIFE_VINCENT_1,      pwRifeVincent1,     U16, ""},
    {RSSIUP_FFT_WINDOW_RIFE_VINCENT_2,      pwRifeVincent2,     U16, ""},
    {RSSIUP_FFT_WINDOW_RIFE_VINCENT_3,      pwRifeVincent3,     U16, ""},
    {RSSIUP_FFT_WINDOW_FLAT_TOP,            pwFlatTop,          U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    Sender;
    ViUInt16                    FilterOrder;
    TFilterBandwidthType        FilterBandwidthType;
    ViReal32                    AbsoluteBandwidth;
    ViReal32                    RelativeBandwidth;
    TAutoFrqMode                FrequencyMode;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TPostFFTWindow              FFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TCmdRMSSelMuTskNoChSetting;

/* DSI_GET_ANLFUN_RMSSEL_MuTsk_CHAN_SETTING (ChAB) */

typedef struct {
    ViUInt16                    FilterOrder;
    TFilterBandwidthType        FilterBandwidthType;
    ViReal32                    AbsoluteBandwidth;
    ViReal32                    RelativeBandwidth;
    TAutoFrqMode                FrequencyMode;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TPostFFTWindow              FFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TGetRMSSelMuTskNoChSetting;

/* DSI_CMD_ANLFUN_RMSSEL_MuTsk_CHAN_SETTING (ChAB, ChA, ChB) */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    Frequency;
} TCmdRMSSelMuTskChanSetting;

/* DSI_GET_ANLFUN_RMSSEL_MuTsk_CHAN_SETTING (ChA, ChB) */

typedef struct {
    ViReal32                    Frequency;
} TGetRMSSelMuTskChanSetting;

/* DSI_CMD_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING (ChAB, ChA, ChB) */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    FrequencyA;
    ViReal32                    FrequencyB;
    ViUInt16                    FilterOrder;
    TFilterBandwidthType        FilterBandwidthType;
    ViReal32                    AbsoluteBandwidth;
    ViReal32                    RelativeBandwidth;
    TAutoFrqMode                FrequencyMode;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TPostFFTWindow              FFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TCmdRMSSelMuTskAllParamSetting;

/* DSI_GET_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING (ChA, ChB) */

typedef struct {
    ViReal32                    FrequencyA;
    ViReal32                    FrequencyB;
    ViUInt16                    FilterOrder;
    TFilterBandwidthType        FilterBandwidthType;
    ViReal32                    AbsoluteBandwidth;
    ViReal32                    RelativeBandwidth;
    TAutoFrqMode                FrequencyMode;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TPostFFTWindow              FFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TGetRMSSelMuTskAllParamSetting;

/* DSI_CMD_ANLFUN_THDN_MEASUREMENT_TIMES (ChAB, ChA, ChB) */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    MeasurTime;
    ViReal32                    TimeOut;
} TCmdTHDNMeasurementTimes;

/* DSI_CMD_ANLFUN_THDN_SETTINGS (ChAB, ChA, ChB) */

#define fbNarrow                0
#define fbOtherwiseWide         1

typedef ViUInt16                TFilterBandwidth;
/*
static TSDiscreteValue          SFilterBandwidthDiscVals[] =
{
    {RSSIUP_FILTER_BWIDTH_NARROW,   fbNarrow,           U16, ""},
    {RSSIUP_FILTER_BWIDTH_WIDE,     fbOtherwiseWide,    U16, ""},
    {0, 0, 0, NULL}
};
*/
#define cf1kHz                  0
#define cf3kHz                  1
#define cf5kHz                  2
#define cf10kHz                 3
#define cf30kHz                 4
#define cf50kHz                 5

typedef ViUInt16                TCenterFreq;
/*
static TSDiscreteValue          SCenterFreqDiscVals[] =
{
    {,  cf1kHz,     U16, ""},
    {,  cf3kHz,     U16, ""},
    {,  cf5kHz,     U16, ""},
    {,  cf10kHz,    U16, ""},
    {,  cf30kHz,    U16, ""},
    {,  cf50kHz,    U16, ""},
    {0, 0, 0, NULL}
};
*/
typedef struct {
    ViUInt16                    Sender;
    TCenterFreq                 Frequency;
    TFilterBandwidth            FilterBandwidth;
    TSynchroSource              SynchroSource;
} TCmdTHDNSetting;

/* DSI_CMD_ANLFUN_THDN_AVERANGING (ChAB, ChA, ChB) */

typedef struct {
    ViUInt16                    Reserve;
    TAverageMode                AverMode_Freq;
    ViUInt16                    AverFactor_Freq;
    TAverageMode                AverMode_THDN;
    ViUInt16                    AverFactor_THDN;
} TCmdTHDNAveraging;

/* DSI_GET_ANLFUN_THDN_MEASUREMENT_TIMES (ChA, ChB) */

typedef struct {
    ViReal32                    MeasurTime;
    ViReal32                    TimeOut;
} TTHDNMeasurementTimes;

/* DSI_GET_ANLFUN_THDN_SETTINGS (ChA, ChB) */

typedef struct {
  TCenterFreq                   Frequency;
  TFilterBandwidth              FilterBandwidth;
  TSynchroSource                SynchroSource;
} TTHDNSetting;

/* DSI_GET_ANLFUN_THDN_AVERANGING (ChA, ChB) */

typedef struct {
  TAverageMode                  AverMode_Freq;
  ViUInt16                      AverFactor_Freq;
  TAverageMode                  AverMode_THDN;
  ViUInt16                      AverFactor_THDN;
} TTHDNAveraging;

/* DSI_CMD_ANLFUN_FFTMuTsk_SETTING (ChAB) */

static TSDiscreteValue          SFFTSizeNumbersDiscVals[] =
{
    {RSSIUP_FFT_SIZE_1024,  1024,   U16, ""},
    {RSSIUP_FFT_SIZE_2048,  2048,   U16, ""},
    {RSSIUP_FFT_SIZE_4096,  4096,   U16, ""},
    {RSSIUP_FFT_SIZE_8192,  8192,   U16, ""},
    {RSSIUP_FFT_SIZE_16384, 16384,  U16, ""},
    {0, 0, 0, NULL}
};

/* TZoomFactor */

#define zf_000                  0
#define zf_002                  1
#define zf_004                  2
#define zf_008                  3
#define zf_016                  4
#define zf_032                  5
#define zf_064                  6
#define zf_128                  7

typedef ViUInt16                TZoomFactor;
/*
static TSDiscreteValue          SZoomFactorDiscVals[] =
{
    {RSSIUP_FFT_ZOOM_FACTOR_0,      zf_000,   U16, ""},
    {RSSIUP_FFT_ZOOM_FACTOR_2,      zf_002,   U16, ""},
    {RSSIUP_FFT_ZOOM_FACTOR_4,      zf_004,   U16, ""},
    {RSSIUP_FFT_ZOOM_FACTOR_8,      zf_008,   U16, ""},
    {RSSIUP_FFT_ZOOM_FACTOR_16,     zf_016,   U16, ""},
    {RSSIUP_FFT_ZOOM_FACTOR_32,     zf_032,   U16, ""},
    {RSSIUP_FFT_ZOOM_FACTOR_64,     zf_064,   U16, ""},
    {RSSIUP_FFT_ZOOM_FACTOR_128,    zf_128,   U16, ""},
    {0, 0, 0, NULL}
};
*/
/* TWindowMode */

#define wmRectangular           0
#define wmHamming               1
#define wmHanning               2
#define wmBlackmanHarris        3
#define wmRifeVincent1          4
#define wmRifeVincent2          5
#define wmRifeVincent3          6
#define wmFlatTop               7
#define wmKaiser                8
#define wmKaiser17              9

typedef ViUInt16                TWindowMode;

static TSDiscreteValue          SWindowModeDiscVals[] =
{
    {RSSIUP_FFT_WINDOW_RECTANGULAR,         wmRectangular,      U16, ""},
    {RSSIUP_FFT_WINDOW_HAMMING,             wmHamming,          U16, ""},
    {RSSIUP_FFT_WINDOW_HANNING,             wmHanning,          U16, ""},
    {RSSIUP_FFT_WINDOW_BLACKMANN_HARRIS,    wmBlackmanHarris,   U16, ""},
    {RSSIUP_FFT_WINDOW_RIFE_VINCENT_1,      wmRifeVincent1,     U16, ""},
    {RSSIUP_FFT_WINDOW_RIFE_VINCENT_2,      wmRifeVincent2,     U16, ""},
    {RSSIUP_FFT_WINDOW_RIFE_VINCENT_3,      wmRifeVincent3,     U16, ""},
    {RSSIUP_FFT_WINDOW_FLAT_TOP,            wmFlatTop,          U16, ""},
    {RSSIUP_FFT_WINDOW_KAISER,              wmKaiser,           U16, ""},
    {RSSIUP_FFT_WINDOW_KAISER_17,           wmKaiser17,         U16, ""},
    {0, 0, 0, NULL}
};

/* TFFTAverMode */

#define fmOff                   0
#define fmNormal                1
#define fmExponencial           2

typedef ViUInt16                TFFTAverMode;

static TSDiscreteValue          SFFTAverModeDiscVals[] =
{
    {RSSIUP_AVERAGING_MODE_OFF,         fmOff,          U16, ""},
    {RSSIUP_AVERAGING_MODE_NORMAL,      fmNormal,       U16, ""},
    {RSSIUP_AVERAGING_MODE_EXPONENCIAL, fmExponencial,  U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    Sender;
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TZoomFactor                 ZoomFactor;
    ViReal32                    ZoomOffset;
    TWindowMode                 WindowType;
    ViReal32                    KaiserWindowBeta;
    TFFTAverMode                AverageMode;
    ViUInt32                    AverageCount;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TCmdFFTMuTskSetting;

/* DSI_GET_ANLFUN_FFTMuTsk_SETTING (ChA, ChB, ChAB) */

typedef struct {
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TZoomFactor                 ZoomFactor;
    ViReal32                    ZoomOffset;
    TWindowMode                 WindowType;
    ViReal32                    KaiserWindowBeta;
    TFFTAverMode                AverageMode;
    ViUInt32                    AverageCount;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TGetFFTMuTskSetting;

/* DSI_CMD_ANLFUN_THDpmN_SETTING (ChAB) */

/* TTHDFreqMode */

#define fmAutoTuning            0
#define fmFixedFreq             1

typedef ViUInt16                TTHDFreqMode;

static TSDiscreteValue          STHDFreqModeDiscVals[] =
{
    {RSSIUP_FREQ_MODE_AUTO,     fmAutoTuning,   U16, ""},
    {RSSIUP_FREQ_MODE_FIXED,    fmFixedFreq,    U16, ""},
    {0, 0, 0, NULL}
};

/* TMeasTime */

#define fbFast                  0
#define fbNormal                1

typedef ViUInt16                TMeasTime;

static TSDiscreteValue          SMeasTimeDiscVals[] =
{
    {RSSIUP_MEAS_TIME_FAST,     fbFast,     U16, ""},
    {RSSIUP_MEAS_TIME_NORMAL,   fbNormal,   U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    Sender;
    TTHDFreqMode                FreqMode;
    ViReal32                    FixFreq_A;
    ViReal32                    FixFreq_B;
    TFilterBandwidth            FilterBandwidth;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TMeasTime                   MeasTime;
    ViReal32                    FreqLimitLo;
    ViReal32                    FreqLimitHi;
    TFFTSize                    PostFFTSize;
    TPostFFTWindow              PostFFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TCmdTHDpmNSetting;

/* DSI_GET_ANLFUN_THDpmN_SETTING (ChAB) */

typedef struct {
    TTHDFreqMode                FreqMode;
    ViReal32                    FixFreq_A;
    ViReal32                    FixFreq_B;
    TFilterBandwidth            FilterBandwidth;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TMeasTime                   MeasTime;
    ViReal32                    FreqLimitLo;
    ViReal32                    FreqLimitHi;
    TFFTSize                    PostFFTSize;
    TPostFFTWindow              PostFFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TGetTHDpmNSetting;

/* DSI_CMD_ANLFUN_PHASEMuTsk_SETTING (ChAB) */

/* TMaster */

#define maFreqFromStrongerSignalChannel     0
#define maMaxFormA                          1
#define maMaxFormB                          2

typedef ViUInt16                TMaster;

static TSDiscreteValue          SMasterDiscVals[] =
{
    {RSSIUP_FREQ_MASTER_AUTO,   maFreqFromStrongerSignalChannel,    U16, ""},
    {RSSIUP_FREQ_MASTER_CHA,    maMaxFormA,                         U16, ""},
    {RSSIUP_FREQ_MASTER_CHB,    maMaxFormB,                         U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    Sender;
    TTHDFreqMode                FrequencyMode;
    TMaster                     Master;
    TFFTSize                    FFTSize;
    ViReal32                    FixFreq;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TCmdPhaseMuTskSetting;

/* DSI_GET_ANLFUN_PHASEMuTsk_SETTING (ChAB) */

typedef struct {
    TTHDFreqMode                FrequencyMode;
    TMaster                     Master;
    TFFTSize                    FFTSize;
    ViReal32                    FixFreq;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TGetPhaseMuTskSetting;

/* DSI_CMD_ANLFUN_DIGITALFILTER_SETTING (ChAB, ChA, ChB) */

/* TFilterType */

#define ftNoFilter              0
#define ftA_Weighting           1
#define ftC_Message             2
#define ftCCITT                 3
#define ftCCIR_Weigh            4
#define ftCCIR_Unweigh          5
#define ftCCIR_ARM              6
#define ftDeemphasis_50p15      7
#define ftDeemphasis_50         8
#define ftDeemphasis_75         9
#define ftDeemphasis_J17        10
#define ftRumble_Weigh          11
#define ftRumble_Unweigh        12
#define ftDCnoiseHPF            13
#define ftIEC_IEEE_tuner        14
#define ftJitter_Weigh          15
#define ft1p3_Octave            16
#define ft1p1_Octave            17
#define ftUserFilter1           18
#define ftUserFilter2           19
#define ftUserFilter3           20
#define ftBSEllip               21

typedef ViUInt16                TFilterType;

static TSDiscreteValue          SFilterTypeDiscVals[] =
{
    {RSSIUP_DIGI_FILTER_TYPE_NONE,          ftNoFilter,         U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_A_WEIGHT,      ftA_Weighting,      U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_C_MESSAGE,     ftC_Message,        U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_CCITT,         ftCCITT,            U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_CCIR_WEIGHT,   ftCCIR_Weigh,       U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_CCIR_UNWEGHT,  ftCCIR_Unweigh,     U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_CCIR_ARM,      ftCCIR_ARM,         U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_DEEMPH_50P15,  ftDeemphasis_50p15, U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_DEEMPH_50,     ftDeemphasis_50,    U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_DEEMPH_75,     ftDeemphasis_75,    U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_DEEMPH_J17,    ftDeemphasis_J17,   U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_R_WEIGHTING,   ftRumble_Weigh,     U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_R_UNWEIGHT,    ftRumble_Unweigh,   U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_DC_NOISE_HPF,  ftDCnoiseHPF,       U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_IEC_IEE,       ftIEC_IEEE_tuner,   U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_JITTER_WEIGHT, ftJitter_Weigh,     U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_1P3_OCTAVE,    ft1p3_Octave,       U16, ""},
    {RSSIUP_DIGI_FILTER_TYPE_1P1_OCTAVE,    ft1p1_Octave,       U16, ""},
/*  {RSSIUP_DIGI_FILTER_TYPE_USER_1,        ftUserFilter1,      U16, ""}, */
/*  {RSSIUP_DIGI_FILTER_TYPE_USER_2,        ftUserFilter2,      U16, ""}, */
/*  {RSSIUP_DIGI_FILTER_TYPE_USER_3,        ftUserFilter3,      U16, ""}, */
/*  {RSSIUP_DIGI_FILTER_TYPE_BSELLIP,       ftBSEllip,          U16, ""}, */
    {0, 0, 0, NULL}
};

/* TOctaveFilterCenterFreq*/

typedef ViUInt16                TOctaveFilterCenterFreq;

static TSMixedValPair GOctaveFilterCenterFreqDiscVals[] =
{
    /* constant, index, value */
    {0, 0,  25.0},
    {0, 1,  31.0},
    {0, 2,  40.0},
    {0, 3,  50.0},
    {0, 4,  63.0},
    {0, 5,  80.0},
    {0, 6,  100.0},
    {0, 7,  125.0},
    {0, 8,  160.0},
    {0, 9,  200.0},
    {0, 10, 250.0},
    {0, 11, 315.0},
    {0, 12, 400.0},
    {0, 13, 500.0},
    {0, 14, 630.0},
    {0, 15, 800.0},
    {0, 16, 1000.0},
    {0, 17, 1250.0},
    {0, 18, 1600.0},
    {0, 19, 2000.0},
    {0, 20, 2500.0},
    {0, 21, 3150.0},
    {0, 22, 4000.0},
    {0, 23, 5000.0},
    {0, 24, 6300.0},
    {0, 25, 8000.0},
    {0, 26, 10000.0},
    {0, 27, 12500.0},
    {0, 28, 16000.0},
    {0, 29, 20000.0},
    /* Last element */
    {0, 0, 0.0}
};

static TSDiscreteValue          SFilterSectionDiscVals[] =
{
    {RSSIUP_DIGI_FILTER_SECTION_1,  0, U16, ""},
    {RSSIUP_DIGI_FILTER_SECTION_2,  1, U16, ""},
    {RSSIUP_DIGI_FILTER_SECTION_3,  2, U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    FilterSection;
    TFilterType                 FilterType;
    TOctaveFilterCenterFreq     CenterFreqForOctaves;
} TCmdDigFilterSetting;

/* DSI_GET_ANLFUN_DIGITALFILTER_SETTING (FilterSection) */

typedef struct {
    ViUInt16                    FilterSection; /* 0 = Filter in position 1, 1 = Filter in position 2, 2 = Filter in position 3 */
    ViUInt16                    FilterTypeInChannelA;
    ViUInt16                    FilterTypeInChannelB;
    ViUInt16                    CenterFreqInChanA;
    ViUInt16                    CenterFreqInChanB;
    ViUInt16                    FilterDelayInChanA;
    ViUInt16                    FilterDelayInChanB;
    ViUInt16                    FilterBiQuadsInChanA;
    ViUInt16                    FilterBiQuadsInChanB;
    ViUInt16                    SectionBiQuadsCnt;
    //ViUInt32                    Coefs[4075 /* 4075 is max */]; /* = NormalCoefs[SectionBiQuadsCnt*10] + ExtCoefs[SectionBiQuadsCnt*10] */
} TGetDigFilterSetting;

/* DSI_CMD_ANLFUN_USERFILTER_SETTING (ChAB, ChA, ChB) */
/* DSI_GET_ANLFUN_USERFILTER_SETTING (ChA, ChB) */

static TSDiscreteValue          SUserFilterNbDiscVals[] =
{
    {RSSIUP_USER_FILTER_1,  0, U16, ""},
    {RSSIUP_USER_FILTER_2,  1, U16, ""},
    {RSSIUP_USER_FILTER_3,  2, U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    UserFilterNb;
    ViUInt16                    reserve1;
    ViUInt16                    FilterType;
    ViUInt16                    FilterOrder;
    ViUInt16                    FilterDelay;
    ViUInt16                    reserve2;
    ViUInt16                    FilterCoefficients[310];
} TUserFilterSetting;

/* DSI_CMD_ANLFUN_INTSYNCHRO_SETTING (ChAB, ChA, ChB) */
/* DSI_GET_ANLFUN_INTSYNCHRO_SETTING (ChA, ChB) */

typedef struct {
    ViReal32                    HigherTresholdLevel;
    ViReal32                    LowerTresholdLevel;
    ViReal32                    SynchroTimeout;
} TIntSynchroSetting;

/* DSI_CMD_ANLFUN_INTSYNCHRO_DIGFILTERON (ChAB) */
/* DSI_GET_ANLFUN_INTSYNCHRO_DIGFILTERON (ChAB) */

typedef struct {
    TOnOff                      DigFilterOn;
} TDigFilterOn;

/* DSI_CMD_ANLFUN_EXTSYNCHRO_SETTING (ChAB, ChA, ChB) */
/* DSI_GET_ANLFUN_EXTSYNCHRO_SETTING (ChA, ChB) */

/* TExtSynchroMode */

#define emTrigger               0
#define emGate                  1

typedef ViUInt16                TExtSynchroMode;

/* TExtSynchroSlope */

#define esRising                0
#define esFalling               1

typedef ViUInt16                TExtSynchroSlope;

typedef struct {
    TExtSynchroMode             ExtSynchroMode;
    ViReal32                    Delay;
    ViReal32                    Width;
    TExtSynchroSlope            ExtSynchroSlope;
} TExtSynchroSetting;

/* DSI_CMD_ANLFUN_DFDMuTsk_SETTING (ChAB) */

/* TDFDFreqMode */

typedef TTHDFreqMode            TDFDFreqMode;

typedef struct {
    ViUInt16                    Sender;
    TDFDFreqMode                FrequencyMode;
    ViReal32                    FixFreq1_A;
    ViReal32                    FixFreq2_A;
    ViReal32                    FixFreq1_B;
    ViReal32                    FixFreq2_B;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TPostFFTWindow              PostFFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TCmdDFDMuTskSetting;

/* DSI_GET_ANLFUN_DFDMuTsk_SETTING (ChAB) */

typedef struct {
    TDFDFreqMode                FrequencyMode;
    ViReal32                    FixFreq1_A;
    ViReal32                    FixFreq2_A;
    ViReal32                    FixFreq1_B;
    ViReal32                    FixFreq2_B;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TPostFFTWindow              PostFFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TGetDFDMuTskSetting;

/* DSI_CMD_ANLFUN_ModDist_SETTING (ChAB) */

/* TModDistFreqMode */

typedef TTHDFreqMode            TModDistFreqMode;

typedef struct {
    ViUInt16                    Sender;
    TModDistFreqMode            FrequencyMode;
    ViReal32                    FixFreq1_A;
    ViReal32                    FixFreq2_A;
    ViReal32                    FixFreq1_B;
    ViReal32                    FixFreq2_B;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TPostFFTWindow              PostFFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TCmdModDistSetting;

/* DSI_GET_ANLFUN_ModDist_SETTING (ChAB) */

typedef struct {
    TModDistFreqMode            FrequencyMode;
    ViReal32                    FixFreq1_A;
    ViReal32                    FixFreq2_A;
    ViReal32                    FixFreq1_B;
    ViReal32                    FixFreq2_B;
    TOnOff                      PostFFTOn;
    TOnOff                      DataReductionOn;
    TFFTSize                    FFTSize;
    TPostFFTWindow              PostFFTWindow;
    ViInt16                     DisplaySize;
    ViInt16                     WindowSize;
    ViInt16                     WindowOffset;
    ViInt16                     Marker1Position;
    ViInt16                     Marker2Position;
} TGetModDistSetting;


/* DSI_CMD_ANLFUN_SinRmsSweep_NoChSet */

typedef ViUInt16                TFrSpacing;

static TSDiscreteValue          STFrSpacingDiscVals[] =
{
    {RSSIUP_SPACING_NO,       0, U16, ""},
    {RSSIUP_SPACING_LIN,      1, U16, ""},
    {RSSIUP_SPACING_LOG,      2, U16, ""},
    {0, 0, 0, NULL}
};

typedef ViUInt16                TCtrlStep;

static TSDiscreteValue          STCtrlStepDiscVals[] =
{
    {RSSIUP_CTRL_STEP_RESTART_SWEEPS,      0xFFFD, U16, ""}, // -3
    {RSSIUP_CTRL_STEP_RESTART_SWEEP,       0xFFFE, U16, ""}, // -2
    {RSSIUP_CTRL_STEP_CONTINUE,            0xFFFF, U16, ""}, // -1
    {RSSIUP_CTRL_STEP_STOP,                     0, U16, ""},
    {RSSIUP_CTRL_STEP_NEXT_1_STEP,              1, U16, ""},
    {RSSIUP_CTRL_STEP_TO_END_OF_INS_LOOP,  0x7FF0, U16, ""},
    {0, 0, 0, NULL}
};

typedef ViUInt16                TAverageMode;

static TSDiscreteValue          STAverageModeDiscVals[] =
{
    {RSSIUP_AVER_MODE_OFF,   0, U16, ""},
    {RSSIUP_AVER_MODE_NORM,  1, U16, ""},
    {RSSIUP_AVER_MODE_EXP,   2, U16, ""},
    {RSSIUP_AVER_MODE_FLAT,  3, U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    fFr1Start;
    ViReal32                    fFr1End;
    TFrSpacing                  Fr1Spacing;
    ViReal32                    fFr2Start;
    ViReal32                    fFr2End;
    TFrSpacing                  Fr2Spacing;
    ViUInt16                    FrStepCnt;
    ViReal32                    fPhase1;
    ViReal32                    fPhase2;
    ViUInt16                    AmStepCnt;
    ViUInt16                    RefreshTime;
    ViUInt16                    FrSweepRepeat;
    ViUInt16                    FrStepPause;
    ViUInt16                    AmStepPause;
    TCtrlStep                   StartCtrlStep;
    TAverageMode                AverageMode;
    ViUInt16                    AverageFactor;
} TCmdSinRmsSweep_NoChSet;

/* DSI_GET_ANLFUN_SinRmsSweep_NoChSet */

typedef struct {
    ViReal32                    fFr1Start;
    ViReal32                    fFr1End;
    TFrSpacing                  Fr1Spacing;
    ViReal32                    fFr2Start;
    ViReal32                    fFr2End;
    TFrSpacing                  Fr2Spacing;
    ViUInt16                    FrStepCnt;
    ViReal32                    fPhase1;
    ViReal32                    fPhase2;
    ViUInt16                    AmStepCnt;
    ViUInt16                    RefreshTime;
    ViUInt16                    FrSweepRepeat;
    ViUInt16                    FrStepPause;
    ViUInt16                    AmStepPause;
    TCtrlStep                   StartCtrlStep;
    TAverageMode                AverageMode;
    ViUInt16                    AverageFactor;
} TGetSinRmsSweep_NoChSet;

/* DSI_CMD_ANLFUN_SinRmsSweep_ChanSet */

typedef ViUInt16                TAmSpacing;

static TSDiscreteValue          STAmSpacingDiscVals[] =
{
    {RSSIUP_SPACING_NO,       0, U16, ""},
    {RSSIUP_SPACING_LIN,      1, U16, ""},
    {RSSIUP_SPACING_LOG,      2, U16, ""},
    {RSSIUP_SPACING_INS_LIN,  3, U16, ""},
    {RSSIUP_SPACING_INS_LOG,  4, U16, ""},
    {0, 0, 0, NULL}
};

typedef ViUInt16                TSynchroMode;

static TSDiscreteValue          STSynchroModeDiscVals[] =
{
    {RSSIUP_SYNC_MODE_SYNCHRO,       0, U16, ""},
    {RSSIUP_SYNC_MODE_ASYNCHRO,      1, U16, ""},
    {0, 0, 0, NULL}
};

typedef ViUInt16                TSynchroSources;

static TSDiscreteValue          STSynchroSourcesDiscVals[] =
{
    {RSSIUP_SYNC_SRC_SINE_GEN_A_RISING,    0, U16, ""},
    {RSSIUP_SYNC_SRC_SINE_GEN_A_FALLING,   1, U16, ""},
    {RSSIUP_SYNC_SRC_SINE_GEN_B_RISING,    2, U16, ""},
    {RSSIUP_SYNC_SRC_SINE_GEN_B_FALLING,   3, U16, ""},
    {RSSIUP_SYNC_SRC_SIGNAL_A_RISING,      4, U16, ""},
    {RSSIUP_SYNC_SRC_SIGNAL_A_FALLING,     5, U16, ""},
    {RSSIUP_SYNC_SRC_SIGNAL_B_RISING,      6, U16, ""},
    {RSSIUP_SYNC_SRC_SIGNAL_B_FALLING,     7, U16, ""},
    {RSSIUP_SYNC_SRC_SIGNAL_ARBITRARY_A,   8, U16, ""},
    {RSSIUP_SYNC_SRC_SIGNAL_ARBITRARY_B,   9, U16, ""},
    {RSSIUP_SYNC_SRC_SIGNAL_BURST_SINE,   10, U16, ""},
    {RSSIUP_SYNC_SRC_SIGNAL_MULTI_SINE,   11, U16, ""},
    {0, 0, 0, NULL}
};

typedef ViUInt16                TSynchroLevelMode;

static TSDiscreteValue          STSynchroLevelModeDiscVals[] =
{
    {RSSIUP_SYNC_LEVEL_MODE_AUTO,       0, U16, ""},
    {RSSIUP_SYNC_LEVEL_MODE_FIXED,      1, U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    fDCOffset;
    ViReal32                    fAm1Start;
    ViReal32                    fAm1End;
    TAmSpacing                  fAm1Spacing;
    ViReal32                    fAm2Start;
    ViReal32                    fAm2End;
    TAmSpacing                  fAm2Spacing;
    ViReal32                    fMeasTime;
    ViReal32                    fTimeOut;
    TSynchroMode                SynchroMode;
    TSynchroSources             SynchroSource;
    TSynchroLevelMode           SynchroLevelMode;
    ViReal32                    FixedLevel;
    ViReal32                    FixedHysteresis;
    ViReal32                    AutoHysteresis;
    ViReal32                    SynchroFilterTau;
} TCmdSinRmsSweep_ChanSet;

/* DSI_GET_ANLFUN_SinRmsSweep_ChanSet */

typedef struct {
    ViReal32                    fDCOffset;
    ViReal32                    fAm1Start;
    ViReal32                    fAm1End;
    TAmSpacing                  fAm1Spacing;
    ViReal32                    fAm2Start;
    ViReal32                    fAm2End;
    TAmSpacing                  fAm2Spacing;
    ViReal32                    fMeasTime;
    ViReal32                    fTimeOut;
    TSynchroMode                SynchroMode;
    TSynchroSources             SynchroSource;
    TSynchroLevelMode           SynchroLevelMode;
    ViReal32                    FixedLevel;
    ViReal32                    FixedHysteresis;
    ViReal32                    AutoHysteresis;
    ViReal32                    SynchroFilterTau;
} TGetSinRmsSweep_ChanSet;

/* DSI_CMD_ANLFUN_SinRSmSweep_NoChSet */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    fFr1Start;
    ViReal32                    fFr1End;
    TFrSpacing                  Fr1Spacing;
    ViReal32                    fFr2Start;
    ViReal32                    fFr2End;
    TFrSpacing                  Fr2Spacing;
    ViUInt16                    FrStepCnt;
    ViReal32                    fPhase1;
    ViReal32                    fPhase2;
    ViUInt16                    AmStepCnt;
    ViUInt16                    RefreshTime;
    ViUInt16                    FrSweepRepeat;
    ViUInt16                    FrStepPause;
    ViUInt16                    AmStepPause;
    TCtrlStep                   StartCtrlStep;
    ViUInt16                    wFilterOrder;
    TFilterBandwidthType        FilterBandwidthType;
    ViReal32                    AbsoluteBandwidth;
    ViReal32                    RelativeBandwidth;
    TAutoFrqMode                FrequencyMode;
} TCmdSinRSmSweep_NoChSet;

/* DSI_GET_ANLFUN_SinRSmSweep_NoChSet */

typedef struct {
    ViReal32                    fFr1Start;
    ViReal32                    fFr1End;
    TFrSpacing                  Fr1Spacing;
    ViReal32                    fFr2Start;
    ViReal32                    fFr2End;
    TFrSpacing                  Fr2Spacing;
    ViUInt16                    FrStepCnt;
    ViReal32                    fPhase1;
    ViReal32                    fPhase2;
    ViUInt16                    AmStepCnt;
    ViUInt16                    RefreshTime;
    ViUInt16                    FrSweepRepeat;
    ViUInt16                    FrStepPause;
    ViUInt16                    AmStepPause;
    TCtrlStep                   StartCtrlStep;
    ViUInt16                    wFilterOrder;
    TFilterBandwidthType        FilterBandwidthType;
    ViReal32                    AbsoluteBandwidth;
    ViReal32                    RelativeBandwidth;
    TAutoFrqMode                FrequencyMode;
} TGetSinRSmSweep_NoChSet;


/* DSI_CMD_ANLFUN_SinRSmSweep_ChanSet */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    fDCOffset;
    ViReal32                    fAm1Start;
    ViReal32                    fAm1End;
    TAmSpacing                  fAm1Spacing;
    ViReal32                    fAm2Start;
    ViReal32                    fAm2End;
    TAmSpacing                  fAm2Spacing;
    ViReal32                    fFixFrStart;
    ViReal32                    fFixFrEnd;
    TFrSpacing                  FixFrSpacing;
} TCmdSinRSmSweep_ChanSet;

/* DSI_GET_ANLFUN_SinRSmSweep_ChanSet */

typedef struct {
    ViReal32                    fDCOffset;
    ViReal32                    fAm1Start;
    ViReal32                    fAm1End;
    TAmSpacing                  fAm1Spacing;
    ViReal32                    fAm2Start;
    ViReal32                    fAm2End;
    TAmSpacing                  fAm2Spacing;
    ViReal32                    fFixFrStart;
    ViReal32                    fFixFrEnd;
    TFrSpacing                  FixFrSpacing;
} TGetSinRSmSweep_ChanSet;

/* DSI_CMD_ANLFUN_SinRSmSweep_AllPSet */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    fDCOffsetA;
    ViReal32                    fAm1StartA;
    ViReal32                    fAm1EndA;
    TAmSpacing                  fAm1SpacingA;
    ViReal32                    fAm2StartA;
    ViReal32                    fAm2EndA;
    TAmSpacing                  fAm2SpacingA;
    ViReal32                    fFixFrStartA;
    ViReal32                    fFixFrEndA;
    TFrSpacing                  FixFrSpacingA;
	ViReal32                    fDCOffsetB;
    ViReal32                    fAm1StartB;
    ViReal32                    fAm1EndB;
    TAmSpacing                  fAm1SpacingB;
    ViReal32                    fAm2StartB;
    ViReal32                    fAm2EndB;
    TAmSpacing                  fAm2SpacingB;
    ViReal32                    fFixFrStartB;
    ViReal32                    fFixFrEndB;
    TFrSpacing                  FixFrSpacingB;
	ViReal32                    fFr1Start;
    ViReal32                    fFr1End;
    TFrSpacing                  Fr1Spacing;
    ViReal32                    fFr2Start;
    ViReal32                    fFr2End;
    TFrSpacing                  Fr2Spacing;
    ViUInt16                    FrStepCnt;
    ViReal32                    fPhase1;
    ViReal32                    fPhase2;
    ViUInt16                    AmStepCnt;
    ViUInt16                    RefreshTime;
    ViUInt16                    FrSweepRepeat;
    ViUInt16                    FrStepPause;
    ViUInt16                    AmStepPause;
    TCtrlStep                   StartCtrlStep;
    ViUInt16                    wFilterOrder;
    TFilterBandwidthType        FilterBandwidthType;
    ViReal32                    AbsoluteBandwidth;
    ViReal32                    RelativeBandwidth;
    TAutoFrqMode                FrequencyMode;
} TCmdSinRSmSweep_AllPSet;

/* DSI_GET_ANLFUN_SinRSmSweep_AllPSet */

typedef struct {
    ViReal32                    fDCOffsetA;
    ViReal32                    fAm1StartA;
    ViReal32                    fAm1EndA;
    TAmSpacing                  fAm1SpacingA;
    ViReal32                    fAm2StartA;
    ViReal32                    fAm2EndA;
    TAmSpacing                  fAm2SpacingA;
    ViReal32                    fFixFrStartA;
    ViReal32                    fFixFrEndA;
    TFrSpacing                  FixFrSpacingA;
	ViReal32                    fDCOffsetB;
    ViReal32                    fAm1StartB;
    ViReal32                    fAm1EndB;
    TAmSpacing                  fAm1SpacingB;
    ViReal32                    fAm2StartB;
    ViReal32                    fAm2EndB;
    TAmSpacing                  fAm2SpacingB;
    ViReal32                    fFixFrStartB;
    ViReal32                    fFixFrEndB;
    TFrSpacing                  FixFrSpacingB;
	ViReal32                    fFr1Start;
    ViReal32                    fFr1End;
    TFrSpacing                  Fr1Spacing;
    ViReal32                    fFr2Start;
    ViReal32                    fFr2End;
    TFrSpacing                  Fr2Spacing;
    ViUInt16                    FrStepCnt;
    ViReal32                    fPhase1;
    ViReal32                    fPhase2;
    ViUInt16                    AmStepCnt;
    ViUInt16                    RefreshTime;
    ViUInt16                    FrSweepRepeat;
    ViUInt16                    FrStepPause;
    ViUInt16                    AmStepPause;
    TCtrlStep                   StartCtrlStep;
    ViUInt16                    wFilterOrder;
    TFilterBandwidthType        FilterBandwidthType;
    ViReal32                    AbsoluteBandwidth;
    ViReal32                    RelativeBandwidth;
    TAutoFrqMode                FrequencyMode;
} TGetSinRSmSweep_AllPSet;

/* DSI_CMD_ANLFUN_SinThdSweep_NoChSet */

static TSDiscreteValue          SFilterBandwidthDiscVals[] =
{
    {RSSIUP_FILTER_BWIDTH_NARROW,   0,    U16, ""},
    {RSSIUP_FILTER_BWIDTH_WIDE,     1,    U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    fFr1Start;
    ViReal32                    fFr1End;
    TFrSpacing                  Fr1Spacing;
    ViReal32                    fFr2Start;
    ViReal32                    fFr2End;
    TFrSpacing                  Fr2Spacing;
    ViUInt16                    FrStepCnt;
    ViReal32                    fPhase1;
    ViReal32                    fPhase2;
    ViUInt16                    AmStepCnt;
    ViUInt16                    RefreshTime;
    ViUInt16                    FrSweepRepeat;
    ViUInt16                    FrStepPause;
    ViUInt16                    AmStepPause;
    TCtrlStep                   StartCtrlStep;
    TAutoFrqMode                FreqMode;
    ViReal32                    FixFreqStart_A;
    ViReal32                    FixFreqEnd_A;
    TFrSpacing                  FrSpaceing_A;
    ViReal32                    FixFreqStart_B;
    ViReal32                    FixFreqEnd_B;
    TFrSpacing                  FrSpaceing_B;  
    TFilterBandwidth            FilterBandwidth;
    TMeasTime                   MeasTime;
    ViReal32                    FrqLimitLo;
    ViReal32                    FrqLimitHi;
    ViUInt32                    MeasCharacter;
} TCmdSinThdSweep_NoChSet;

/* DSI_GET_ANLFUN_SinThdSweep_NoChSet */

typedef struct {
    ViReal32                    fFr1Start;
    ViReal32                    fFr1End;
    TFrSpacing                  Fr1Spacing;
    ViReal32                    fFr2Start;
    ViReal32                    fFr2End;
    TFrSpacing                  Fr2Spacing;
    ViUInt16                    FrStepCnt;
    ViReal32                    fPhase1;
    ViReal32                    fPhase2;
    ViUInt16                    AmStepCnt;
    ViUInt16                    RefreshTime;
    ViUInt16                    FrSweepRepeat;
    ViUInt16                    FrStepPause;
    ViUInt16                    AmStepPause;
    TCtrlStep                   StartCtrlStep;
    TAutoFrqMode                FreqMode;
    ViReal32                    FixFreqStart_A;
    ViReal32                    FixFreqEnd_A;
    TFrSpacing                  FrSpaceing_A;
    ViReal32                    FixFreqStart_B;
    ViReal32                    FixFreqEnd_B;
    TFrSpacing                  FrSpaceing_B;  
    TFilterBandwidth            FilterBandwidth;
    TMeasTime                   MeasTime;
    ViReal32                    FrqLimitLo;
    ViReal32                    FrqLimitHi;
    ViUInt32                    MeasCharacter;
} TGetSinThdSweep_NoChSet;

/* DSI_CMD_ANLFUN_SinThdSweep_ChanSet */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    fDCOffset;
    ViReal32                    fAm1Start;
    ViReal32                    fAm1End;
    TAmSpacing                  fAm1Spacing;
    ViReal32                    fAm2Start;
    ViReal32                    fAm2End;
    TAmSpacing                  fAm2Spacing;
} TCmdSinThdSweep_ChanSet;

/* DSI_GET_ANLFUN_SinThdSweep_ChanSet */

typedef struct {
    ViReal32                    fDCOffset;
    ViReal32                    fAm1Start;
    ViReal32                    fAm1End;
    TAmSpacing                  fAm1Spacing;
    ViReal32                    fAm2Start;
    ViReal32                    fAm2End;
    TAmSpacing                  fAm2Spacing;
} TGetSinThdSweep_ChanSet;

/*- Analyzer DSI Tables - Analyzer hardware setting (Get & Cmd table) -------------*/

/* DSI_CMD_ANLHW_DEVICE_SELECTOR (ChAB) */
/* DSI_GET_ANLHW_DEVICE_SELECTOR (ChAB) */

/* --- Already defined for DSI_GET_GENHW_DEVICE_SELECTOR and DSI_CMD_GENHW_DEVICE_SELECTOR ---

#define dsA49                   0
#define dsA98                   1
#define dsA195                  2
#define dsD32                   3
#define dsD44                   4
#define dsD48                   5
#define dsD96                   6
#define dsD192                  7

*/

typedef ViUInt16                TAnlDevSelector;

static TSDiscreteValue          SAnlDevSelectorDiscVals[] =
{
    {RSSIUP_ANL_A49,            dsA49,  U16, ""},
    {RSSIUP_ANL_A98,            dsA98,  U16, ""},
    {RSSIUP_ANL_A195,           dsA195, U16, ""},
    {RSSIUP_ANL_D32,            dsD32,  U16, ""},
    {RSSIUP_ANL_D44,            dsD44,  U16, ""},
    {RSSIUP_ANL_D48,            dsD48,  U16, ""},
    {RSSIUP_ANL_D96,            dsD96,  U16, ""},
    {RSSIUP_ANL_D192,           dsD192, U16, ""},
    {0, 0, 0, NULL}
};

/* DSI_CMD_AANLHW_INPUT (ChAB, ChA, ChB) */
/* DSI_GET_AANLHW_INPUT (ChA, ChB) */

#define aaiOFF                  0
#define aaiOn                   1
#define aaiGenMeas              2

typedef ViUInt16                TAAnlInput;

static TSDiscreteValue          SAAnlInputDiscVals[] =
{
    {RSSIUP_ANL_INPUT_OFF,      aaiOFF,     U16, ""},
    {RSSIUP_ANL_INPUT_ON,       aaiOn,      U16, ""},
    {RSSIUP_ANL_INPUT_LOOPBACK, aaiGenMeas, U16, ""},
    {0, 0, 0, NULL}
};

/* DSI_CMD_AANLHW_COUPLING (ChAB, ChA, ChB) */
/* DSI_GET_AANLHW_COUPLING (ChA, ChB) */

#define aacDC                   0
#define aacAC                   1

typedef ViUInt16                TAAnlCoupling;

static TSDiscreteValue          SAAnlCouplingDiscVals[] =
{
    {RSSIUP_ANL_COUPLING_DC,    aacDC,      U16, ""},
    {RSSIUP_ANL_COUPLING_AC,    aacAC,      U16, ""},
    {0, 0, 0, NULL}
};

/* DSI_CMD_AANLHW_RANGE_NUM (ChAB, ChA, ChB) */
/* DSI_GET_AANLHW_RANGE_NUM (ChA, ChB) */

/*  --- Already defined for DSI_GET_AGENHW_RANGE_NUM, DSI_CMD_AGENHW_RANGE_NUM

#define rtAuto                  0
#define rtFixed                 1
#define rtMinimal               2

*/

typedef ViUInt16                TRangeMode;

static TSDiscreteValue          SAAnlRangeModeDiscVals[] =
{
    {RSSIUP_RANGE_MODE_AUTO,    rtAuto,     U16, ""},
    {RSSIUP_RANGE_MODE_FIXED,   rtFixed,    U16, ""},
    {RSSIUP_RANGE_MODE_MINIMAL, rtMinimal,  U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    TRangeMode                  RangeMode;
    ViUInt16                    RangeNum;
} TAAnlRange;

/* DSI_CMD_AANLHW_RANGE_VOLT (ChAB, ChA, ChB) */

typedef struct {
    TRangeMode                  RangeMode;
    ViReal32                    RangeValue;
} TCmdAnlRangeVolt;

/* DSI_GET_AANLHW_RANGE_VOLT (ChA, ChB) */

typedef struct {
    TRangeMode                  RangeMode;
    ViReal32                    DnLimit;
    ViReal32                    UpLimit;
} TGetAnlRangeVolt;

/* DSI_CMD_AANLHW_RANGE_DEPENDENCY (ChAB) */
/* DSI_GET_AANLHW_RANGE_DEPENDENCY (ChAB) */

#define ooOFF                   0
#define ooON                    1

typedef ViUInt16                TRangeDependency;

typedef struct {
    TRangeDependency            Dependency;
} TAnlDependency;

/* DSI_CMD_AANLHW_DIGITAL_HPF (ChAB) */
/* DSI_GET_AANLHW_DIGITAL_HPF (ChAB) */

#define ooOFF                   0
#define ooON                    1

typedef ViUInt16                TAAnlHPF;

/* DSI_GET_AANLHW_FLOAT_GND (ChA, ChB), DSI_CMD_AANLHW_FLOAT_GND (ChAB, ChA, ChB) */

typedef TOnOff                  TAAnlFloatGnd;

/* DSI_CMD_ANLFUN_DAISAMPLERATE_SETTING (ChAB) */

typedef struct {
    ViUInt16                    Sender;
    ViReal32                    MeasurementTime;
} TCmdDAISampleRate;

/* DSI_GET_ANLFUN_DAISAMPLERATE_SETTING (ChAB) */

typedef struct {
    ViReal32                    MeasurementTime;
} TGetDAISampleRate;

/* DSI_CMD_ANLFUN_DAISAMPLERATE_AVERAGING (ChAB) */

typedef struct {
    ViUInt16                    Reserve;
    ViUInt16                    AverageMode;
    ViUInt16                    AverageFactor;
} TCmdDAISampleRateAveraging;

/* DSI_GET_ANLFUN_DAISAMPLERATE_AVERAGING (ChAB) */

typedef struct {
    ViUInt16                    AverageMode;
    ViUInt16                    AverageFactor;
} TGetDAISampleRateAveraging;

/* DSI_GET_ANLFUN_DAIPROTOCOL_SETTING (ChAB) */

typedef struct {
    ViUInt16                    Type;
    ViReal32                    MeasurementTime;
} TGetDAIProtocol;

/* DSI_CMD_ANLFUN_DAIPROTOCOL_SETTING (ChAB) */

typedef struct {
    ViUInt16                    Sender;
    ViUInt16                    Type;
    ViReal32                    MeasurementTime;
} TCmdDAIProtocol;

/* DSI_CMD_DANLHW_INPUT_SELECTOR (ChAB) */
/* DSI_GET_DANLHW_INPUT_SELECTOR (ChAB) */

#define adiSPDiv                0
#define adiOptical              1
#define adiI2S                  2

typedef ViUInt16                TDAnlInput;

static TSDiscreteValue          STDAnlInputDiscVals[] =
{
    {RSSIUP_DAI_INPUT_BNC,      adiSPDiv,       U16, ""},
    {RSSIUP_DAI_INPUT_OPTO,     adiOptical,     U16, ""},
/*  {RSSIUP_DAI_INPUT_I2S,      adiI2S,         U16, ""}, */
    {0, 0, 0, NULL}
};

/* DSI_CMD_DANLHW_NUM_OF_BITS (ChAB, ChA, ChB) */
/* DSI_GET_DANLHW_NUM_OF_BITS (ChA, ChB) */

/* DSI_CMD_AANLHW_MEAS_MODE (ChAB) */
/* DSI_GET_AANLHW_MEAS_MODE (ChAB) */ 

#define ammContMeas				0
#define ammTrigMeas				1

typedef ViUInt16				TAnlMeasMode;	

static TSDiscreteValue			SAnlMeasModeDiscVals[] =
{
	{RSSIUP_TRG_MEAS_MODE_CONTINUOUS,  ammContMeas,   U16, ""},
	{RSSIUP_TRG_MEAS_MODE_TRIGGERED,   ammTrigMeas,   U16, ""},	
	{0, 0, 0, NULL}
};

/* DSI_GET_AANLHW_FUN_TRIG_MEAS_STATE */

#define afmsIdle				0
#define afmsWFT					1
#define afmsMeas				2

typedef ViUInt16				TAnlFunMeasState;

static TSDiscreteValue			SAnlFunMeasStateDiscVals[] =
{
	{RSSIUP_TRIGGER_STATE_IDLE,   afmsIdle,   U16, ""},
	{RSSIUP_TRIGGER_STATE_WFT,    afmsWFT,    U16, ""},
	{RSSIUP_TRIGGER_STATE_MEAS,   afmsMeas,   U16, ""},
	{0, 0, 0, NULL}
};

/* DSI_GET_DANLHW_CHANNELSTATUSBLOCK (ChA, ChB) */

typedef ViUInt8                 TDAnlChannelStatusBlock[24];

/*- Analyzer DSI Tables - Analyzer functions controlling (Cmd table) --------*/

/* DSI_CMD_ANLFUN_FUNCTION_ON (ChAB, ChA, ChB) */

typedef struct {
    TAnlFunID                   AnlFunID;
    ViUInt16                    FunctionStatus;
    ViUInt16                    DigFilterOnOff_Unload;
    ViUInt16                    CntOfResults;
    ViUInt16                    SenderMarker;
} TAnlSwitchOnOff;

static TSDiscreteValue          SAnlSwitchOnOffDiscVals[] =
{
    {RSSIUP_GEN_FUNC_ALL,               afAllAnlFuns,   U16, ""},
    {RSSIUP_ANL_FUNC_PEAK,              afPeak,         U16, ""},
    {RSSIUP_ANL_FUNC_RMSDC,             afRMSDC,        U16, ""},
    {RSSIUP_ANL_FUNC_QPEAK,             afQPeak,        U16, ""},
    {RSSIUP_ANL_FUNC_RMS_SEL,           afRMSSel,       U16, ""},
    {RSSIUP_ANL_FUNC_THDN,              afTHDpmN,       U16, ""},
    {RSSIUP_ANL_FUNC_PHASE,             afPhaseMuTsk,   U16, ""},
    {RSSIUP_ANL_FUNC_DFD,               afDFDMuTsk,     U16, ""},
    {RSSIUP_ANL_FUNC_MOD_DIST,          afModDist,      U16, ""},
    {RSSIUP_ANL_FUNC_FFT,               afFFTMuTsk,     U16, ""},
    {RSSIUP_ANL_FUNC_DAI_SAMPLE_RATE,   afDAISamplRate, U16, ""},
    {RSSIUP_ANL_FUNC_DAI_PROTOCOL,      afDAIProtocol,  U16, ""},
	{RSSIUP_ANL_FUNC_POLARITY,          afPolarity,     U16, ""},
	{RSSIUP_ANL_FUNC_SIN_RMS_SWEEP, 	afSinRmsSweep, 	U16, ""},
	{RSSIUP_ANL_FUNC_SIN_THD_SWEEP, 	afSinThdSweep, 	U16, ""},
	{RSSIUP_ANL_FUNC_SIN_RSM_SWEEP, 	afSinRSmSweep, 	U16, ""},
	{RSSIUP_ANL_FUNC_RMS_SEL_MuTsk, 	afRMSSelMuTsk, 	U16, ""},
    {0, 0, 0, NULL}
};

/* DSI_CMD_ANLFUN_FUNCTION_SendNextResults (ChAB, ChA, ChB) */

typedef struct {
    TAnlFunID                   AnlFunID;
    ViUInt16                    CntOfResults;
    ViUInt16                    SenderMarker;
} TAnlSendNextRes;

/* DSI_CMD_ANLFUN_FUNCTION_IncChangeCnt */

typedef struct {
    TAnlFunID                   AnlFunID;
    ViUInt16                    Reserved;
    ViUInt16                    SenderMarker;
} TAnlIncChangeCnt;

/* DSI_CMD_ANLFUN_FUNCTION_CtrlStep */

typedef struct {
    TAnlFunID                   AnlFunID;
    ViUInt16                    CtrlStep;
    ViUInt16                    SenderMarker;
} TAnlCtrlStep;

/*- Analyzer DSI Tables - Analyzer Description (Get table) ------------------*/

/* DSI_GET_ANL_DESCRIPTION */

typedef struct {
    TDevStatus                  Status;
    TAnlDevSelector             DevSelector;
    ViReal32                    ActualMaxPeakAmpl;
    ViReal32                    SampleFreq;
    ViReal32                    ActualPeakAmpl[ANL_CHANNEL_CNT];
    ViInt16                     IsRunning;
    ViUInt16                    CntOfAnlFunctions;
    ViInt16                     FunctionIsOn[ANLFUN_CNT][ANL_CHANNEL_CNT];
    ViInt16                     DigitalFilterIsOn[ANL_CHANNEL_CNT];
    ViUInt16                    Sender[ANLFUN_CNT];
} TAnlGenerally;

typedef struct {
    TAAnlInput                  Input[ANL_CHANNEL_CNT];
    TAAnlHPF                    HPF;
    TAAnlCoupling               Coupling[ANL_CHANNEL_CNT];
    TAAnlRange                  Range[ANL_CHANNEL_CNT];
    TRangeDependency            Dependency;
    TAAnlFloatGnd               FloatGnd[ANL_CHANNEL_CNT];
} TAAnlUserHW;

typedef struct {
    TDevEnabled                 Enabled;
    ViReal32                    MaxPeakAmpl;
    TAAnlUserHW                 AAnlUserHW;
} TAAnl;

typedef struct {
    TDAnlChannelStatusBlock     ChannelStatusBlock[ANL_CHANNEL_CNT];
    TDDevNoOfBits               NoOfBits[ANL_CHANNEL_CNT];
    TDAnlInput                  Input;
} TDAnlUserHW;

typedef struct {
    TDevEnabled                 Enabled;
    ViReal32                    fiMaxPeakAmpl;
    TDAnlUserHW                 DAnlUserHW;
} TDAnl;

#if 1
typedef struct {
    TAnlMeasMode                MeasMode;
    TAnlFunMeasState            FunMeasState[ANLFUN_CNT];
    ViInt16                     Reserve[ANLFUN_CNT];
}TAnlMeasDescr;
#endif

typedef struct {
    TAnlGenerally               AnlGenerally;
    TAAnl                       AAnl;
    TDAnl                       DAnl;

    /* --- TODO: Describe remaining bytes --- */
	ViChar                      unknown[60+130]; /* since FW version 1.2 the size was raised by +130 */

} TAnlDescription;

/* DSI_GET_AANL_RANGETABLE */

typedef struct {
    ViUInt16                    CntOfLines;
    TLimitLine                  Line[ANL_RANGE_CNT];
} TAnlRangeTable;

/*- Audio Monitor -----------------------------------------------------------*/

#define Anl1                    0
#define Anl2                    1
#define Gen                     2
#define None                    3

typedef ViUInt16                TDspMonSrc;

static TSDiscreteValue          SDspMonSrcDiscVals[] =
{
    {RSSIUP_MONITOR_SOURCE_NONE,        None,   U16, ""},
    {RSSIUP_MONITOR_SOURCE_ANALYZER_1,  Anl1,   U16, ""},
    {RSSIUP_MONITOR_SOURCE_ANALYZER_2,  Anl2,   U16, ""},
    {RSSIUP_MONITOR_SOURCE_GENERATOR,   Gen,    U16, ""},
    {0, 0, 0, NULL}
};

/*- Analyzer Function Results -----------------------------------------------*/

/* Analyzer Function Frame & Data header */

typedef struct {
    ViUInt16                    FrSz;       /* Frame Size (Bytes = FrSz * 4) */
    ViUInt16                    ClassID;    /* Class ID */
} TAnlFunFrameHeader;

typedef struct {
    ViUInt16                    FunSz;      /* Function Size (Bytes = FunSz * 4) */
    ViUInt16                    FunID;      /* Function identificator */
    ViUInt16                    PartyID;    /* Party identificator */
    ViUInt16                    ResCnt;     /* Result counter */
    ViUInt16                    FunDtSz;    /* Function Data Size (Bytes = FunDtSz * 4) */
    ViUInt16                    Marker;     /* Sender Marker */
    ViUInt16                    PartyMax;   /* Party Max (for N parts is PartyMax = N-1 and PartyID is 0,1,...,N-2,N-3) */
    ViUInt16                    ChnCnt;     /* Change counter */
} TAnlFunDataHeader;

typedef struct {
    ViUInt16                    FunID;      /* Function identificator */
    ViBoolean                   completed;  /* Function data completed? */
    ViChar                      *data;      /* Pointer to the complete data */
    ViChar                      *p2data;    /* Pointer to the end of data */
    ViUInt16                    size;       /* Data size */
} TAnlFunData;

/* FFT result header */

typedef struct {
    ViUInt32                    FunId;
    ViUInt32                    FFTSize;
    ViUInt32                    NOSL;
    ViUInt32                    SptrOffset;
    ViUInt32                    AverMode;
    ViUInt32                    AverCount;
    ViReal32                    AverQuotient;
    ViUInt32                    ZoomFactor;
    ViUInt32                    ZoomOffset;
    ViReal32                    SamplFreq;
    ViUInt32                    WindowSize;
    ViUInt32                    DisplaySize;
    ViUInt32                    Reserved_1;
    ViUInt32                    Reserved_2;
    ViUInt32                    Reserved_3;
    ViUInt32                    ChnlMode;
} TFFTResHeader;

/* MEAS_PEAK */

typedef struct {
    ViReal32                    PeakMax_A;
    ViReal32                    PeakMin_A;
    ViReal32                    PeakMax_B;
    ViReal32                    PeakMin_B;
} TAnlMeasPeak;

/* MEAS_QPEAK */

typedef struct {
    ViReal32                    QuasiPeakMax_A;
    ViReal32                    QuasiPeakMin_A;
    ViReal32                    QuasiPeakCurrentValue_A;
    ViReal32                    QuasiPeakMax_B;
    ViReal32                    QuasiPeakMin_B;
    ViReal32                    QuasiPeakCurrentValue_B;
} TAnlMeasQpeak;

/* MEAS_RMSDC */

typedef struct {
    ViUInt32                    AsynchroIndication_A;
    ViUInt32                    Valid_A;
    ViReal32                    DC_A;
    ViReal32                    SqrRMS_A;
    ViReal32                    Frequency_A;
    ViUInt32                    AsynchroIndication_B;
    ViUInt32                    Valid_B;
    ViReal32                    DC_B;
    ViReal32                    SqrRMS_B;
    ViReal32                    Frequency_B;
} TAnlMeasRMSDC;

/* MEAS_RMSSEL */

typedef struct {
    ViReal32                    SqrRMSValue_A;
    ViReal32                    SqrRMSValue_B;
    ViUInt32                    Valid;
} TAnlMeasRMSSel;

/* MEAS_RMSSEL_MUTSK */

typedef struct {
    ViReal32                    Marker1_FFTFreq;
    ViReal32                    Marker2_FFTFreq;
    ViReal32                    Marker1_A_Value;
    ViReal32                    Marker2_A_Value;
    ViReal32                    Marker1_B_Value;
    ViReal32                    Marker2_B_Value;
    ViUInt32                    Tag;
    ViInt32                     AutoTuneLocked_A;
    ViReal32                    Frequency_A;
    ViReal32                    RMS_A;
    ViInt32                     AutoTuneLocked_B;
    ViReal32                    Frequency_B;
    ViReal32                    RMS_B;
} TAnlMeasRMSSelMuTsk;

/* MEAS_RMSSEL_MUTSK_FFT */

typedef struct {
    TFFTResHeader               Header_A;
    ViReal32                    SpLines_A[FFT_NOSL_MAX];
    TFFTResHeader               Header_B;
    ViReal32                    SpLines_B[FFT_NOSL_MAX];
} TAnlMeasRMSSelMuTskPostFFT;

/* MEAS_RMSSEL_MUTSK_REDUCED_FFT */

typedef struct {
    TFFTResHeader               HeaderMax;
    ViReal32                    SLmax[FFT_DISPLAY_SIZE_MAX];
    TFFTResHeader               HeaderMin;
    ViReal32                    SLmin[FFT_DISPLAY_SIZE_MAX];
} TAnlMeasRMSSelMuTskReducedFFT;

/* MEAS_THDN */

typedef struct {
    ViReal32                    Marker1_FFTFreq;
    ViReal32                    Marker2_FFTFreq;
    ViReal32                    Marker1_A_Value;
    ViReal32                    Marker2_A_Value;
    ViReal32                    Marker1_B_Value;
    ViReal32                    Marker2_B_Value;
    ViUInt32                    Tag;
    ViInt32                     AutoTuneLocked_A;
    ViReal32                    Frequency_A;
    ViReal32                    TotalRMS_A_THDN;
    ViReal32                    Noise_A_THDN;
    ViReal32                    TotalRMS_A_THDN_NonFund;
    ViReal32                    TotalRMS_A_THD;
    ViReal32                    Harmonic_A[10];
    ViInt32                     AutoTuneLocked_B;
    ViReal32                    Frequency_B;
    ViReal32                    TotalRMS_B_THDN;
    ViReal32                    Noise_B_THDN;
    ViReal32                    TotalRMS_B_THDN_NonFund;
    ViReal32                    TotalRMS_B_THD;
    ViReal32                    Harmonic_B[10];
} TAnlMeasTHDN;

/* MEAS_THDN_POST_FFT */

typedef struct {
    TFFTResHeader               Header_A;
    ViReal32                    SpLines_A[FFT_NOSL_MAX];
	TFFTResHeader               Header_B;
    ViReal32                    SpLines_B[FFT_NOSL_MAX];
} TAnlMeasTHDNPostFFT;

/* MEAS_THDN_REDUCED_FFT */

typedef struct {
    TFFTResHeader               HeaderMax;
    ViReal32                    SLmax[FFT_DISPLAY_SIZE_MAX];
    TFFTResHeader               HeaderMin;
    ViReal32                    SLmin[FFT_DISPLAY_SIZE_MAX];
} TAnlMeasTHDNReducedFFT;

/* MEAS_PHASE */

typedef struct {
    ViReal32                    Marker1_FFTFrequency;
    ViReal32                    Marker2_FFTFrequency;
    ViReal32                    Marker1_Value_A;
    ViReal32                    Marker2_Value_A;
    ViReal32                    Marker1_Value_B;
    ViReal32                    Marker2_Value_B;
    ViUInt32                    Reserved;
    ViInt32                     AutotuneLocked;
    ViInt32                     Master;
    ViReal32                    PhaseDifference;
    ViReal32                    Frequency;
} TAnlMeasPhase;

/* MEAS_PHASE_POST_FFT */

typedef struct {
    TFFTResHeader               Header;
    ViReal32                    SpLines[FFT_NOSL_MAX];
} TAnlMeasPhasePostFFT;

/* MEAS_PHASE_REDUCED_FFT */

typedef struct {
    TFFTResHeader               HeaderMax;
    ViReal32                    SLmax[FFT_DISPLAY_SIZE_MAX];
    TFFTResHeader               HeaderMin;
    ViReal32                    SLmin[FFT_DISPLAY_SIZE_MAX];
} TAnlMeasPhaseReducedFFT;

/* MEAS_DFD */

typedef struct {
    ViReal32                    Marker1_FFTFrequency;
    ViReal32                    Marker2_FFTFrequency;
    ViReal32                    Marker1_Value_A;
    ViReal32                    Marker2_Value_A;
    ViReal32                    Marker1_Value_B;
    ViReal32                    Marker2_Value_B;
    ViUInt32                    Reserved;
    ViInt32                     AutotuneLocked_A;
    ViReal32                    Frequencies_A[5];
    ViReal32                    RMSValues_A[5];
    ViInt32                     AutotuneLocked_B;
    ViReal32                    Frequencies_B[5];
    ViReal32                    RMSValues_B[5];
} TAnlMeasDFD;

/* MEAS_DFD_POST_FFT */

typedef struct {
    TFFTResHeader               Header_A;
    ViReal32                    SpLines_A[FFT_NOSL_MAX];
	TFFTResHeader               Header_B;
    ViReal32                    SpLines_B[FFT_NOSL_MAX];
} TAnlMeasDFDPostFFT;

/* MEAS_DFD_REDUCED_FFT */

typedef struct {
    TFFTResHeader               HeaderMax;
    ViReal32                    SLmax[FFT_DISPLAY_SIZE_MAX];
    TFFTResHeader               HeaderMin;
    ViReal32                    SLmin[FFT_DISPLAY_SIZE_MAX];
} TAnlMeasDFDReducedFFT;

/* MEAS_MOD_DIST */

typedef struct {
    ViReal32                    Marker1_FFTFrequency;
    ViReal32                    Marker2_FFTFrequency;
    ViReal32                    Marker1_Value_A;
    ViReal32                    Marker2_Value_A;
    ViReal32                    Marker1_Value_B;
    ViReal32                    Marker2_Value_B;
    ViUInt32                    Reserved;
    ViInt32                     AutotuneLocked_A;
    ViReal32                    Frequencies_A[6];
    ViReal32                    RMSValues_A[6];
    ViInt32                     AutotuneLocked_B;
    ViReal32                    Frequencies_B[6];
    ViReal32                    RMSValues_B[6];
} TAnlMeasModDist;

/* MEAS_MOD_DIST_POST_FFT */

typedef struct {
    TFFTResHeader               Header_A;
    ViReal32                    SpLines_A[FFT_NOSL_MAX];
	TFFTResHeader               Header_B;
    ViReal32                    SpLines_B[FFT_NOSL_MAX];
} TAnlMeasModDistPostFFT;

/* MEAS_MOD_DIST_REDUCED_FFT */

typedef struct {
    TFFTResHeader               HeaderMax;
    ViReal32                    SLmax[FFT_DISPLAY_SIZE_MAX];
    TFFTResHeader               HeaderMin;
    ViReal32                    SLmin[FFT_DISPLAY_SIZE_MAX];
} TAnlMeasModDistReducedFFT;

/* MEAS_FFT */

typedef struct {
    TFFTResHeader               Header_A;  
    ViReal32                    SpLines_A[FFT_NOSL_MAX];    
    TFFTResHeader               Header_B;   
    ViReal32                    SpLines_B[FFT_NOSL_MAX];    
    ViReal32                    Marker1_FFTFrequency;
    ViReal32                    Marker2_FFTFrequency;
    ViReal32                    Marker1_Value_A;
    ViReal32                    Marker2_Value_A;
    ViReal32                    Marker1_Value_B;
    ViReal32                    Marker2_Value_B;
    ViUInt32                    TaskTag;
} TAnlMeasFFT;

/* MEAS_FFT_REDUCED */

typedef struct {
    TFFTResHeader               Header_A_max; 
    ViReal32                    SpLnMax_A_max[FFT_DISPLAY_SIZE_MAX];
    TFFTResHeader               Header_A_min;  
    ViReal32                    SpLnMin_A_min[FFT_DISPLAY_SIZE_MAX];
    TFFTResHeader               Header_B_max;
    ViReal32                    SpLnMax_B_max[FFT_DISPLAY_SIZE_MAX];
    TFFTResHeader               Header_B_min;
    ViReal32                    SpLnMin_B_min[FFT_DISPLAY_SIZE_MAX];
    ViReal32                    Marker1_FFTFrequency;
    ViReal32                    Marker2_FFTFrequency;
    ViReal32                    Marker1_Value_A;
    ViReal32                    Marker2_Value_A;
    ViReal32                    Marker1_Value_B;
    ViReal32                    Marker2_Value_B;
    ViUInt32                    TaskTag;
} TAnlMeasFFTReduced;

/* MEAS_DAI_SAMPLING_FREQUENCY */

typedef struct {
    ViReal32                    DAISamplFreq;
} TAnlMeasDAISamplingFrequency;

/* MEAS_DAI_PROTOCOL */

typedef struct {
  ViUInt8                       ChannelStatusA[24];
  ViUInt8                       ChannelStatusB[24];
  ViUInt16                      ReceiveError;
} TAnlMeasDAIProtocol;

/* MEAS_RMS_SWEEP */

typedef ViInt16                 TReasonOfSending;

typedef struct {
    ViReal64                    fiFr1AmA;
    ViReal64                    fiFr2AmB;
    ViReal64                    fiRmsA;
    ViReal64                    fiRmsB;
} TSinRmsSweepSample;

typedef struct {
    ViInt16                     bAmSweepInside;
    ViUInt16                    wAmSweepRepCnt;
    ViUInt16                    wFrSweepRepCnt;
    ViUInt16                    wSampleCount;
    ViUInt16                    wFrSwStep;
    ViUInt16                    wFrSwStCnt;
    TFrSpacing                  Fr1spacing;
    TFrSpacing                  Fr2spacing;
    ViReal32                    fiFr1start;
    ViReal32                    fiFr1end;
    ViReal32                    fiFr2start;
    ViReal32                    fiFr2end;
    ViReal32                    fiActualFr1;
    ViReal32                    fiActualFr2;
    ViUInt16                    wAmSwStep;
    ViUInt16                    wAmSwStCnt;
    TAmSpacing                  Am1spacing[GEN_CHANNEL_CNT];
    TAmSpacing                  Am2spacing[GEN_CHANNEL_CNT];
    ViReal32                    fiAm1start[GEN_CHANNEL_CNT];
    ViReal32                    fiAm1end[GEN_CHANNEL_CNT];
    ViReal32                    fiAm2start[GEN_CHANNEL_CNT];
    ViReal32                    fiAm2end[GEN_CHANNEL_CNT];
    ViReal32                    fiActualAm1[GEN_CHANNEL_CNT];
    ViReal32                    fiActualAm2[GEN_CHANNEL_CNT];
    ViUInt16                    wStartSwCnt;
    TReasonOfSending            ReasonOfSending;
    ViUInt32                    Reserve[2];
    TSinRmsSweepSample          Sample[RMS_SWEEP_MAX_SAMPLES];
} TAnlMeasRMSSweep;

/* MEAS_RMS_SELECTIVE_SWEEP */

typedef struct {
    ViInt32                     iAutoTuneLocked;
    ViReal32                    fiFrequency; 
    ViReal32                    fiRMS;
} TRSmSaCh;

typedef struct {
    ViReal32                    fiFr1AmA;
    ViReal32                    fiFr2AmB;
    ViReal32                    fiFrAAnl;
    ViReal32                    fiFrBAnl;
    TRSmSaCh                    RSmA;
    TRSmSaCh                    RSmB;
} TSinRSmSweepSample;

typedef struct {
    ViInt16                     bAmSweepInside;
    ViUInt16                    wAmSweepRepCnt;
    ViUInt16                    wFrSweepRepCnt;
    ViUInt16                    wSampleCount;
    ViUInt16                    wFrSwStep;
    ViUInt16                    wFrSwStCnt;
    TFrSpacing                  FrGen1spacing;
    TFrSpacing                  FrGen2spacing;
    TFrSpacing                  FrAnlAspacing;
    TFrSpacing                  FrAnlBspacing;
    ViReal32                    fiFrGen1start;
    ViReal32                    fiFrGen1end;
    ViReal32                    fiFrGen2start;
    ViReal32                    fiFrGen2end;
    ViReal32                    fiFrAnlAstart;
    ViReal32                    fiFrAnlAend;
    ViReal32                    fiFrAnlBstart;
    ViReal32                    fiFrAnlBend;
    ViReal32                    fiActualFrGen1;
    ViReal32                    fiActualFrGen2;
    ViReal32                    fiActualFrAnlA;
    ViReal32                    fiActualFrAnlB;
    ViUInt16                    wAmSwStep;
    ViUInt16                    wAmSwStCnt;
    TAmSpacing                  Am1spacing[GEN_CHANNEL_CNT];
    TAmSpacing                  Am2spacing[GEN_CHANNEL_CNT];
    ViReal32                    fiAm1start[GEN_CHANNEL_CNT];
    ViReal32                    fiAm1end[GEN_CHANNEL_CNT];
    ViReal32                    fiAm2start[GEN_CHANNEL_CNT];
    ViReal32                    fiAm2end[GEN_CHANNEL_CNT];
    ViReal32                    fiActualAm1[GEN_CHANNEL_CNT];
    ViReal32                    fiActualAm2[GEN_CHANNEL_CNT];
    ViUInt16                    wStartSwCnt;
    TReasonOfSending            ReasonOfSending;
    ViUInt32                    dwRSmReserve[3];
    ViUInt32                    dwFrameReserve[4];
    TSinRSmSweepSample          Sample[RMS_SEL_SWEEP_MAX_SAMPLES];
} TAnlMeasRMSSelectiveSweep;

/* MEAS_THD_SWEEP */

typedef struct {
    ViInt32                     AutoTuneLocked;
    ViReal32                    Frequency; 
    ViReal32                    TotalRMS_THDN; 
    ViReal32                    Noise_THDN;
    ViReal32                    TotalRMS_THDN_NonFund;
    ViReal32                    TotalRMS_THD;	
    ViReal32                    Harmonic[10];
} TTHDpmNSaCh;

typedef struct {
    ViReal32                    fiFr1AmA;
    ViReal32                    fiFr2AmB;
    ViReal32                    fiFrAAnl;
    ViReal32                    fiFrBAnl;
    TTHDpmNSaCh                 ThdA;
    TTHDpmNSaCh                 ThdB;
    ViReal32                    fiSampleResrve[4];
} TSinTHDSweepSample;

typedef struct {
    ViInt16                     bAmSweepInside;
    ViUInt16                    wAmSweepRepCnt;
    ViUInt16                    wFrSweepRepCnt;
    ViUInt16                    wSampleCount;
    ViUInt16                    wFrSwStep;
    ViUInt16                    wFrSwStCnt;
    TFrSpacing                  FrGen1spacing;
    TFrSpacing                  FrGen2spacing;
    TFrSpacing                  FrAnlAspacing;
    TFrSpacing                  FrAnlBspacing;
    ViReal32                    fiFrGen1start;
    ViReal32                    fiFrGen1end;
    ViReal32                    fiFrGen2start;
    ViReal32                    fiFrGen2end;
    ViReal32                    fiFrAnlAstart;
    ViReal32                    fiFrAnlAend;
    ViReal32                    fiFrAnlBstart;
    ViReal32                    fiFrAnlBend;
    ViReal32                    fiActualFrGen1;
    ViReal32                    fiActualFrGen2;
    ViReal32                    fiActualFrAnlA;
    ViReal32                    fiActualFrAnlB;
    ViUInt16                    wAmSwStep;
    ViUInt16                    wAmSwStCnt;
    TAmSpacing                  Am1spacing[GEN_CHANNEL_CNT];
    TAmSpacing                  Am2spacing[GEN_CHANNEL_CNT];
    ViReal32                    fiAm1start[GEN_CHANNEL_CNT];
    ViReal32                    fiAm1end[GEN_CHANNEL_CNT];
    ViReal32                    fiAm2start[GEN_CHANNEL_CNT];
    ViReal32                    fiAm2end[GEN_CHANNEL_CNT];
    ViReal32                    fiActualAm1[GEN_CHANNEL_CNT];
    ViReal32                    fiActualAm2[GEN_CHANNEL_CNT];
    ViUInt16                    wStartSwCnt;
    TReasonOfSending            ReasonOfSending;
    ViUInt32                    dwRSmReserve[3];
    ViUInt32                    dwFrameReserve[4];
    TSinTHDSweepSample          Sample[THD_SWEEP_MAX_SAMPLES];
} TAnlMeasTHDSweep;

/*- DSI_CMD_DEV_ROSC_SETTING (ChAB), DSI_GET_DEV_ROSC_SETTING (ChAB)-*/

#define srcINTERNAL             0
#define srcEXTERNAL             1

typedef ViUInt16                TRefOscSource;

static TSDiscreteValue          SRefOscSourceDiscVals[] =
{
    {RSSIUP_REF_OSCILLATOR_SOURCE_INT,  srcINTERNAL,    U16, ""},
    {RSSIUP_REF_OSCILLATOR_SOURCE_EXT,  srcEXTERNAL,    U16, ""},
    {0, 0, 0, NULL}
};

#define ext2MHz                 0
#define ext5MHz                 1
#define ext10MHz                2

typedef ViUInt16                TRefOscExtFreq;

static TSDiscreteValue          SRefOscExtFreqDiscVals[] =
{
/*  {RSSIUP_REF_OSCILLATOR_FREQ_2MHZ,   ext2MHz,    U16, ""}, */
/*  {RSSIUP_REF_OSCILLATOR_FREQ_5MHZ,   ext5MHz,    U16, ""}, */
    {RSSIUP_REF_OSCILLATOR_FREQ_10MHZ,  ext10MHz,   U16, ""},
    {0, 0, 0, NULL}
};

typedef struct {
    TOnOff                      State;
    TRefOscSource               Source;
    TRefOscExtFreq              ExtFreq;
 } TRefOsc;

/*****************************************************************************/
/*- TStatusDataRanges is used to track session dependent data ---------------*/
/*****************************************************************************/

typedef struct {
    ViInt32                     	instrModel;     /* Currently not used */
    ViInt32                     	instrOption;    /* Currently not used */
    ViSession                   	instrSession;
    ViBoolean                   	warningChecking;
    ViBoolean                   	errorChecking;
    ViChar                      	instrDriverRevision[256];

    /* --- General Purpose Parameters --- */

    ViInt32                     	measMode;
    ViInt32                     	analyzerMode;
    ViInt32                     	generatorMode;
    ViBoolean                   	abortCurrentMeasurement;
	ViInt32							triggerSource;
	ViBoolean						cachedData;
	ViReal32						fwVersion;
	ViInt32							anlDiscSize;
//	ViUInt16						sampleCount;
//	ViReal64						oldTimeout;
//	ViBoolean						newSweep;

//  TGenDescription             	GenDescription;
//  TAGenRangeTable             	AGenRangeTable;
    TAnlDescription             	AnlDescription;
//  TAnlRangeTable              	AnlRangeTable;

    /* --- Analyzer Function Results --- */

    TAnlMeasPeak                    AnlMeasPeak;
    TAnlMeasRMSDC                   AnlMeasRMSDC;
    TAnlMeasQpeak                   AnlMeasQpeak;
    TAnlMeasRMSSel                  AnlMeasRMSSel;
	TAnlMeasRMSSelMuTsk             AnlMeasRMSSelMuTsk;
	TAnlMeasRMSSelMuTskPostFFT      AnlMeasRMSSelMuTskPostFFT;
	TAnlMeasRMSSelMuTskReducedFFT   AnlMeasRMSSelMuTskReducedFFT;
    TAnlMeasTHDN                    AnlMeasTHDN;
    TAnlMeasTHDNPostFFT             AnlMeasTHDNPostFFT;
    TAnlMeasTHDNReducedFFT          AnlMeasTHDNReducedFFT;
    TAnlMeasPhase                   AnlMeasPhase;
    TAnlMeasPhasePostFFT            AnlMeasPhasePostFFT;
    TAnlMeasPhaseReducedFFT         AnlMeasPhaseReducedFFT;
    TAnlMeasDFD                     AnlMeasDFD;
    TAnlMeasDFDPostFFT              AnlMeasDFDPostFFT;
    TAnlMeasDFDReducedFFT           AnlMeasDFDReducedFFT;
    TAnlMeasModDist                 AnlMeasModDist;
    TAnlMeasModDistPostFFT          AnlMeasModDistPostFFT;
    TAnlMeasModDistReducedFFT       AnlMeasModDistReducedFFT;
    TAnlMeasFFT                     AnlMeasFFT;
    TAnlMeasFFTReduced              AnlMeasFFTReduced;
    TAnlMeasDAISamplingFrequency    AnlMeasDAISamplingFrequency;
    TAnlMeasDAIProtocol             AnlMeasDAIProtocol;
    TAnlMeasRMSSweep                AnlMeasRMSSweep;
    TAnlMeasRMSSelectiveSweep       AnlMeasRMSSelectiveSweep;
    TAnlMeasTHDSweep                AnlMeasTHDSweep;

    ViBoolean                       FFTChannelRunning[2];
    ViInt32                         enabledMeasIdCnt;
    ViInt32                         enabledMeasId[ANLFUN_CNT];
    ViBoolean                       enabledMeasIdDataValid[ANLFUN_CNT];
    
    /* --- Driver Core Parameters --- */

    ViUInt16                        errorCount;
    TStringErrorPair                errorQueue[MAX_ERROR_QUEUE_LENGTH];
} TStatusDataRanges, *pTStatusDataRanges;

/*****************************************************************************/
/*= UTILITY ROUTINE DECLARATIONS (Non-Exportable Functions) =================*/
/*****************************************************************************/
ViBoolean rssiup_invalidViBooleanRange (ViBoolean val);
ViBoolean rssiup_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rssiup_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max);
ViBoolean rssiup_invalidViString (ViString val, ViUInt32 maxLength);
ViStatus rssiup_initCleanUp (ViPSession openInstrSession, ViStatus currentStatus);
void rssiup_delay (ViReal64 numberOfSeconds);
ViStatus rssiup_param_to_val (TSDiscreteValue table[], ViInt32 parameter,
    void *value, ViStatus error_code);
ViStatus rssiup_val_to_param (TSDiscreteValue table[], ViPInt32 parameter,
    void *value, ViStatus error_code);

/*****************************************************************************/
/*------ INSERT INSTRUMENT-DEPENDENT UTILITY ROUTINE DECLARATIONS HERE ------*/
/*****************************************************************************/
ViStatus rssiup_defaultInstrSetup (ViSession openInstrSession);
ViStatus rssiup_waitForDeviceState (ViSession instrSession, ViInt32 deviceState);
ViStatus rssiup_checkStatus (ViSession instrSession, ViInt16 checkEvent,
    ViPBoolean checkEnventFound);
ViStatus rssiup_DSI_Get (ViSession instrSession, ViInt32 regId, ViInt32 channel,
    void *value, ViInt32 size);
ViStatus rssiup_DSI_Set (ViSession instrSession, ViInt32 regId, ViInt32 channel,
    void *value, ViInt32 size);
ViStatus rssiup_readAnalyzerFunctionData (ViSession instrSession,
    TAnlFunFrameHeader *frame, void *data);
ViStatus rssiup_handleAnalyzerFunctionData (ViSession instrSession, ViInt32 measId[], ViInt32 noMeasId);
ViStatus rssiup_parseAnalyzerFunctionData (ViSession instrSession, ViInt32 FunID, ViChar *buffer, ViUInt16 size);
void rssiup_coerceToNearestMixedValPair (void *table, ViPReal64 value, ViPInt16 index);
void rssiup_float_to_double(ViReal64 *target, ViReal32 *source, ViUInt16 values);
void rssiup_recalculateFFTMeasurement(TFFTResHeader fftResponseHeader, ViReal64 spectralLines[], ViInt32 analyzerMode);
ViStatus rssiup_GetGeneratorSamplingFrequency (ViSession instrSession, ViPReal64 samplingFrequency);
void rssiup_coerceToNearest (void *table, ViPReal64 value, ViPInt16 index);
ViStatus rssiup_clearAnalyzerFunctionResults (ViSession instrSession);

/*****************************************************************************/
/*====== USER-CALLABLE FUNCTIONS (Exportable Functions) =====================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrSession)
{
    ViStatus rssiup_status  = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssiup_invalidViBooleanRange (IDQuery))
        return VI_ERROR_PARAMETER2;
    if (rssiup_invalidViBooleanRange (resetDevice))
        return VI_ERROR_PARAMETER3;

    /*- Initialize SiControl library and open instrument session(s) ---------*/
    if((rssiup_status = SiLibInit ()) != SI_ERROR_LIB_ALREADY_INITIALIZED)
        {
        CHECKERR (SiUpdateDeviceList());
        }

    /* Check device list if requested device is present in the system */
    {
    unsigned int    idx                 = 0,
                    deviceCount         = 0,
                    VendorId            = 0x0,
                    VID                 = 0x0,
                    ProductId           = 0x0,
                    PID                 = 0x0;
    unsigned long   SerialNumber        = 0,
                    ModelSerialNumber   = 0,
                    MSN                 = 0;
    char            dupResourceName[256];
    ViBoolean       ResourceNameMatched = VI_FALSE;

        /* Parse resource string "USB::Vendor_IDentifier::Product_IDentifier::Serial_Number" */
        if ((sscanf (resourceName, "USB::%x::%x::%u", &VID, &PID, &MSN)) != 3)
            {
            /* If resource string does not fit, try to pass it as alias */
            strcpy (dupResourceName, resourceName);
            }
        else
            {
            deviceCount = SiGetDeviceCount();

            for (idx = 0; idx < deviceCount; idx++)
                {
                CHECKERR (SiGetDeviceInfo(idx, &VendorId, &ProductId, &SerialNumber, &ModelSerialNumber));
                if ((VendorId == VID) && (ProductId == PID) && (ModelSerialNumber == MSN))
                    {
                    ResourceNameMatched = VI_TRUE;
                    break;
                    }
                }

            if (ResourceNameMatched == VI_FALSE)
                return SI_ERROR_RSRC_NFOUND;

            /* Create duplicate resource name with module serial number */
            sprintf (dupResourceName, "USB::0x%x::0x%x::%u", VID, PID, SerialNumber);
            }

        if ((rssiup_status = SiOpenDevice(dupResourceName, instrSession)) < 0)
            {
            SiCloseDevice (*instrSession);
            return rssiup_status;
            }
    }

    /*- Configure SiControl session parameters ------------------------------*/
    CHECKERR_CU (SiSetAttribute (*instrSession, SI_ATTR_TMO_VALUE, RSSIUP_DEFAULT_TIMEOUT));
    CHECKERR_CU (SiSetAttribute (*instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE_ID, MSG_HANDSHAKE));
    CHECKERR_CU (SiSetAttribute (*instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, RSSIUP_HANDSHAKE_GDI_ACKNOWLEDGE));

    /*- Identification Query ------------------------------------------------*/
    if (IDQuery)
        {
        unsigned int VID = 0x0,
                     PID = 0x0;

        CHECKERR_CU (SiGetAttribute (*instrSession, SI_ATTR_VENDOR_ID, &VID));
        CHECKERR_CU (SiGetAttribute (*instrSession, SI_ATTR_PRODUCT_ID, &PID));

        if ((VID != RSSIUP_VID_ROHDE_SCHWARZ) || (PID != RSSIUP_PID_UP300))
            return rssiup_initCleanUp (instrSession, VI_ERROR_FAIL_ID_QUERY);
        }

    /*- Reset instrument ----------------------------------------------------*/
    if (resetDevice)
        rssiup_status = rssiup_reset (*instrSession);
    else  /*- Send Default Instrument Setup ---------------------------------*/
        rssiup_status = rssiup_defaultInstrSetup (*instrSession);

    /*- Do the cleanup if initialization fails ------------------------------*/
    if (rssiup_status < VI_SUCCESS)
        return rssiup_initCleanUp (instrSession, rssiup_status);

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analyzer Function Peak Settings
 * Purpose:  This function sets parameters for peak value measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionPeakSettings (ViSession instrSession,
                                                          ViReal64 measurementTime)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TCmdPeakSetting     value           = {0};

    if (rssiup_invalidViReal64Range (measurementTime, 1.0e-3, 10.0))
        return VI_ERROR_PARAMETER2;

    DBL2FLT(measurementTime, value.MeasurTime);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_PEAK_SETTING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analyzer Function Peak Settings
 * Purpose:  This function returns parameters for peak value measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionPeakSettings (ViSession instrSession,
                                                          ViPReal64 measurementTime)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetPeakSetting     value           = {0};

    if (!measurementTime)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_PEAK_SETTING, ChAB, &value, sizeof(value)));
    *measurementTime = value.MeasureTime;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analyzer Function Peak Averaging
 * Purpose:  This function sets parameters of averaging mode for peak
 *           measurement.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_SetAnalyzerFunctionPeakAveraging (ViSession instrSession,
                                                           ViInt32 averagingMode,
                                                           ViInt32 averagingFactor)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TCmdPeakAveraging   value           = {0};

    CHECKERR (rssiup_param_to_val (SAverageModeDiscVals, averagingMode, &value.AverageMode, VI_ERROR_PARAMETER2));

    if (rssiup_invalidViInt32Range (averagingFactor, 1, 65535))
        return VI_ERROR_PARAMETER3;

    value.AverageFactor = averagingFactor;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_PEAK_AVERAGING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analyzer Function Peak Averaging
 * Purpose:  This function returns parameters of averaging mode for peak
 *           measurement.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_GetAnalyzerFunctionPeakAveraging (ViSession instrSession,
                                                           ViPInt32 averagingMode,
                                                           ViPInt32 averagingFactor)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetPeakAveraging   value           = {0};

    if (!averagingMode)
        return VI_ERROR_PARAMETER2;
    if (!averagingFactor)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_PEAK_AVERAGING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAverageModeDiscVals, averagingMode, &value.AverageMode, VI_ERROR_INV_RESPONSE));
    *averagingFactor = value.AverageFactor;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function RMSDC Settings
/* Purpose:  This function sets parameters for RMS, DC, frequency measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionRMSDCSettings(
    ViSession   instrSession,
    ViInt32     channel,
    ViReal64    measurementTime,
    ViReal64    timeout,
    ViInt32     syncMode,
    ViInt32     syncSource
/*  ViInt32     syncLevelMode, */
/*  ViReal64    fixedTriggerLevel, */
/*  ViReal64    fixedHysteresis, */
/*  ViReal64    autoHysteresis, */
/*  ViReal64    syncFilterTau */
)
{
    ViStatus                        rssiup_status   = VI_SUCCESS;
    TCmdRMSWidebandSettingAndTimes  value_set       = {0};
    TGetRMSWidebandSettingAndTimes  value_get       = {0};
    pTStatusDataRanges              instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (rssiup_invalidViReal64Range (measurementTime, 1.0e-3, DBL_MAX))
        return VI_ERROR_PARAMETER3;
    if (rssiup_invalidViReal64Range (timeout, 0.2, DBL_MAX))
        return VI_ERROR_PARAMETER4;

    CHECKERR (rssiup_param_to_val (SSynchroModeDiscVals, syncMode, &value_set.SynchroMode, VI_ERROR_PARAMETER5));
    CHECKERR (rssiup_param_to_val (SSynchroSourceDiscVals, syncSource, &value_set.SynchroSource, VI_ERROR_PARAMETER6));
/*  CHECKERR (rssiup_param_to_val (SSynchroLevelModDiscVals, syncLevelMode, &value_set.SynchroLevelMode, VI_ERROR_PARAMETER7)); */
/*
    if (rssiup_invalidViReal64Range (fixedTriggerLevel, -142.0, 142.0))
        return VI_ERROR_PARAMETER8;
    if (rssiup_invalidViReal64Range (fixedHysteresis, 0.0, 284.0))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssiup_invalidViReal64Range (autoHysteresis, 0.0, 100.0))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssiup_invalidViReal64Range (syncFilterTau, 0.001, 100.0))
        return VI_ERROR_INSTR_PARAMETER11;
*/
    DBL2FLT (measurementTime, value_set.MeasureTime);
    DBL2FLT (timeout, value_set.TimeOut);
/*  DBL2FLT (fixedTriggerLevel, value_set.FixedLevel); */
/*  DBL2FLT (fixedHysteresis, value_set.FixedHysteresis); */
/*  DBL2FLT (autoHysteresis, value_set.AutoHysteresis); */
/*  DBL2FLT (syncFilterTau, value_set.SynchroFilterTau); */

    /* Data are splitted, get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSDC_MEASTIMES_WIDESET, (channel == ChAB) ? ChA : channel, &value_get, sizeof(value_get)));

    value_set.SynchroLevelMode = value_get.SynchroLevelMode;
    value_set.FixedLevel = value_get.FixedLevel;
    value_set.FixedHysteresis = value_get.FixedHysteresis;
    value_set.AutoHysteresis = value_get.AutoHysteresis;
    value_set.SynchroFilterTau = value_get.SynchroFilterTau;

    /*---*/

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_RMSDC_MEASTIMES_WIDESET, channel, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function RMSDC Settings
/* Purpose:  This function returns parameters for RMS, DC, frequency measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionRMSDCSettings(
    ViSession   instrSession,
    ViInt32     channel,
    ViPReal64   measurementTime,
    ViPReal64   timeout,
    ViPInt32    syncMode,
    ViPInt32    syncSource
/*  ViPInt32    syncLevelMode, */
/*  ViPReal64   fixedTriggerLevel, */
/*  ViPReal64   fixedHysteresis, */
/*  ViPReal64   autoHysteresis, */
/*  ViPReal64   syncFilterTau */
)
{
    ViStatus                        rssiup_status   = VI_SUCCESS;
    TGetRMSWidebandSettingAndTimes  value           = {0};
    pTStatusDataRanges              instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!measurementTime)
        return VI_ERROR_PARAMETER3;
    if (!timeout)
        return VI_ERROR_PARAMETER4;
    if (!syncMode)
        return VI_ERROR_PARAMETER5;
    if (!syncSource)
        return VI_ERROR_PARAMETER6;
/*
    if (!syncLevelMode)
        return VI_ERROR_PARAMETER7;
    if (!fixedTriggerLevel)
        return VI_ERROR_PARAMETER8;
    if (!fixedHysteresis)
        return VI_ERROR_INSTR_PARAMETER9;
    if (!autoHysteresis)
        return VI_ERROR_INSTR_PARAMETER10;
    if (!syncFilterTau)
        return VI_ERROR_INSTR_PARAMETER11;
*/
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSDC_MEASTIMES_WIDESET, channel, &value, sizeof(value)));

    *measurementTime = value.MeasureTime;
    *timeout = value.TimeOut;

    CHECKERR (rssiup_val_to_param (SSynchroModeDiscVals, syncMode, &value.SynchroMode, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_val_to_param (SSynchroSourceDiscVals, syncSource, &value.SynchroSource, VI_ERROR_INV_RESPONSE));
/*  CHECKERR (rssiup_val_to_param (SSynchroLevelModDiscVals, syncLevelMode, &value.SynchroLevelMode, VI_ERROR_INV_RESPONSE)); */

/*  *fixedTriggerLevel = value.FixedLevel; */
/*  *fixedHysteresis = value.FixedHysteresis; */
/*  *autoHysteresis = value.AutoHysteresis; */
/*  *syncFilterTau = value.SynchroFilterTau; */

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function RMSDC Averaging
/* Purpose:  This function sets parameters of averaging mode for RMS, DC, 
/*           frequency measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionRMSDCAveraging(
    ViSession   instrSession,
    ViInt32 channel,
    ViInt32 averagingModeDC,
    ViInt32 averagingFactorDC,
    ViInt32 averagingModeRMS,
    ViInt32 averagingFactorRMS,
    ViInt32 averagingModeFrequency,
    ViInt32 averagingFactorFrequency
)
{
    ViStatus                    rssiup_status   = VI_SUCCESS;
    TCmdRMSWidebandAveraging    value           = {0};
    pTStatusDataRanges          instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SAverageModeDiscVals, averagingModeDC, &value.AverMode_DC, VI_ERROR_PARAMETER3));

    if (rssiup_invalidViInt32Range (averagingFactorDC, 1, 65535))
        return VI_ERROR_PARAMETER4;
    
    CHECKERR (rssiup_param_to_val (SAverageModeDiscVals, averagingModeRMS, &value.AverMode_RMS, VI_ERROR_PARAMETER5));

    if (rssiup_invalidViInt32Range (averagingFactorRMS, 1, 65535))
        return VI_ERROR_PARAMETER6;
    
    CHECKERR (rssiup_param_to_val (SAverageModeDiscVals, averagingModeFrequency, &value.AverMode_Freq, VI_ERROR_PARAMETER7));

    if (rssiup_invalidViInt32Range (averagingFactorFrequency, 1, 65535))
        return VI_ERROR_PARAMETER8;

    value.AverFactor_DC = averagingFactorDC;
    value.AverFactor_RMS = averagingFactorRMS;
    value.AverFactor_Freq = averagingFactorFrequency;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_RMSDC_WIDEBAND_AVERAGING, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function RMSDC Averaging
/* Purpose:  This function returns parameters of averaging mode for RMS, DC, 
/*           frequency measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionRMSDCAveraging(
    ViSession   instrSession,
    ViInt32     channel,
    ViPInt32    averagingModeDC,
    ViPInt32    averagingFactorDC,
    ViPInt32    averagingModeRMS,
    ViPInt32    averagingFactorRMS,
    ViPInt32    averagingModeFrequency,
    ViPInt32    averagingFactorFrequency
)
{
    ViStatus                    rssiup_status   = VI_SUCCESS;
    TGetRMSWidebandAveraging    value           = {0};
    pTStatusDataRanges          instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!averagingModeDC)
        return VI_ERROR_PARAMETER3;
    if (!averagingFactorDC)
        return VI_ERROR_PARAMETER4;
    if (!averagingModeRMS)
        return VI_ERROR_PARAMETER5;
    if (!averagingFactorRMS)
        return VI_ERROR_PARAMETER6;
    if (!averagingModeFrequency)
        return VI_ERROR_PARAMETER7;
    if (!averagingFactorFrequency)
        return VI_ERROR_PARAMETER8;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSDC_WIDEBAND_AVERAGING, channel, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAverageModeDiscVals, averagingModeDC, &value.AverMode_DC, VI_ERROR_INV_RESPONSE));
    *averagingFactorDC = value.AverFactor_DC;
    CHECKERR (rssiup_val_to_param (SAverageModeDiscVals, averagingModeRMS, &value.AverMode_RMS, VI_ERROR_INV_RESPONSE));
    *averagingFactorRMS = value.AverFactor_RMS;
    CHECKERR (rssiup_val_to_param (SAverageModeDiscVals, averagingModeFrequency, &value.AverMode_Freq, VI_ERROR_INV_RESPONSE));
    *averagingFactorFrequency = value.AverFactor_Freq;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function Qpeak Settings
/* Purpose:  This function sets parameters for quasi-peak measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionQpeakSettings(
    ViSession   instrSession,
    ViReal64    intervalTime
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TCmdQPeakSetting    value           = {0};

    if (rssiup_invalidViReal64Range (intervalTime, 1.0e-3, 1.0e4))
        return VI_ERROR_PARAMETER2;

    DBL2FLT (intervalTime, value.InitDelay);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_QPEAK_SETTING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function Qpeak Settings
/* Purpose:  This function returns parameters for quasi-peak measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionQpeakSettings(
    ViSession   instrSession,
    ViPReal64   intervalTime
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetQPeakSetting    value           = {0};

    if (!intervalTime)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_QPEAK_SETTING, ChAB, &value, sizeof(value)));
    *intervalTime = value.InitDelay;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer Function Qpeak Reset
/* Purpose:  This function resets measurement of maximum and minimum values 
/*           parameters for quasi-peak measurement.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_AnalyzerFunctionQpeakReset(
    ViSession   instrSession
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TCmdQPeakMinMaxReset    value           = {0};

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_QPEAK_MINMAXRESET, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function RMS Selective Settings
/* Purpose:  This function sets parameters for selective RMS measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionRMSSelectiveSettings(
    ViSession   instrSession,
    ViReal64    measurementTime,
    ViReal64    centerFrequency,
/*  ViInt32     frequencyMode, */
    ViInt32     bandwidth
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TCmdRMSSelSetting   value           = {0};

    if (rssiup_invalidViReal64Range (measurementTime, 1.0e-3, 1.0e4))
        return VI_ERROR_PARAMETER2;
/*
    if (rssiup_invalidViReal64Range (centerFrequency, , ))
        return VI_ERROR_PARAMETER3;
*/
    CHECKERR (rssiup_param_to_val (SFreqModeDiscVals, RSSIUP_FREQ_MODE_RMS_FIXED_VALUE /* frequencyMode */, &value.FrequencyMode, VI_ERROR_PARAMETER4));
    CHECKERR (rssiup_param_to_val (SBandwidthDiscVals, bandwidth, &value.Bandwidth, VI_ERROR_PARAMETER4));

    DBL2FLT (measurementTime, value.MeasTime);
    DBL2FLT (centerFrequency, value.CenterFrequency);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_RMSSEL_SETTING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function RMS Selective Settings
/* Purpose:  This function returns parameters of selective RMS measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionRMSSelectiveSettings(
    ViSession   instrSession,
    ViPReal64   measurementTime,
    ViPReal64   centerFrequency,
    ViPInt32    frequencyMode,
    ViPInt32    bandwidth
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetRMSSelSetting   value           = {0};

    if (!measurementTime)
        return VI_ERROR_PARAMETER2;
    if (!centerFrequency)
        return VI_ERROR_PARAMETER3;
    if (!frequencyMode)
        return VI_ERROR_PARAMETER4;
    if (!bandwidth)
        return VI_ERROR_PARAMETER5;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_SETTING, ChAB, &value, sizeof(value)));
    *measurementTime = value.MeasTime;
    *centerFrequency = value.CenterFrequency;
    CHECKERR (rssiup_val_to_param (SFreqModeDiscVals, frequencyMode, &value.FrequencyMode, VI_ERROR_PARAMETER4));
    CHECKERR (rssiup_val_to_param (SBandwidthDiscVals, bandwidth, &value.Bandwidth, VI_ERROR_PARAMETER5));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function RMS Selective Averaging
/* Purpose:  This function sets parameters of averaging mode for RMS 
/*           selective measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionRMSSelectiveAveraging(
    ViSession   instrSession,
    ViInt32     averagingMode,
    ViInt32     averagingFactor
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TCmdRMSSelAveraging value           = {0};

    CHECKERR (rssiup_param_to_val (SAverageModeDiscVals, averagingMode, &value.AverageMode, VI_ERROR_PARAMETER2));

    if (rssiup_invalidViInt32Range (averagingFactor, 1, 65535))
        return VI_ERROR_PARAMETER3;

    if ((averagingMode == RSSIUP_AVERAGING_MODE_NORMAL) ||
        (averagingMode == RSSIUP_AVERAGING_MODE_EXPONENCIAL))
        return VI_ERROR_PARAMETER2;

    value.AverageFactor = averagingFactor;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_RMSSEL_AVERANGING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function RMS Selective Averaging
/* Purpose:  This function returns parameters of averaging mode for RMS 
/*           selective measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionRMSSelectiveAveraging(
    ViSession   instrSession,
    ViPInt32    averagingMode,
    ViPInt32    averagingFactor
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetRMSSelAveraging value           = {0};

    if (!averagingMode)
        return VI_ERROR_PARAMETER2;
    if (!averagingFactor)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_AVERANGING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAverageModeDiscVals, averagingMode, &value.AverageMode, VI_ERROR_INV_RESPONSE));

    if ((*averagingMode == RSSIUP_AVERAGING_MODE_NORMAL) ||
        (*averagingMode == RSSIUP_AVERAGING_MODE_EXPONENCIAL))
        return VI_ERROR_INV_RESPONSE;

    *averagingFactor = value.AverageFactor;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function RMS Selective Variable Bandwidth Settings
/* Purpose:  This function sets parameters for RMS Selective 
/*           Variable Bandwidth measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionRMSSelectiveVariableBWSettings (ViSession instrSession,
                                                                       ViInt32 filterBandwidthType,
                                                                       ViReal64 filterBandwidth,
                                                                       ViReal64 multipleOfCenterFrequency,
                                                                       ViInt32 tuningMode)
{
	ViStatus                    rssiup_status   = VI_SUCCESS;
    TCmdRMSSelMuTskNoChSetting  set_value       = {0};
	TGetRMSSelMuTskNoChSetting  get_value       = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (rssiup_invalidViInt32Range (filterBandwidthType, RSSIUP_FILTER_BWID_TYPE_CONST, RSSIUP_FILTER_BWID_TYPE_RELAT))
        return VI_ERROR_PARAMETER2;
/*
	if (rssiup_invalidViReal64Range (filterBandwidth, 10.0, 0.1*fs))
        return VI_ERROR_PARAMETER3;
*/
	if (rssiup_invalidViReal64Range (multipleOfCenterFrequency, 0.00001, 1.0))
        return VI_ERROR_PARAMETER4;
	if (rssiup_invalidViInt32Range (tuningMode, RSSIUP_FREQ_MODE_AUTO, RSSIUP_FREQ_MODE_FIXED))
        return VI_ERROR_PARAMETER5;
	
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING, ChAB, &get_value, sizeof(get_value)));
	
	set_value.Sender = 0x07FE;
    set_value.FilterOrder = 8;
    
	CHECKERR (rssiup_param_to_val (STFilterBandwidthTypeDiscVals, filterBandwidthType, &set_value.FilterBandwidthType, VI_ERROR_PARAMETER2));
	
	if (filterBandwidthType == RSSIUP_FILTER_BWID_TYPE_CONST)
	{
		DBL2FLT (filterBandwidth, set_value.AbsoluteBandwidth);
		set_value.RelativeBandwidth = get_value.RelativeBandwidth;
	}
	else
	{
    	DBL2FLT (multipleOfCenterFrequency, set_value.RelativeBandwidth);
		set_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth;
	}
    
	CHECKERR (rssiup_param_to_val (STAutoFrqModeDiscVals, tuningMode, &set_value.FrequencyMode, VI_ERROR_PARAMETER5));
	
    set_value.PostFFTOn = get_value.PostFFTOn;
    set_value.DataReductionOn = get_value.DataReductionOn;
    set_value.FFTSize = get_value.FFTSize;
    set_value.FFTWindow = get_value.FFTWindow;
    
	set_value.DisplaySize = get_value.DisplaySize;
    set_value.WindowSize = get_value.WindowSize;
    set_value.WindowOffset = get_value.WindowOffset;
    set_value.Marker1Position = get_value.Marker1Position;
    set_value.Marker2Position = get_value.Marker2Position;
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING, ChAB, &set_value, sizeof(set_value)));
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Get Analyzer Function RMS Selective Variable Bandwidth Settings
/* Purpose:  This function returns parameters for RMS Selective 
/*           Variable Bandwidth measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionRMSSelectiveVariableBWSettings (ViSession instrSession,
                                                                       ViInt32 *filterBandwidthType,
                                                                       ViReal64 *filterBandwidth,
                                                                       ViReal64 *multipleOfCenterFrequency,
                                                                       ViInt32 *tuningMode)
{
	ViStatus                    rssiup_status   = VI_SUCCESS;
    TGetRMSSelMuTskNoChSetting  value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (!filterBandwidthType)
        return VI_ERROR_PARAMETER2;
	if (!filterBandwidth)
        return VI_ERROR_PARAMETER3;
	if (!multipleOfCenterFrequency)
        return VI_ERROR_PARAMETER4;
	if (!tuningMode)
        return VI_ERROR_PARAMETER5;
	
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING, ChAB, &value, sizeof(value)));
	
	CHECKERR (rssiup_val_to_param (STFilterBandwidthTypeDiscVals, filterBandwidthType, &value.FilterBandwidthType, VI_ERROR_INV_RESPONSE));
	
	*filterBandwidth = value.AbsoluteBandwidth;
	*multipleOfCenterFrequency = value.RelativeBandwidth;
	
	CHECKERR (rssiup_val_to_param (STAutoFrqModeDiscVals, tuningMode, &value.FrequencyMode, VI_ERROR_INV_RESPONSE));
	
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Set Analyzer Function RMS Selective Variable Bandwidth FFT Settings
/* Purpose:  This function sets FFT parameters for RMS Selective 
/*           Variable Bandwidth measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionRMSSelVariableBWFFTSettings (ViSession instrSession,
                                                                    ViBoolean postFFT,
                                                                    ViInt32 postFFTSize,
                                                                    ViInt32 postFFTWindow)
{
	ViStatus                    rssiup_status   = VI_SUCCESS;
    TCmdRMSSelMuTskNoChSetting  set_value       = {0};
	TGetRMSSelMuTskNoChSetting  get_value       = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (rssiup_invalidViBooleanRange (postFFT))
        return VI_ERROR_PARAMETER2;
    
	CHECKERR (rssiup_param_to_val (SFFTSizeDiscVals, postFFTSize, &set_value.FFTSize, VI_ERROR_PARAMETER3));
    
    CHECKERR (rssiup_param_to_val (SPostFFTWindowDiscVals, postFFTWindow, &set_value.FFTWindow, VI_ERROR_PARAMETER4));

    set_value.PostFFTOn = (postFFT == VI_TRUE) ? ON : OFF;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING, ChAB, &get_value, sizeof(get_value)));
	
	set_value.Sender = 0x07FE;
    set_value.FilterOrder = get_value.FilterOrder;
	set_value.FilterBandwidthType = get_value.FilterBandwidthType;
	set_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth;
	set_value.RelativeBandwidth = get_value.RelativeBandwidth;
	set_value.FrequencyMode = get_value.FrequencyMode;
	
	set_value.DataReductionOn = OFF;
	
	set_value.DisplaySize = 200;
    set_value.WindowSize = 400;
    set_value.WindowOffset = 0;
    set_value.Marker1Position = 10;
    set_value.Marker2Position = 100;
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING, ChAB, &set_value, sizeof(set_value)));
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Get Analyzer Function RMS Selective Variable Bandwidth FFT Settings
/* Purpose:  This function returns FFT parameters for RMS Selective 
/*           Variable Bandwidth measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionRMSSelVariableBWFFTSettings (ViSession instrSession,
                                                                    ViBoolean *postFFT,
                                                                    ViInt32 *postFFTSize,
                                                                    ViInt32 *postFFTWindow)
{
	ViStatus                    rssiup_status   = VI_SUCCESS;
    TGetRMSSelMuTskNoChSetting  value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (!postFFT)
        return VI_ERROR_PARAMETER2;
    if (!postFFTSize)
        return VI_ERROR_PARAMETER3;
    if (!postFFTWindow)
        return VI_ERROR_PARAMETER4;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING, ChAB, &value, sizeof(value)));
	
	CHECKERR (rssiup_val_to_param (SFFTSizeDiscVals, postFFTSize, &value.FFTSize, VI_ERROR_INV_RESPONSE));
    
    CHECKERR (rssiup_val_to_param (SPostFFTWindowDiscVals, postFFTWindow, &value.FFTWindow, VI_ERROR_INV_RESPONSE));

    *postFFT = (value.PostFFTOn == ON) ? VI_TRUE : VI_FALSE;
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Set Analyzer Function RMS Selective Variable Bandwidth Frequency 
/*           Settings
/* Purpose:  This function sets frequency parameters for RMS Selective 
/*           Variable Bandwidth measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionRMSSelectiveVariableBWFrequencySettings (ViSession instrSession,
                                                                              ViInt32 channel,
                                                                              ViReal64 frequency)
{
	ViStatus                    rssiup_status   = VI_SUCCESS;
    TCmdRMSSelMuTskChanSetting  value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	value.Sender = 0x07FE;
    
	DBL2FLT (frequency, value.Frequency);
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_RMSSEL_MuTsk_CHAN_SETTING, channel, &value, sizeof(value)));
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;
    
}

/*===========================================================================*/
/* Function: Get Analyzer Function RMS Selective Variable Bandwidth Frequency 
/*           Settings
/* Purpose:  This function returns frequency parameters for RMS Selective 
/*           Variable Bandwidth measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionRMSSelectiveVariableBWFrequencySettings (ViSession instrSession,
                                                                              ViInt32 channel,
                                                                              ViReal64 *frequency)
{
	ViStatus                    rssiup_status   = VI_SUCCESS;
    TGetRMSSelMuTskChanSetting  value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_CHAN_SETTING, channel, &value, sizeof(value)));
	
	*frequency = value.Frequency;
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Set Analyzer Function All Parameters RMS Selective Variable 
/*           Bandwidth Settings
/* Purpose:  This function sets channel and non channel parameters for RMS
/*           Selective Variable Bandwidth measurement. To set remaining parameters of 
/*           this measurement, use functions Set Analyzer Function All 
/*           Parameters RMS Selective Variable Bandwidth FFT Settings.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionAllParamsRMSSelectiveVariableBWSettings (ViSession instrSession,
                                                                                ViReal64 frequency[],
                                                                                ViInt32 filterBandwidthType,
                                                                                ViReal64 filterBandwidth,
                                                                                ViReal64 multipleOfCenterFrequency,
                                                                                ViInt32 tuningMode)
{
	ViStatus                       rssiup_status   = VI_SUCCESS;
    TCmdRMSSelMuTskAllParamSetting set_value       = {0};
	TGetRMSSelMuTskAllParamSetting get_value       = {0};
	pTStatusDataRanges             instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (rssiup_invalidViInt32Range (filterBandwidthType, RSSIUP_FILTER_BWID_TYPE_CONST, RSSIUP_FILTER_BWID_TYPE_RELAT))
        return VI_ERROR_PARAMETER3;
/*
	if (rssiup_invalidViReal64Range (filterBandwidth, 10.0, 0.1*fs))
        return VI_ERROR_PARAMETER4;
*/
	if (rssiup_invalidViReal64Range (multipleOfCenterFrequency, 0.00001, 1.0))
        return VI_ERROR_PARAMETER5;
	if (rssiup_invalidViInt32Range (tuningMode, RSSIUP_FREQ_MODE_AUTO, RSSIUP_FREQ_MODE_FIXED))
        return VI_ERROR_PARAMETER6;
	
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING, ChAB, &get_value, sizeof(get_value)));
	
	set_value.Sender = 0x07FE;
	
	DBL2FLT (frequency[0], set_value.FrequencyA);
	DBL2FLT (frequency[1], set_value.FrequencyB);
	
    set_value.FilterOrder = 8;
    
	CHECKERR (rssiup_param_to_val (STFilterBandwidthTypeDiscVals, filterBandwidthType, &set_value.FilterBandwidthType, VI_ERROR_PARAMETER3));
	
	if (filterBandwidthType == RSSIUP_FILTER_BWID_TYPE_CONST)
	{
		DBL2FLT (filterBandwidth, set_value.AbsoluteBandwidth);
		set_value.RelativeBandwidth = get_value.RelativeBandwidth;
	}
	else
	{
    	DBL2FLT (multipleOfCenterFrequency, set_value.RelativeBandwidth);
		set_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth;
	}
    
	CHECKERR (rssiup_param_to_val (STAutoFrqModeDiscVals, tuningMode, &set_value.FrequencyMode, VI_ERROR_PARAMETER6));
	
    set_value.PostFFTOn = get_value.PostFFTOn;
    set_value.DataReductionOn = get_value.DataReductionOn;
    set_value.FFTSize = get_value.FFTSize;
    set_value.FFTWindow = get_value.FFTWindow;
    
	set_value.DisplaySize = get_value.DisplaySize;
    set_value.WindowSize = get_value.WindowSize;
    set_value.WindowOffset = get_value.WindowOffset;
    set_value.Marker1Position = get_value.Marker1Position;
    set_value.Marker2Position = get_value.Marker2Position;
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING, ChAB, &set_value, sizeof(set_value)));
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Get Analyzer Function All Parameters RMS Selective Variable 
/*           Bandwidth Settings
/* Purpose:  This function returns channel and non channel parameters for RMS
/*           Selective Variable Bandwidth measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionAllParamsRMSSelectiveVariableBWSettings (ViSession instrSession,
                                                                                ViReal64 frequency[],
                                                                                ViInt32 *filterBandwidthType,
                                                                                ViReal64 *filterBandwidth,
                                                                                ViReal64 *multipleOfCenterFrequency,
                                                                                ViInt32 *tuningMode)
{
	ViStatus                       rssiup_status   = VI_SUCCESS;
    TGetRMSSelMuTskAllParamSetting value           = {0};
	pTStatusDataRanges             instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (!frequency)
		return VI_ERROR_PARAMETER2;
	if (!filterBandwidthType)
        return VI_ERROR_PARAMETER3;
	if (!filterBandwidth)
        return VI_ERROR_PARAMETER4;
	if (!multipleOfCenterFrequency)
        return VI_ERROR_PARAMETER5;
	if (!tuningMode)
        return VI_ERROR_PARAMETER6;
	
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING, ChAB, &value, sizeof(value)));
	
	frequency[0] = value.FrequencyA;
	frequency[1]  = value.FrequencyB;
	
    CHECKERR (rssiup_val_to_param (STFilterBandwidthTypeDiscVals, filterBandwidthType, &value.FilterBandwidthType, VI_ERROR_INV_RESPONSE));
	
	*filterBandwidth = value.AbsoluteBandwidth;
	*multipleOfCenterFrequency = value.RelativeBandwidth;
	
	CHECKERR (rssiup_val_to_param (STAutoFrqModeDiscVals, tuningMode, &value.FrequencyMode, VI_ERROR_INV_RESPONSE));
	
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Set Analyzer Function All Parameters RMS Selective Variable 
/*           Bandwidth FFT Settings
/* Purpose:  This function sets non channel FFT parameters for RMS Selective 
/*           Variable Bandwidth measurement. To set remaining parameters of this 
/*           measurement, use functions Set Analyzer Function All Parameters 
/*           RMS Selective Variable Bandwidth Settings.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionAllParamsRMSSelVariableBWFFTSettings (ViSession instrSession,
                                                                             ViBoolean postFFT,
                                                                             ViInt32 postFFTSize,
                                                                             ViInt32 postFFTWindow)
{
	ViStatus                       rssiup_status   = VI_SUCCESS;
    TCmdRMSSelMuTskAllParamSetting set_value       = {0};
	TGetRMSSelMuTskAllParamSetting get_value       = {0};
	pTStatusDataRanges             instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (rssiup_invalidViBooleanRange (postFFT))
        return VI_ERROR_PARAMETER2;
    
	CHECKERR (rssiup_param_to_val (SFFTSizeDiscVals, postFFTSize, &set_value.FFTSize, VI_ERROR_PARAMETER3));
    
    CHECKERR (rssiup_param_to_val (SPostFFTWindowDiscVals, postFFTWindow, &set_value.FFTWindow, VI_ERROR_PARAMETER4));

    set_value.PostFFTOn = (postFFT == VI_TRUE) ? ON : OFF;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING, ChAB, &get_value, sizeof(get_value)));
	
	set_value.Sender = 0x07FE;
	
	set_value.FrequencyA = get_value.FrequencyA;
	set_value.FrequencyB = get_value.FrequencyB;
	set_value.FilterOrder = get_value.FilterOrder;
	set_value.FilterBandwidthType = get_value.FilterBandwidthType;
	set_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth;
	set_value.RelativeBandwidth = get_value.RelativeBandwidth;
	set_value.FrequencyMode = get_value.FrequencyMode;
	
	set_value.DataReductionOn = OFF;
	
	set_value.DisplaySize = 200;
    set_value.WindowSize = 400;
    set_value.WindowOffset = 0;
    set_value.Marker1Position = 10;
    set_value.Marker2Position = 100;
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING, ChAB, &set_value, sizeof(set_value)));
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Get Analyzer Function All Parameters RMS Selective Variable 
/*           Bandwidth FFT Settings
/* Purpose:  This function returns non channel FFT parameters for RMS Selective 
/*           Variable Bandwidth measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionAllParamsRMSSelVariableBWFFTSettings (ViSession instrSession,
                                                                             ViBoolean *postFFT,
                                                                             ViInt32 *postFFTSize,
                                                                             ViInt32 *postFFTWindow)
{
	ViStatus                        rssiup_status   = VI_SUCCESS;
    TGetRMSSelMuTskAllParamSetting  value           = {0};
	pTStatusDataRanges              instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (!postFFT)
        return VI_ERROR_PARAMETER2;
    if (!postFFTSize)
        return VI_ERROR_PARAMETER3;
    if (!postFFTWindow)
        return VI_ERROR_PARAMETER4;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_ALL_PARAM_SETTING, ChAB, &value, sizeof(value)));
	
	CHECKERR (rssiup_val_to_param (SFFTSizeDiscVals, postFFTSize, &value.FFTSize, VI_ERROR_INV_RESPONSE));
    
    CHECKERR (rssiup_val_to_param (SPostFFTWindowDiscVals, postFFTWindow, &value.FFTWindow, VI_ERROR_INV_RESPONSE));

    *postFFT = (value.PostFFTOn == ON) ? VI_TRUE : VI_FALSE;
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Set Analyzer Function THD (+N) Settings
/* Purpose:  This function sets parameters for THD (+N) measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionTHDNSettings(
    ViSession   instrSession,
    ViInt32     measurementTime,
    ViInt32     frequencyMode,
/*  ViInt32     filterBandwidth, */
    ViReal64    fixedFrequencyChA,
    ViReal64    fixedFrequencyChB,
    ViReal64    frequencyLimitLo,
    ViReal64    frequencyLimitHi
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetTHDpmNSetting   value_get       = {0};
    TCmdTHDpmNSetting   value_set       = {0};

    CHECKERR (rssiup_param_to_val (SMeasTimeDiscVals, measurementTime, &value_set.MeasTime, VI_ERROR_PARAMETER2));
    CHECKERR (rssiup_param_to_val (STHDFreqModeDiscVals, frequencyMode, &value_set.FreqMode, VI_ERROR_PARAMETER3));
/*  CHECKERR (rssiup_param_to_val (SFilterBandwidthDiscVals, filterBandwidth, &value_set.FilterBandwidth, VI_ERROR_PARAMETER4)); */
/*
    if (rssiup_invalidViReal64Range (fixedFrequencyChA, 10.0, ))
        return VI_ERROR_PARAMETER5;
    if (rssiup_invalidViReal64Range (fixedFrequencyChB, 10.0, ))
        return VI_ERROR_PARAMETER6;
    if (rssiup_invalidViReal64Range (frequencyLimitLo, 10.0, ))
        return VI_ERROR_PARAMETER7;
    if (rssiup_invalidViReal64Range (frequencyLimitHi, 10.0, ))
        return VI_ERROR_PARAMETER8;
*/
    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_THDpmN_SETTING, ChAB, &value_get, sizeof(value_get)));

    value_set.FilterBandwidth = fbOtherwiseWide; /* Hardcoded value (constant) */

    value_set.PostFFTOn = value_get.PostFFTOn;
    value_set.DataReductionOn = value_get.DataReductionOn;
    value_set.PostFFTSize = value_get.PostFFTSize;
    value_set.PostFFTWindow = value_get.PostFFTWindow;
    value_set.DisplaySize = value_get.DisplaySize;
    value_set.WindowSize = value_get.WindowSize;
    value_set.WindowOffset = value_get.WindowOffset;
    value_set.Marker1Position = value_get.Marker1Position;
    value_set.Marker2Position = value_get.Marker2Position;

    /* Passed parameters */

    DBL2FLT (fixedFrequencyChA, value_set.FixFreq_A);
    DBL2FLT (fixedFrequencyChB, value_set.FixFreq_B);
    DBL2FLT (frequencyLimitLo, value_set.FreqLimitLo);
    DBL2FLT (frequencyLimitHi, value_set.FreqLimitHi);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_THDpmN_SETTING, ChAB, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function THD (+N) Settings
/* Purpose:  This function returns parameters of THD (+N) measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionTHDNSettings(
    ViSession   instrSession,
    ViPInt32    measurementTime,
    ViPInt32    frequencyMode,
    /* ViPInt32    filterBandwidth, */
    ViPReal64   fixedFrequencyChA,
    ViPReal64   fixedFrequencyChB,
    ViPReal64   frequencyLimitLo,
    ViPReal64   frequencyLimitHi
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetTHDpmNSetting   value_get       = {0};

    if (!measurementTime)
        return VI_ERROR_PARAMETER2;
    if (!frequencyMode)
        return VI_ERROR_PARAMETER3;
/*
    if (!filterBandwidth)
        return VI_ERROR_PARAMETER4;
*/
    if (!fixedFrequencyChA)
        return VI_ERROR_PARAMETER4;
    if (!fixedFrequencyChB)
        return VI_ERROR_PARAMETER5;
    if (!frequencyLimitLo)
        return VI_ERROR_PARAMETER6;
    if (!frequencyLimitHi)
        return VI_ERROR_PARAMETER7;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_THDpmN_SETTING, ChAB, &value_get, sizeof(value_get)));

    CHECKERR (rssiup_val_to_param (SMeasTimeDiscVals, measurementTime, &value_get.MeasTime, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_val_to_param (STHDFreqModeDiscVals, frequencyMode, &value_get.FreqMode, VI_ERROR_INV_RESPONSE));
/*  CHECKERR (rssiup_val_to_param (SFilterBandwidthDiscVals, filterBandwidth, &value_get.FilterBandwidth, VI_ERROR_INV_RESPONSE)); */

    *fixedFrequencyChA = value_get.FixFreq_A;
    *fixedFrequencyChB = value_get.FixFreq_B;
    *frequencyLimitLo = value_get.FreqLimitLo;
    *frequencyLimitHi = value_get.FreqLimitHi;

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function THD (+N) FFT Settings
/* Purpose:  This function sets FFT parameters for THD (+N) measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionTHDNFFTSettings(
    ViSession   instrSession,
    ViBoolean   postFFT,
/*  ViBoolean   dataReduction, */
    ViInt32     postFFTSize,
    ViInt32     postFFTWindow
/*  ViInt32     displaySize, */
/*  ViInt32     windowSize, */
/*  ViInt32     windowOffset, */
/*  ViInt32     marker1Position, */
/*  ViInt32     marker2Position */
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             fft_size        = 0;
    TGetTHDpmNSetting   value_get       = {0};
    TCmdTHDpmNSetting   value_set       = {0};

    if (rssiup_invalidViBooleanRange (postFFT))
        return VI_ERROR_PARAMETER2;
/*
    if (rssiup_invalidViBooleanRange (dataReduction))
        return VI_ERROR_PARAMETER3;
*/
    CHECKERR (rssiup_param_to_val (SFFTSizeDiscVals, postFFTSize, &value_set.PostFFTSize, VI_ERROR_PARAMETER3));
    CHECKERR (rssiup_param_to_val (SFFTSizeNumbersDiscVals, postFFTSize, &fft_size, VI_ERROR_PARAMETER3));

    CHECKERR (rssiup_param_to_val (SPostFFTWindowDiscVals, postFFTWindow, &value_set.PostFFTWindow, VI_ERROR_PARAMETER4));
/*
    if (rssiup_invalidViInt32Range (displaySize, 1, 310))
        return VI_ERROR_PARAMETER6;
    if (rssiup_invalidViInt32Range (windowSize, displaySize, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_PARAMETER7;
    if (rssiup_invalidViInt32Range (windowOffset, 0, FFT_MAGIC_CONST * fft_size - windowSize))
        return VI_ERROR_PARAMETER8;
    if (rssiup_invalidViInt32Range (marker1Position, 0, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssiup_invalidViInt32Range (marker2Position, 0, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_INSTR_PARAMETER10;
*/
    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_THDpmN_SETTING, ChAB, &value_get, sizeof(value_get)));

    value_set.FreqMode = value_get.FreqMode;
    value_set.FixFreq_A = value_get.FixFreq_A;
    value_set.FixFreq_B = value_get.FixFreq_B;
    value_set.FilterBandwidth = value_get.FilterBandwidth;
    value_set.MeasTime = value_get.MeasTime;
    value_set.FreqLimitLo = value_get.FreqLimitLo;
    value_set.FreqLimitHi = value_get.FreqLimitHi;

    /* Passed parameters */

    value_set.PostFFTOn = (postFFT == VI_TRUE) ? ON : OFF;
    value_set.DataReductionOn = OFF; /* (dataReduction == VI_TRUE) ? ON : OFF; */

    value_set.DisplaySize = 200; /* displaySize; */
    value_set.WindowSize = 400; /* windowSize; */
    value_set.WindowOffset = 0; /* windowOffset; */
    value_set.Marker1Position = 10; /* marker1Position; */
    value_set.Marker2Position = 100; /* marker2Position; */

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_THDpmN_SETTING, ChAB, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function THD (+N) FFT Settings
/* Purpose:  This function returns FFT parameters of THD (+N) measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionTHDNFFTSettings(
    ViSession   instrSession,
    ViPBoolean  postFFT,
/*  ViPBoolean  dataReduction, */
    ViPInt32    postFFTSize,
    ViPInt32    postFFTWindow
/*  ViPInt32    displaySize, */
/*  ViPInt32    windowSize, */
/*  ViPInt32    windowOffset, */
/*  ViPInt32    marker1Position, */
/*  ViPInt32    marker2Position */
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetTHDpmNSetting   value_get       = {0};

    if (!postFFT)
        return VI_ERROR_PARAMETER2;
/*
    if (!dataReduction)
        return VI_ERROR_PARAMETER3;
*/
    if (!postFFTSize)
        return VI_ERROR_PARAMETER3;
    if (!postFFTWindow)
        return VI_ERROR_PARAMETER4;
/*
    if (!displaySize)
        return VI_ERROR_PARAMETER6;
    if (!windowSize)
        return VI_ERROR_PARAMETER7;
    if (!windowOffset)
        return VI_ERROR_PARAMETER8;
    if (!marker1Position)
        return VI_ERROR_INSTR_PARAMETER9;
    if (!marker2Position)
        return VI_ERROR_INSTR_PARAMETER10;
*/
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_THDpmN_SETTING, ChAB, &value_get, sizeof(value_get)));

    CHECKERR (rssiup_val_to_param (SFFTSizeDiscVals, postFFTSize, &value_get.PostFFTSize, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_val_to_param (SPostFFTWindowDiscVals, postFFTWindow, &value_get.PostFFTWindow, VI_ERROR_INV_RESPONSE));

    *postFFT = (value_get.PostFFTOn == ON) ? VI_TRUE : VI_FALSE;
/*  *dataReduction = (value_get.DataReductionOn == ON) ? VI_TRUE : VI_FALSE; */
/*  *displaySize = value_get.DisplaySize; */
/*  *windowSize = value_get.WindowSize; */
/*  *windowOffset = value_get.WindowOffset; */
/*  *marker1Position = value_get.Marker1Position; */
/*  *marker2Position = value_get.Marker2Position; */

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function Phase Settings
/* Purpose:  This function sets parameters for phase measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionPhaseSettings(
    ViSession   instrSession,
    ViInt32     frequencyMode,
    ViReal64    fixedFrequency,
    ViInt32     frequencyMaster
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetPhaseMuTskSetting   value_get       = {0};
    TCmdPhaseMuTskSetting   value_set       = {0};

    CHECKERR (rssiup_param_to_val (STHDFreqModeDiscVals, frequencyMode, &value_set.FrequencyMode, VI_ERROR_PARAMETER2));
/*
    if (rssiup_invalidViReal64Range (fixedFrequency, 10.0, ))
        return VI_ERROR_PARAMETER3;
*/
    CHECKERR (rssiup_param_to_val (SMasterDiscVals, frequencyMaster, &value_set.Master, VI_ERROR_PARAMETER4));

    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_PHASEMuTsk_SETTING, ChAB, &value_get, sizeof(value_get)));

    value_set.PostFFTOn = value_get.PostFFTOn;
    value_set.DataReductionOn = value_get.DataReductionOn;
    value_set.FFTSize = value_get.FFTSize;
    value_set.DisplaySize = value_get.DisplaySize;
    value_set.WindowSize = value_get.WindowSize;
    value_set.WindowOffset = value_get.WindowOffset;
    value_set.Marker1Position = value_get.Marker1Position;
    value_set.Marker2Position = value_get.Marker2Position;

    /* Passed parameters */

    DBL2FLT (fixedFrequency, value_set.FixFreq);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_PHASEMuTsk_SETTING, ChAB, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function Phase Settings
/* Purpose:  This function returns parameters of phase measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionPhaseSettings(
    ViSession   instrSession,
    ViPInt32    frequencyMode,
    ViPReal64   fixedFrequency,
    ViPInt32    frequencyMaster
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetPhaseMuTskSetting   value_get       = {0};

    if (!frequencyMode)
        return VI_ERROR_PARAMETER2;
    if (!fixedFrequency)
        return VI_ERROR_PARAMETER3;
    if (!frequencyMaster)
        return VI_ERROR_PARAMETER4;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_PHASEMuTsk_SETTING, ChAB, &value_get, sizeof(value_get)));

    CHECKERR (rssiup_val_to_param (STHDFreqModeDiscVals, frequencyMode, &value_get.FrequencyMode, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_val_to_param (SMasterDiscVals, frequencyMaster, &value_get.Master, VI_ERROR_INV_RESPONSE));

    *fixedFrequency = value_get.FixFreq;

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function Phase FFT Settings
/* Purpose:  This function sets FFT parameters for phase measurement.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_SetAnalyzerFunctionPhaseFFTSettings(
    ViSession   instrSession,
    ViBoolean   postFFT,
    ViBoolean   dataReduction,
    ViInt32     postFFTSize,
    ViInt32     displaySize,
    ViInt32     windowSize,
    ViInt32     windowOffset,
    ViInt32     marker1Position,
    ViInt32     marker2Position
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    ViInt32                 fft_size        = 0;
    TGetPhaseMuTskSetting   value_get       = {0};
    TCmdPhaseMuTskSetting   value_set       = {0};

    if (rssiup_invalidViBooleanRange (postFFT))
        return VI_ERROR_PARAMETER2;
    if (rssiup_invalidViBooleanRange (dataReduction))
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_param_to_val (SFFTSizeDiscVals, postFFTSize, &value_set.FFTSize, VI_ERROR_PARAMETER4));
    CHECKERR (rssiup_param_to_val (SFFTSizeNumbersDiscVals, postFFTSize, &fft_size, VI_ERROR_PARAMETER4));

    if (rssiup_invalidViInt32Range (displaySize, 1, 310))
        return VI_ERROR_PARAMETER5;
    if (rssiup_invalidViInt32Range (windowSize, displaySize, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_PARAMETER6;
    if (rssiup_invalidViInt32Range (windowOffset, 0, FFT_MAGIC_CONST * fft_size - windowSize))
        return VI_ERROR_PARAMETER7;
    if (rssiup_invalidViInt32Range (marker1Position, 0, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_PARAMETER8;
    if (rssiup_invalidViInt32Range (marker2Position, 0, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_INSTR_PARAMETER9;

    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_PHASEMuTsk_SETTING, ChAB, &value_get, sizeof(value_get)));

    value_set.FrequencyMode = value_get.FrequencyMode;
    value_set.Master = value_get.Master;
    value_set.FixFreq = value_get.FixFreq;

    /* Passed parameters */

    value_set.PostFFTOn = (postFFT == VI_TRUE) ? ON : OFF;
    value_set.DataReductionOn = (dataReduction == VI_TRUE) ? ON : OFF;

    value_set.DisplaySize = displaySize;
    value_set.WindowSize = windowSize;
    value_set.WindowOffset = windowOffset;
    value_set.Marker1Position = marker1Position;
    value_set.Marker2Position = marker2Position;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_PHASEMuTsk_SETTING, ChAB, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function Phase FFT Settings
/* Purpose:  This function returns FFT parameters of phase measurement.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_GetAnalyzerFunctionPhaseFFTSettings(
    ViSession   instrSession,
    ViPBoolean  postFFT,
    ViPBoolean  dataReduction,
    ViPInt32    postFFTSize,
    ViPInt32    displaySize,
    ViPInt32    windowSize,
    ViPInt32    windowOffset,
    ViPInt32    marker1Position,
    ViPInt32    marker2Position
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetPhaseMuTskSetting   value_get       = {0};

    if (!postFFT)
        return VI_ERROR_PARAMETER2;
    if (!dataReduction)
        return VI_ERROR_PARAMETER3;
    if (!postFFTSize)
        return VI_ERROR_PARAMETER4;
    if (!displaySize)
        return VI_ERROR_PARAMETER5;
    if (!windowSize)
        return VI_ERROR_PARAMETER6;
    if (!windowOffset)
        return VI_ERROR_PARAMETER7;
    if (!marker1Position)
        return VI_ERROR_PARAMETER8;
    if (!marker2Position)
        return VI_ERROR_INSTR_PARAMETER9;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_PHASEMuTsk_SETTING, ChAB, &value_get, sizeof(value_get)));
    CHECKERR (rssiup_val_to_param (SFFTSizeDiscVals, postFFTSize, &value_get.FFTSize, VI_ERROR_INV_RESPONSE));

    *postFFT = (value_get.PostFFTOn == ON) ? VI_TRUE : VI_FALSE;
    *dataReduction = (value_get.DataReductionOn == ON) ? VI_TRUE : VI_FALSE;
    *displaySize = value_get.DisplaySize;
    *windowSize = value_get.WindowSize;
    *windowOffset = value_get.WindowOffset;
    *marker1Position = value_get.Marker1Position;
    *marker2Position = value_get.Marker2Position;

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function DFD Settings
/* Purpose:  This function sets parameters for Difference Frequency 
/*           Distortion measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionDFDSettings(
    ViSession   instrSession,
    ViInt32     frequencyMode,
    ViReal64    fixedFrequency1ChA,
    ViReal64    fixedFrequency2ChA,
    ViReal64    fixedFrequency1ChB,
    ViReal64    fixedFrequency2ChB
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetDFDMuTskSetting     value_get       = {0};
    TCmdDFDMuTskSetting     value_set       = {0};

    CHECKERR (rssiup_param_to_val (STHDFreqModeDiscVals, frequencyMode, &value_set.FrequencyMode, VI_ERROR_PARAMETER2));
/*
    if (rssiup_invalidViReal64Range (fixedFrequency1ChA, , ))
        return VI_ERROR_PARAMETER3;
    if (rssiup_invalidViReal64Range (fixedFrequency2ChA, , ))
        return VI_ERROR_PARAMETER4;
    if (rssiup_invalidViReal64Range (fixedFrequency1ChB, , ))
        return VI_ERROR_PARAMETER5;
    if (rssiup_invalidViReal64Range (fixedFrequency2ChB, , ))
        return VI_ERROR_PARAMETER6;
*/
    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_DFDMuTsk_SETTING, ChAB, &value_get, sizeof(value_get)));

    value_set.PostFFTOn = value_get.PostFFTOn;
    value_set.DataReductionOn = value_get.DataReductionOn;
    value_set.FFTSize = value_get.FFTSize;
    value_set.PostFFTWindow = value_get.PostFFTWindow;
    value_set.DisplaySize = value_get.DisplaySize;
    value_set.WindowSize = value_get.WindowSize;
    value_set.WindowOffset = value_get.WindowOffset;
    value_set.Marker1Position = value_get.Marker1Position;
    value_set.Marker2Position = value_get.Marker2Position;

    /* Passed parameters */

    DBL2FLT (fixedFrequency1ChA, value_set.FixFreq1_A);
    DBL2FLT (fixedFrequency2ChA, value_set.FixFreq2_A);
    DBL2FLT (fixedFrequency1ChB, value_set.FixFreq1_B);
    DBL2FLT (fixedFrequency2ChB, value_set.FixFreq2_B);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_DFDMuTsk_SETTING, ChAB, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function DFD Settings
/* Purpose:  This function returns parameters of Difference Frequency 
/*           Distortion measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionDFDSettings(
    ViSession   instrSession,
    ViPInt32    frequencyMode,
    ViPReal64   fixedFrequency1ChA,
    ViPReal64   fixedFrequency2ChA,
    ViPReal64   fixedFrequency1ChB,
    ViPReal64   fixedFrequency2ChB
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetDFDMuTskSetting     value_get       = {0};

    if (!frequencyMode)
        return VI_ERROR_PARAMETER2;
    if (!fixedFrequency1ChA)
        return VI_ERROR_PARAMETER3;
    if (!fixedFrequency2ChA)
        return VI_ERROR_PARAMETER4;
    if (!fixedFrequency1ChB)
        return VI_ERROR_PARAMETER5;
    if (!fixedFrequency2ChB)
        return VI_ERROR_PARAMETER6;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_DFDMuTsk_SETTING, ChAB, &value_get, sizeof(value_get)));
    CHECKERR (rssiup_val_to_param (STHDFreqModeDiscVals, frequencyMode, &value_get.FrequencyMode, VI_ERROR_INV_RESPONSE));

    *fixedFrequency1ChA = value_get.FixFreq1_A;
    *fixedFrequency2ChA = value_get.FixFreq2_A;
    *fixedFrequency1ChB = value_get.FixFreq1_B;
    *fixedFrequency2ChB = value_get.FixFreq2_B;

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function DFD FFT Settings
/* Purpose:  This function sets FFT parameters for Difference Frequency 
/*           Distortion measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionDFDFFTSettings(
    ViSession   instrSession,
    ViBoolean   postFFT,
/*  ViBoolean   dataReduction, */
    ViInt32     postFFTSize,
    ViInt32     postFFTWindow
/*  ViInt32     displaySize, */
/*  ViInt32     windowSize, */
/*  ViInt32     windowOffset, */
/*  ViInt32     marker1Position, */
/*  ViInt32     marker2Position */
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    ViInt32                 fft_size        = 0;
    TGetDFDMuTskSetting     value_get       = {0};
    TCmdDFDMuTskSetting     value_set       = {0};

    if (rssiup_invalidViBooleanRange (postFFT))
        return VI_ERROR_PARAMETER2;
/*
    if (rssiup_invalidViBooleanRange (dataReduction))
        return VI_ERROR_PARAMETER3;
*/
    CHECKERR (rssiup_param_to_val (SFFTSizeDiscVals, postFFTSize, &value_set.FFTSize, VI_ERROR_PARAMETER4));
    CHECKERR (rssiup_param_to_val (SFFTSizeNumbersDiscVals, postFFTSize, &fft_size, VI_ERROR_PARAMETER4));

    CHECKERR (rssiup_param_to_val (SPostFFTWindowDiscVals, postFFTWindow, &value_set.PostFFTWindow, VI_ERROR_PARAMETER5));
/*
    if (rssiup_invalidViInt32Range (displaySize, 1, 310))
        return VI_ERROR_PARAMETER6;
    if (rssiup_invalidViInt32Range (windowSize, displaySize, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_PARAMETER7;
    if (rssiup_invalidViInt32Range (windowOffset, 0, FFT_MAGIC_CONST * fft_size - windowSize))
        return VI_ERROR_PARAMETER8;
    if (rssiup_invalidViInt32Range (marker1Position, 0, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssiup_invalidViInt32Range (marker2Position, 0, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_INSTR_PARAMETER10;
*/
    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_DFDMuTsk_SETTING, ChAB, &value_get, sizeof(value_get)));

    value_set.FrequencyMode = value_get.FrequencyMode;
    value_set.FixFreq1_A = value_get.FixFreq1_A;
    value_set.FixFreq2_A = value_get.FixFreq2_A;
    value_set.FixFreq1_B = value_get.FixFreq1_B;
    value_set.FixFreq2_B = value_get.FixFreq2_B;

    /* Passed parameters */

    value_set.PostFFTOn = (postFFT == VI_TRUE) ? ON : OFF;
    value_set.DataReductionOn = OFF; /* (dataReduction == VI_TRUE) ? ON : OFF; */

    value_set.DisplaySize = 200; /* displaySize; */
    value_set.WindowSize = 400; /* windowSize; */
    value_set.WindowOffset = 0; /* windowOffset; */
    value_set.Marker1Position = 10; /* marker1Position; */
    value_set.Marker2Position = 100; /* marker2Position; */

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_DFDMuTsk_SETTING, ChAB, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function DFD FFT Settings
/* Purpose:  This function returns FFT parameters of Difference Frequency 
/*           Distortion measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionDFDFFTSettings(
    ViSession   instrSession,
    ViPBoolean  postFFT,
/*  ViPBoolean  dataReduction, */
    ViPInt32    postFFTSize,
    ViPInt32    postFFTWindow
/*  ViPInt32    displaySize, */
/*  ViPInt32    windowSize, */
/*  ViPInt32    windowOffset, */
/*  ViPInt32    marker1Position, */
/*  ViPInt32    marker2Position */
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetDFDMuTskSetting     value_get       = {0};

    if (!postFFT)
        return VI_ERROR_PARAMETER2;
/*
    if (!dataReduction)
        return VI_ERROR_PARAMETER3;
*/
    if (!postFFTSize)
        return VI_ERROR_PARAMETER3;
    if (!postFFTWindow)
        return VI_ERROR_PARAMETER4;
/*
    if (!displaySize)
        return VI_ERROR_PARAMETER6;
    if (!windowSize)
        return VI_ERROR_PARAMETER7;
    if (!windowOffset)
        return VI_ERROR_PARAMETER8;
    if (!marker1Position)
        return VI_ERROR_INSTR_PARAMETER9;
    if (!marker2Position)
        return VI_ERROR_INSTR_PARAMETER10;
*/
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_DFDMuTsk_SETTING, ChAB, &value_get, sizeof(value_get)));

    CHECKERR (rssiup_val_to_param (SFFTSizeDiscVals, postFFTSize, &value_get.FFTSize, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_val_to_param (SPostFFTWindowDiscVals, postFFTWindow, &value_get.PostFFTWindow, VI_ERROR_INV_RESPONSE));

    *postFFT = (value_get.PostFFTOn == ON) ? VI_TRUE : VI_FALSE;
/*  *dataReduction = (value_get.DataReductionOn == ON) ? VI_TRUE : VI_FALSE; */
/*  *displaySize = value_get.DisplaySize; */
/*  *windowSize = value_get.WindowSize; */
/*  *windowOffset = value_get.WindowOffset; */
/*  *marker1Position = value_get.Marker1Position; */
/*  *marker2Position = value_get.Marker2Position; */

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function Mod Dist Settings
/* Purpose:  This function sets parameters for Modulation Distortion 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionModDistSettings(
    ViSession   instrSession,
    ViInt32     frequencyMode,
    ViReal64    fixedFrequency1ChA,
    ViReal64    fixedFrequency2ChA,
    ViReal64    fixedFrequency1ChB,
    ViReal64    fixedFrequency2ChB
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetModDistSetting      value_get       = {0};
    TCmdModDistSetting      value_set       = {0};

    CHECKERR (rssiup_param_to_val (STHDFreqModeDiscVals, frequencyMode, &value_set.FrequencyMode, VI_ERROR_PARAMETER2));
/*
    if (rssiup_invalidViReal64Range (fixedFrequency1ChA, , ))
        return VI_ERROR_PARAMETER3;
    if (rssiup_invalidViReal64Range (fixedFrequency2ChA, , ))
        return VI_ERROR_PARAMETER4;
    if (rssiup_invalidViReal64Range (fixedFrequency1ChB, , ))
        return VI_ERROR_PARAMETER5;
    if (rssiup_invalidViReal64Range (fixedFrequency2ChB, , ))
        return VI_ERROR_PARAMETER6;
*/
    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_ModDist_SETTING, ChAB, &value_get, sizeof(value_get)));

    value_set.PostFFTOn = value_get.PostFFTOn;
    value_set.DataReductionOn = value_get.DataReductionOn;
    value_set.FFTSize = value_get.FFTSize;
    value_set.PostFFTWindow = value_get.PostFFTWindow;
    value_set.DisplaySize = value_get.DisplaySize;
    value_set.WindowSize = value_get.WindowSize;
    value_set.WindowOffset = value_get.WindowOffset;
    value_set.Marker1Position = value_get.Marker1Position;
    value_set.Marker2Position = value_get.Marker2Position;

    /* Passed parameters */

    DBL2FLT (fixedFrequency1ChA, value_set.FixFreq1_A);
    DBL2FLT (fixedFrequency2ChA, value_set.FixFreq2_A);
    DBL2FLT (fixedFrequency1ChB, value_set.FixFreq1_B);
    DBL2FLT (fixedFrequency2ChB, value_set.FixFreq2_B);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_ModDist_SETTING, ChAB, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function Mod Dist Settings
/* Purpose:  This function returns parameters of Modulation Distortion 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionModDistSettings(
    ViSession   instrSession,
    ViPInt32    frequencyMode,
    ViPReal64   fixedFrequency1ChA,
    ViPReal64   fixedFrequency2ChA,
    ViPReal64   fixedFrequency1ChB,
    ViPReal64   fixedFrequency2ChB
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetModDistSetting  value_get       = {0};

    if (!frequencyMode)
        return VI_ERROR_PARAMETER2;
    if (!fixedFrequency1ChA)
        return VI_ERROR_PARAMETER3;
    if (!fixedFrequency2ChA)
        return VI_ERROR_PARAMETER4;
    if (!fixedFrequency1ChB)
        return VI_ERROR_PARAMETER5;
    if (!fixedFrequency2ChB)
        return VI_ERROR_PARAMETER6;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_ModDist_SETTING, ChAB, &value_get, sizeof(value_get)));
    CHECKERR (rssiup_val_to_param (STHDFreqModeDiscVals, frequencyMode, &value_get.FrequencyMode, VI_ERROR_INV_RESPONSE));

    *fixedFrequency1ChA = value_get.FixFreq1_A;
    *fixedFrequency2ChA = value_get.FixFreq2_A;
    *fixedFrequency1ChB = value_get.FixFreq1_B;
    *fixedFrequency2ChB = value_get.FixFreq2_B;

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function Mod Dist FFT Settings
/* Purpose:  This function sets FFT parameters for Modulation Distortion 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionModDistFFTSettings(
    ViSession   instrSession,
    ViBoolean   postFFT,
/*  ViBoolean   dataReduction, */
    ViInt32     postFFTSize,
    ViInt32     postFFTWindow
/*  ViInt32     displaySize, */
/*  ViInt32     windowSize, */
/*  ViInt32     windowOffset, */
/*  ViInt32     marker1Position, */
/*  ViInt32     marker2Position */
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    ViInt32                 fft_size        = 0;
    TGetModDistSetting      value_get       = {0};
    TCmdModDistSetting      value_set       = {0};

    if (rssiup_invalidViBooleanRange (postFFT))
        return VI_ERROR_PARAMETER2;
/*      
    if (rssiup_invalidViBooleanRange (dataReduction))
        return VI_ERROR_PARAMETER3;
*/
    CHECKERR (rssiup_param_to_val (SFFTSizeDiscVals, postFFTSize, &value_set.FFTSize, VI_ERROR_PARAMETER3));
    CHECKERR (rssiup_param_to_val (SFFTSizeNumbersDiscVals, postFFTSize, &fft_size, VI_ERROR_PARAMETER3));

    CHECKERR (rssiup_param_to_val (SPostFFTWindowDiscVals, postFFTWindow, &value_set.PostFFTWindow, VI_ERROR_PARAMETER4));
/*
    if (rssiup_invalidViInt32Range (displaySize, 1, 310))
        return VI_ERROR_PARAMETER6;
    if (rssiup_invalidViInt32Range (windowSize, displaySize, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_PARAMETER7;
    if (rssiup_invalidViInt32Range (windowOffset, 0, FFT_MAGIC_CONST * fft_size - windowSize))
        return VI_ERROR_PARAMETER8;
    if (rssiup_invalidViInt32Range (marker1Position, 0, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssiup_invalidViInt32Range (marker2Position, 0, FFT_MAGIC_CONST * fft_size))
        return VI_ERROR_INSTR_PARAMETER10;
*/
    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_ModDist_SETTING, ChAB, &value_get, sizeof(value_get)));

    value_set.FrequencyMode = value_get.FrequencyMode;
    value_set.FixFreq1_A = value_get.FixFreq1_A;
    value_set.FixFreq2_A = value_get.FixFreq2_A;
    value_set.FixFreq1_B = value_get.FixFreq1_B;
    value_set.FixFreq2_B = value_get.FixFreq2_B;

    /* Passed parameters */

    value_set.PostFFTOn = (postFFT == VI_TRUE) ? ON : OFF;
    value_set.DataReductionOn = OFF; /* (dataReduction == VI_TRUE) ? ON : OFF; */

    value_set.DisplaySize = 200; /* displaySize; */
    value_set.WindowSize = 400; /* windowSize; */
    value_set.WindowOffset = 0; /* windowOffset; */
    value_set.Marker1Position = 10; /* marker1Position; */
    value_set.Marker2Position = 100; /* marker2Position; */

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_ModDist_SETTING, ChAB, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function Mod Dist FFT Settings
/* Purpose:  This function returns FFT parameters of Modulation Distortion 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionDistFFTSettings(
    ViSession   instrSession,
    ViPBoolean  postFFT,
/*  ViPBoolean  dataReduction, */
    ViPInt32    postFFTSize,
    ViPInt32    postFFTWindow
/*  ViPInt32    displaySize, */
/*  ViPInt32    windowSize, */
/*  ViPInt32    windowOffset, */
/*  ViPInt32    marker1Position, */
/*  ViPInt32    marker2Position */
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetModDistSetting  value_get       = {0};

    if (!postFFT)
        return VI_ERROR_PARAMETER2;
/*
    if (!dataReduction)
        return VI_ERROR_PARAMETER3;
*/
    if (!postFFTSize)
        return VI_ERROR_PARAMETER3;
    if (!postFFTWindow)
        return VI_ERROR_PARAMETER4;
/*
    if (!displaySize)
        return VI_ERROR_PARAMETER6;
    if (!windowSize)
        return VI_ERROR_PARAMETER7;
    if (!windowOffset)
        return VI_ERROR_PARAMETER8;
    if (!marker1Position)
        return VI_ERROR_INSTR_PARAMETER9;
    if (!marker2Position)
        return VI_ERROR_INSTR_PARAMETER10;
*/
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_ModDist_SETTING, ChAB, &value_get, sizeof(value_get)));

    CHECKERR (rssiup_val_to_param (SFFTSizeDiscVals, postFFTSize, &value_get.FFTSize, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_val_to_param (SPostFFTWindowDiscVals, postFFTWindow, &value_get.PostFFTWindow, VI_ERROR_INV_RESPONSE));

    *postFFT = (value_get.PostFFTOn == ON) ? VI_TRUE : VI_FALSE;
/*  *dataReduction = (value_get.DataReductionOn == ON) ? VI_TRUE : VI_FALSE; */
/*  *displaySize = value_get.DisplaySize; */
/*  *windowSize = value_get.WindowSize; */
/*  *windowOffset = value_get.WindowOffset; */
/*  *marker1Position = value_get.Marker1Position; */
/*  *marker2Position = value_get.Marker2Position; */

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function FFT Settings
/* Purpose:  This function sets parameters for FFT spectrum measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionFFTSettings(
    ViSession   instrSession,
    ViInt32     channel,
/*  ViBoolean   dataReduction, */
    ViInt32     fftSize,
    ViInt32     fftWindow,
    ViReal64    kaiserWindowBeta
/*  ViInt32     zoomFactor, */
/*  ViReal64    zoomOffset, */
/*  ViInt32     displaySize, */
/*  ViInt32     windowSize, */
/*  ViInt32     windowOffset, */
/*  ViInt32     marker1Position, */
/*  ViInt32     marker2Position */
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    ViInt32                 fft_size        = 0;
    ViReal64                kval            = FFT_MAGIC_CONST;
    TGetFFTMuTskSetting     value_get       = {0};
    TCmdFFTMuTskSetting     value_set       = {0};

    if (!((channel == ChAB) /* || (channel == ChA) || (channel == ChB) */))
        return VI_ERROR_PARAMETER2;
/*
    if (rssiup_invalidViBooleanRange (dataReduction))
        return VI_ERROR_PARAMETER3;
*/
    CHECKERR (rssiup_param_to_val (SFFTSizeDiscVals, fftSize, &value_set.FFTSize, VI_ERROR_PARAMETER3));
    CHECKERR (rssiup_param_to_val (SFFTSizeNumbersDiscVals, fftSize, &fft_size, VI_ERROR_PARAMETER3));

    CHECKERR (rssiup_param_to_val (SWindowModeDiscVals, fftWindow, &value_set.WindowType, VI_ERROR_PARAMETER4));

    if (rssiup_invalidViReal64Range (kaiserWindowBeta, 1.0, 20.0))
        return VI_ERROR_PARAMETER5;
/*
    CHECKERR (rssiup_param_to_val (SZoomFactorDiscVals, zoomFactor, &value_set.ZoomFactor, VI_ERROR_PARAMETER7));

    if (rssiup_invalidViReal64Range (zoomOffset, , ))
        return VI_ERROR_PARAMETER8;
*/
    kval = (/* zoomFactor */ RSSIUP_FFT_ZOOM_FACTOR_0 == RSSIUP_FFT_ZOOM_FACTOR_0) ? FFT_MAGIC_CONST : 0.4;
/*  
    if (rssiup_invalidViInt32Range (displaySize, 1, 310))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rssiup_invalidViInt32Range (windowSize, displaySize, kval * fft_size))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rssiup_invalidViInt32Range (windowOffset, 0, kval * fft_size - windowSize))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rssiup_invalidViInt32Range (marker1Position, 0, kval * fft_size))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rssiup_invalidViInt32Range (marker2Position, 0, kval * fft_size))
        return VI_ERROR_INSTR_PARAMETER13;
*/
    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_FFTMuTsk_SETTING, channel, &value_get, sizeof(value_get)));

    value_set.AverageMode = value_get.AverageMode;
    value_set.AverageCount = value_get.AverageCount;

    /* Passed parameters */

/*  DBL2FLT (zoomOffset, value_set.ZoomOffset); */
    DBL2FLT (kaiserWindowBeta, value_set.KaiserWindowBeta);

    value_set.DataReductionOn = OFF; /* (dataReduction == VI_TRUE) ? ON : OFF; */
    value_set.DisplaySize = 200; /* displaySize; */
    value_set.WindowSize = 400; /* windowSize; */
    value_set.WindowOffset = 0; /* windowOffset; */
    value_set.Marker1Position = 10; /* marker1Position; */
    value_set.Marker2Position = 100; /* marker2Position; */

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FFTMuTsk_SETTING, channel, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function FFT Settings
/* Purpose:  This function returns parameters of FFT spectrum measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionFFTSettings(
    ViSession   instrSession,
    ViInt32     channel,
/*  ViPBoolean  dataReduction, */
    ViPInt32    fftSize,
    ViPInt32    fftWindow,
    ViPReal64   kaiserWindowBeta
/*  ViPInt32    zoomFactor, */
/*  ViPReal64   zoomOffset, */
/*  ViPInt32    displaySize, */
/*  ViPInt32    windowSize, */
/*  ViPInt32    windowOffset, */
/*  ViPInt32    marker1Position, */
/*  ViPInt32    marker2Position */
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetFFTMuTskSetting     value_get       = {0};

    if (!((channel == ChAB) /* || (channel == ChA) || (channel == ChB) */))
        return VI_ERROR_PARAMETER2;
/*
    if (!dataReduction)
        return VI_ERROR_PARAMETER3;
*/
    if (!fftSize)
        return VI_ERROR_PARAMETER3;
    if (!fftWindow)
        return VI_ERROR_PARAMETER4;
    if (!kaiserWindowBeta)
        return VI_ERROR_PARAMETER5;
/*
    if (!zoomFactor)
        return VI_ERROR_PARAMETER7;
    if (!zoomOffset)
        return VI_ERROR_PARAMETER8;
    if (!displaySize)
        return VI_ERROR_INSTR_PARAMETER9;
    if (!windowSize)
        return VI_ERROR_INSTR_PARAMETER10;
    if (!windowOffset)
        return VI_ERROR_INSTR_PARAMETER11;
    if (!marker1Position)
        return VI_ERROR_INSTR_PARAMETER12;
    if (!marker2Position)
        return VI_ERROR_INSTR_PARAMETER13;
*/
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_FFTMuTsk_SETTING, channel, &value_get, sizeof(value_get)));

    CHECKERR (rssiup_val_to_param (SFFTSizeDiscVals, fftSize, &value_get.FFTSize, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_val_to_param (SWindowModeDiscVals, fftWindow, &value_get.WindowType, VI_ERROR_INV_RESPONSE));
/*  CHECKERR (rssiup_val_to_param (SZoomFactorDiscVals, zoomFactor, &value_get.ZoomFactor, VI_ERROR_INV_RESPONSE)); */

/*  *zoomOffset = value_get.ZoomOffset; */
    *kaiserWindowBeta = value_get.KaiserWindowBeta;
/*  *dataReduction = (value_get.DataReductionOn == ON) ? VI_TRUE : VI_FALSE; */
/*  *displaySize = value_get.DisplaySize; */
/*  *windowSize = value_get.WindowSize; */
/*  *windowOffset = value_get.WindowOffset; */
/*  *marker1Position = value_get.Marker1Position; */
/*  *marker2Position = value_get.Marker2Position; */

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Function FFT Averaging
/* Purpose:  This function sets parameters of averaging mode for FFT 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionFFTAveraging(
    ViSession   instrSession,
    ViInt32     channel,
    ViInt32     averagingMode,
    ViInt32     averagingFactor
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetFFTMuTskSetting     value_get       = {0};
    TCmdFFTMuTskSetting     value_set       = {0};

    if (!((channel == ChAB) /* || (channel == ChA) || (channel == ChB) */))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SFFTAverModeDiscVals, averagingMode, &value_set.AverageMode, VI_ERROR_PARAMETER3));

    if (rssiup_invalidViInt32Range (averagingFactor, 1, 128))
        return VI_ERROR_PARAMETER4;

    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_FFTMuTsk_SETTING, channel, &value_get, sizeof(value_get)));

    value_set.DataReductionOn = value_get.DataReductionOn;
    value_set.FFTSize = value_get.FFTSize;
    value_set.ZoomFactor = value_get.ZoomFactor;
    value_set.ZoomOffset = value_get.ZoomOffset;
    value_set.WindowType = value_get.WindowType;
    value_set.KaiserWindowBeta = value_get.KaiserWindowBeta;
    value_set.DisplaySize = value_get.DisplaySize;
    value_set.WindowSize = value_get.WindowSize;
    value_set.WindowOffset = value_get.WindowOffset;
    value_set.Marker1Position = value_get.Marker1Position;
    value_set.Marker2Position = value_get.Marker2Position;

    /* Passed parameters */

    value_set.AverageCount = averagingFactor;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FFTMuTsk_SETTING, channel, &value_set, sizeof(value_set)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Function FFT Averaging
/* Purpose:  This function returns parameters of averaging mode for FFT 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionFFTAveraging(
    ViSession   instrSession,
    ViInt32     channel,
    ViPInt32    averagingMode,
    ViPInt32    averagingFactor
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TGetFFTMuTskSetting     value_get       = {0};

    if (!((channel == ChAB) /* || (channel == ChA) || (channel == ChB) */))
        return VI_ERROR_PARAMETER2;

    if (!averagingMode)
        return VI_ERROR_PARAMETER3;
    if (!averagingFactor)
        return VI_ERROR_PARAMETER4;

    /* Data are splitted to the two functions. Get them first to keep unused parameters. */

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_FFTMuTsk_SETTING, channel, &value_get, sizeof(value_get)));
    CHECKERR (rssiup_val_to_param (SFFTAverModeDiscVals, averagingMode, &value_get.AverageMode, VI_ERROR_INV_RESPONSE));

    *averagingFactor = value_get.AverageCount;

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer Digital Filter
/* Purpose:  This function sets parameters for digital filter.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetAnalyzerDigitalFilter(
    ViSession   instrSession,
    ViInt32     channel,
    ViInt32     filterSection,
    ViInt32     filterType,
    ViReal64    centerFrequency
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    ViInt16                 index           = 0;
    TCmdDigFilterSetting    value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SFilterSectionDiscVals, filterSection, &value.FilterSection, VI_ERROR_PARAMETER3));
    CHECKERR (rssiup_param_to_val (SFilterTypeDiscVals, filterType, &value.FilterType, VI_ERROR_PARAMETER4));

    /* Coerce to nearest acceptable value */
    rssiup_coerceToNearestMixedValPair (GOctaveFilterCenterFreqDiscVals, &centerFrequency, &index);
    value.CenterFreqForOctaves = index;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_DIGITALFILTER_SETTING, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer Digital Filter
/* Purpose:  This function gets parameters of digital filter.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetAnalyzerDigitalFilter(
    ViSession   instrSession,
    ViInt32     filterSection,
    ViInt32     _VI_FAR filterType[],
    ViReal64    _VI_FAR centerFrequency[],
    ViReal64    _VI_FAR filterDelay[],
    ViInt32     _VI_FAR filterBiQuads[],
    ViPInt32    biquadsCount
/*  ViInt32     _VI_FAR normalCoeficients[], */
/*  ViInt32     _VI_FAR extCoeficients[] */
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    ViInt32                 filter_section  = 0,
/*                          idx             = 0, */
                            count           = 0;
    TGetDigFilterSetting    value           = {0};

    CHECKERR (rssiup_param_to_val (SFilterSectionDiscVals, filterSection, &filter_section, VI_ERROR_PARAMETER2));
    
    if (!filterType)
        return VI_ERROR_PARAMETER3;
    if (!centerFrequency)
        return VI_ERROR_PARAMETER4;
    if (!filterDelay)
        return VI_ERROR_PARAMETER5;
    if (!filterBiQuads)
        return VI_ERROR_PARAMETER6;
    if (!biquadsCount)
        return VI_ERROR_PARAMETER7;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_DIGITALFILTER_SETTING, filter_section, &value, sizeof(value)));

    CHECKERR (rssiup_val_to_param (SFilterTypeDiscVals, &filterType[0], &value.FilterTypeInChannelA, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_val_to_param (SFilterTypeDiscVals, &filterType[1], &value.FilterTypeInChannelB, VI_ERROR_INV_RESPONSE));

    centerFrequency[0] = GOctaveFilterCenterFreqDiscVals[value.CenterFreqInChanA].value;
    centerFrequency[1] = GOctaveFilterCenterFreqDiscVals[value.CenterFreqInChanB].value;

    filterDelay[0] = value.FilterDelayInChanA / 1000.0;
    filterDelay[1] = value.FilterDelayInChanB / 1000.0;

    filterBiQuads[0] = value.FilterBiQuadsInChanA;
    filterBiQuads[1] = value.FilterBiQuadsInChanB;

    *biquadsCount = value.SectionBiQuadsCnt;

    count = 10 * value.SectionBiQuadsCnt;
/*
    if (normalCoeficients)
        for (idx = 0; idx < count; idx++)
            normalCoeficients[idx] = value.Coefs[idx];

    if (extCoeficients)
        for (idx = 0; idx < count; idx++)
            normalCoeficients[idx] = value.Coefs[idx + count];
*/
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Analyzer User Filter
/* Purpose:  This function sets parameters for user filter.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_SetAnalyzerUserFilter(
    ViSession   instrSession,
    ViInt32     userFilterNo,
    ViInt32     filterType,
    ViInt32     filterOrder,
    ViReal64    filterDelay,
    ViInt32     noofCoefficients,
    ViInt32     _VI_FAR filterCoefficients[]
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    ViInt16                 idx             = 0;
    TUserFilterSetting      value           = {0};

    CHECKERR (rssiup_param_to_val (SUserFilterNbDiscVals, userFilterNo, &value.UserFilterNb, VI_ERROR_PARAMETER2));
    CHECKERR (rssiup_param_to_val (SFilterTypeDiscVals, filterType, &value.FilterType, VI_ERROR_PARAMETER3));

    if (rssiup_invalidViInt32Range (filterOrder, 1, 12))
        return VI_ERROR_PARAMETER4;
    if (rssiup_invalidViReal64Range (filterDelay, 0.0, 65.535))
        return VI_ERROR_PARAMETER5;
    if (rssiup_invalidViInt32Range (noofCoefficients, 26, 310))
        return VI_ERROR_PARAMETER6;

    value.FilterOrder = filterOrder;
    value.FilterDelay = filterDelay * 1000.0;
    
    if (filterCoefficients)
        for (idx = 0; idx < noofCoefficients; idx++)
            value.FilterCoefficients[idx] = filterCoefficients[idx];

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_USERFILTER_SETTING, value.UserFilterNb, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Analyzer User Filter
/* Purpose:  This function returns parameters of user filter.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_GetAnalyzerUserFilter(
    ViSession   instrSession,
    ViInt32     userFilterNo,
    ViPInt32    filterType,
    ViPInt32    filterOrder,
    ViPReal64   filterDelay,
    ViPInt32    noofCoefficients,
    ViInt32     _VI_FAR filterCoefficients[]
)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    ViInt16                 idx             = 0,
                            count           = 0;
    TUserFilterSetting      value           = {0};

    CHECKERR (rssiup_param_to_val (SUserFilterNbDiscVals, userFilterNo, &value.UserFilterNb, VI_ERROR_PARAMETER2));

    if (!filterType)
        return VI_ERROR_PARAMETER3;
    if (!filterOrder)
        return VI_ERROR_PARAMETER4;
    if (!filterDelay)
        return VI_ERROR_PARAMETER5;
    if (!noofCoefficients)
        return VI_ERROR_PARAMETER6;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_USERFILTER_SETTING, value.UserFilterNb, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SFilterTypeDiscVals, filterType, &value.FilterType, VI_ERROR_INV_RESPONSE));

    *filterOrder = value.FilterOrder;
    *filterDelay = value.FilterDelay / 1000.0;

    count = value.FilterOrder * 13 * 2;
    count = (count > 310) ? 310 : count;
    
    *noofCoefficients = count;

    if (filterCoefficients)
        for (idx = 0; idx < count; idx++)
            filterCoefficients[idx] = value.FilterCoefficients[idx];

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analyzer Function State
 * Purpose:  This function selects the analyzer function and state of the
 *           selected function.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalyzerFunctionState (ViSession instrSession,
                                                   ViInt32 channel,
                                                   ViInt32 functionID,
                                                   ViBoolean functionState,
                                                   ViBoolean digitalFilterState)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TAnlSwitchOnOff     value           = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SAnlSwitchOnOffDiscVals, functionID, &value.AnlFunID, VI_ERROR_PARAMETER3));

    if (rssiup_invalidViBooleanRange (functionState))
        return VI_ERROR_PARAMETER4;
    if (rssiup_invalidViBooleanRange (digitalFilterState))
        return VI_ERROR_PARAMETER5;

    /* Crosscheck if the functions can run simultaneously. If =1 means not allowed. */
    {
        TAnlDescription data = {0};
		
        ViUInt16        AnlFunID = value.AnlFunID,
                        i = 0,
                        j = 0;
		ViBoolean       bool1 = VI_FALSE,
		                bool2 = VI_FALSE;

        ViInt32 crossTable[16][17] =
        {
            {/* Peak          */ afPeak,         0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* QPeak         */ afQPeak,        0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* RMS DC        */ afRMSDC,        0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0},
            {/* RMS Sel       */ afRMSSel,       0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* Polarity      */ afPolarity,     0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* FFT           */ afFFTMuTsk,     0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0},
            {/* THD (+N)      */ afTHDpmN,       0,0,0,0,0,1,0,1,1,1,1,0,0,0,1,0},
            {/* DFD           */ afDFDMuTsk,     0,0,0,0,0,1,1,0,1,1,1,0,0,0,0,0},
            {/* MOD Dist      */ afModDist,      0,0,0,0,0,1,1,1,0,1,1,0,0,0,0,0},
            {/* Phase         */ afPhaseMuTsk,   0,0,0,0,0,1,1,1,1,0,1,0,0,0,0,0},
			{/* RMS Sel MuTsk */ afRMSSelMuTsk,  0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,1},
            {/* Sample Freq   */ afDAISamplRate, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* DAI Protocol  */ afDAIProtocol,  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
			{/* RMS Sweep     */ afSinRmsSweep,  0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0},
			{/* THD Sweep     */ afSinThdSweep,  0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0},
			{/* RSM Sweep     */ afSinRSmSweep,  0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0}
        };

        CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB, &data, instrPtr->anlDiscSize));

        for (i = 0; i < 16; i++) /* rows */
            for (j = 1; j < 17; j++) /* columns */
                {
                if (((data.AnlGenerally.FunctionIsOn[crossTable[i][0]][0 /* channel */] == ON) ||
                    (data.AnlGenerally.FunctionIsOn[crossTable[i][0]][1 /* channel */] == ON)) &&
                    (crossTable[j - 1][0] == AnlFunID) &&
                    (functionState == VI_TRUE) &&
                    (crossTable[i][j] == 1))
                    {
                    return RSSIUP_ERROR_SETTINGS_CONFLICT;
                    }
                }
		
		/* Sine generator function can't run simultaneously with Sweep functions */
		CHECKERR (rssiup_GetGeneratorFunctionState (instrSession, RSSIUP_CHA, RSSIUP_GEN_FUNC_SINE, &bool1));
		CHECKERR (rssiup_GetGeneratorFunctionState (instrSession, RSSIUP_CHB, RSSIUP_GEN_FUNC_SINE, &bool2));
		if ((bool1 || bool2) && ((AnlFunID == afSinRmsSweep) || (AnlFunID == afSinThdSweep) || (AnlFunID == afSinRSmSweep)))
			return RSSIUP_ERROR_SETTINGS_CONFLICT;
    }

    if ((functionID == RSSIUP_GEN_FUNC_ALL) && (functionState == VI_TRUE))
        return RSSIUP_ERROR_SETTINGS_CONFLICT;
    
    value.CntOfResults = (instrPtr -> measMode == RSSIUP_MEAS_MODE_IDLE) ? 0 /* no results sent */ :
                         (instrPtr -> measMode == RSSIUP_MEAS_MODE_SINGLE) ? 1 /* one result sent */ : 0xFFFF /* continuous */;

    value.DigFilterOnOff_Unload = (functionState == VI_FALSE) ? 1 /* Digi Filter Unload */ :
        (digitalFilterState == VI_TRUE) ? ON : OFF /* Digital Filter State */;
    value.FunctionStatus = (functionState == VI_TRUE) ? ON : OFF;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
	
	/* NOT NEEDED
	// when any other measurement than RMS Sweep, RMS Selective Sweep, THD Sweep is switched on,
	// then sampleCount (the old value) is set back to 0
	// this is needed when the instrument returns valid/invalid data for sweep measurements
	if (((functionID != RSSIUP_ANL_FUNC_SIN_RMS_SWEEP) || (functionID != RSSIUP_ANL_FUNC_SIN_THD_SWEEP) || 
		(functionID != RSSIUP_ANL_FUNC_SIN_RSM_SWEEP)) && (functionState == VI_TRUE))
		instrPtr->sampleCount = 0;
	*/

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analyzer Function State
 * Purpose:  This function returns state of selected analyzer function.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalyzerFunctionState (ViSession instrSession,
                                                   ViInt32 channel,
                                                   ViInt32 functionID,
                                                   ViPBoolean functionState)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViUInt16            AnlFunID        = 0;
    TAnlDescription     value           = {0};
	pTStatusDataRanges  instrPtr        = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    if (functionID == RSSIUP_ANL_FUNC_ALL)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_param_to_val (SAnlSwitchOnOffDiscVals, functionID, &AnlFunID, VI_ERROR_PARAMETER3));

    if (!functionState)
        return VI_ERROR_PARAMETER4;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB, &value, instrPtr->anlDiscSize));
	*functionState = value.AnlGenerally.FunctionIsOn[AnlFunID][channel - 1];
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Measurement Mode
 * Purpose:  This function selects whether is instrument in continuous or
 *           single measurement mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetMeasurementMode (ViSession instrSession,
                                             ViInt32 measurementMode)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViUInt16            idx             = 0;
    ViUInt16            AnlFunID        = 0;
    ViUInt16            value           = OFF;
	ViUInt16			meas_mode		= ammContMeas;
    TAnlDescription     AnlDescription  = {0};
    TAnlSendNextRes     SendNextResults = {0};
    pTStatusDataRanges  instrPtr        = {0};
	TAnlSwitchOnOff     func_settings   = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    instrPtr -> abortCurrentMeasurement = VI_FALSE;
	
	switch (measurementMode)    
        {
        case RSSIUP_MEAS_MODE_IDLE:
            SendNextResults.CntOfResults = 0; /* no results sent */
            break;
        case RSSIUP_MEAS_MODE_SINGLE:
            SendNextResults.CntOfResults = 1; /* one result sent */
            break;
        case RSSIUP_MEAS_MODE_CONTINUOUS:

            SendNextResults.CntOfResults = 0xFFFF; /* continuous */
            break;
        default:
            return VI_ERROR_PARAMETER2;
        }

	instrPtr -> measMode = measurementMode;
	instrPtr -> cachedData = VI_FALSE;
	
	/* Get Analyzer Description */
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB, &AnlDescription, instrPtr->anlDiscSize));
	
	if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
	{
		// all functions have to be switched off before changing the meas mode
		func_settings.AnlFunID = afAllAnlFuns;
		func_settings.FunctionStatus = OFF;
		func_settings.CntOfResults = 0xFFFF;
		func_settings.DigFilterOnOff_Unload = 1;
    
		CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, RSSIUP_CHAB, &func_settings, sizeof(func_settings)));
	    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

		// have to switch to contiuous mode before setting the SendNextResults
	    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_MEAS_MODE, ChAB, &meas_mode, sizeof(meas_mode)));
		CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
	}
	
    for (idx = 0; SAnlSwitchOnOffDiscVals[idx].opt; idx++)
    {
        AnlFunID = SAnlSwitchOnOffDiscVals[idx].value;

        if (AnlFunID != afAllAnlFuns)
        {
            SendNextResults.AnlFunID = AnlFunID;

			if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
			{
				if ((AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1] == ON) &&
					(AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1] == OFF))
				{
					func_settings.FunctionStatus = AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1];
					func_settings.DigFilterOnOff_Unload = AnlDescription.AnlGenerally.DigitalFilterIsOn[ChA - 1];
	    			func_settings.AnlFunID = AnlFunID;
					func_settings.CntOfResults = (measurementMode == RSSIUP_MEAS_MODE_IDLE) ? 0 /* no results sent */ :
		                         				 (measurementMode == RSSIUP_MEAS_MODE_SINGLE) ? 1 /* one result sent */ : 0xFFFF /* continuous */;
			
					CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, RSSIUP_CHA, &func_settings, sizeof(func_settings)));
				    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
				}
			
				if ((AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1] == ON) &&
					(AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1] == OFF))
				{
					func_settings.FunctionStatus = AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1];
					func_settings.DigFilterOnOff_Unload = AnlDescription.AnlGenerally.DigitalFilterIsOn[ChB - 1];
	    			func_settings.AnlFunID = AnlFunID;
					func_settings.CntOfResults = (measurementMode == RSSIUP_MEAS_MODE_IDLE) ? 0 /* no results sent */ :
		                         				 (measurementMode == RSSIUP_MEAS_MODE_SINGLE) ? 1 /* one result sent */ : 0xFFFF /* continuous */;
			
					CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, RSSIUP_CHB, &func_settings, sizeof(func_settings)));
				    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
				}
				if ((AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1] == ON) &&
					(AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1] == ON))
				{
					func_settings.FunctionStatus = AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1];
					func_settings.DigFilterOnOff_Unload = AnlDescription.AnlGenerally.DigitalFilterIsOn[ChA - 1];
	    			func_settings.AnlFunID = AnlFunID;
					func_settings.CntOfResults = (measurementMode == RSSIUP_MEAS_MODE_IDLE) ? 0 /* no results sent */ :
		                         				 (measurementMode == RSSIUP_MEAS_MODE_SINGLE) ? 1 /* one result sent */ : 0xFFFF /* continuous */;
			
					CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, RSSIUP_CHAB, &func_settings, sizeof(func_settings)));
				    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
				}
			}

            /* Avoid to set digital functions in analog mode */
            if (((AnlDescription.AnlGenerally.DevSelector == dsA49) ||
                (AnlDescription.AnlGenerally.DevSelector == dsA98) ||
                (AnlDescription.AnlGenerally.DevSelector == dsA195)) &&
                ((AnlFunID == afDAISamplRate) ||
                (AnlFunID == afDAIProtocol)))
            {
                /* Do nothing */
            }
            else
            {
                /* DAI Sample Rate and DAI Protocol is not possible to use here */
                if ((AnlFunID == afDAISamplRate) || (AnlFunID == afDAIProtocol))
                {
                    /* Do nothing */
                }
                else
                {
                    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
                        ChA, &SendNextResults, sizeof(SendNextResults)));

                    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
                        ChB, &SendNextResults, sizeof(SendNextResults)));
					
					CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
                }
            }
        }
    }

	if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
	{
		// all functions have to be switched off before changing the meas mode
		func_settings.AnlFunID = afAllAnlFuns;
		func_settings.FunctionStatus = OFF;
		func_settings.CntOfResults = 0xFFFF;
		func_settings.DigFilterOnOff_Unload = 1;
    
		CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, RSSIUP_CHAB, &func_settings, sizeof(func_settings)));
	    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

		// set the selected trigger mode
		if (measurementMode != RSSIUP_MEAS_MODE_IDLE)
		{
			meas_mode = (measurementMode == RSSIUP_MEAS_MODE_SINGLE) ? ammTrigMeas : ammContMeas;

			/* set the trigger mode */
		    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_MEAS_MODE, ChAB, &meas_mode, sizeof(meas_mode)));
		
			CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
		}
	
		// switch on all the functions again like at the beginning
		for (idx = 0; SAnlSwitchOnOffDiscVals[idx].opt; idx++)
	    {
	        AnlFunID = SAnlSwitchOnOffDiscVals[idx].value;

	        if (AnlFunID != afAllAnlFuns)
	        {
	            if ((AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1] == ON) &&
					(AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1] == OFF))
				{
					func_settings.FunctionStatus = AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1];
					func_settings.DigFilterOnOff_Unload = AnlDescription.AnlGenerally.DigitalFilterIsOn[ChA - 1];
	    			func_settings.AnlFunID = AnlFunID;
					func_settings.CntOfResults = (measurementMode == RSSIUP_MEAS_MODE_IDLE) ? 0 /* no results sent */ :
		                         				 (measurementMode == RSSIUP_MEAS_MODE_SINGLE) ? 1 /* one result sent */ : 0xFFFF /* continuous */;
			
					CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, RSSIUP_CHA, &func_settings, sizeof(func_settings)));
				    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
				}
			
				if ((AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1] == ON) &&
					(AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1] == OFF))
				{
					func_settings.FunctionStatus = AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1];
					func_settings.DigFilterOnOff_Unload = AnlDescription.AnlGenerally.DigitalFilterIsOn[ChB - 1];
	    			func_settings.AnlFunID = AnlFunID;
					func_settings.CntOfResults = (measurementMode == RSSIUP_MEAS_MODE_IDLE) ? 0 /* no results sent */ :
		                         				 (measurementMode == RSSIUP_MEAS_MODE_SINGLE) ? 1 /* one result sent */ : 0xFFFF /* continuous */;
			
					CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, RSSIUP_CHB, &func_settings, sizeof(func_settings)));
				    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
				}
				if ((AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1] == ON) &&
					(AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1] == ON))
				{
					func_settings.FunctionStatus = AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1];
					func_settings.DigFilterOnOff_Unload = AnlDescription.AnlGenerally.DigitalFilterIsOn[ChA - 1];
	    			func_settings.AnlFunID = AnlFunID;
					func_settings.CntOfResults = (measurementMode == RSSIUP_MEAS_MODE_IDLE) ? 0 /* no results sent */ :
		                         				 (measurementMode == RSSIUP_MEAS_MODE_SINGLE) ? 1 /* one result sent */ : 0xFFFF /* continuous */;
			
					CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, RSSIUP_CHAB, &func_settings, sizeof(func_settings)));
				    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
				}
			}
		}
	}

	/* Enable (Disable) flag for reading of results from device and DSP. */
    value = (measurementMode == RSSIUP_MEAS_MODE_IDLE) ? OFF : ON;

    if (instrPtr->fwVersion - 1.2 < 0.00001) /* do only with FW versions smaller than 1.2 */
	{
		CHECKERR (rssiup_DSI_Set (instrSession, ENABLE_RESULT_LOOP, ChAB, &value, sizeof (value)));
		CHECKERR (rssiup_DSI_Set (instrSession, ENABLE_RESULTS_READING, ChAB, &value, sizeof (value)));
	}

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Measurement Mode
 * Purpose:  This function returns whether is instrument in continuous or
 *           single measurement mode.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetMeasurementMode (ViSession instrSession,
                                             ViPInt32 measurementMode)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};
	TAnlMeasMode        value			= {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!measurementMode)
        return VI_ERROR_PARAMETER2;

    if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
	{
		if (instrPtr -> measMode != RSSIUP_MEAS_MODE_IDLE)
		{
			CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AANLHW_MEAS_MODE,
		                        ChAB, &value, sizeof(value)));

			CHECKERR (rssiup_val_to_param (SAnlMeasModeDiscVals, measurementMode, &value, VI_ERROR_INV_RESPONSE));
		
			// 
			if (*measurementMode == ammContMeas) *measurementMode = RSSIUP_MEAS_MODE_CONTINUOUS;
			else if (*measurementMode == ammTrigMeas) *measurementMode = RSSIUP_MEAS_MODE_SINGLE;

			CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
		}
		else
		*measurementMode = instrPtr -> measMode;			
	}
	else
		*measurementMode = instrPtr -> measMode;

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Trigger State
 * Purpose:  This function returns the trigger state.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetTriggerState (ViSession instrSession,
                                          ViInt32 channel, ViInt32 *triggerState)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TAnlFunMeasState	value			= {0};
    pTStatusDataRanges  instrPtr        = {0};
    TAnlSwitchOnOff     funcID          = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);
	
	CHECKERR (rssiup_param_to_val (SAnlSwitchOnOffDiscVals, channel, &funcID.AnlFunID, VI_ERROR_PARAMETER3));

	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AANLHW_FUN_TRIG_MEAS_STATE,
                        funcID.AnlFunID, &value, sizeof(value)));
    
	CHECKERR (rssiup_val_to_param (SAnlFunMeasStateDiscVals, triggerState, &value, VI_ERROR_INV_RESPONSE));
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
		 
	return rssiup_status;    
}

/*****************************************************************************
 * Function: Set Trigger Source
 * Purpose:  This function selects the trigger source.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetTriggerSource (ViSession instrSession,
                                           ViInt32 channel,
										   ViInt32 functionID,
	                                       ViInt32 triggerSource)
{
    ViStatus            rssiup_status   = VI_SUCCESS;    
	ViInt32             measMode        = 0;
	pTStatusDataRanges  instrPtr        = {0};
	TAnlDescription     AnlDescription  = {0};
	ViUInt16            idx             = 0;
	ViUInt16            digital_filter[2] = {OFF,OFF};
    ViUInt16            AnlFunID        = 0;
    TAnlSwitchOnOff     Value_A         = {0};
	TAnlSwitchOnOff     Value_B         = {0};
	TAnlSwitchOnOff 	value  			= {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

	CHECKERR (rssiup_param_to_val (SAnlSwitchOnOffDiscVals, functionID, &value.AnlFunID, VI_ERROR_PARAMETER3));
		
	/* Crosscheck if the functions can run simultaneously. If =1 means not allowed. */
    {
        TAnlDescription data = {0};
		
        ViUInt16        AnlFunID = value.AnlFunID,
                        i = 0,
                        j = 0;
		ViBoolean       bool1 = VI_FALSE,
		                bool2 = VI_FALSE;

        ViInt32 crossTable[16][17] =
        {
            {/* Peak          */ afPeak,         0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* QPeak         */ afQPeak,        0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* RMS DC        */ afRMSDC,        0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0},
            {/* RMS Sel       */ afRMSSel,       0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* Polarity      */ afPolarity,     0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* FFT           */ afFFTMuTsk,     0,0,0,0,0,0,1,1,1,1,1,0,0,0,0,0},
            {/* THD (+N)      */ afTHDpmN,       0,0,0,0,0,1,0,1,1,1,1,0,0,0,1,0},
            {/* DFD           */ afDFDMuTsk,     0,0,0,0,0,1,1,0,1,1,1,0,0,0,0,0},
            {/* MOD Dist      */ afModDist,      0,0,0,0,0,1,1,1,0,1,1,0,0,0,0,0},
            {/* Phase         */ afPhaseMuTsk,   0,0,0,0,0,1,1,1,1,0,1,0,0,0,0,0},
			{/* RMS Sel MuTsk */ afRMSSelMuTsk,  0,0,0,0,0,1,1,1,1,1,0,0,0,0,0,1},
            {/* Sample Freq   */ afDAISamplRate, 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
            {/* DAI Protocol  */ afDAIProtocol,  0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0},
			{/* RMS Sweep     */ afSinRmsSweep,  0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0},
			{/* THD Sweep     */ afSinThdSweep,  0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0},
			{/* RSM Sweep     */ afSinRSmSweep,  0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0}
        };

        CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB, &data, instrPtr->anlDiscSize));

        for (i = 0; i < 16; i++) /* rows */
            for (j = 1; j < 17; j++) /* columns */
                {
                if (((data.AnlGenerally.FunctionIsOn[crossTable[i][0]][0 /* channel */] == ON) ||
                    (data.AnlGenerally.FunctionIsOn[crossTable[i][0]][1 /* channel */] == ON)) &&
                    (crossTable[j - 1][0] == AnlFunID) &&
                    (crossTable[i][j] == 1))
                    {
                    return RSSIUP_ERROR_SETTINGS_CONFLICT;
                    }
                }
		
		/* Sine generator function can't run simultaneously with Sweep functions */
		CHECKERR (rssiup_GetGeneratorFunctionState (instrSession, RSSIUP_CHA, RSSIUP_GEN_FUNC_SINE, &bool1));
		CHECKERR (rssiup_GetGeneratorFunctionState (instrSession, RSSIUP_CHB, RSSIUP_GEN_FUNC_SINE, &bool2));
		if ((bool1 || bool2) && ((AnlFunID == afSinRmsSweep) || (AnlFunID == afSinThdSweep) || (AnlFunID == afSinRSmSweep)))
			return RSSIUP_ERROR_SETTINGS_CONFLICT;
    }
	
    CHECKERR (rssiup_GetMeasurementMode (instrSession, &measMode));
	
	if (measMode == RSSIUP_MEAS_MODE_SINGLE)
    {		
		CHECKERR (rssiup_param_to_val (SAnlSwitchOnOffDiscVals, functionID, &Value_A.AnlFunID, VI_ERROR_PARAMETER3));
		CHECKERR (rssiup_param_to_val (SAnlSwitchOnOffDiscVals, functionID, &Value_B.AnlFunID, VI_ERROR_PARAMETER3));

		/* Get Analyzer Description */
        CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
            &AnlDescription, instrPtr->anlDiscSize));

		for (idx = 0; SAnlSwitchOnOffDiscVals[idx].opt; idx++)  
		{
			AnlFunID = SAnlSwitchOnOffDiscVals[idx].value;
            
            if (AnlFunID == Value_A.AnlFunID)
			{	
				/* get digital filter state */
				digital_filter[0] = AnlDescription.AnlGenerally.DigitalFilterIsOn[ChA-1];
				digital_filter[1] = AnlDescription.AnlGenerally.DigitalFilterIsOn[ChB-1];
				
				/* store back to the structure */
				Value_A.DigFilterOnOff_Unload = digital_filter[0];
				Value_B.DigFilterOnOff_Unload = digital_filter[1];
			}
		}
		/* triggered measurement mode */ 
		Value_A.FunctionStatus = 2;
		Value_B.FunctionStatus = 2; 
					
		switch (triggerSource)    
	    {
	        case RSSIUP_TRIGGER_SOURCE_IMMEDIATE:
				
				Value_A.CntOfResults = 0;
				Value_B.CntOfResults = 0;
    			
	            break;
	        case RSSIUP_TRIGGER_SOURCE_BUS:
    
				Value_A.CntOfResults = 1;
				Value_B.CntOfResults = 1;
    			
	            break;
	        default:
	            return VI_ERROR_PARAMETER4;
	    }
		
		instrPtr -> triggerSource = triggerSource;
		
		switch (channel)
		{
			case ChAB:	
				CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, ChAB, &Value_A, sizeof(Value_A)));
				break;
			case ChA:	
				CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, ChA, &Value_A, sizeof(Value_A)));
				break;
			case ChB:	
				CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, ChB, &Value_B, sizeof(Value_B)));
				break;
		}
	}
	
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Trigger Source
 * Purpose:  This function returns the trigger source.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetTriggerSource (ViSession instrSession,
                                           ViInt32 *triggerSource)
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!triggerSource)
        return VI_ERROR_PARAMETER2;

    *triggerSource = instrPtr -> triggerSource;

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Set Sweep Control
 * Purpose:  This function sets the analyzer function and the sweep step.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetSweepControl (ViSession instrSession,
                                          ViInt32 functionID,
                                          ViInt32 controlStep)
{
	ViStatus    		rssiup_status   = VI_SUCCESS;
	pTStatusDataRanges  instrPtr        = {0};
    TAnlCtrlStep     	value      		= {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    CHECKERR (rssiup_param_to_val (SAnlSwitchOnOffDiscVals, functionID, &value.AnlFunID, VI_ERROR_PARAMETER2));

    if (rssiup_invalidViInt32Range (controlStep, -3, 32752))
        return VI_ERROR_PARAMETER3;

    value.CtrlStep = controlStep;
									 
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_CtrlStep, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Start Measurement
 * Purpose:  This function starts a single measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_StartMeasurement (ViSession instrSession){
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViUInt16            idx             = 0;
    ViUInt16            AnlFunID        = 0;
    ViUInt16            measIdCnt       = 0;
    ViUInt16            value           = ON;
//    TAnlDescription     AnlDescription  = {0};
    TAnlSendNextRes     SendNextResults = {0};
    pTStatusDataRanges  instrPtr        = {0};
	TAnlSwitchOnOff     Value           = {0};

	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);
	
    instrPtr->abortCurrentMeasurement = VI_FALSE;
	instrPtr->cachedData = VI_FALSE;
	for (idx = 0; idx < ANLFUN_CNT; idx++)
	{
		instrPtr->enabledMeasIdCnt = 0;
		instrPtr->enabledMeasId[idx] = 0;
		instrPtr->enabledMeasIdDataValid[idx] = OFF;
	}

    if (instrPtr -> measMode != RSSIUP_MEAS_MODE_IDLE)
    {
        /* Get Analyzer Description */
        CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));

        for (idx = 0; SAnlSwitchOnOffDiscVals[idx].opt; idx++)
        {
            AnlFunID = SAnlSwitchOnOffDiscVals[idx].value;
            
            if (AnlFunID != afAllAnlFuns)
            {
                SendNextResults.AnlFunID = AnlFunID;
        
                /* Avoid to set digital functions in analog mode */
                if (((instrPtr -> AnlDescription.AnlGenerally.DevSelector == dsA49) ||
                    (instrPtr -> AnlDescription.AnlGenerally.DevSelector == dsA98) ||
                    (instrPtr -> AnlDescription.AnlGenerally.DevSelector == dsA195)) &&
                    ((AnlFunID == afDAISamplRate) ||
                    (AnlFunID == afDAIProtocol)))
                {
                    /* Do nothing */
                }
                else
                {
                    if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
					{
						/* Sending Bus Trigger Command to both channels - ChAB */
					
						if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1] == ON) ||
						    (instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1] == ON))
						{
						
							if ((instrPtr -> measMode == RSSIUP_MEAS_MODE_SINGLE) &&
								(instrPtr -> triggerSource == RSSIUP_TRIGGER_SOURCE_BUS))
							{
								Value.AnlFunID = AnlFunID;
								Value.FunctionStatus = 3; /* send bus trigger command */
								Value.DigFilterOnOff_Unload = ON;
								Value.CntOfResults = 0;
								
								CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, ChAB, &Value, sizeof(Value)));	
							
								CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
							}
						
	                    }
					}

					/* ChA */
					
					if (instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1] == ON)
                    {
                        /* Update list of enabled functions */
                        instrPtr -> enabledMeasId[measIdCnt] = AnlFunID;
                        measIdCnt++;
                        /* --- */
                        SendNextResults.CntOfResults = (instrPtr -> measMode == RSSIUP_MEAS_MODE_SINGLE) ?
                            1 /* One result sent */ : 0xFFFF /* Continuous */;

                        /* DAI Sample Rate and DAI Protocol is not possible to use here */
                        if ((AnlFunID == afDAISamplRate) || (AnlFunID == afDAIProtocol))
                        {
                            /* Do nothing */
                        }
                        else
                        {
							if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
							{
								if (instrPtr -> measMode == RSSIUP_MEAS_MODE_CONTINUOUS)
								{
									CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
		                                ChA, &SendNextResults, sizeof(SendNextResults)));
						
									CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
								}
							}
							else
							{
								CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
                                ChA, &SendNextResults, sizeof(SendNextResults)));
			
								CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
							}
							
                        }

//#if 1 // Patchwork ... first results of selected measurements are discarted (delete when not needed!)
						
						/* new handling - version dependent - older version use the old patchwork */
						if (instrPtr->fwVersion - 1.2 < 0.00001) /* do only with FW versions smaller than 1.2 */
						{

	                        if ((instrPtr -> measMode == RSSIUP_MEAS_MODE_SINGLE) && 
	                            ((AnlFunID == afRMSDC) || (AnlFunID == afRMSSel) ||
	                             (AnlFunID == afDAISamplRate) || (AnlFunID == afDAIProtocol)))
	                        {
	                            if (AnlFunID == afRMSDC)
	                            {
	                                ViInt32 measId[] = {MEAS_RMSDC};

	                                CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
	                            }

	                            if (AnlFunID == afRMSSel)
	                            {
	                                ViInt32 measId[] = {MEAS_RMSSEL};

	                                CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
	                            }

	                            /* DAI Sample Rate and DAI Protocol is not possible to use here */
	                            if ((AnlFunID == afDAISamplRate) || (AnlFunID == afDAIProtocol))
	                            {
	                                /* Do nothing */
	                            }
	                            else
	                            {
	                                CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
	                                    ChA, &SendNextResults, sizeof(SendNextResults)));
	                            }
	                        }
						}
                    }
                    else
                    {
#if 0 /* Excluded */
                        SendNextResults.CntOfResults = 0; /* Results not sent */

                        CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
                            ChA, &SendNextResults, sizeof(SendNextResults)));
#endif
                    }

                    /* ChB */

                    if (instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChB - 1] == ON)
                    {
                        if (instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[AnlFunID][ChA - 1] != ON)
						{
							instrPtr -> enabledMeasId[measIdCnt] = AnlFunID;
	                        measIdCnt++;
						}
                        /* --- */
                        SendNextResults.CntOfResults = (instrPtr -> measMode == RSSIUP_MEAS_MODE_SINGLE) ?
                            1 /* One result sent */ : 0xFFFF /* Continuous */;

                        /* DAI Sample Rate and DAI Protocol is not possible to use here */
                        if ((AnlFunID == afDAISamplRate) || (AnlFunID == afDAIProtocol))
                        {
                            /* Do nothing */
                        }
                        else
                        {
                            if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
							{
								if (instrPtr -> measMode == RSSIUP_MEAS_MODE_CONTINUOUS)
								{
									CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
		                            	ChB, &SendNextResults, sizeof(SendNextResults)));
							
									CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
								}
							}
							else
							{
								CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
	                            	ChB, &SendNextResults, sizeof(SendNextResults)));
						
								CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
							}
                        }

//#if 1 // Patchwork ... first results of selected measurements are discarted (delete when not needed!)
						if (instrPtr->fwVersion - 1.2 < 0.00001) /* do only with FW versions smaller than 1.2 */
						{
	                        if ((instrPtr -> measMode == RSSIUP_MEAS_MODE_SINGLE) && 
	                            ((AnlFunID == afRMSDC) || (AnlFunID == afRMSSel) ||
	                             (AnlFunID == afDAISamplRate) || (AnlFunID == afDAIProtocol)))
	                        {
	                            if (AnlFunID == afRMSDC)
	                            {
	                                ViInt32 measId[] = {MEAS_RMSDC};

	                                CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
	                            }

	                            if (AnlFunID == afRMSSel)
	                            {
	                                ViInt32 measId[] = {MEAS_RMSSEL};

	                                CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
	                            }

	                            /* DAI Sample Rate and DAI Protocol is not possible to use here */
	                            if ((AnlFunID == afDAISamplRate) || (AnlFunID == afDAIProtocol))
	                            {
	                                /* Do nothing */
	                            }
	                            else
	                            {
	                                CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
	                                    ChB, &SendNextResults, sizeof(SendNextResults)));
	                            }
	                        }
						}
                    }
                    else
                    {
#if 0 /* Excluded */
                        SendNextResults.CntOfResults = 0; /* Results not sent */

                        CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
                            ChB, &SendNextResults, sizeof(SendNextResults)));
#endif
                    }
                }
            }
        }

        instrPtr -> enabledMeasIdCnt = measIdCnt;

	    if (instrPtr->fwVersion - 1.2 < 0.00001) /* do only with FW versions smaller than 1.2 */
		{
			/* Enable flag for reading of results from device and DSP. */
	        CHECKERR (rssiup_DSI_Set (instrSession, ENABLE_RESULT_LOOP, ChAB, &value, sizeof (value)));
	        CHECKERR (rssiup_DSI_Set (instrSession, ENABLE_RESULTS_READING, ChAB, &value, sizeof (value)));
		}
    }

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Abort Measurement
 * Purpose:  This function aborts a running measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_AbortMeasurement (ViSession instrSession)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViUInt16            idx             = 0;
    ViUInt16            AnlFunID        = 0;
    ViUInt16            value           = OFF;
    TAnlSendNextRes     SendNextResults = {0};
    TAnlDescription     AnlDescription  = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    instrPtr -> abortCurrentMeasurement = VI_TRUE;

    /* Get Analyzer Description */
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
        &AnlDescription, instrPtr->anlDiscSize));

    for (idx = 0; SAnlSwitchOnOffDiscVals[idx].opt; idx++)
    {
        AnlFunID = SAnlSwitchOnOffDiscVals[idx].value;
        SendNextResults.AnlFunID = AnlFunID;

        if (AnlFunID != afAllAnlFuns)
        {
            /* Avoid to set digital functions in analog mode */
            if (((AnlDescription.AnlGenerally.DevSelector == dsA49) ||
                (AnlDescription.AnlGenerally.DevSelector == dsA98) ||
                (AnlDescription.AnlGenerally.DevSelector == dsA195)) &&
                ((AnlFunID == afDAISamplRate) ||
                (AnlFunID == afDAIProtocol)))
            {
                /* Do nothing */
            }
            else
            {
                /* ChAB */
                SendNextResults.CntOfResults = 0; /* Results not sent */

                /* DAI Sample Rate and DAI Protocol is not possible to use here */
                if ((AnlFunID == afDAISamplRate) || (AnlFunID == afDAIProtocol))
                {
                    /* Do nothing */
                }
                else
                {
                    if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
					{
						if (instrPtr -> measMode == RSSIUP_MEAS_MODE_CONTINUOUS)
						{
							CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
		                        ChA, &SendNextResults, sizeof(SendNextResults)));

		                    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
		                        ChB, &SendNextResults, sizeof(SendNextResults)));
						}
					}
					else
					{
						CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
	                        ChA, &SendNextResults, sizeof(SendNextResults)));

	                    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_SendNextResults,
	                        ChB, &SendNextResults, sizeof(SendNextResults)));
					}	
                }
            }
        }
    }

	if (instrPtr->fwVersion - 1.2 < 0.00001) /* do only with FW versions smaller than 1.2 */
	{
		/* Disable flag for reading of results from device and DSP. */
	    CHECKERR (rssiup_DSI_Set (instrSession, ENABLE_RESULT_LOOP, ChAB, &value, sizeof (value)));
	    CHECKERR (rssiup_DSI_Set (instrSession, ENABLE_RESULTS_READING, ChAB, &value, sizeof (value)));
	}
	
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Start Measurement and Wait for OPC
 * Purpose:  This function starts a single measurement and waits for
 *           operation completed (OPC) before returning the status code.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_StartMeasurementWaitOPC (ViSession instrSession,
                                                  ViInt32 timeout)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};
    ViInt32             old_timeout     = 0;
	ViInt32				idx, i   		= 0;
	ViBoolean			end_loop        = VI_FALSE;
	ViBoolean			opc				= VI_FALSE;
	ViInt32				measId[ANLFUN_CNT]  = {0};
	ViUInt16			stored			= OFF;
	clock_t             start_time      = 0;
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    instrPtr -> abortCurrentMeasurement = VI_FALSE;

    GOCHECKERR (SiGetAttribute (instrSession, SI_ATTR_TMO_VALUE, &old_timeout));
    GOCHECKERR (SiSetAttribute (instrSession, SI_ATTR_TMO_VALUE, timeout));
	
	/* NOT NEEDED
	instrPtr->oldTimeout = timeout;
	*/

    if (instrPtr -> measMode == RSSIUP_MEAS_MODE_SINGLE)
    {
        GOCHECKERR (rssiup_StartMeasurement (instrSession));
		
		if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
		{
			start_time = clock();

			// check if all enabled measurement functions have finished
			do
			{
				//ProcessSystemEvents ();
				GOCHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
				
				/* Exit when timeout elapsed */
	            if ((((double)(clock() - start_time))/(double)CLOCKS_PER_SEC) > (timeout / 1000))
	            {
	                rssiup_status = SI_ERROR_TMO;

	                goto ERROR;
	            }
			
				end_loop = VI_TRUE;
			
				for (i = 0; i < instrPtr -> enabledMeasIdCnt; i++)
				{
					if (instrPtr->enabledMeasIdDataValid[instrPtr->enabledMeasId[i]] != ON)
					{	
						opc = VI_FALSE;
						rssiup_delay (0.005);
					}
					else
						opc = VI_TRUE;
				
					if (opc == VI_FALSE) end_loop = VI_FALSE;
				}
			} while (end_loop == VI_FALSE);
		
			// read measurement data from all enabled function
			{
				TGetModDistSetting           get_MOD_DIST    = {0};
				TGetDFDMuTskSetting          get_DFD		 = {0};
				TGetTHDpmNSetting            get_THD		 = {0};
				TGetRMSSelMuTskNoChSetting   get_RMSSelMuTsk = {0};
				
				static TIntValPair function[] =
	            {
	                {MEAS_PEAK,                   afPeak},
	                {MEAS_QPEAK,                  afQPeak},
	                {MEAS_RMSDC,                  afRMSDC},
	                {MEAS_RMSSEL,                 afRMSSel},
	                {MEAS_THDN,                   afTHDpmN},
	                {MEAS_THDN_POST_FFT,          afTHDpmN},
	                /*{MEAS_THDN_REDUCED_FFT,       afTHDpmN},*/
	                {MEAS_PHASE,                  afPhaseMuTsk},
	                {MEAS_PHASE_POST_FFT,         afPhaseMuTsk},
	                /*{MEAS_PHASE_REDUCED_FFT,      afPhaseMuTsk},*/
	                {MEAS_DFD,                    afDFDMuTsk},
	                {MEAS_DFD_POST_FFT,           afDFDMuTsk},
	                /*{MEAS_DFD_REDUCED_FFT,        afDFDMuTsk},*/
	                {MEAS_MOD_DIST,               afModDist},
	                {MEAS_MOD_DIST_POST_FFT,      afModDist},
	                /*{MEAS_MOD_DIST_REDUCED_FFT,   afModDist},*/
	                {MEAS_FFT,                    afFFTMuTsk},
	                /*{MEAS_FFT_REDUCED,            afFFTMuTsk},*/
	                {MEAS_DAI_SAMPLING_FREQUENCY, afDAISamplRate},
	                {MEAS_DAI_PROTOCOL,           afDAIProtocol},
					{MEAS_RMSSEL_MUTSK,           afRMSSelMuTsk},
					{MEAS_RMSSEL_MUTSK_FFT,       afRMSSelMuTsk},
					/*{MEAS_RMSSEL_MUTSK_REDUCED_FFT, afRMSSelMuTsk},*/
					{MEAS_RMS_SWEEP,              afSinRmsSweep},
					{MEAS_THD_SWEEP,              afSinThdSweep},
					{MEAS_RMS_SELECTIVE_SWEEP,    afSinRSmSweep},
					{0, NULL}	
	            };
			
				for (i = 0; function[i].intVal; i++)
				{
					if (instrPtr->enabledMeasId[i] == afTHDpmN)
					{
						GOCHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_THDpmN_SETTING, ChAB, &get_THD, sizeof(get_THD)));
						break;
					}
					if (instrPtr->enabledMeasId[i] == afDFDMuTsk)
					{
						GOCHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_DFDMuTsk_SETTING, ChAB, &get_DFD, sizeof(get_DFD)));
						break;
					}
					if (instrPtr->enabledMeasId[i] == afModDist)
					{
						GOCHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_ModDist_SETTING, ChAB, &get_MOD_DIST, sizeof(get_MOD_DIST)));
						break;
					}
					if (instrPtr->enabledMeasId[i] == afRMSSelMuTsk)
					{
						GOCHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_RMSSEL_MuTsk_NO_CHAN_SETTING, ChAB, &get_RMSSelMuTsk, sizeof(get_RMSSelMuTsk)));
						break;
					}
				}
				
				for (i = 0; i < instrPtr -> enabledMeasIdCnt; i++)
				{
					for (idx = 0; function[idx].intName; idx++)
					{
			            if ((function[idx].intName == instrPtr->enabledMeasId[i]) && (stored == OFF))
						{
							if (((get_DFD.PostFFTOn == ON) && (instrPtr->enabledMeasId[i] == afDFDMuTsk)) || 
								((get_THD.PostFFTOn == ON) && (instrPtr->enabledMeasId[i] == afTHDpmN)) || 
								((get_MOD_DIST.PostFFTOn == ON) && (instrPtr->enabledMeasId[i] == afModDist)) ||
								((get_RMSSelMuTsk.PostFFTOn == ON) && (instrPtr->enabledMeasId[i] == afRMSSelMuTsk)))
							{
								idx++;
								measId[i] = function[idx].intVal;
								stored = ON;
							}
							else
							{
								measId[i] = function[idx].intVal;
								stored = ON;
							}
						}
					}
					stored = OFF;
				}
			}
		
			// left ouf for performance
			//GOCHECKERR (rssiup_clearAnalyzerFunctionResults(instrSession));
			
			GOCHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, instrPtr -> enabledMeasIdCnt));
		
			// store all measured data into cache
			instrPtr->cachedData = VI_TRUE;
		}
	}

ERROR:

    SiSetAttribute (instrSession, SI_ATTR_TMO_VALUE, old_timeout);
	
    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analyzer Device Selector
 * Purpose:  This function selects input device and sampling frequency of the
 *           analyzer.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalyzerDeviceSelector (ViSession instrSession,
                                                    ViInt32 device)
{
    ViStatus    rssiup_status       = VI_SUCCESS;
    ViUInt16    value               = 0;
    pTStatusDataRanges  instrPtr    = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    CHECKERR (rssiup_param_to_val (SAnlDevSelectorDiscVals, device, &value, VI_ERROR_PARAMETER2));
    /* Switch all functions to off */
    CHECKERR (rssiup_SetAnalyzerFunctionState (instrSession, RSSIUP_CHAB, RSSIUP_ANL_FUNC_ALL, VI_FALSE, VI_FALSE));

    /* --- */

    if ((value == dsA49) || (value == dsA98) || (value == dsA195))
        {
        instrPtr -> analyzerMode = RSSIUP_ANALYZER_MODE_ANALOG;
        }
    else
        {
        instrPtr -> analyzerMode = RSSIUP_ANALYZER_MODE_DIGITAL;
        }

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLHW_DEVICE_SELECTOR, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analyzer Device Selector
 * Purpose:  This function returns input device and sampling frequency of the
 *           analyzer.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalyzerDeviceSelector (ViSession instrSession,
                                                    ViPInt32 device)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViUInt16            value           = 0;
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!device)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLHW_DEVICE_SELECTOR, ChAB, &value, sizeof(value)));

    if ((value == dsA49) || (value == dsA98) || (value == dsA195))
        {
        instrPtr -> analyzerMode = RSSIUP_ANALYZER_MODE_ANALOG;
        }
    else
        {
        instrPtr -> analyzerMode = RSSIUP_ANALYZER_MODE_DIGITAL;
        }

    CHECKERR (rssiup_val_to_param (SAnlDevSelectorDiscVals, device, &value, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Analyzer Input
 * Purpose:  This function selects the analyzer input.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalogAnalyzerInput (ViSession instrSession,
                                                 ViInt32 channel,
                                                 ViInt32 analyzerInput)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TAAnlInput  value           = 0;

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SAAnlInputDiscVals, analyzerInput, &value, VI_ERROR_PARAMETER3));

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_INPUT, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Analyzer Input
 * Purpose:  This function returns the analyzer input.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalogAnalyzerInput (ViSession instrSession,
                                                 ViInt32 channel,
                                                 ViPInt32 analyzerInput)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TAAnlInput  value           = 0;

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!analyzerInput)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AANLHW_INPUT, channel, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAAnlInputDiscVals, analyzerInput, &value, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Analyzer Coupling
 * Purpose:  This function selects the analyzer input coupling. AC or DC
 *           coupling can be selected.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalogAnalyzerCoupling (ViSession instrSession,
                                                    /* ViInt32 channel, */
                                                    ViInt32 coupling)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TAAnlCoupling   value           = 0;
/*
    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
*/
    CHECKERR (rssiup_param_to_val (SAAnlCouplingDiscVals, coupling, &value, VI_ERROR_PARAMETER3));

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_COUPLING, ChAB /* channel */, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Analyzer Coupling
 * Purpose:  This function returns the analyzer input coupling.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalogAnalyzerCoupling (ViSession instrSession,
                                                    /* ViInt32 channel, */
                                                    ViPInt32 coupling)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TAAnlCoupling   value           = 0;
/*
    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
*/
    if (!coupling)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AANLHW_COUPLING, ChA /* channel */, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAAnlCouplingDiscVals, coupling, &value, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Analyzer High Pass Filter
 * Purpose:  This function sets state of the analog analyzer input High Pass
 *           Filter On or Off.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_SetAnalogAnalyzerHighPassFilter (ViSession instrSession,
                                                          ViBoolean HPFilter)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;

    if (rssiup_invalidViBooleanRange (HPFilter))
        return VI_ERROR_PARAMETER2;

    value = (HPFilter == VI_TRUE) ? ON : OFF;
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_DIGITAL_HPF, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Analyzer High Pass Filter
 * Purpose:  This function returns state of the analog analyzer input High
 *           Pass Filter.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_GetAnalogAnalyzerHighPassFilter (ViSession instrSession,
                                                          ViPBoolean HPFilter)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;
    if (!HPFilter)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AANLHW_DIGITAL_HPF, ChAB, &value, sizeof(value)));
    *HPFilter = (value == ON) ? VI_TRUE : VI_FALSE;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Analyzer Float Ground
 * Purpose:  This function sets the analog analyzer ground.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalogAnalyzerFloatGround (ViSession instrSession,
                                                       ViInt32 channel,
                                                       ViBoolean floatGround)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;
    ViUInt32    SN              = 0;

    CHECKERR (rssiup_DSI_Get (instrSession, 0x1000, 0, &SN, 4));

    if (SN >= 100050)
        {
        if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
            return VI_ERROR_PARAMETER2;
        if (rssiup_invalidViBooleanRange (floatGround))
            return VI_ERROR_PARAMETER3;

        value = (floatGround == VI_TRUE) ? ON : OFF;
        CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_FLOAT_GND, channel, &value, sizeof(value)));
        CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
        }
    else
        rssiup_status = RSSIUP_ERROR_INSTRUMENT_NSUP_MODEL;

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Analyzer Float Ground
 * Purpose:  This function returns the analog analyzer ground.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalogAnalyzerFloatGround (ViSession instrSession,
                                                       ViInt32 channel,
                                                       ViPBoolean floatGround)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;
    ViUInt32    SN              = 0;

    CHECKERR (rssiup_DSI_Get (instrSession, 0x1000, 0, &SN, 4));

    if (SN >= 100050)
        {
        if (!((channel == ChA) || (channel == ChB)))
            return VI_ERROR_PARAMETER2;
        if (!floatGround)
            return VI_ERROR_PARAMETER3;

        CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AANLHW_FLOAT_GND, channel, &value, sizeof(value)));
        *floatGround = (value == ON) ? VI_TRUE : VI_FALSE;
        CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
        }
    else
        rssiup_status = RSSIUP_ERROR_INSTRUMENT_NSUP_MODEL;

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Analyzer Range Dependency
 * Purpose:  This function sets whether to use the same range settings for
 *           both channels.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalogAnalyzerRangeDependency (ViSession instrSession,
                                                           ViInt32 rangeDependency)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;

    if (rssiup_invalidViInt32Range (rangeDependency, 0, 1))
        return VI_ERROR_PARAMETER2;

    value = (rangeDependency == RSSIUP_RANGE_DEPENDENT) ? ON : OFF;
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_RANGE_DEPENDENCY, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Analyzer Range Dependency
 * Purpose:  This function returns whether to use the same range settings for
 *           both channels.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalogAnalyzerRangeDependency (ViSession instrSession,
                                                           ViPInt32 rangeDependency)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;

    if (!rangeDependency)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AANLHW_RANGE_DEPENDENCY, ChAB, &value, sizeof(value)));
    *rangeDependency = (value == ON) ? RSSIUP_RANGE_DEPENDENT : RSSIUP_RANGE_INDEPENDENT;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Analyzer Range Number
 * Purpose:  This function sets analog analyzer range mode and range number.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_SetAnalogAnalyzerRangeNumber (ViSession instrSession,
                                                       ViInt32 channel,
                                                       ViInt32 rangeMode,
                                                       ViInt32 rangeNumber)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TAAnlRange          value           = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SAAnlRangeModeDiscVals, rangeMode, &value.RangeMode, VI_ERROR_PARAMETER3));

    if (rssiup_invalidViInt32Range (rangeNumber, 0, 7))
        return VI_ERROR_PARAMETER4;

    value.RangeNum = rangeNumber;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_RANGE_NUM, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Analyzer Range Number
 * Purpose:  This function returns analog analyzer range mode and range number.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_GetAnalogAnalyzerRangeNumber (ViSession instrSession,
                                                       ViInt32 channel,
                                                       ViPInt32 rangeMode,
                                                       ViPInt32 rangeNumber)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TAAnlRange  value           = {0};

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!rangeMode)
        return VI_ERROR_PARAMETER3;
    if (!rangeNumber)
        return VI_ERROR_PARAMETER4;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AANLHW_RANGE_NUM, channel, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAAnlRangeModeDiscVals, rangeMode, &value.RangeMode, VI_ERROR_INV_RESPONSE));
    *rangeNumber = value.RangeNum;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Analyzer Range Value
 * Purpose:  This function sets analog analyzer range mode and range value.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalogAnalyzerRangeValue (ViSession instrSession,
                                                      ViInt32 channel,
                                                      ViInt32 rangeMode,
                                                      ViReal64 rangeValue
                                                      /* ViInt32 unit */)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TCmdAnlRangeVolt    value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SAAnlRangeModeDiscVals, rangeMode, &value.RangeMode, VI_ERROR_PARAMETER3));

    if (rssiup_invalidViReal64Range (rangeValue, 0.0, 55.0))
        return VI_ERROR_PARAMETER4;
/*
    if (unit != RSSIUP_UNIT_V)
        return VI_ERROR_PARAMETER5;
*/
    DBL2FLT(rangeValue, value.RangeValue);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_RANGE_VOLT, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Analyzer Range
 * Purpose:  This function returns range mode, down limit and upper limit of
 *           the current range.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalogAnalyzerRange (ViSession instrSession,
                                                 ViInt32 channel,
                                                 ViPInt32 rangeMode,
                                                 ViPReal64 lowerLimit,
                                                 /* ViPInt32 downLimitUnit, */
                                                 ViPReal64 upperLimit
                                                 /* ViPInt32 upperLimitUnit */)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetAnlRangeVolt    value           = {0};

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!rangeMode)
        return VI_ERROR_PARAMETER3;
    if (!lowerLimit)
        return VI_ERROR_PARAMETER4;
/*
    if (!downLimitUnit)
        return VI_ERROR_PARAMETER5;
*/
    if (!upperLimit)
        return VI_ERROR_PARAMETER5;
/*
    if (!upperLimitUnit)
        return VI_ERROR_PARAMETER7;
*/
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AANLHW_RANGE_VOLT, channel, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAAnlRangeModeDiscVals, rangeMode, &value.RangeMode, VI_ERROR_INV_RESPONSE));
    *lowerLimit = value.DnLimit;
/*  *downLimitUnit = RSSIUP_UNIT_V; */
    *upperLimit = value.UpLimit;
/*  *upperLimitUnit = RSSIUP_UNIT_V; */
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Analyzer Peak Response Data
 * Purpose:  This function returns measurement response of peak measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_AnalyzerPeakResponseData (ViSession instrSession,
                                                   ViReal64 _VI_FAR peakMin[],
                                                   ViPInt32 peakMinUnit,
                                                   ViReal64 _VI_FAR peakMax[],
                                                   ViPInt32 peakMaxUnit)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_PEAK};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}

	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afPeak][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afPeak][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
		
    if (peakMin || peakMax)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (peakMin)
            {
            peakMin[0] = instrPtr -> AnlMeasPeak.PeakMin_A;
            peakMin[1] = instrPtr -> AnlMeasPeak.PeakMin_B;

            if (peakMinUnit)
                *peakMinUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
            }
    
        if (peakMax)
            {
            peakMax[0] = instrPtr -> AnlMeasPeak.PeakMax_A;
            peakMax[1] = instrPtr -> AnlMeasPeak.PeakMax_B;

            if (peakMaxUnit)
                *peakMaxUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
            }
        }

	return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer RMSDC Measurement
/* Purpose:  This function returns measurement response of RMS, DC, 
/*           frequency measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerRMSDCMeasurement(
    ViSession   instrSession,
    ViReal64    _VI_FAR dc[],
    ViPInt32    dcUnit,
    ViReal64    _VI_FAR RMS[],
    ViPInt32    RMSUnit,
    ViReal64    _VI_FAR frequency[],
    ViPInt32    frequencyUnit,
    ViInt32     _VI_FAR dataStatus[],
    ViInt32     _VI_FAR asynchronousStatus[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_RMSDC};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afRMSDC][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afRMSDC][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (dc || RMS || frequency || dataStatus || asynchronousStatus)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (dc)
            {
            dc[0] = instrPtr -> AnlMeasRMSDC.DC_A;
            dc[1] = instrPtr -> AnlMeasRMSDC.DC_B;
        
            if (dcUnit)
                *dcUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
            }

        if (RMS)
            {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                RMS[0] = sqrt(instrPtr -> AnlMeasRMSDC.SqrRMS_A);
                RMS[1] = sqrt(instrPtr -> AnlMeasRMSDC.SqrRMS_B);
                }
            else /* Digital analyzer */
                {
                RMS[0] = sqrt(2) * sqrt(instrPtr -> AnlMeasRMSDC.SqrRMS_A);
                RMS[1] = sqrt(2) * sqrt(instrPtr -> AnlMeasRMSDC.SqrRMS_B);
                }

            if (RMSUnit)
                *RMSUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
            }

        if (frequency)
            {
            frequency[0] = instrPtr -> AnlMeasRMSDC.Frequency_A;
            frequency[1] = instrPtr -> AnlMeasRMSDC.Frequency_B;

            if (frequencyUnit)
                *frequencyUnit = RSSIUP_UNIT_HZ;
            }

        if (dataStatus)
            {
            dataStatus[0] = instrPtr -> AnlMeasRMSDC.Valid_A;
            dataStatus[1] = instrPtr -> AnlMeasRMSDC.Valid_B;
            }

        if (asynchronousStatus)
            {
            asynchronousStatus[0] = instrPtr -> AnlMeasRMSDC.AsynchroIndication_A;
            asynchronousStatus[1] = instrPtr -> AnlMeasRMSDC.AsynchroIndication_B;
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer Qpeak Measurement
/* Purpose:  This function returns measurement response of quasi peak 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerQpeakMeasurement(
    ViSession   instrSession,
    ViReal64    _VI_FAR qpeakMin[],
    ViPInt32    qpeakMinUnit,
    ViReal64    _VI_FAR qpeakMax[],
    ViPInt32    qpeakMaxUnit,
    ViReal64    _VI_FAR qpeakCurrent[],
    ViPInt32    qpeakCurrentUnit
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_QPEAK};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afQPeak][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afQPeak][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (qpeakMin || qpeakMax || qpeakCurrent)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (qpeakMin)
            {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                qpeakMin[0] = (instrPtr -> AnlMeasQpeak.QuasiPeakMin_A) / sqrt(2);
                qpeakMin[1] = (instrPtr -> AnlMeasQpeak.QuasiPeakMin_B) / sqrt(2);
                }
            else /* Digital analyzer */
                {
                qpeakMin[0] = instrPtr -> AnlMeasQpeak.QuasiPeakMin_A;
                qpeakMin[1] = instrPtr -> AnlMeasQpeak.QuasiPeakMin_B;
                }

            if (qpeakMinUnit)
                *qpeakMinUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
            }

            if (qpeakMax)
            {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                qpeakMax[0] = (instrPtr -> AnlMeasQpeak.QuasiPeakMax_A) / sqrt(2);
                qpeakMax[1] = (instrPtr -> AnlMeasQpeak.QuasiPeakMax_B) / sqrt(2);
                }
            else /* Digital analyzer */
                {
                qpeakMax[0] = instrPtr -> AnlMeasQpeak.QuasiPeakMax_A;
                qpeakMax[1] = instrPtr -> AnlMeasQpeak.QuasiPeakMax_B;
                }

            if (qpeakMaxUnit)
                *qpeakMaxUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
            }

            if (qpeakCurrent)
            {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                qpeakCurrent[0] = (instrPtr -> AnlMeasQpeak.QuasiPeakCurrentValue_A) / sqrt(2);
                qpeakCurrent[1] = (instrPtr -> AnlMeasQpeak.QuasiPeakCurrentValue_B) / sqrt(2);
                }
            else /* Digital analyzer */
                {
                qpeakCurrent[0] = instrPtr -> AnlMeasQpeak.QuasiPeakCurrentValue_A;
                qpeakCurrent[1] = instrPtr -> AnlMeasQpeak.QuasiPeakCurrentValue_B;
                }

            if (qpeakCurrentUnit)
                *qpeakCurrentUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer RMS Selective Measurement
/* Purpose:  This function returns measurement response of RMS selective 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerRMSSelectiveMeasurement(
    ViSession   instrSession,
    ViReal64    _VI_FAR RMSValue[],
    ViPInt32    unit,
    ViPInt32    dataStatus
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_RMSSEL};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afRMSSel][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afRMSSel][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (RMSValue || dataStatus)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (RMSValue)
            {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                RMSValue[0] = sqrt(instrPtr -> AnlMeasRMSSel.SqrRMSValue_A);
                RMSValue[1] = sqrt(instrPtr -> AnlMeasRMSSel.SqrRMSValue_B);
                }
            else /* Digital analyzer */
                {
                RMSValue[0] = sqrt(2) * sqrt(instrPtr -> AnlMeasRMSSel.SqrRMSValue_A);
                RMSValue[1] = sqrt(2) * sqrt(instrPtr -> AnlMeasRMSSel.SqrRMSValue_B);
                }

            if (unit)
                *unit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
            }

        if (dataStatus)
            {
            *dataStatus = instrPtr -> AnlMeasRMSSel.Valid;
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer RMS Selective Variable Bandwidth Main Measurement
/* Purpose:  This function returns main result of RMS Selective Multi Task 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerRMSSelectiveVariableBWMainMeasurement (ViSession instrSession,
                                                                   ViInt32 autoTuneLocked[],
                                                                   ViReal64 frequency[],
                                                                   ViReal64 RMS[],
                                                                   ViInt32 *levelValuesUnit)
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_RMSSEL_MUTSK},
                        postMeasId[]    = {MEAS_RMSSEL_MUTSK_FFT, MEAS_RMSSEL_MUTSK}; /* Exceptional handling. Do not change order! */
    pTStatusDataRanges  instrPtr        = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    /* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afRMSSelMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afRMSSelMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (autoTuneLocked || frequency || RMS)
    {
        ViBoolean   post_fft        = VI_FALSE;
        ViInt32     post_fft_size   = 0,
                    post_fft_window = 0;
        
        CHECKERR (rssiup_GetAnalyzerFunctionRMSSelVariableBWFFTSettings (instrSession, &post_fft,
                                                                    &post_fft_size,
                                                                    &post_fft_window));

        if (post_fft == VI_TRUE)
        {
            // no reading has been done yet, do it now
			if (instrPtr->cachedData == VI_FALSE)
	        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, postMeasId, 1));
        }
        else
        {
            // no reading has been done yet, do it now
			if (instrPtr->cachedData == VI_FALSE)
	        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
        }

        if (autoTuneLocked)
        {
            autoTuneLocked[0] = instrPtr -> AnlMeasRMSSelMuTsk.AutoTuneLocked_A;
            autoTuneLocked[1] = instrPtr -> AnlMeasRMSSelMuTsk.AutoTuneLocked_B;
        }

        if (frequency)
        {
            frequency[0] = instrPtr -> AnlMeasRMSSelMuTsk.Frequency_A;
            frequency[1] = instrPtr -> AnlMeasRMSSelMuTsk.Frequency_B;
        }

        if (RMS)
        {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
            {
                RMS[0] =  instrPtr -> AnlMeasRMSSelMuTsk.RMS_A;
                RMS[1] =  instrPtr -> AnlMeasRMSSelMuTsk.RMS_B;
            }
            else /* Digital analyzer */
            {
                RMS[0] = sqrt(2) * (instrPtr -> AnlMeasRMSSelMuTsk.RMS_A);
                RMS[1] = sqrt(2) * (instrPtr -> AnlMeasRMSSelMuTsk.RMS_B);
            }
        }

        if (levelValuesUnit)
            *levelValuesUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
    }

    return rssiup_status;    
}

/*===========================================================================*/
/* Function: Analyzer RMS Selective Variable Bandwidth Post FFT Measurement
/* Purpose:  This function returns possible addition of main result of RMS 
/*           Selective Multi Task measurement when Post FFT is ON and Data 
/*           Reduction is OFF.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerRMSSelectiveVariableBWPostFFTMeasurement (ViSession instrSession,
                                                                      ViInt32 FFTResponseHeader[],
                                                                      ViReal64 spectralLines[])
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_RMSSEL_MUTSK_FFT};
    pTStatusDataRanges  instrPtr        = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    /* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afRMSSelMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afRMSSelMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (FFTResponseHeader || spectralLines)
    {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (FFTResponseHeader)
	    {
	        ViChar  *p2response;

	        p2response = (ViChar *)FFTResponseHeader;

	        if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	        {
	            memcpy (p2response, &instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_A, sizeof (TFFTResHeader));

	            p2response += sizeof (TFFTResHeader);
	        }
        
	        if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	            memcpy (p2response, &instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_B, sizeof (TFFTResHeader));
	    }

	    if (spectralLines)
	    {
	        ViChar      *p2response;

	        p2response = (ViChar *)spectralLines;

	        if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	        {
	            rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasRMSSelMuTskPostFFT.SpLines_A,
	                instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_A.NOSL);

	            /* Recalculate FFT data */
	            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_A,
	                (ViReal64 *)p2response, instrPtr -> analyzerMode);

	            p2response += instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_A.NOSL * sizeof (ViReal64);
	        }

	        if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	        {
	            rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasRMSSelMuTskPostFFT.SpLines_B,
	                instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_B.NOSL);

	            /* Recalculate FFT data */
	            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_B,
	                (ViReal64 *)p2response, instrPtr -> analyzerMode);
	        }
	    }
	}	

    return rssiup_status;    
}

/*===========================================================================*/
/* Function: Analyzer THD (+N) Main Measurement
/* Purpose:  This function returns main result of THD (+N) measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerTHDNMainMeasurement(
    ViSession   instrSession,
/*  ViReal64    _VI_FAR markerFrequencies[], */
/*  ViReal64    _VI_FAR markerValues[], */
    ViInt32     _VI_FAR autoTuneLocked[],
    ViReal64    _VI_FAR frequency[],
    ViReal64    _VI_FAR totalRMS[],
    ViReal64    _VI_FAR noiseRMS[],
    ViReal64    _VI_FAR totalRMSNonfund[],
    ViReal64    _VI_FAR totalRMSTHD[],
    ViReal64    _VI_FAR harmonicLines[],
    ViPInt32    levelValuesUnit
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_THDN},
                        postMeasId[]    = {MEAS_THDN_POST_FFT, MEAS_THDN}; /* Exceptional handling. Do not change order! */
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afTHDpmN][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afTHDpmN][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (/* markerFrequencies || markerValues || */ autoTuneLocked || frequency ||
        totalRMS || noiseRMS || totalRMSNonfund || totalRMSTHD || harmonicLines)
        {
        ViBoolean   post_fft        = VI_FALSE;
        ViInt32     post_fft_size   = 0,
                    post_fft_window = 0;
        
        CHECKERR (rssiup_GetAnalyzerFunctionTHDNFFTSettings (instrSession, &post_fft,
                                                             &post_fft_size,
                                                             &post_fft_window));

        if (post_fft == VI_TRUE)
            {
            // no reading has been done yet, do it now
			if (instrPtr->cachedData == VI_FALSE)
	        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, postMeasId, 2));
            }
        else
            {
            // no reading has been done yet, do it now
			if (instrPtr->cachedData == VI_FALSE)
	        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
            }
/*
        if (markerFrequencies)
            {
            markerFrequencies[0] = instrPtr -> AnlMeasTHDN.Marker1_FFTFreq;
            markerFrequencies[1] = instrPtr -> AnlMeasTHDN.Marker2_FFTFreq;
            }

        if (markerValues)
            {
            markerValues[0] = instrPtr -> AnlMeasTHDN.Marker1_A_Value;
            markerValues[1] = instrPtr -> AnlMeasTHDN.Marker2_A_Value;
            markerValues[2] = instrPtr -> AnlMeasTHDN.Marker1_B_Value;
            markerValues[3] = instrPtr -> AnlMeasTHDN.Marker2_B_Value;
            }
*/
        if (autoTuneLocked)
            {
            autoTuneLocked[0] = instrPtr -> AnlMeasTHDN.AutoTuneLocked_A;
            autoTuneLocked[1] = instrPtr -> AnlMeasTHDN.AutoTuneLocked_B;
            }

        if (frequency)
            {
            frequency[0] = instrPtr -> AnlMeasTHDN.Frequency_A;
            frequency[1] = instrPtr -> AnlMeasTHDN.Frequency_B;
            }

        if (totalRMS)
            {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                totalRMS[0] =  instrPtr -> AnlMeasTHDN.TotalRMS_A_THDN;
                totalRMS[1] =  instrPtr -> AnlMeasTHDN.TotalRMS_B_THDN;
                }
            else /* Digital analyzer */
                {
                totalRMS[0] = sqrt(2) * (instrPtr -> AnlMeasTHDN.TotalRMS_A_THDN);
                totalRMS[1] = sqrt(2) * (instrPtr -> AnlMeasTHDN.TotalRMS_B_THDN);
                }
            }

        if (noiseRMS)
            {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                noiseRMS[0] = instrPtr -> AnlMeasTHDN.Noise_A_THDN;
                noiseRMS[1] = instrPtr -> AnlMeasTHDN.Noise_B_THDN;
                }
            else /* Digital analyzer */
                {
                noiseRMS[0] = sqrt(2) * (instrPtr -> AnlMeasTHDN.Noise_A_THDN);
                noiseRMS[1] = sqrt(2) * (instrPtr -> AnlMeasTHDN.Noise_B_THDN);
                }
            }

        if (totalRMSNonfund)
            {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                totalRMSNonfund[0] = instrPtr -> AnlMeasTHDN.TotalRMS_A_THDN_NonFund;
                totalRMSNonfund[1] = instrPtr -> AnlMeasTHDN.TotalRMS_B_THDN_NonFund;
                }
            else /* Digital analyzer */
                {
                totalRMSNonfund[0] = sqrt(2) * (instrPtr -> AnlMeasTHDN.TotalRMS_A_THDN_NonFund);
                totalRMSNonfund[1] = sqrt(2) * (instrPtr -> AnlMeasTHDN.TotalRMS_B_THDN_NonFund);
                }
            }

        if (totalRMSTHD)
            {
            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                totalRMSTHD[0] = instrPtr -> AnlMeasTHDN.TotalRMS_A_THD;
                totalRMSTHD[1] = instrPtr -> AnlMeasTHDN.TotalRMS_B_THD;
                }
            else /* Digital analyzer */
                {
                totalRMSTHD[0] = sqrt(2) * (instrPtr -> AnlMeasTHDN.TotalRMS_A_THD);
                totalRMSTHD[1] = sqrt(2) * (instrPtr -> AnlMeasTHDN.TotalRMS_B_THD);
                }
            }

        if (harmonicLines)
            {
            ViInt32     idx = 0;

            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                for (idx = 0; idx < 10; idx++)
                    {
                    harmonicLines[idx] =  instrPtr -> AnlMeasTHDN.Harmonic_A[idx];
                    harmonicLines[idx + 10] =  instrPtr -> AnlMeasTHDN.Harmonic_B[idx];
                    }
                }
            else /* Digital analyzer */
                {
                for (idx = 0; idx < 10; idx++)
                    {
                    harmonicLines[idx] =  sqrt(2) * (instrPtr -> AnlMeasTHDN.Harmonic_A[idx]);
                    harmonicLines[idx + 10] =  sqrt(2) * (instrPtr -> AnlMeasTHDN.Harmonic_B[idx]);
                    }
                }
            }

        if (levelValuesUnit)
            *levelValuesUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer THD (+N) Measurement Results
/* Purpose:  This function returns calculated harmonics results of THD (+N) 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerTHDNMeasurementResults (ViSession instrSession,
                                                         ViInt32 units,
                                                         ViReal64 frequency[],
                                                         ViReal64 THDAllHarmonics[],
                                                         ViReal64 THDEvenHarmonics[],
                                                         ViReal64 THDOddHarmonics[],
                                                         ViReal64 SINAD[],
                                                         ViReal64 noiseSignal[])
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};
	ViReal64            outputA         = 0.0,
                        outputB         = 0.0,
                        inputA          = 0.0,
                        inputB          = 0.0;
	ViInt32             idx             = 0;
	ViInt32             autoTuneLocked[2];
    ViReal64            getFrequency[2];
    ViReal64            totalRMS[2];
    ViReal64            noiseRMS[2];
    ViReal64            totalRMSNonfund[2];
    ViReal64            totalRMSTHD[2];
    ViReal64            harmonicLines[20];
	ViInt32             levelValuesUnit;
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	CHECKERR (rssiup_AnalyzerTHDNMainMeasurement (instrSession, autoTuneLocked,
												  getFrequency, totalRMS, noiseRMS,
												  totalRMSNonfund, totalRMSTHD,
												  harmonicLines, &levelValuesUnit));
	
	if (frequency)
	{
		frequency[0] = getFrequency[0];
        frequency[1] = getFrequency[1];
	}
	
	if (THDAllHarmonics)
	{
		for (idx = 1; idx < 10; idx++)
		{
			inputA += harmonicLines[idx]*harmonicLines[idx];
			inputB += harmonicLines[idx+10]*harmonicLines[idx+10];
		}
		
		if (inputA != 0.0)
			outputA = sqrt (inputA) / totalRMSTHD[0];
		if (inputB != 0.0)
			outputB = sqrt (inputB) / totalRMSTHD[1];
	
		if (units == RSSIUP_UNIT_DB)
		{
			if (outputA != 0.0)
				THDAllHarmonics[0] = 20 * log10 (outputA);
			if (outputB != 0.0)
				THDAllHarmonics[1] = 20 * log10 (outputB);
		}
		else
		{
			if (outputA != 0.0)
				THDAllHarmonics[0] = 100 * outputA;
			if (outputB != 0.0)
				THDAllHarmonics[1] = 100 * outputB;
		}
	}
	
	outputA = 0.0;
    outputB = 0.0;
    inputA  = 0.0;
    inputB  = 0.0;
	
	if (THDEvenHarmonics)
	{
		for (idx = 1; idx < 10; idx=idx+2)
		{
			inputA += harmonicLines[idx]*harmonicLines[idx];
			inputB += harmonicLines[idx+10]*harmonicLines[idx+10];
		}
		
		if (inputA != 0.0)
			outputA = sqrt (inputA) / totalRMSTHD[0];
		if (inputB != 0.0)
			outputB = sqrt (inputB) / totalRMSTHD[1];
	
		if (units == RSSIUP_UNIT_DB)
		{
			if (outputA != 0.0)
				THDEvenHarmonics[0] = 20 * log10 (outputA);
			if (outputB != 0.0)
				THDEvenHarmonics[1] = 20 * log10 (outputB);
		}
		else
		{
			if (outputA != 0.0)
				THDEvenHarmonics[0] = 100 * outputA;
			if (outputB != 0.0)
				THDEvenHarmonics[1] = 100 * outputB;
		}
	}
	
	outputA = 0.0;
    outputB = 0.0;
    inputA  = 0.0;
    inputB  = 0.0;
	
	if (THDOddHarmonics)
	{
		for (idx = 2; idx < 10; idx=idx+2)
		{
			inputA += harmonicLines[idx]*harmonicLines[idx];
			inputB += harmonicLines[idx+10]*harmonicLines[idx+10];
		}
		
		if (inputA != 0.0)
			outputA = sqrt (inputA) / totalRMSTHD[0];
		if (inputB != 0.0)
			outputB = sqrt (inputB) / totalRMSTHD[1];
	
		if (units == RSSIUP_UNIT_DB)
		{
			if (outputA != 0.0)
				THDOddHarmonics[0] = 20 * log10 (outputA);
			if (outputB != 0.0)
				THDOddHarmonics[1] = 20 * log10 (outputB);
		}
		else
		{
			if (outputA != 0.0)
				THDOddHarmonics[0] = 100 * outputA;
			if (outputB != 0.0)
				THDOddHarmonics[1] = 100 * outputB;
		}
	}
	
	outputA = 0.0;
    outputB = 0.0;
    inputA  = 0.0;
    inputB  = 0.0;
	
	if (SINAD)
	{
		inputA = totalRMSNonfund[0] / totalRMS[0];
		inputB = totalRMSNonfund[1] / totalRMS[1];
		
		if (units == RSSIUP_UNIT_DB)
		{
			if (inputA != 0.0)
				SINAD[0] = -20 * log10 (inputA);
			if (inputB != 0.0)
				SINAD[1] = -20 * log10 (inputB);
		}
		else
		{
			SINAD[0] = 0.0;
			SINAD[1] = 0.0;
		}
	}
	
	outputA = 0.0;
    outputB = 0.0;
    inputA  = 0.0;
    inputB  = 0.0;
	
	if (noiseSignal)
	{
		outputA = noiseRMS[0] / totalRMS[0];
		outputB = noiseRMS[1] / totalRMS[1];
		
		if (units == RSSIUP_UNIT_DB)
		{
			if (outputA != 0.0)
				noiseSignal[0] = 20 * log10 (outputA);
			if (outputB != 0.0)
				noiseSignal[1] = 20 * log10 (outputB);
		}
		else
		{
			if (outputA != 0.0)
				noiseSignal[0] = 100 * outputA;
			if (outputB != 0.0)
				noiseSignal[1] = 100 * outputB;
		}	
	}

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Analyzer THD (+N) Post FFT Measurement
/* Purpose:  This function returns possible addition of main result of THD 
/*           (+N) measurement when Post FFT is ON and Data Reduction is OFF.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerTHDNPostFFTMeasurement(
    ViSession   instrSession,
    ViInt32     _VI_FAR fftResponseHeader[],
    ViReal64    _VI_FAR spectralLines[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_THDN_POST_FFT};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afTHDpmN][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afTHDpmN][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (fftResponseHeader || spectralLines)
    {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (fftResponseHeader)
	    {
	        ViChar  *p2response;

	        p2response = (ViChar *)fftResponseHeader;

	        if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	        {
	            memcpy (p2response, &instrPtr -> AnlMeasTHDNPostFFT.Header_A, sizeof (TFFTResHeader));

	            p2response += sizeof (TFFTResHeader);
	        }
        
	        if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	            memcpy (p2response, &instrPtr -> AnlMeasTHDNPostFFT.Header_B, sizeof (TFFTResHeader));
	    }

	    if (spectralLines)
	    {
	        ViChar      *p2response;

	        p2response = (ViChar *)spectralLines;

	        if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	        {
	            rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasTHDNPostFFT.SpLines_A,
	                instrPtr -> AnlMeasTHDNPostFFT.Header_A.NOSL);

	            /* Recalculate FFT data */
	            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasTHDNPostFFT.Header_A,
	                (ViReal64 *)p2response, instrPtr -> analyzerMode);

	            p2response += instrPtr -> AnlMeasTHDNPostFFT.Header_A.NOSL * sizeof (ViReal64);
	        }

	        if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	        {
	            rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasTHDNPostFFT.SpLines_B,
	                instrPtr -> AnlMeasTHDNPostFFT.Header_B.NOSL);

	            /* Recalculate FFT data */
	            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasTHDNPostFFT.Header_B,
	                (ViReal64 *)p2response, instrPtr -> analyzerMode);
	        }
	    }
	}	

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer THD (+N) Data Reduction FFT Measurement
/* Purpose:  This function returns possible addition of main result of THD 
/*           (+N) measurement when Post FFT is ON and Data Reduction is ON.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_AnalyzerTHDNDataReductionFFTMeasurement(
    ViSession   instrSession,
    ViInt32     _VI_FAR fftResponseHeaderMin[],
    ViReal64    _VI_FAR spectralLinesMin[],
    ViInt32     _VI_FAR fftResponseHeaderMax[],
    ViReal64    _VI_FAR spectralLinesMax[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_THDN_REDUCED_FFT};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afTHDpmN][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afTHDpmN][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (fftResponseHeaderMin || spectralLinesMin || fftResponseHeaderMax || spectralLinesMax)
        {
        if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (fftResponseHeaderMin)
            memcpy (fftResponseHeaderMin, &instrPtr -> AnlMeasTHDNReducedFFT.HeaderMin,
                sizeof (TFFTResHeader));

        if (spectralLinesMin)
            {
            rssiup_float_to_double (spectralLinesMin, instrPtr -> AnlMeasTHDNReducedFFT.SLmin,
                instrPtr -> AnlMeasTHDNReducedFFT.HeaderMin.DisplaySize);

            /* Recalculate FFT data */
            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasTHDNReducedFFT.HeaderMin,
                spectralLinesMin, instrPtr -> analyzerMode);
            }

        if (fftResponseHeaderMax)
            memcpy (fftResponseHeaderMax, &instrPtr -> AnlMeasTHDNReducedFFT.HeaderMax,
                sizeof (TFFTResHeader));

        if (spectralLinesMax)
            {
            rssiup_float_to_double (spectralLinesMax, instrPtr -> AnlMeasTHDNReducedFFT.SLmax,
                instrPtr -> AnlMeasTHDNReducedFFT.HeaderMax.DisplaySize);

            /* Recalculate FFT data */
            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasTHDNReducedFFT.HeaderMax,
                spectralLinesMax, instrPtr -> analyzerMode);
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer THD (+N) Measurement Results Extended
/* Purpose:  This function returns calculated THD+N results of 
/*           THD (+N) measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerTHDNMeasurementResultsExt (ViSession instrSession,
                                                            ViInt32 units,
                                                            ViReal64 THDN[])
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};
	ViReal64            inputA          = 0.0,
                        inputB          = 0.0;
	ViInt32             autoTuneLocked[2];
    ViReal64            getFrequency[2];
    ViReal64            totalRMS[2];
    ViReal64            noiseRMS[2];
    ViReal64            totalRMSNonfund[2];
    ViReal64            totalRMSTHD[2];
    ViReal64            harmonicLines[20];
	ViInt32             levelValuesUnit;
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	CHECKERR (rssiup_AnalyzerTHDNMainMeasurement (instrSession, autoTuneLocked,
												  getFrequency, totalRMS, noiseRMS,
												  totalRMSNonfund, totalRMSTHD,
												  harmonicLines, &levelValuesUnit));
	
	THDN[0] = THDN[1] = 0.0;
	
	if (THDN)
	{
		inputA = totalRMSNonfund[0] / totalRMS[0];
		inputB = totalRMSNonfund[1] / totalRMS[1];
		
		if (units == RSSIUP_UNIT_DB)
		{
			if (inputA != 0.0)
				THDN[0] = 20 * log10 (inputA);
			if (inputB != 0.0)
				THDN[1] = 20 * log10 (inputB);
		}
		else
		{
			THDN[0] = inputA * 100.0;
			THDN[1] = inputB * 100.0;
		}
	}
	
	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Analyzer Phase Main Measurement
/* Purpose:  This function returns main result of phase measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerPhaseMainMeasurement(
    ViSession   instrSession,
/*  ViReal64    _VI_FAR markerFrequencies[], */
/*  ViReal64    _VI_FAR markerValues[], */
    ViPInt32    autoTuneLocked,
    ViPReal64   frequency,
    ViPReal64   phaseDifference,
    ViPInt32    frequencyMaster
    /* ViPInt32    levelValuesUnit */
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_PHASE};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afPhaseMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afPhaseMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
	if (/* markerFrequencies || markerValues || */ autoTuneLocked || frequency ||
        phaseDifference || frequencyMaster)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
/*
        if (markerFrequencies)
            {
            markerFrequencies[0] = instrPtr -> AnlMeasPhase.Marker1_FFTFrequency;
            markerFrequencies[1] = instrPtr -> AnlMeasPhase.Marker2_FFTFrequency;
            }

        if (markerValues)
            {
            markerValues[0] = instrPtr -> AnlMeasPhase.Marker1_Value_A;
            markerValues[1] = instrPtr -> AnlMeasPhase.Marker2_Value_A;
            markerValues[2] = instrPtr -> AnlMeasPhase.Marker1_Value_B;
            markerValues[3] = instrPtr -> AnlMeasPhase.Marker2_Value_B;
            }
*/
        if (autoTuneLocked)
            *autoTuneLocked = instrPtr -> AnlMeasPhase.AutotuneLocked;

        if (frequency)
            *frequency = instrPtr -> AnlMeasPhase.Frequency;

        if (phaseDifference)
            *phaseDifference = instrPtr -> AnlMeasPhase.PhaseDifference;

        if (frequencyMaster)
            *frequencyMaster = instrPtr -> AnlMeasPhase.Master;
/*
        if (levelValuesUnit)
            *levelValuesUnit = RSSIUP_UNIT_V;
*/
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer Phase Post FFT Measurement
/* Purpose:  This function returns possible addition of main result of phase 
/*           measurement when Post FFT is ON and Data Reduction is OFF.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_AnalyzerPhasePostFFTMeasurement(
    ViSession   instrSession,
    ViInt32     _VI_FAR fftResponseHeader[],
    ViReal64    _VI_FAR spectralLines[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_PHASE_POST_FFT};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afPhaseMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afPhaseMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (fftResponseHeader || spectralLines)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (fftResponseHeader)
            memcpy (fftResponseHeader, &instrPtr -> AnlMeasPhasePostFFT.Header,
                sizeof (TFFTResHeader));

        if (spectralLines)
            {
            rssiup_float_to_double (spectralLines, instrPtr -> AnlMeasPhasePostFFT.SpLines,
                instrPtr -> AnlMeasPhasePostFFT.Header.NOSL);

            /* Recalculate FFT data */
            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasPhasePostFFT.Header,
                spectralLines, instrPtr -> analyzerMode);
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer Phase Data Reduction FFT Measurement
/* Purpose:  This function returns possible addition of main result of phase 
/*           measurement when Post FFT is ON and Data Reduction is ON.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_AnalyzerPhaseDataReductionFFTMeasurement(
    ViSession   instrSession,
    ViInt32     _VI_FAR fftResponseHeaderMin[],
    ViReal64    _VI_FAR spectralLinesMin[],
    ViInt32     _VI_FAR fftResponseHeaderMax[],
    ViReal64    _VI_FAR spectralLinesMax[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_PHASE_REDUCED_FFT};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afPhaseMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afPhaseMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
	if (fftResponseHeaderMin || spectralLinesMin || fftResponseHeaderMax || spectralLinesMax)
        {
        if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (fftResponseHeaderMin)
            memcpy (fftResponseHeaderMin, &instrPtr -> AnlMeasPhaseReducedFFT.HeaderMin,
                sizeof (TFFTResHeader));

        if (spectralLinesMin)
            {
            rssiup_float_to_double (spectralLinesMin, instrPtr -> AnlMeasPhaseReducedFFT.SLmin,
                instrPtr -> AnlMeasPhaseReducedFFT.HeaderMin.DisplaySize);

            /* Recalculate FFT data */
            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasPhaseReducedFFT.HeaderMin,
                spectralLinesMin, instrPtr -> analyzerMode);
            }

        if (fftResponseHeaderMax)
            memcpy (fftResponseHeaderMax, &instrPtr -> AnlMeasPhaseReducedFFT.HeaderMax,
                sizeof (TFFTResHeader));

        if (spectralLinesMax)
            {
            rssiup_float_to_double (spectralLinesMax, instrPtr -> AnlMeasPhaseReducedFFT.SLmax,
                instrPtr -> AnlMeasPhaseReducedFFT.HeaderMax.DisplaySize);

            /* Recalculate FFT data */
            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasPhaseReducedFFT.HeaderMax,
                spectralLinesMax, instrPtr -> analyzerMode);
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer DFD Main Measurement
/* Purpose:  This function returns main result of Difference Frequency 
/*           Distortion measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerDFDMainMeasurement(
    ViSession   instrSession,
/*  ViReal64    _VI_FAR markerFrequencies[], */
/*  ViReal64    _VI_FAR markerValues[], */
    ViInt32     _VI_FAR autoTuneLocked[],
    ViReal64    _VI_FAR frequencies[],
    ViReal64    _VI_FAR rmsValues[],
    ViPInt32    levelValuesUnit
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_DFD};
    pTStatusDataRanges  instrPtr        = {0};
	ViInt32             measId_post[]   = {MEAS_DFD_POST_FFT};
//    TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDFDMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDFDMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (/* markerFrequencies || markerValues || */ autoTuneLocked || frequencies || rmsValues)
    {
		ViBoolean   post_fft        = VI_FALSE;
        ViInt32     post_fft_size   = 0,
                    post_fft_window = 0;
        
        // get the Post FFT state
		CHECKERR (rssiup_GetAnalyzerFunctionDFDFFTSettings (instrSession, &post_fft, &post_fft_size, &post_fft_window)); 
		
	    // Post FFT is turned ON
		if (post_fft == VI_TRUE)
		{
			// no reading has been done yet, do it now
			if (instrPtr->cachedData == VI_FALSE) 
			{
				// get Post FFT and Main DFD data together
				CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId_post, 1));
			}
		}
		// Post FFT is turned OFF - measuring ONLY Main DFD data
		else
		{
			// no reading has been done yet, do it now
			if (instrPtr->cachedData == VI_FALSE) 
			{
				// get Main DFD data
				CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
			}
		}
/*
        if (markerFrequencies)
            {
            markerFrequencies[0] = instrPtr -> AnlMeasDFD.Marker1_FFTFrequency;
            markerFrequencies[1] = instrPtr -> AnlMeasDFD.Marker2_FFTFrequency;
            }

        if (markerValues)
            {
            markerValues[0] = instrPtr -> AnlMeasDFD.Marker1_Value_A;
            markerValues[1] = instrPtr -> AnlMeasDFD.Marker2_Value_A;
            markerValues[2] = instrPtr -> AnlMeasDFD.Marker1_Value_B;
            markerValues[3] = instrPtr -> AnlMeasDFD.Marker2_Value_B;
            }
*/
        if (autoTuneLocked)
        {
            autoTuneLocked[0] = instrPtr -> AnlMeasDFD.AutotuneLocked_A;
            autoTuneLocked[1] = instrPtr -> AnlMeasDFD.AutotuneLocked_B;
        }

        if (frequencies)
        {
            ViInt32     idx = 0;

            for (idx = 0; idx < 5; idx++)
            {
                frequencies[idx] = instrPtr -> AnlMeasDFD.Frequencies_A[idx];
                frequencies[idx + 5] = instrPtr -> AnlMeasDFD.Frequencies_B[idx];
            }
        }

        if (rmsValues)
        {
            ViInt32     idx = 0;

            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
            {
                for (idx = 0; idx < 5; idx++)
                {
                    rmsValues[idx] = sqrt(instrPtr -> AnlMeasDFD.RMSValues_A[idx]);
                    rmsValues[idx + 5] = sqrt(instrPtr -> AnlMeasDFD.RMSValues_B[idx]);
                }
            }
            else /* Digital analyzer */
            {
                for (idx = 0; idx < 5; idx++)
                {
                    rmsValues[idx] = sqrt (2) * sqrt(instrPtr -> AnlMeasDFD.RMSValues_A[idx]);
                    rmsValues[idx + 5] = sqrt (2) * sqrt(instrPtr -> AnlMeasDFD.RMSValues_B[idx]);
                }
            }
        }

        if (levelValuesUnit)
            *levelValuesUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
    }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer DFD Measurement Results
/* Purpose:  This function returns calculated results of 2nd and 3rd order 
/*           according to IEC 268 and IEC 118 of Difference Frequency 
/*           Distortion measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerDFDMeasurementResults (ViSession instrSession,
                                                           ViInt32 units,
                                                           ViReal64 d2IEC268[],
                                                           ViReal64 d3IEC268[],
                                                           ViReal64 d2IEC118[],
                                                           ViReal64 d3IEC118[])
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};
	ViReal64            outputA         = 0.0,
                        outputB         = 0.0;
	ViInt32             autoTuneLocked[2];
    ViReal64            frequency[10];
    ViReal64            RMS[10];
    ViInt32             levelValuesUnit;
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	CHECKERR (rssiup_AnalyzerDFDMainMeasurement (instrSession, autoTuneLocked,
												 frequency, RMS, &levelValuesUnit));
	
	if (d2IEC268)
	{
		outputA = fabs (frequency[2]) / fabs (2*frequency[1]);
        outputB = fabs (frequency[7]) / fabs (2*frequency[6]);
		
		if (units == RSSIUP_UNIT_DB)
		{
			if (outputA != 0.0)
				d2IEC268[0] = 20 * log10 (outputA);
			if (outputB != 0.0)
				d2IEC268[1] = 20 * log10 (outputB);
		}
		else
		{
			if (outputA != 0.0)
				d2IEC268[0] = 100 * outputA;
			if (outputB != 0.0)
				d2IEC268[1] = 100 * outputB;
		}
	}
	
    outputA = 0.0;
    outputB = 0.0;
	
	if (d3IEC268)
	{
		outputA = (fabs (frequency[4]) + fabs (frequency[3])) / fabs (2*frequency[1]);
        outputB = (fabs (frequency[9]) + fabs (frequency[8])) / fabs (2*frequency[1]);
		
		if (units == RSSIUP_UNIT_DB)
		{
			if (outputA != 0.0)
				d3IEC268[0] = 20 * log10 (outputA);
			if (outputB != 0.0)
				d3IEC268[1] = 20 * log10 (outputB);
		}
		else
		{
			if (outputA != 0.0)
				d3IEC268[0] = 100 * outputA;
			if (outputB != 0.0)
				d3IEC268[1] = 100 * outputB;
		}
	}
	
    outputA = 0.0;
    outputB = 0.0;
	
	if (d2IEC118)
	{
		outputA = fabs (frequency[2]) / fabs (frequency[1]);
        outputB = fabs (frequency[7]) / fabs (frequency[6]);
		
		if (units == RSSIUP_UNIT_DB)
		{
			if (outputA != 0.0)
				d2IEC118[0] = 20 * log10 (outputA);
			if (outputB != 0.0)
				d2IEC118[1] = 20 * log10 (outputB);
		}
		else
		{
			if (outputA != 0.0)
				d2IEC118[0] = 100 * outputA;
			if (outputB != 0.0)
				d2IEC118[1] = 100 * outputB;
		}
	}
	
    outputA = 0.0;
    outputB = 0.0;
	
	if (d3IEC118)
	{
		outputA = fabs (frequency[3]) / fabs (frequency[1]);
		outputB = fabs (frequency[8]) / fabs (frequency[6]);
		
		if (units == RSSIUP_UNIT_DB)
		{
			if (outputA != 0.0)
				d3IEC118[0] = 20 * log10 (outputA);
			if (outputB != 0.0)
				d3IEC118[1] = 20 * log10 (outputB);
		}
		else
		{
			if (outputA != 0.0)
				d3IEC118[0] = 100 * outputA;
			if (outputB != 0.0)
				d3IEC118[1] = 100 * outputB;
		}
	}
	
    return rssiup_status; 
}

/*===========================================================================*/
/* Function: Analyzer DFD Post FFT Measurement
/* Purpose:  This function returns possible addition of main result of 
/*           Difference Frequency Distortion measurement when Post FFT is ON 
/*           and Data Reduction is OFF.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerDFDPostFFTMeasurement(
    ViSession   instrSession,
    ViInt32     _VI_FAR fftResponseHeader[],
    ViReal64    _VI_FAR spectralLines[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_DFD_POST_FFT};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDFDMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDFDMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (fftResponseHeader || spectralLines)
    {
		// no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
		
		if (fftResponseHeader)
	    {
	        ViChar  *p2response;

	        p2response = (ViChar *)fftResponseHeader;

	        if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	        {
	            memcpy (p2response, &instrPtr -> AnlMeasDFDPostFFT.Header_A, sizeof (TFFTResHeader));

	            p2response += sizeof (TFFTResHeader);
	        }
        
	        if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	            memcpy (p2response, &instrPtr -> AnlMeasDFDPostFFT.Header_B, sizeof (TFFTResHeader));
	    }

	    if (spectralLines)
	    {
	        ViChar      *p2response;

	        p2response = (ViChar *)spectralLines;

	        if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	        {
	            rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasDFDPostFFT.SpLines_A,
	                instrPtr -> AnlMeasDFDPostFFT.Header_A.NOSL);

	            /* Recalculate FFT data */
	            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasDFDPostFFT.Header_A,
	                (ViReal64 *)p2response, instrPtr -> analyzerMode);

	            p2response += instrPtr -> AnlMeasDFDPostFFT.Header_A.NOSL * sizeof (ViReal64);
	        }

	        if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	        {
	            rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasDFDPostFFT.SpLines_B,
	                instrPtr -> AnlMeasDFDPostFFT.Header_B.NOSL);

	            /* Recalculate FFT data */
	            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasDFDPostFFT.Header_B,
	                (ViReal64 *)p2response, instrPtr -> analyzerMode);
	        }
	    }
	}

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer DFD Data Reduction FFT Measurement
/* Purpose:  This function returns possible addition of main result of 
/*           Difference Frequency Distortion measurement when Post FFT is ON 
/*           and Data Reduction is ON.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_AnalyzerDFDDataReductionFFTMeasurement(
    ViSession   instrSession,
    ViInt32     _VI_FAR fftResponseHeaderMin[],
    ViReal64    _VI_FAR spectralLinesMin[],
    ViInt32     _VI_FAR fftResponseHeaderMax[],
    ViReal64    _VI_FAR spectralLinesMax[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_DFD_REDUCED_FFT};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDFDMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDFDMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (fftResponseHeaderMin || spectralLinesMin || fftResponseHeaderMax || spectralLinesMax)
        {
        if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (fftResponseHeaderMin)
            memcpy (fftResponseHeaderMin, &instrPtr -> AnlMeasDFDReducedFFT.HeaderMin,
                sizeof (TFFTResHeader));

        if (spectralLinesMin)
            {
            rssiup_float_to_double (spectralLinesMin, instrPtr -> AnlMeasDFDReducedFFT.SLmin,
                instrPtr -> AnlMeasDFDReducedFFT.HeaderMin.DisplaySize);

            /* Recalculate FFT data */
            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasDFDReducedFFT.HeaderMin,
                spectralLinesMin, instrPtr -> analyzerMode);
            }

        if (fftResponseHeaderMax)
            memcpy (fftResponseHeaderMax, &instrPtr -> AnlMeasDFDReducedFFT.HeaderMax,
                sizeof (TFFTResHeader));

        if (spectralLinesMax)
            {
            rssiup_float_to_double (spectralLinesMax, instrPtr -> AnlMeasDFDReducedFFT.SLmax,
                instrPtr -> AnlMeasDFDReducedFFT.HeaderMax.DisplaySize);

            /* Recalculate FFT data */
            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasDFDReducedFFT.HeaderMax,
                spectralLinesMax, instrPtr -> analyzerMode);
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer Mod Dist Main Measurement
/* Purpose:  This function returns main result of Modulation Distortion 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerModDistMainMeasurement(
    ViSession   instrSession,
/*  ViReal64    _VI_FAR markerFrequencies[], */
/*  ViReal64    _VI_FAR markerValues[], */
    ViInt32     _VI_FAR autoTuneLocked[],
    ViReal64    _VI_FAR frequencies[],
    ViReal64    _VI_FAR rmsValues[],
    ViPInt32    levelValuesUnit
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_MOD_DIST};
	ViInt32             measId_post[]   = {MEAS_MOD_DIST_POST_FFT};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afModDist][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afModDist][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (/* markerFrequencies || markerValues || */ autoTuneLocked || frequencies || rmsValues)
    {
        ViBoolean   post_fft        = VI_FALSE;
        ViInt32     post_fft_size   = 0,
                    post_fft_window = 0;
        
        // get the Post FFT state
		CHECKERR (rssiup_GetAnalyzerFunctionDistFFTSettings (instrSession, &post_fft, &post_fft_size, &post_fft_window)); 
		
	    // Post FFT is turned ON
		if (post_fft == VI_TRUE)
		{
			// no reading has been done yet, do it now
			if (instrPtr->cachedData == VI_FALSE)
        		CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId_post, 1));
		}
		else
			if (instrPtr->cachedData == VI_FALSE)
				CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
/*
        if (markerFrequencies)
            {
            markerFrequencies[0] = instrPtr -> AnlMeasModDist.Marker1_FFTFrequency;
            markerFrequencies[1] = instrPtr -> AnlMeasModDist.Marker2_FFTFrequency;
            }

        if (markerValues)
            {
            markerValues[0] = instrPtr -> AnlMeasModDist.Marker1_Value_A;
            markerValues[1] = instrPtr -> AnlMeasModDist.Marker2_Value_A;
            markerValues[2] = instrPtr -> AnlMeasModDist.Marker1_Value_B;
            markerValues[3] = instrPtr -> AnlMeasModDist.Marker2_Value_B;
            }
*/
        if (autoTuneLocked)
            {
            autoTuneLocked[0] = instrPtr -> AnlMeasModDist.AutotuneLocked_A;
            autoTuneLocked[1] = instrPtr -> AnlMeasModDist.AutotuneLocked_B;
            }

        if (frequencies)
            {
            ViInt32     idx = 0;

            for (idx = 0; idx < 6; idx++)
                {
                frequencies[idx] =  instrPtr -> AnlMeasModDist.Frequencies_A[idx];
                frequencies[idx + 6] =  instrPtr -> AnlMeasModDist.Frequencies_B[idx];
                }
            }

        if (rmsValues)
            {
            ViInt32     idx = 0;

            if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
                {
                for (idx = 0; idx < 6; idx++)
                    {
                    rmsValues[idx] =  sqrt(instrPtr -> AnlMeasModDist.RMSValues_A[idx]);
                    rmsValues[idx + 6] =  sqrt(instrPtr -> AnlMeasModDist.RMSValues_B[idx]);
                    }
                }
            else /* Digital analyzer */
                {
                for (idx = 0; idx < 6; idx++)
                    {
                    rmsValues[idx] = sqrt(2) * sqrt(instrPtr -> AnlMeasModDist.RMSValues_A[idx]);
                    rmsValues[idx + 6] = sqrt(2) * sqrt(instrPtr -> AnlMeasModDist.RMSValues_B[idx]);
                    }
                }
            }

        if (levelValuesUnit)
            *levelValuesUnit = (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL) ?
                    RSSIUP_UNIT_FS : RSSIUP_UNIT_V;
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer Mod Dist Measurement Results
/* Purpose:  This function returns calculated result of combined 2nd and 3rd 
/*           order of Modulation Distortion measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerModDistMeasurementResults (ViSession instrSession,
                                                            ViInt32 units,
                                                            ViReal64 modDist[])
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};
	ViReal64            outputA         = 0.0,
                        outputB         = 0.0,
						inputA_2        = 0.0,
						inputA_3        = 0.0,
						inputB_2        = 0.0,
						inputB_3        = 0.0;
	ViInt32             autoTuneLocked[2];
    ViReal64            frequency[12];
    ViReal64            RMS[12];
    ViInt32             levelValuesUnit;
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	CHECKERR (rssiup_AnalyzerModDistMainMeasurement (instrSession, autoTuneLocked,
												 frequency, RMS, &levelValuesUnit));
	
	if (modDist && (frequency[1] || frequency[7]))
	{
		inputA_2 = (fabs (frequency[3]) + fabs (frequency[2])) / fabs (frequency[1]);
		inputA_3 = (fabs (frequency[9]) + fabs (frequency[8])) / fabs (frequency[7]);
		inputB_2 = (fabs (frequency[4]) + fabs (frequency[5])) / fabs (frequency[1]);
		inputB_3 = (fabs (frequency[10]) + fabs (frequency[11])) / fabs (frequency[7]);
		
		outputA = sqrt (inputA_2*inputA_2 + inputA_3*inputA_3);
        outputB = sqrt (inputB_2*inputB_2 + inputB_3*inputB_3);
		
		if (units == RSSIUP_UNIT_DB)
		{
			if (outputA != 0.0)
				modDist[0] = 20 * log10 (outputA);
			if (outputB != 0.0)
				modDist[1] = 20 * log10 (outputB);
		}
		else
		{
			if (outputA != 0.0)
				modDist[0] = 100 * outputA;
			if (outputB != 0.0)
				modDist[1] = 100 * outputB;
		}
	}
	
    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer Mod Dist Post FFT Measurement
/* Purpose:  This function returns possible addition of main result of 
/*           Modulation Distortion measurement when Post FFT is ON and Data 
/*           Reduction is OFF.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerModDistPostFFTMeasurement(
    ViSession   instrSession,
    ViInt32     _VI_FAR fftResponseHeader[],
    ViReal64    _VI_FAR spectralLines[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_MOD_DIST_POST_FFT};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afModDist][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afModDist][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (fftResponseHeader || spectralLines)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (fftResponseHeader)
	    {
	        ViChar  *p2response;

	        p2response = (ViChar *)fftResponseHeader;

	        if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	        {
	            memcpy (p2response, &instrPtr -> AnlMeasModDistPostFFT.Header_A, sizeof (TFFTResHeader));

	            p2response += sizeof (TFFTResHeader);
	        }
        
	        if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	            memcpy (p2response, &instrPtr -> AnlMeasModDistPostFFT.Header_B, sizeof (TFFTResHeader));
	    }

	    if (spectralLines)
	    {
	        ViChar      *p2response;

	        p2response = (ViChar *)spectralLines;

	        if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	        {
	            rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasModDistPostFFT.SpLines_A,
	                instrPtr -> AnlMeasModDistPostFFT.Header_A.NOSL);

	            /* Recalculate FFT data */
	            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasModDistPostFFT.Header_A,
	                (ViReal64 *)p2response, instrPtr -> analyzerMode);

	            p2response += instrPtr -> AnlMeasModDistPostFFT.Header_A.NOSL * sizeof (ViReal64);
	        }

	        if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	        {
	            rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasModDistPostFFT.SpLines_B,
	                instrPtr -> AnlMeasModDistPostFFT.Header_B.NOSL);

	            /* Recalculate FFT data */
	            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasModDistPostFFT.Header_B,
	                (ViReal64 *)p2response, instrPtr -> analyzerMode);
	        }
	    }
    }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer Mod Dist Data Reduction FFT Measurement
/* Purpose:  This function returns possible addition of main result of 
/*           Modulation Distortion measurement when Post FFT is ON and Data 
/*           Reduction is ON.
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_AnalyzerModDistDataReductionFFTMeasurement(
    ViSession   instrSession,
    ViInt32     _VI_FAR fftResponseHeaderMin[],
    ViReal64    _VI_FAR spectralLinesMin[],
    ViInt32     _VI_FAR fftResponseHeaderMax[],
    ViReal64    _VI_FAR spectralLinesMax[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_MOD_DIST_REDUCED_FFT};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afModDist][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afModDist][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (fftResponseHeaderMin || spectralLinesMin || fftResponseHeaderMax || spectralLinesMax)
        {
        if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (fftResponseHeaderMin)
            memcpy (fftResponseHeaderMin, &instrPtr -> AnlMeasModDistReducedFFT.HeaderMin,
                sizeof (TFFTResHeader));

        if (spectralLinesMin)
            {
            rssiup_float_to_double (spectralLinesMin, instrPtr -> AnlMeasModDistReducedFFT.SLmin,
                instrPtr -> AnlMeasModDistReducedFFT.HeaderMin.DisplaySize);

            /* Recalculate FFT data */
            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasModDistReducedFFT.HeaderMin,
                spectralLinesMin, instrPtr -> analyzerMode);
            }

        if (fftResponseHeaderMax)
            memcpy (fftResponseHeaderMax, &instrPtr -> AnlMeasModDistReducedFFT.HeaderMax,
                sizeof (TFFTResHeader));

        if (spectralLinesMax)
            {
            rssiup_float_to_double (spectralLinesMax, instrPtr -> AnlMeasModDistReducedFFT.SLmax,
                instrPtr -> AnlMeasModDistReducedFFT.HeaderMax.DisplaySize);

            /* Recalculate FFT data */
            rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasModDistReducedFFT.HeaderMax,
                spectralLinesMax, instrPtr -> analyzerMode);
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer FFT Spectrum Main Measurement
/* Purpose:  This function returns main result of FFT spectrum measurement 
/*           (Data Reduction is OFF).
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerFFTSpectrumMainMeasurement(
    ViSession   instrSession,
/*  ViReal64    _VI_FAR markerFrequencies[], */
/*  ViReal64    _VI_FAR markerValues[], */
    ViInt32     _VI_FAR fftResponseHeader[],
    ViReal64    _VI_FAR spectralLines[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_FFT};
    pTStatusDataRanges  instrPtr        = {0};
    TGetFFTMuTskSetting value_get       = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afFFTMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afFFTMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_FFTMuTsk_SETTING, ChAB, &value_get, sizeof(value_get)));

    /* Support for data reduced results */
    if (value_get.DataReductionOn == ON)
        {
        measId[0] = MEAS_FFT_REDUCED;
        }

    if (/* markerFrequencies || markerValues || */ fftResponseHeader || spectralLines)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
        	CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
/*
        if (markerFrequencies)
            {
            markerFrequencies[0] = instrPtr -> AnlMeasFFT.Marker1_FFTFrequency;
            markerFrequencies[1] = instrPtr -> AnlMeasFFT.Marker2_FFTFrequency;
            }

        if (markerValues)
            {
            markerValues[0] = instrPtr -> AnlMeasFFT.Marker1_Value_A;
            markerValues[1] = instrPtr -> AnlMeasFFT.Marker2_Value_A;
            markerValues[2] = instrPtr -> AnlMeasFFT.Marker1_Value_B;
            markerValues[3] = instrPtr -> AnlMeasFFT.Marker2_Value_B;
            }
*/
        if (fftResponseHeader)
            {
            ViChar  *p2response;

            p2response = (ViChar *)fftResponseHeader;

            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                memcpy (p2response, &instrPtr -> AnlMeasFFT.Header_A, sizeof (TFFTResHeader));

                p2response += sizeof (TFFTResHeader);
                }
            
            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                memcpy (p2response, &instrPtr -> AnlMeasFFT.Header_B, sizeof (TFFTResHeader));
            }

        if (spectralLines)
            {
            ViChar      *p2response;

            p2response = (ViChar *)spectralLines;

            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasFFT.SpLines_A,
                    instrPtr -> AnlMeasFFT.Header_A.NOSL);

                /* Recalculate FFT data */
                rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasFFT.Header_A,
                    (ViReal64 *)p2response, instrPtr -> analyzerMode);

                p2response += instrPtr -> AnlMeasFFT.Header_A.NOSL * sizeof (ViReal64);
                }

            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                {
                rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasFFT.SpLines_B,
                    instrPtr -> AnlMeasFFT.Header_B.NOSL);

                /* Recalculate FFT data */
                rssiup_recalculateFFTMeasurement (instrPtr -> AnlMeasFFT.Header_B,
                    (ViReal64 *)p2response, instrPtr -> analyzerMode);
                }
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer FFT Spectrum Data Reduction Measurement
/* Purpose:  This function returns result of FFT spectrum measurement (Data 
/*           Reduction is ON).
/*===========================================================================*/
ViStatus /* _VI_FUNC */ rssiup_AnalyzerFFTSpectrumDataReductionMeasurement(
    ViSession   instrSession,
    ViReal64    _VI_FAR markerFrequencies[],
    ViReal64    _VI_FAR markerValues[],
    ViInt32     _VI_FAR fftResponseHeaderMin[],
    ViReal64    _VI_FAR spectralLinesMin[],
    ViInt32     _VI_FAR fftResponseHeaderMax[],
    ViReal64    _VI_FAR spectralLinesMax[]
)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_FFT_REDUCED};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afFFTMuTsk][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afFFTMuTsk][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
	if (markerFrequencies || markerValues || fftResponseHeaderMin ||
        spectralLinesMin || fftResponseHeaderMax || spectralLinesMax)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (markerFrequencies)
            {
            markerFrequencies[0] = instrPtr -> AnlMeasFFTReduced.Marker1_FFTFrequency;
            markerFrequencies[1] = instrPtr -> AnlMeasFFTReduced.Marker2_FFTFrequency;
            }

        if (markerValues)
            {
            markerValues[0] = instrPtr -> AnlMeasFFTReduced.Marker1_Value_A;
            markerValues[1] = instrPtr -> AnlMeasFFTReduced.Marker2_Value_A;
            markerValues[2] = instrPtr -> AnlMeasFFTReduced.Marker1_Value_B;
            markerValues[3] = instrPtr -> AnlMeasFFTReduced.Marker2_Value_B;
            }

        /* Min */

        if (fftResponseHeaderMin)
            {
            ViChar  *p2response;

            p2response = (ViChar *)fftResponseHeaderMin;

            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                memcpy (p2response, &instrPtr -> AnlMeasFFTReduced.Header_A_min,
                    sizeof (TFFTResHeader));

                p2response += sizeof (TFFTResHeader);
                }
            
            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                memcpy (p2response, &instrPtr -> AnlMeasFFTReduced.Header_B_min,
                    sizeof (TFFTResHeader));
            }

        if (spectralLinesMin)
            {
            ViChar      *p2response;

            p2response = (ViChar *)spectralLinesMin;

            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasFFTReduced.SpLnMin_A_min,
                    instrPtr -> AnlMeasFFTReduced.Header_A_min.DisplaySize);

                p2response += instrPtr -> AnlMeasFFTReduced.Header_A_min.DisplaySize * sizeof (ViReal64);
                }

            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasFFTReduced.SpLnMin_B_min,
                    instrPtr -> AnlMeasFFTReduced.Header_B_min.DisplaySize);
            }

        /* Max */

        if (fftResponseHeaderMax)
            {
            ViChar  *p2response;

            p2response = (ViChar *)fftResponseHeaderMax;

            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                memcpy (p2response, &instrPtr -> AnlMeasFFTReduced.Header_A_max,
                    sizeof (TFFTResHeader));

                p2response += sizeof (TFFTResHeader);
                }
            
            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                memcpy (p2response, &instrPtr -> AnlMeasFFTReduced.Header_B_max,
                    sizeof (TFFTResHeader));
            }

        if (spectralLinesMax)
            {
            ViChar      *p2response;

            p2response = (ViChar *)spectralLinesMax;

            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasFFTReduced.SpLnMax_A_max,
                    instrPtr -> AnlMeasFFTReduced.Header_A_max.DisplaySize);

                p2response += instrPtr -> AnlMeasFFTReduced.Header_A_max.DisplaySize * sizeof (ViReal64);
                }

            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                rssiup_float_to_double ((ViReal64 *)p2response, instrPtr -> AnlMeasFFTReduced.SpLnMax_B_max,
                    instrPtr -> AnlMeasFFTReduced.Header_B_max.DisplaySize);
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer RMS Sweep Measurement
/* Purpose:  This function returns data results of RMS Sweep measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerRMSSweepMeasurement (ViSession instrSession,
                                                      ViUInt16 *sweepCount,
                                                      ViUInt16 *sampleCount,
                                                      ViReal64 actualAmplitude[],
													  ViReal64 sweepParams[],
													  ViReal64 RMSValues[])
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_RMS_SWEEP};
    pTStatusDataRanges  instrPtr        = {0};
	ViInt32             i               = 0;
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afSinRmsSweep][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afSinRmsSweep][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
	if (sampleCount || sweepCount || actualAmplitude || RMSValues || sweepParams)
    {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

		/* NOT NEEDED
        // check if the data is old, make new measurement
		if ((instrPtr->AnlMeasRMSSweep.wSampleCount == instrPtr->sampleCount) && 
			(instrPtr->newSweep == VI_TRUE))
		{
			if (instrPtr->cachedData == VI_TRUE) // single sweep mode
				CHECKERR (rssiup_StartMeasurementWaitOPC (instrSession, instrPtr->oldTimeout));
			else // continuous mode
				CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
		}
		*/
		
		if (sampleCount)
		{
			*sampleCount = instrPtr->AnlMeasRMSSweep.wSampleCount;
			//instrPtr->sampleCount = instrPtr->AnlMeasRMSSweep.wSampleCount;
		}
		
		if (sweepCount)
			*sweepCount = instrPtr->AnlMeasRMSSweep.wStartSwCnt;
		
		
		if (actualAmplitude) 
		{
			actualAmplitude[0] = instrPtr->AnlMeasRMSSweep.fiActualAm1[0];
			actualAmplitude[1] = instrPtr->AnlMeasRMSSweep.fiActualAm1[1];
			actualAmplitude[2] = instrPtr->AnlMeasRMSSweep.fiActualAm2[0];
			actualAmplitude[3] = instrPtr->AnlMeasRMSSweep.fiActualAm2[1];
		}
		
		for (i = 0; i < instrPtr->AnlMeasRMSSweep.wSampleCount; i++)
		{
			if ((instrPtr->AnlMeasRMSSweep.Fr1spacing == 0) && (instrPtr->AnlMeasRMSSweep.Am1spacing[0] == 1))
			{
			sweepParams[i*2] = instrPtr->AnlMeasRMSSweep.Sample[i].fiFr1AmA / sqrt (2);
			sweepParams[i*2+1] = instrPtr->AnlMeasRMSSweep.Sample[i].fiFr2AmB / sqrt (2);
			}
			else
			{
				sweepParams[i*2] = instrPtr->AnlMeasRMSSweep.Sample[i].fiFr1AmA;
				sweepParams[i*2+1] = instrPtr->AnlMeasRMSSweep.Sample[i].fiFr2AmB;
			}
			RMSValues[i*2] = sqrt (instrPtr->AnlMeasRMSSweep.Sample[i].fiRmsA);
			RMSValues[i*2+1] = sqrt (instrPtr->AnlMeasRMSSweep.Sample[i].fiRmsB);
		}
    } 
	
	//instrPtr->newSweep = VI_FALSE;
			
	return rssiup_status;			
}

/*===========================================================================*/
/* Function: Analyzer RMS Selective Sweep Measurement
/* Purpose:  This function returns data results of RMS Selective Sweep 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerRMSSelectiveSweepMeasurement (ViSession instrSession,
                                                               ViUInt16 *sweepCount,
                                                               ViUInt16 *sampleCount,
                                                               ViReal64 sweepParams[],
															   ViReal64 actualAmplitude[],
                                                               /*ViReal64 amplitudeFrequency[],*/
                                                               ViInt32 autoTuneLocked[],
                                                               ViReal64 frequency[],
                                                               ViReal64 RMS[])
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_RMS_SELECTIVE_SWEEP};
    pTStatusDataRanges  instrPtr        = {0};
	ViInt32             i               = 0;
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afSinRSmSweep][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afSinRSmSweep][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
	if (sampleCount || sweepCount || sweepParams || actualAmplitude || autoTuneLocked || frequency || RMS)
    {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

		/* NOT NEEDED
        // check if the data is old, make new measurement
		if ((instrPtr->AnlMeasRMSSelectiveSweep.wSampleCount == instrPtr->sampleCount) && 
			(instrPtr->newSweep == VI_TRUE))
		{
			if (instrPtr->cachedData == VI_TRUE) // single sweep mode
				CHECKERR (rssiup_StartMeasurementWaitOPC (instrSession, instrPtr->oldTimeout));
			else // continuous mode
				CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
		}
		*/
		
		if (sampleCount)
		{
			*sampleCount = instrPtr->AnlMeasRMSSelectiveSweep.wSampleCount;
			//instrPtr->sampleCount = instrPtr->AnlMeasRMSSelectiveSweep.wSampleCount;
		}
		
		if (sweepCount)
			*sweepCount = instrPtr->AnlMeasRMSSelectiveSweep.wStartSwCnt;
		
		if (actualAmplitude)
		{
			actualAmplitude[0] = instrPtr->AnlMeasRMSSelectiveSweep.fiActualAm1[0];
			actualAmplitude[1] = instrPtr->AnlMeasRMSSelectiveSweep.fiActualAm1[1];
			actualAmplitude[2] = instrPtr->AnlMeasRMSSelectiveSweep.fiActualAm2[0];
			actualAmplitude[3] = instrPtr->AnlMeasRMSSelectiveSweep.fiActualAm2[1];
		}
		
		for (i = 0; i < instrPtr->AnlMeasRMSSelectiveSweep.wSampleCount; i++)
		{
			if ((instrPtr->AnlMeasRMSSelectiveSweep.FrGen1spacing == 0) && (instrPtr->AnlMeasRMSSelectiveSweep.Am1spacing[0] == 1))
			{
			sweepParams[i*2] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFr1AmA / sqrt (2);
			sweepParams[i*2+1] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFr2AmB / sqrt (2);
			}
			else
			{
				sweepParams[i*2] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFr1AmA;
				sweepParams[i*2+1] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFr2AmB;
			}
			/*amplitudeFrequency[i*2] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFrAAnl;*/
			/*amplitudeFrequency[i*2+1] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFrBAnl;*/
			autoTuneLocked[i*2] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmA.iAutoTuneLocked;
			autoTuneLocked[i*2+1] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmB.iAutoTuneLocked;
			frequency[i*2] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmA.fiFrequency;
			frequency[i*2+1] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmB.fiFrequency;
			RMS[i*2] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmA.fiRMS;
			RMS[i*2+1] = instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmB.fiRMS;
		}
    }    
			
	//instrPtr->newSweep = VI_FALSE;
			
	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Analyzer THD Sweep Measurement
/* Purpose:  This function returns data results of THD Sweep measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerTHDSweepMeasurement (ViSession instrSession,
                                                      ViUInt16 *sweepCount,
                                                      ViUInt16 *sampleCount,
                                                      ViReal64 sweepParams[],
                                                      ViReal64 actualAmplitude[],
                                                      /*ViReal64 amplitudeFrequency[],*/
                                                      ViInt32 autoTuneLocked[],
                                                      ViReal64 frequency[],
                                                      ViReal64 totalRMS[],
                                                      ViReal64 noiseRMS[],
                                                      ViReal64 totalRMSNonfund[],
                                                      ViReal64 totalRMSTHD[],
                                                      ViReal64 harmonicLines[])
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_THD_SWEEP};
    pTStatusDataRanges  instrPtr        = {0};
	ViInt32             i               = 0;
	ViInt32             idx             = 0;
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afSinThdSweep][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afSinThdSweep][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
	if (sampleCount || sweepCount || sweepParams || actualAmplitude || autoTuneLocked || frequency ||
		totalRMS || noiseRMS || totalRMSNonfund || totalRMSTHD || harmonicLines)
    {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

		/* NOT NEEDED
        // check if the data is old, make new measurement
		if ((instrPtr->AnlMeasTHDSweep.wSampleCount == instrPtr->sampleCount) && 
			(instrPtr->newSweep == VI_TRUE))
		{
			if (instrPtr->cachedData == VI_TRUE) // single sweep mode
				CHECKERR (rssiup_StartMeasurementWaitOPC (instrSession, instrPtr->oldTimeout));
			else // continuous mode
				CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));
		}
		*/
		
		if (sampleCount)
		{
			*sampleCount = instrPtr->AnlMeasTHDSweep.wSampleCount;
			/*instrPtr->sampleCount = instrPtr->AnlMeasTHDSweep.wSampleCount;*/
		}
		
		if (sweepCount)
			*sweepCount = instrPtr->AnlMeasTHDSweep.wStartSwCnt;
		
		if (actualAmplitude)
		{
			actualAmplitude[0] = instrPtr->AnlMeasTHDSweep.fiActualAm1[0];
			actualAmplitude[1] = instrPtr->AnlMeasTHDSweep.fiActualAm1[1];
			actualAmplitude[2] = instrPtr->AnlMeasTHDSweep.fiActualAm2[0];
			actualAmplitude[3] = instrPtr->AnlMeasTHDSweep.fiActualAm2[1];
		}
		
		for (i = 0; i < instrPtr->AnlMeasTHDSweep.wSampleCount; i++)
		{
			if ((instrPtr->AnlMeasTHDSweep.FrGen1spacing == 0) && (instrPtr->AnlMeasTHDSweep.Am1spacing[0] == 1))
			{
			sweepParams[i*2] = instrPtr->AnlMeasTHDSweep.Sample[i].fiFr1AmA / sqrt (2);
			sweepParams[i*2+1] = instrPtr->AnlMeasTHDSweep.Sample[i].fiFr2AmB / sqrt (2);
			}
			else
			{
				sweepParams[i*2] = instrPtr->AnlMeasTHDSweep.Sample[i].fiFr1AmA;
				sweepParams[i*2+1] = instrPtr->AnlMeasTHDSweep.Sample[i].fiFr2AmB;
			}
			/*amplitudeFrequency[i*2] = instrPtr->AnlMeasTHDSweep.Sample[i].fiFrAAnl;*/
			/*amplitudeFrequency[i*2+1] = instrPtr->AnlMeasTHDSweep.Sample[i].fiFrBAnl;*/
			autoTuneLocked[i*2] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.AutoTuneLocked;
			autoTuneLocked[i*2+1] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.AutoTuneLocked;
			frequency[i*2] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.Frequency;
			frequency[i*2+1] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.Frequency;
			
			if (instrPtr -> analyzerMode == RSSIUP_ANALYZER_MODE_ANALOG) /* Analog analyzer */
			{
				totalRMS[i*2] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.TotalRMS_THDN;
				totalRMS[i*2+1] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.TotalRMS_THDN;
				noiseRMS[i*2] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.Noise_THDN;
				noiseRMS[i*2+1] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.Noise_THDN;
				totalRMSNonfund[i*2] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.TotalRMS_THDN_NonFund;
				totalRMSNonfund[i*2+1] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.TotalRMS_THDN_NonFund;
				totalRMSTHD[i*2] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.TotalRMS_THD;	
				totalRMSTHD[i*2+1] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.TotalRMS_THD;	
			
				for (idx = 0; idx < 10; idx++)
				{
					harmonicLines[i*20+idx] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.Harmonic[idx];
					harmonicLines[i*20+idx+10] = instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.Harmonic[idx];
				}
			}
			else  /* Digital analyzer */ 
			{
				totalRMS[i*2] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.TotalRMS_THDN);
				totalRMS[i*2+1] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.TotalRMS_THDN);
				noiseRMS[i*2] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.Noise_THDN);
				noiseRMS[i*2+1] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.Noise_THDN);
				totalRMSNonfund[i*2] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.TotalRMS_THDN_NonFund);
				totalRMSNonfund[i*2+1] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.TotalRMS_THDN_NonFund);
				totalRMSTHD[i*2] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.TotalRMS_THD);	
				totalRMSTHD[i*2+1] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.TotalRMS_THD);	
			
				for (idx = 0; idx < 10; idx++)
				{
					harmonicLines[i*20+idx] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.Harmonic[idx]);
					harmonicLines[i*20+idx+10] = sqrt(2) * (instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.Harmonic[idx]);
				}
			}	
		}
    }    
			
	//instrPtr->newSweep = VI_FALSE;
			
	return rssiup_status;
}

/*===========================================================================*/
/* Function: Analyzer THD Sweep Measurement Results
/* Purpose:  This function returns calculated harmonics results of THD sweep 
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerTHDSweepMeasurementResults (ViSession instrSession,
                                                             ViInt32 units,
                                                             ViInt32 *valuesReturned,
                                                             ViReal64 sweepParams[],
                                                             ViReal64 THDAllHarmonics[],
                                                             ViReal64 THDEvenHarmonics[],
                                                             ViReal64 THDOddHarmonics[],
                                                             ViReal64 SINAD[],
                                                             ViReal64 noiseSignal[])
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};
	ViReal64            outputA         = 0.0,
                        outputB         = 0.0,
                        inputA          = 0.0,
                        inputB          = 0.0;
	ViInt32             idx             = 0;
	ViInt32             i               = 0;
	ViUInt16 			sweepCount		= 0;
	ViUInt16 			sampleCount		= 0;
	ViReal64 			getSweepParams[2*200];
	ViReal64 			amplitudeFrequency[2*200];
	ViInt32 			autoTuneLocked[2*200];
	ViReal64 			getFrequency[2*200];
	ViReal64 			totalRMS[2*200];
	ViReal64 			noiseRMS[2*200];
	ViReal64 			totalRMSNonfund[2*200];
	ViReal64 			totalRMSTHD[2*200];
	ViReal64 			harmonicLines[2*10*200];
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	CHECKERR (rssiup_AnalyzerTHDSweepMeasurement (instrSession, &sweepCount, &sampleCount, getSweepParams,
                                                  amplitudeFrequency, autoTuneLocked, getFrequency, totalRMS,
                                                  noiseRMS, totalRMSNonfund, totalRMSTHD, harmonicLines));
	
	*valuesReturned = 2 * sampleCount;
	
	for (i = 0; i < sampleCount; i++)
	{
		if (sweepParams)
		{
			sweepParams[i*2] = getSweepParams[i*2];
	        sweepParams[i*2+1] = getSweepParams[i*2+1];
		}
	
		if (THDAllHarmonics)
		{
			for (idx = 1; idx < 10; idx++)
			{
				inputA += harmonicLines[i*20+idx]*harmonicLines[i*20+idx];
				inputB += harmonicLines[i*20+idx+10]*harmonicLines[i*20+idx+10];
			}
		
			if (inputA != 0.0)
				outputA = sqrt (inputA) / totalRMSTHD[i*2];
			if (inputB != 0.0)
				outputB = sqrt (inputB) / totalRMSTHD[i*2+1];
	
			if (units == RSSIUP_UNIT_DB)
			{
				if (outputA != 0.0)
					THDAllHarmonics[i*2] = 20 * log10 (outputA);
				if (outputB != 0.0)
					THDAllHarmonics[i*2+1] = 20 * log10 (outputB);
			}
			else
			{
				if (outputA != 0.0)
					THDAllHarmonics[i*2] = 100 * outputA;
				if (outputB != 0.0)
					THDAllHarmonics[i*2+1] = 100 * outputB;
			}
		}
	
		outputA = 0.0;
	    outputB = 0.0;
	    inputA  = 0.0;
	    inputB  = 0.0;
	
		if (THDEvenHarmonics)
		{
			for (idx = 1; idx < 10; idx=idx+2)
			{
				inputA += harmonicLines[i*20+idx]*harmonicLines[i*20+idx];
				inputB += harmonicLines[i*20+idx+10]*harmonicLines[i*20+idx+10];
			}
		
			if (inputA != 0.0)
				outputA = sqrt (inputA) / totalRMSTHD[i*2];
			if (inputB != 0.0)
				outputB = sqrt (inputB) / totalRMSTHD[i*2+1];
	
			if (units == RSSIUP_UNIT_DB)
			{
				if (outputA != 0.0)
					THDEvenHarmonics[i*2] = 20 * log10 (outputA);
				if (outputB != 0.0)
					THDEvenHarmonics[i*2+1] = 20 * log10 (outputB);
			}
			else
			{
				if (outputA != 0.0)
					THDEvenHarmonics[i*2] = 100 * outputA;
				if (outputB != 0.0)
					THDEvenHarmonics[i*2+1] = 100 * outputB;
			}
		}
	
		outputA = 0.0;
	    outputB = 0.0;
	    inputA  = 0.0;
	    inputB  = 0.0;
	
		if (THDOddHarmonics)
		{
			for (idx = 2; idx < 10; idx=idx+2)
			{
				inputA += harmonicLines[i*20+idx]*harmonicLines[i*20+idx];
				inputB += harmonicLines[i*20+idx+10]*harmonicLines[i*20+idx+10];
			}
		
			if (inputA != 0.0)
				outputA = sqrt (inputA) / totalRMSTHD[i*2];
			if (inputB != 0.0)
				outputB = sqrt (inputB) / totalRMSTHD[i*2+1];
	
			if (units == RSSIUP_UNIT_DB)
			{
				if (outputA != 0.0)
					THDOddHarmonics[i*2] = 20 * log10 (outputA);
				if (outputB != 0.0)
					THDOddHarmonics[i*2+1] = 20 * log10 (outputB);
			}
			else
			{
				if (outputA != 0.0)
					THDOddHarmonics[i*2] = 100 * outputA;
				if (outputB != 0.0)
					THDOddHarmonics[i*2+1] = 100 * outputB;
			}
		}
	
		outputA = 0.0;
	    outputB = 0.0;
	    inputA  = 0.0;
	    inputB  = 0.0;
	
		if (SINAD)
		{
			inputA = totalRMSNonfund[i*2] / totalRMS[i*2];
			inputB = totalRMSNonfund[i*2+1] / totalRMS[i*2+1];
		
			if (units == RSSIUP_UNIT_DB)
			{
				if (inputA != 0.0)
					SINAD[i*2] = -20 * log10 (inputA);
				if (inputB != 0.0)
					SINAD[i*2+1] = -20 * log10 (inputB);
			}
			else
			{
				SINAD[0] = 0.0;
				SINAD[1] = 0.0;
			}
		}
	
		outputA = 0.0;
	    outputB = 0.0;
	    inputA  = 0.0;
	    inputB  = 0.0;
	
		if (noiseSignal)
		{
			outputA = noiseRMS[i*2] / totalRMS[i*2];
			outputB = noiseRMS[i*2+1] / totalRMS[i*2+1];
		
			if (units == RSSIUP_UNIT_DB)
			{
				if (outputA != 0.0)
					noiseSignal[i*2] = 20 * log10 (outputA);
				if (outputB != 0.0)
					noiseSignal[i*2+1] = 20 * log10 (outputB);
			}
			else
			{
				if (outputA != 0.0)
					noiseSignal[i*2] = 100 * outputA;
				if (outputB != 0.0)
					noiseSignal[i*2+1] = 100 * outputB;
			}	
		}
	}

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Analyzer THD Sweep Measurement Results Extended
/* Purpose:  This function returns calculated THD+N results 
/*           of THD sweep measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerTHDSweepMeasurementResultsExt (ViSession instrSession,
                                                                ViInt32 units,
                                                                ViInt32 *valuesReturned,
                                                                ViReal64 THDN[])
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};
	ViReal64            inputA          = 0.0,
                        inputB          = 0.0;
	ViInt32             i               = 0;
	ViUInt16 			sweepCount		= 0;
	ViUInt16 			sampleCount		= 0;
	ViReal64 			getSweepParams[2*200];
	ViReal64 			amplitudeFrequency[2*200];
	ViInt32 			autoTuneLocked[2*200];
	ViReal64 			getFrequency[2*200];
	ViReal64 			totalRMS[2*200];
	ViReal64 			noiseRMS[2*200];
	ViReal64 			totalRMSNonfund[2*200];
	ViReal64 			totalRMSTHD[2*200];
	ViReal64 			harmonicLines[2*10*200];
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	CHECKERR (rssiup_AnalyzerTHDSweepMeasurement (instrSession, &sweepCount, &sampleCount, getSweepParams,
                                                  amplitudeFrequency, autoTuneLocked, getFrequency, totalRMS,
                                                  noiseRMS, totalRMSNonfund, totalRMSTHD, harmonicLines));
	
	*valuesReturned = 2 * sampleCount;
	
	for (i = 0; i < sampleCount; i++)
	{
		if (THDN)
		{
			inputA = totalRMSNonfund[i*2] / totalRMS[i*2];
			inputB = totalRMSNonfund[i*2+1] / totalRMS[i*2+1];
		
			if (units == RSSIUP_UNIT_DB)
			{
				if (inputA != 0.0)
					THDN[i*2] = 20 * log10 (inputA);
				if (inputB != 0.0)
					THDN[i*2+1] = 20 * log10 (inputB);
			}
			else
			{
				THDN[i*2] = inputA * 100.0;
				THDN[i*2+1] = inputB * 100.0;
			}
		}
	}

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Analyzer THD Sweep Measurement Results 2
/* Purpose:  This function returns the Sweep Paremeters and calculated THD+N 
/*           results of THD sweep measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_AnalyzerTHDSweepMeasurementResults2 (ViSession instrSession,
                                                              ViInt32 units,
                                                              ViInt32 *valuesReturned,
                                                              ViReal64 sweepParams[],
                                                              ViReal64 THDN[])
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};
	ViReal64            inputA          = 0.0,
                        inputB          = 0.0;
	ViInt32             i               = 0;
	ViUInt16 			sweepCount		= 0;
	ViUInt16 			sampleCount		= 0;
	ViReal64 			getSweepParams[2*200];
	ViReal64 			amplitudeFrequency[2*200];
	ViInt32 			autoTuneLocked[2*200];
	ViReal64 			getFrequency[2*200];
	ViReal64 			totalRMS[2*200];
	ViReal64 			noiseRMS[2*200];
	ViReal64 			totalRMSNonfund[2*200];
	ViReal64 			totalRMSTHD[2*200];
	ViReal64 			harmonicLines[2*10*200];
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	CHECKERR (rssiup_AnalyzerTHDSweepMeasurement (instrSession, &sweepCount, &sampleCount, getSweepParams,
                                                  amplitudeFrequency, autoTuneLocked, getFrequency, totalRMS,
                                                  noiseRMS, totalRMSNonfund, totalRMSTHD, harmonicLines));
	
	*valuesReturned = 2 * sampleCount;
	
	for (i = 0; i < sampleCount; i++)
	{
		if (sweepParams)
		{
			sweepParams[i*2] = getSweepParams[i*2];
	        sweepParams[i*2+1] = getSweepParams[i*2+1];
		}
	
		if (THDN)
		{
			inputA = totalRMSNonfund[i*2] / totalRMS[i*2];
			inputB = totalRMSNonfund[i*2+1] / totalRMS[i*2+1];
		
			if (units == RSSIUP_UNIT_DB)
			{
				if (inputA != 0.0)
					THDN[i*2] = 20 * log10 (inputA);
				if (inputB != 0.0)
					THDN[i*2+1] = 20 * log10 (inputB);
			}
			else
			{
				THDN[i*2] = inputA * 100.0;
				THDN[i*2+1] = inputB * 100.0;
			}
		}
	}

	return rssiup_status;    
}

/*===========================================================================*/
/* Function: Set Digital Analyzer Sample Rate Settings
/* Purpose:  This function sets parameters for DAI sample rate measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetDigitalAnalyzerSampleRateSettings (ViSession instrSession,
                                                               ViReal64 measurementTime)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TCmdDAISampleRate   value           = {0};

    if (rssiup_invalidViReal64Range (measurementTime, 0.02, 30.0))
        return VI_ERROR_PARAMETER2;

    DBL2FLT(measurementTime, value.MeasurementTime);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_DAISAMPLERATE_SETTING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Digital Analyzer Sample Rate Settings
/* Purpose:  This function returns parameters for DAI sample rate measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetDigitalAnalyzerSampleRateSettings (ViSession instrSession,
                                                               ViPReal64 measurementTime)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetDAISampleRate   value           = {0};

    if (!measurementTime)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_DAISAMPLERATE_SETTING, ChAB, &value, sizeof(value)));
    *measurementTime = value.MeasurementTime;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Digital Analyzer Sample Rate Averaging
/* Purpose:  This function sets parameters of averaging mode for DAI sample
/*           rate measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetDigitalAnalyzerSampleRateAveraging (ViSession instrSession,
                                                                ViInt32 averagingMode,
                                                                ViInt32 averagingFactor)
{
    ViStatus                    rssiup_status   = VI_SUCCESS;
    TCmdDAISampleRateAveraging  value           = {0};

    CHECKERR (rssiup_param_to_val (SAverageModeDiscVals, averagingMode, &value.AverageMode, VI_ERROR_PARAMETER2));

    if ((averagingMode == RSSIUP_AVERAGING_MODE_NORMAL) ||
        (averagingMode == RSSIUP_AVERAGING_MODE_EXPONENCIAL))
        return VI_ERROR_PARAMETER2;

    if (rssiup_invalidViInt32Range (averagingFactor, 1, 256))
        return VI_ERROR_PARAMETER3;

    value.AverageFactor = averagingFactor;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_DAISAMPLERATE_AVERAGING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Digital Analyzer Sample Rate Averaging
/* Purpose:  This function returns parameters of averaging mode for DAI
/*           sample rate measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetDigitalAnalyzerSampleRateAveraging (ViSession instrSession,
                                                                ViPInt32 averagingMode,
                                                                ViPInt32 averagingFactor)
{
    ViStatus                    rssiup_status   = VI_SUCCESS;
    TGetDAISampleRateAveraging  value           = {0};

    if (!averagingMode)
        return VI_ERROR_PARAMETER2;
    if (!averagingFactor)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_DAISAMPLERATE_AVERAGING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAverageModeDiscVals, averagingMode, &value.AverageMode, VI_ERROR_INV_RESPONSE));

    if ((*averagingMode == RSSIUP_AVERAGING_MODE_NORMAL) ||
        (*averagingMode == RSSIUP_AVERAGING_MODE_EXPONENCIAL))
        return VI_ERROR_INV_RESPONSE;

    *averagingFactor = value.AverageFactor;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Digital Analyzer Sample Rate Measurement
/* Purpose:  This function returns result of sampling frequency measurement
/*           of DAI input signal.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_DigitalAnalyzerSampleRateMeasurement (ViSession instrSession,
                                                               ViPReal64 samplingFrequency)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_DAI_SAMPLING_FREQUENCY};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDAISamplRate][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDAISamplRate][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (samplingFrequency)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        *samplingFrequency = instrPtr -> AnlMeasDAISamplingFrequency.DAISamplFreq;
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Digital Analyzer Protocol
/* Purpose:  This function sets parameters for received DAI Protocol.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetDigitalAnalyzerProtocol (ViSession instrSession,
                                                     ViInt32 DAIProtocol,
                                                     ViReal64 measurementTime)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TCmdDAIProtocol     value           = {0};

    value.Type = (DAIProtocol == RSSIUP_DAI_PROTOCOL_CH_STATUS) ? 0 : 1; /* 1 = User data */

    if (rssiup_invalidViReal64Range (measurementTime, 1.0e-2, 30.0))
        return VI_ERROR_PARAMETER3;

    DBL2FLT (measurementTime, value.MeasurementTime);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_DAIPROTOCOL_SETTING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Digital Analyzer Protocol
/* Purpose:  This function returns parameters configured for received DAI
/*           Protocol.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetDigitalAnalyzerProtocol (ViSession instrSession,
                                                     ViPInt32 DAIProtocol,
                                                     ViPReal64 measurementTime)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TGetDAIProtocol     value           = {0};

    if (!DAIProtocol)
        return VI_ERROR_PARAMETER2;
    if (!measurementTime)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_DAIPROTOCOL_SETTING, ChAB, &value, sizeof(value)));

    *DAIProtocol = (value.Type == 0) ? RSSIUP_DAI_PROTOCOL_CH_STATUS : RSSIUP_DAI_PROTOCOL_USER_DATA; /* 0 = Channel status */
    *measurementTime = value.MeasurementTime;

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Digital Analyzer Protocol Measurement
/* Purpose:  This function returns result of DAI protocol measurement.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_DigitalAnalyzerProtocolMeasurement (ViSession instrSession,
                                                             ViChar _VI_FAR chAData[],
                                                             ViChar _VI_FAR chBData[],
                                                             ViPInt32 receiverError)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             measId[]        = {MEAS_DAI_PROTOCOL};
    pTStatusDataRanges  instrPtr        = {0};
//	TAnlDescription     AnlDescription  = {0};
	
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

	/* If data are already cached, do not read from instrument DSI_GET_ANL_DESCRIPTION */
	if (instrPtr->cachedData == VI_FALSE)
	{
		CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANL_DESCRIPTION, ChAB,
	            &instrPtr -> AnlDescription, instrPtr->anlDiscSize));
	}
	
	if ((instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDAIProtocol][ChA - 1] != ON) &&
		(instrPtr -> AnlDescription.AnlGenerally.FunctionIsOn[afDAIProtocol][ChB - 1] != ON))
		return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
	
    if (chAData || chBData || receiverError)
        {
        // no reading has been done yet, do it now
		if (instrPtr->cachedData == VI_FALSE)
			CHECKERR (rssiup_handleAnalyzerFunctionData (instrSession, measId, 1));

        if (chAData)
            {
            memcpy (chAData, instrPtr -> AnlMeasDAIProtocol.ChannelStatusA, 24);
            }
        
        if (chBData)
            {
            memcpy (chBData, instrPtr -> AnlMeasDAIProtocol.ChannelStatusB, 24);
            }
        
        if (receiverError)
            {
            *receiverError = instrPtr -> AnlMeasDAIProtocol.ReceiveError;
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Digital Analyzer Input
/* Purpose:  This function selects the digital analyzer input.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetDigitalAnalyzerInput (ViSession instrSession,
                                                  ViInt32 digitalInput)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TDAnlInput  value           = {0};

    CHECKERR (rssiup_param_to_val (STDAnlInputDiscVals, digitalInput, &value, VI_ERROR_PARAMETER2));
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_DANLHW_INPUT_SELECTOR, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Digital Analyzer Input
/* Purpose:  This function returns used digital analyzer input.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetDigitalAnalyzerInput (ViSession instrSession,
                                                  ViPInt32 digitalInput)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TDAnlInput  value           = {0};

    if (!digitalInput)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_DANLHW_INPUT_SELECTOR, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (STDAnlInputDiscVals, digitalInput, &value, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Set Digital Analyzer No of Bits
/* Purpose:  This function sets number of valid bits of DAI Reciever.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_SetDigitalAnalyzerNoofBits (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViInt32 no_ofBits)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TDDevNoOfBits   value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SDDevNoOfBitsDiscVals, no_ofBits, &value, VI_ERROR_PARAMETER3));

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_DANLHW_NUM_OF_BITS, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Get Digital Analyzer No of Bits
/* Purpose:  This function returns number of valid bits of DAI Reciever.
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_GetDigitalAnalyzerNoofBits (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViPInt32 no_ofBits)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TDDevNoOfBits   value           = {0};

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!no_ofBits)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_DANLHW_NUM_OF_BITS, channel, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SDDevNoOfBitsDiscVals, no_ofBits, &value, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Sine Shape
 * Purpose:  This function sets frequency and phase parameters for sine
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionSineShape (ViSession instrSession,
                                                        ViReal64 frequency1,
                                                        ViInt32 frequency1Unit,
                                                        ViReal64 initialPhase1,
                                                        ViInt32 initialPhase1Unit,
                                                        ViReal64 frequency2,
                                                        ViInt32 frequency2Unit,
                                                        ViReal64 initialPhase2,
                                                        ViInt32 initialPhase2Unit)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TSine_SHAPE     value           = {0};

/*
    if (rssiup_invalidViReal64Range (frequency1, , ))
        return VI_ERROR_PARAMETER2;
*/
    if (frequency1Unit != RSSIUP_UNIT_HZ)
        return VI_ERROR_PARAMETER3;
    if (rssiup_invalidViReal64Range (initialPhase1, -180.0, 180.0))
        return VI_ERROR_PARAMETER4;
    if (initialPhase1Unit != RSSIUP_UNIT_DEG)
        return VI_ERROR_PARAMETER5;
/*
    if (rssiup_invalidViReal64Range (frequency2, , ))
        return VI_ERROR_PARAMETER6;
*/
    if (frequency2Unit != RSSIUP_UNIT_HZ)
        return VI_ERROR_PARAMETER7;
    if (rssiup_invalidViReal64Range (initialPhase2, -180.0, 180.0))
        return VI_ERROR_PARAMETER8;
    if (initialPhase2Unit != RSSIUP_UNIT_DEG)
        return VI_ERROR_INSTR_PARAMETER9;

    DBL2FLT(frequency1, value.Frequency1);
    DBL2FLT(initialPhase1, value.InitialPhase1);
    DBL2FLT(frequency2, value.Frequency2);
    DBL2FLT(initialPhase2, value.InitialPhase2);

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_SINE_SHAPE, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Sine Shape
 * Purpose:  This function returns frequency and phase parameters for sine
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionSineShape (ViSession instrSession,
                                                        ViPReal64 frequency1,
                                                        ViPInt32 frequency1Unit,
                                                        ViPReal64 initialPhase1,
                                                        ViPInt32 initialPhase1Unit,
                                                        ViPReal64 frequency2,
                                                        ViPInt32 frequency2Unit,
                                                        ViPReal64 initialPhase2,
                                                        ViPInt32 initialPhase2Unit)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TSine_SHAPE     value           = {0};

    if (!frequency1)
        return VI_ERROR_PARAMETER2;
    if (!frequency1Unit)
        return VI_ERROR_PARAMETER3;
    if (!initialPhase1)
        return VI_ERROR_PARAMETER4;
    if (!initialPhase1Unit)
        return VI_ERROR_PARAMETER5;
    if (!frequency2)
        return VI_ERROR_PARAMETER6;
    if (!frequency2Unit)
        return VI_ERROR_PARAMETER7;
    if (!initialPhase2)
        return VI_ERROR_PARAMETER8;
    if (!initialPhase2Unit)
        return VI_ERROR_INSTR_PARAMETER9;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_SINE_SHAPE, ChAB, &value, sizeof(value)));
    *frequency1 = value.Frequency1;
    *frequency1Unit = RSSIUP_UNIT_HZ;
    *initialPhase1 = value.InitialPhase1;
    *initialPhase1Unit = RSSIUP_UNIT_DEG;
    *frequency2 = value.Frequency2;
    *frequency2Unit = RSSIUP_UNIT_HZ;
    *initialPhase2 = value.InitialPhase2;
    *initialPhase2Unit = RSSIUP_UNIT_DEG;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Sine Dimension
 * Purpose:  This function sets amplitude and offset parameters for sine
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionSineDimension (ViSession instrSession,
                                                            ViInt32 channel,
                                                            ViReal64 DCOffset,
                                                            ViInt32 DCOffsetUnit,
                                                            ViReal64 amplitude1,
                                                            ViInt32 amplitude1Unit,
                                                            ViReal64 amplitude2,
                                                            ViInt32 amplitude2Unit)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TSine_DIMENSION     value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    /* DC Offset */
    switch (DCOffsetUnit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (DCOffset, -1.0, 1.0))
                return VI_ERROR_PARAMETER3;
            
            DBL2FLT(DCOffset, value.DCOffset);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (DCOffset, -10.61, 10.61))
                return VI_ERROR_PARAMETER3;
            
            DBL2FLT(DCOffset, value.DCOffset);
            break;
        default:
            return VI_ERROR_PARAMETER4;
        }

    /* Amplitude 1 */
    switch (amplitude1Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 1.0))
                return VI_ERROR_PARAMETER5;

            DBL2FLT(amplitude1, value.Amplitude1);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 7.5))
                return VI_ERROR_PARAMETER5;

            DBL2FLT(amplitude1, value.Amplitude1);
            /* Vrms to Vp */
            value.Amplitude1 *= sqrt(2);
            break;
        default:
            return VI_ERROR_PARAMETER6;
        }

    /* Amplitude 2 */
    switch (amplitude2Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 1.0))
                return VI_ERROR_PARAMETER7;
            
            DBL2FLT(amplitude2, value.Amplitude2);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 7.5))
                return VI_ERROR_PARAMETER7;

            DBL2FLT(amplitude2, value.Amplitude2);
            /* Vrms to Vp */
            value.Amplitude2 *= sqrt(2);
            break;
        default:
            return VI_ERROR_PARAMETER8;
        }

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_SINE_DIMENSION, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Sine Dimension
 * Purpose:  This function returns amplitude and offset parameters for sine
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionSineDimension (ViSession instrSession,
                                                            ViInt32 channel,
                                                            ViPReal64 DCOffset,
                                                            ViPInt32 DCOffsetUnit,
                                                            ViPReal64 amplitude1,
                                                            ViPInt32 amplitude1Unit,
                                                            ViPReal64 amplitude2,
                                                            ViPInt32 amplitude2Unit)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TSine_DIMENSION     value           = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!DCOffset)
        return VI_ERROR_PARAMETER3;
    if (!DCOffsetUnit)
        return VI_ERROR_PARAMETER4;
    if (!amplitude1)
        return VI_ERROR_PARAMETER5;
    if (!amplitude1Unit)
        return VI_ERROR_PARAMETER6;
    if (!amplitude2)
        return VI_ERROR_PARAMETER7;
    if (!amplitude2Unit)
        return VI_ERROR_PARAMETER8;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_SINE_DIMENSION, channel, &value, sizeof(value)));

    if (instrPtr -> generatorMode == RSSIUP_GENERATOR_MODE_ANALOG) /* Analog generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_V;
        *amplitude1 = value.Amplitude1 / sqrt(2); /* Vp tp Vrms */
        *amplitude1Unit = RSSIUP_UNIT_V;
        *amplitude2 = value.Amplitude2 / sqrt(2); /* Vp to Vrms */
        *amplitude2Unit = RSSIUP_UNIT_V;
        }
    else /* Digital generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_FS;
        *amplitude1 = value.Amplitude1;
        *amplitude1Unit = RSSIUP_UNIT_FS;
        *amplitude2 = value.Amplitude2;
        *amplitude2Unit = RSSIUP_UNIT_FS;
        }

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Noise Shape
 * Purpose:  This function sets PDF parameters of noise generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionNoiseShape (ViSession instrSession,
                                                         ViInt32 PDF,
                                                         ViInt32 gaussianFactor)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TNoise_SHAPE    value           = {0};

    CHECKERR (rssiup_param_to_val (SNoisePDFDiscVals, PDF, &value.PDF, VI_ERROR_PARAMETER2));

    if (rssiup_invalidViInt32Range (gaussianFactor, 1, 100))
        return VI_ERROR_PARAMETER3;

    value.GaussianFactor = gaussianFactor;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_NOISE_SHAPE, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Noise Shape
 * Purpose:  This function returns PDF parameters of noise generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionNoiseShape (ViSession instrSession,
                                                         ViPInt32 PDF,
                                                         ViPInt32 gaussianFactor)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TNoise_SHAPE    value           = {0};

    if (!PDF)
        return VI_ERROR_PARAMETER2;
    if (!gaussianFactor)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_NOISE_SHAPE, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SNoisePDFDiscVals, PDF, &value.PDF, VI_ERROR_INV_RESPONSE));
    *gaussianFactor = value.GaussianFactor;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Noise Dimension
 * Purpose:  This function sets amplitude and offset parameters for noise
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionNoiseDimension (ViSession instrSession,
                                                             ViInt32 channel,
                                                             ViReal64 DCOffset,
                                                             ViInt32 DCOffsetUnit,
                                                             ViReal64 amplitude1,
                                                             ViInt32 amplitude1Unit,
                                                             ViReal64 amplitude2,
                                                             ViInt32 amplitude2Unit)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TNoise_SHAPE        shape_value     = {0};
    TNoise_DIMENSION    dimension_value = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

//  if (rssiup_invalidViReal64Range (amplitude1, 0.0, 10.61))
//      return VI_ERROR_PARAMETER5;
//  if (amplitude1Unit != RSSIUP_UNIT_V)
//      return VI_ERROR_PARAMETER6;
//  if (rssiup_invalidViReal64Range (amplitude2, 0.0, 10.61))
//      return VI_ERROR_PARAMETER7;
//  if (amplitude2Unit != RSSIUP_UNIT_V)
//      return VI_ERROR_PARAMETER8;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_NOISE_SHAPE, ChAB, &shape_value, sizeof(shape_value)));

    DBL2FLT(amplitude1, dimension_value.Amplitude1);
    DBL2FLT(amplitude2, dimension_value.Amplitude2);

    /* DC Offset */
    switch (DCOffsetUnit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (DCOffset, -1.0, 1.0))
                return VI_ERROR_PARAMETER3;
            
            DBL2FLT(DCOffset, dimension_value.DCOffset);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (DCOffset, -10.61, 10.61))
                return VI_ERROR_PARAMETER3;

            DBL2FLT(DCOffset, dimension_value.DCOffset);
            break;
        default:
            return VI_ERROR_PARAMETER4;
        }

    /* Level's recalculation fator */
    if (instrPtr -> generatorMode == RSSIUP_GENERATOR_MODE_ANALOG) /* Analog generator */
        {
        /*
            TODO: Valid Ranges:

            Rectangular: 0.0 V to 6.118 V
            Triangular:  0.0 V to 4.327 V
            Gaussian:    0.0 V to 2.736 V
        */
        switch (shape_value.PDF)
            {
            case rectangular:
                dimension_value.Amplitude1 /= 0.577345;
                dimension_value.Amplitude2 /= 0.577345;
                break;
            case triangular:
                dimension_value.Amplitude1 /= 0.408245;
                dimension_value.Amplitude2 /= 0.408245;
                break;
            case gaussian:
            default:
                dimension_value.Amplitude1 /= 0.258197;
                dimension_value.Amplitude2 /= 0.258197;
                break;
            }
        }
    else /* Digital generator */
        {
        /*
            TODO: Valid Ranges:

            Rectangular: 0.0 FS to 0.8164 FS
            Triangular:  0.0 FS to 0.5773 FS
            Gaussian:    0.0 FS to 0.3651 FS
        */
        switch (shape_value.PDF)
            {
            case rectangular:
                dimension_value.Amplitude1 *= 1.224889;
                dimension_value.Amplitude2 *= 1.224889;
                break;
            case triangular:
                dimension_value.Amplitude1 *= 1.732201;
                dimension_value.Amplitude2 *= 1.732201;
                break;
            case gaussian:
            default:
                dimension_value.Amplitude1 *= 2.738975;
                dimension_value.Amplitude2 *= 2.738975;
                break;
            }
        }

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_NOISE_DIMENSION, channel, &dimension_value, sizeof(dimension_value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Noise Dimension
 * Purpose:  This function returns amplitude and offset parameters for noise
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionNoiseDimension (ViSession instrSession,
                                                             ViInt32 channel,
                                                             ViPReal64 DCOffset,
                                                             ViPInt32 DCOffsetUnit,
                                                             ViPReal64 amplitude1,
                                                             ViPInt32 amplitude1Unit,
                                                             ViPReal64 amplitude2,
                                                             ViPInt32 amplitude2Unit)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TNoise_SHAPE        shape_value     = {0};
    TNoise_DIMENSION    dimension_value = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!DCOffset)
        return VI_ERROR_PARAMETER3;
    if (!DCOffsetUnit)
        return VI_ERROR_PARAMETER4;
    if (!amplitude1)
        return VI_ERROR_PARAMETER5;
    if (!amplitude1Unit)
        return VI_ERROR_PARAMETER6;
    if (!amplitude2)
        return VI_ERROR_PARAMETER7;
    if (!amplitude2Unit)
        return VI_ERROR_PARAMETER8;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_NOISE_SHAPE, ChAB, &shape_value, sizeof(shape_value)));
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_NOISE_DIMENSION, channel, &dimension_value, sizeof(dimension_value)));

    /* Level's recalculation fator */
    if (instrPtr -> generatorMode == RSSIUP_GENERATOR_MODE_ANALOG) /* Analog generator */
        {
        switch (shape_value.PDF)
            {
            case rectangular:
                dimension_value.Amplitude1 *= 0.577345;
                dimension_value.Amplitude2 *= 0.577345;
                break;
            case triangular:
                dimension_value.Amplitude1 *= 0.408245;
                dimension_value.Amplitude2 *= 0.408245;
                break;
            case gaussian:
            default:
                dimension_value.Amplitude1 *= 0.258197;
                dimension_value.Amplitude2 *= 0.258197;
                break;
            }

        *DCOffsetUnit = RSSIUP_UNIT_V;
        *amplitude1Unit = RSSIUP_UNIT_V;
        *amplitude2Unit = RSSIUP_UNIT_V;
        }
    else /* Digital generator */
        {
        switch (shape_value.PDF)
            {
            case rectangular:
                dimension_value.Amplitude1 /= 1.224889;
                dimension_value.Amplitude2 /= 1.224889;
                break;
            case triangular:
                dimension_value.Amplitude1 /= 1.732201;
                dimension_value.Amplitude2 /= 1.732201;
                break;
            case gaussian:
            default:
                dimension_value.Amplitude1 /= 2.738975;
                dimension_value.Amplitude2 /= 2.738975;
                break;
            }

        *DCOffsetUnit = RSSIUP_UNIT_FS;
        *amplitude1Unit = RSSIUP_UNIT_FS;
        *amplitude2Unit = RSSIUP_UNIT_FS;
        }

    *DCOffset = dimension_value.DCOffset;
    *amplitude1 = dimension_value.Amplitude1;
    *amplitude2 = dimension_value.Amplitude2;

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Multisine Shape
 * Purpose:  This function sets frequency and phase parameters for multisine
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionMultisineShape (ViSession instrSession,
                                                             ViInt32 no_ofHarmonic,
                                                             ViReal64 _VI_FAR frequency[],
                                                             ViReal64 _VI_FAR initialPhase[],
                                                             ViReal64 _VI_FAR relativeAmplitude[],
                                                             ViReal64 AMFrequency)
{
    ViStatus            rssiup_status       = VI_SUCCESS;
    TMultisine_SHAPE    value               = {0};
    ViInt32             idx                 = 0;
    ViReal64            samplingFrequency   = 0.0,
                        spacing             = 0.0,
                        frequency_value     = 0.0,
                        decimal_part        = 0.0,
                        integral_part       = 0.0;

    if (rssiup_invalidViInt32Range (no_ofHarmonic, 1, GEN_MULTISINE_HARMONIC))
        return VI_ERROR_PARAMETER2;
    if (!frequency)
        return VI_ERROR_PARAMETER3;
    if (!initialPhase)
        return VI_ERROR_PARAMETER4;
    if (!relativeAmplitude)
        return VI_ERROR_PARAMETER5;
/*
    if (rssiup_invalidViReal64Range (AMFrequency, , ))
        return VI_ERROR_PARAMETER6;
*/
    memset (&value, 0, sizeof(value));

    CHECKERR (rssiup_GetGeneratorSamplingFrequency (instrSession, &samplingFrequency));

    value.ComponentNumber = no_ofHarmonic;
    value.BufferLen = 20480; /* Used max length of data buffer (4 to 20480). */
    DBL2FLT(AMFrequency, value.AMFrequency);

    /* Find optimal (smallest) spacing */
    spacing = samplingFrequency;

    if (no_ofHarmonic > 1)
        {
        for (idx = 0; idx < (no_ofHarmonic - 1); idx++)
            {
            spacing = (spacing > fabs (frequency[idx + 1] - frequency[idx])) ? fabs (frequency[idx + 1] - frequency[idx]) : spacing;
            }

        spacing = (spacing > frequency[0]) ? frequency[0] : spacing;

        /* Keep the buffer size within allowed range 4 to 20480 */
        value.BufferLen = samplingFrequency / spacing;
        value.BufferLen = (value.BufferLen < 4) ? 4 : (value.BufferLen > 20480) ? 20480 : value.BufferLen;
        }
    else
        {
        /* Keep buffer length as it is set by default */
        }

    for (idx = 0; idx < no_ofHarmonic; idx++)
        {
        frequency_value = value.BufferLen * (frequency[idx] / samplingFrequency);
        /* Properly round the value to the nearest integer */
        decimal_part = modf (frequency_value, &integral_part);

        value.Frequency[idx] = (decimal_part >= 0.5) ? integral_part + 1 : integral_part;

        /* Frequency multiple must be >= 1 */
        value.Frequency[idx] = (value.Frequency[idx] < 1 ) ? 1 : value.Frequency[idx];

        DBL2FLT(initialPhase[idx], value.Phase[idx]);
        DBL2FLT(relativeAmplitude[idx], value.RelativeAmplitude[idx]);
        }

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_MULTISINE_SHAPE, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Multisine Shape
 * Purpose:  This function returns frequency and phase parameters for
 *           multisine generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionMultisineShape (ViSession instrSession,
                                                             ViPInt32 no_ofHarmonic,
                                                             ViReal64 _VI_FAR frequency[],
                                                             ViReal64 _VI_FAR initialPhase[],
                                                             ViReal64 _VI_FAR relativeAmplitude[],
                                                             ViPReal64 AMFrequency)
{
    ViStatus            rssiup_status       = VI_SUCCESS;
    TMultisine_SHAPE    value               = {0};
    ViInt32             idx                 = 0,
                        BufferLen           = 0;
    ViReal64            samplingFrequency   = 0.0;

    if (!no_ofHarmonic)
        return VI_ERROR_PARAMETER2;
    if (!frequency)
        return VI_ERROR_PARAMETER3;
    if (!initialPhase)
        return VI_ERROR_PARAMETER4;
    if (!relativeAmplitude)
        return VI_ERROR_PARAMETER5;
    if (!AMFrequency)
        return VI_ERROR_PARAMETER6;

    CHECKERR (rssiup_GetGeneratorSamplingFrequency (instrSession, &samplingFrequency));
    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_MULTISINE_SHAPE, ChAB, &value, sizeof(value)));

    BufferLen = value.BufferLen;
    *no_ofHarmonic = value.ComponentNumber;
    *AMFrequency = value.AMFrequency;

    for (idx = 0; idx < value.ComponentNumber; idx++)
        {
        frequency[idx] = value.Frequency[idx] * (samplingFrequency / BufferLen);
        initialPhase[idx] = value.Phase[idx];
        relativeAmplitude[idx] = value.RelativeAmplitude[idx];
        }

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Multisine Dimension
 * Purpose:  This function sets amplitude and offset parameters for multisine
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionMultisineDimension (ViSession instrSession,
                                                                 ViInt32 channel,
                                                                 ViReal64 DCOffset,
                                                                 ViInt32 DCOffsetUnit,
                                                                 ViReal64 amplitude1,
                                                                 ViInt32 amplitude1Unit,
                                                                 ViReal64 amplitude2,
                                                                 ViInt32 amplitude2Unit,
                                                                 ViReal64 AMModulationDepth)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TMultisine_DIMENSION    value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (rssiup_invalidViReal64Range (AMModulationDepth, 0.0, 100.0))
        return VI_ERROR_INSTR_PARAMETER9;

    /* DC Offset */
    switch (DCOffsetUnit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (DCOffset, -1.0, 1.0))
                return VI_ERROR_PARAMETER3;
            
            DBL2FLT(DCOffset, value.DCOffset);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (DCOffset, -10.61, 10.61))
                return VI_ERROR_PARAMETER3;

            DBL2FLT(DCOffset, value.DCOffset);
            break;
        default:
            return VI_ERROR_PARAMETER4;
        }
    
    /* Amplitude 1 */
    switch (amplitude1Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 1.0))
                return VI_ERROR_PARAMETER5;
            
            DBL2FLT(amplitude1, value.Amplitude1);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 7.5))
                return VI_ERROR_PARAMETER5;

            DBL2FLT(amplitude1, value.Amplitude1);
            /* Vrms to Vp */
            value.Amplitude1 *= sqrt(2.0);
            break;
        default:
            return VI_ERROR_PARAMETER6;
        }

    /* Amplitude 2 */
    switch (amplitude2Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 1.0))
                return VI_ERROR_PARAMETER7;
            
            DBL2FLT(amplitude2, value.Amplitude2);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 7.5))
                return VI_ERROR_PARAMETER7;

            DBL2FLT(amplitude2, value.Amplitude2);
            /* Vrms to Vp */
            value.Amplitude2 *= sqrt(2.0);
            break;
        default:
            return VI_ERROR_PARAMETER8;
        }

    value.AMModDepth = AMModulationDepth * 100;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_MULTISINE_DIMENSION, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Multisine Dimension
 * Purpose:  This function returns amplitude and offset parameters for
 *           multisine generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionMultisineDimension (ViSession instrSession,
                                                                 ViInt32 channel,
                                                                 ViPReal64 DCOffset,
                                                                 ViPInt32 DCOffsetUnit,
                                                                 ViPReal64 amplitude1,
                                                                 ViPInt32 amplitude1Unit,
                                                                 ViPReal64 amplitude2,
                                                                 ViPInt32 amplitude2Unit,
                                                                 ViPReal64 AMModulationDepth)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TMultisine_DIMENSION    value           = {0};
    pTStatusDataRanges  instrPtr            = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!DCOffset)
        return VI_ERROR_PARAMETER3;
    if (!DCOffsetUnit)
        return VI_ERROR_PARAMETER4;
    if (!amplitude1)
        return VI_ERROR_PARAMETER5;
    if (!amplitude1Unit)
        return VI_ERROR_PARAMETER6;
    if (!amplitude2)
        return VI_ERROR_PARAMETER7;
    if (!amplitude2Unit)
        return VI_ERROR_PARAMETER8;
    if (!AMModulationDepth)
        return VI_ERROR_INSTR_PARAMETER9;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_MULTISINE_DIMENSION, channel, &value, sizeof(value)));

    if (instrPtr -> generatorMode == RSSIUP_GENERATOR_MODE_ANALOG) /* Analog generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_V;
        *amplitude1 = value.Amplitude1 / sqrt (2.0);
        *amplitude1Unit = RSSIUP_UNIT_V;
        *amplitude2 = value.Amplitude2 / sqrt (2.0);
        *amplitude2Unit = RSSIUP_UNIT_V;
        }
    else /* Digital generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_FS;
        *amplitude1 = value.Amplitude1;
        *amplitude1Unit = RSSIUP_UNIT_FS;
        *amplitude2 = value.Amplitude2;
        *amplitude2Unit = RSSIUP_UNIT_FS;
        }

    *AMModulationDepth = value.AMModDepth / 100.0;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Arbitrary
 * Purpose:  This function uploads shape data for arbitrary generator as
 *           floating-point values between -1.0 and +1.0 into the module for
 *           selected channel.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_SetGeneratorFunctionArbitrary (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViInt32 no_ofSamples,
                                                        ViReal64 _VI_FAR samplesArray[])
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             idx             = 0;
    ViInt32             min             = -1;
    ViInt32             max             = 1;
    ViReal32            sample          = 0.0;
    ViBoolean           gdi_acknowledge = VI_TRUE;
    TArbitrary_SHAPE    value           = {0};
    ViReal32            *dataArray;
    ViUInt16            sender          = 0x0001; /* 0x0000 and 0x0FFF are reserved for the system */

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (rssiup_invalidViInt32Range (no_ofSamples, 1, GEN_MAX_ARB_SAMPLES))
        return VI_ERROR_PARAMETER3;

    /* Predefined FFT noise signals */
    if (!samplesArray)
        {
        ViReal64        FFT_size[]      = {1024, 2048, 4096, 8192, 16384, 0},
                        code_FFT_size   = no_ofSamples;

        value.PartyID = 0xFFFF;
        value.PartyMax = 0xFFFF;
        value.ShapeDataSzInSa = 0;

        rssiup_coerceToNearest (FFT_size, &code_FFT_size, &value.PartySzInSa); /* Size of FFT signal */ 

        CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_ARBITRARY_SHAPE, channel, &value, 8 /* Simplified structure */));
        CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
        
        return rssiup_status;
        }

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, &gdi_acknowledge));
    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, VI_FALSE));

    dataArray = malloc (no_ofSamples * sizeof (ViReal32));
    dataArray = memset (dataArray, 0, no_ofSamples * sizeof (ViReal32));

    /* Copy and coerce data into the limits */
    for (idx = 0; idx < no_ofSamples; idx++)
        {
        DBL2FLT(samplesArray[idx], sample);

        dataArray[idx] = (sample > max) ? max : (sample < min) ? min : sample;
        }

    /* Divide data to parties and transmit them to the module */
    {

    ViInt32     parties         = 0,
                remainder       = 0,
                blockSize       = 1000; /* block size limit */
    ViReal32    *p2dataArray;
    ViUInt16    *p2sender;
    
    /* Due to internal device limit (4000 Bytes => 1000 points) use block transfer */

    parties                 = no_ofSamples / blockSize;
    remainder               = no_ofSamples % blockSize;

    value.PartyMax          = (remainder > 0) ? parties : parties - 1;
    value.ShapeDataSzInSa   = no_ofSamples;
    value.PartySzInSa       = blockSize;

    for (idx = 0; idx < parties; idx++)
        {
        value.PartyID = idx;
        p2dataArray = dataArray + idx * blockSize;
        value.Sender = sender;
        
        memcpy (value.TransferedData, p2dataArray, blockSize * sizeof (ViReal32));
        
        GOCHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_ARBITRARY_SHAPE, channel, &value, sizeof(value)));
        }

    if (remainder > 0)
        {
        p2dataArray = dataArray + idx * blockSize;
        value.PartyID = idx;
        value.PartySzInSa = remainder;

        memset (value.TransferedData, 0, blockSize * sizeof (ViReal32));
        memcpy (value.TransferedData, p2dataArray, remainder * sizeof (ViReal32));

        p2sender = (ViInt16 *)(&value) + (remainder * sizeof (ViReal32) + 8) / 2; /* header is 8 bytes + 2 bytes of sender */
        *p2sender = sender;

        GOCHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_ARBITRARY_SHAPE, channel, &value, remainder * sizeof (ViReal32) + 10 /* 10 bytes is header */));
        }
    }

    GOCHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

ERROR:

    if (dataArray)
        free (dataArray);

    SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, gdi_acknowledge);

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Arbitrary
 * Purpose:  This function downloads shape data of arbitrary generator as
 *           floating-point values between -1.0 and +1.0 from the module for
 *           selected channel.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_GetGeneratorFunctionArbitrary (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViPInt32 no_ofSamples,
                                                        ViReal64 _VI_FAR samplesArray[])
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32             PtChId          = 0;
    ViInt32             PartyID         = 0;
    ViInt32             samples         = 0;
    ViInt32             idx             = 0;
    ViBoolean           gdi_acknowledge = VI_TRUE;
    TArbitrary_SHAPE    value           = {0};
    ViReal32            *dataArray;
    ViReal32            *p2dataArray;

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!no_ofSamples)
        return VI_ERROR_PARAMETER3;
    if (!samplesArray)
        return VI_ERROR_PARAMETER4;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, &gdi_acknowledge));
    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, VI_FALSE));

    dataArray = malloc (GEN_MAX_ARB_SAMPLES * sizeof (ViReal32));
    dataArray = memset (dataArray, 0, GEN_MAX_ARB_SAMPLES * sizeof (ViReal32));

    samples = 0;
    PartyID = 0;
    p2dataArray = dataArray;

    do
        {
        PtChId = PartyID * 0x0100 + channel;

        GOCHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_ARBITRARY_SHAPE, PtChId, &value, sizeof(value)));

        memcpy (p2dataArray, value.TransferedData, value.PartySzInSa * sizeof (ViReal32));
        p2dataArray = dataArray + (value.PartyID + 1) * value.PartySzInSa;

        samples += value.PartySzInSa;
        PartyID++;

        } while (PartyID <= value.PartyMax);

    if (value.ShapeDataSzInSa != samples)
        return RSSIUP_ERROR_DATA_CORRUPTED;

    *no_ofSamples = samples;

    for (idx = 0; idx < samples; idx++)
        {
        samplesArray[idx] = dataArray[idx];
        }

    GOCHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

ERROR:

    free (dataArray);

    SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, gdi_acknowledge);

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Arbitrary Dimension
 * Purpose:  This function sets amplitude and offset parameters for arbitrary
 *           generator.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_SetGeneratorFunctionArbitraryDimension (ViSession instrSession,
                                                                 ViInt32 channel,
                                                                 ViReal64 DCOffset,
                                                                 ViInt32 DCOffsetUnit,
                                                                 ViReal64 amplitude1,
                                                                 ViInt32 amplitude1Unit,
                                                                 ViReal64 amplitude2,
                                                                 ViInt32 amplitude2Unit)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TArbitrary_DIMENSION    value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    /* DC Offset */
    switch (DCOffsetUnit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (DCOffset, -1.0, 1.0))
                return VI_ERROR_PARAMETER3;
            
            DBL2FLT(DCOffset, value.DCOffset);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (DCOffset, -10.61, 10.61))
                return VI_ERROR_PARAMETER3;

            DBL2FLT(DCOffset, value.DCOffset);
            break;
        default:
            return VI_ERROR_PARAMETER4;
        }

    /* Amplitude 1 */
    switch (amplitude1Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 1.0))
                return VI_ERROR_PARAMETER5;
            
            DBL2FLT(amplitude1, value.Amplitude1);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 7.5))
                return VI_ERROR_PARAMETER5;

            DBL2FLT(amplitude1, value.Amplitude1);
            /* Vrms to Vp */
            value.Amplitude1 *= sqrt(2);
            break;
        default:
            return VI_ERROR_PARAMETER6;
        }

    /* Amplitude 2 */
    switch (amplitude2Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 1.0))
                return VI_ERROR_PARAMETER7;
            
            DBL2FLT(amplitude2, value.Amplitude2);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 7.5))
                return VI_ERROR_PARAMETER7;

            DBL2FLT(amplitude2, value.Amplitude2);
            /* Vrms to Vp */
            value.Amplitude2 *= sqrt(2);
            break;
        default:
            return VI_ERROR_PARAMETER8;
        }

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_ARBITRARY_DIMENSION, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Arbitrary Dimension
 * Purpose:  This function returns amplitude and offset parameters for
 *           arbitrary generator.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_GetGeneratorFunctionArbitraryDimension (ViSession instrSession,
                                                                 ViInt32 channel,
                                                                 ViPReal64 DCOffset,
                                                                 ViPInt32 DCOffsetUnit,
                                                                 ViPReal64 amplitude1,
                                                                 ViPInt32 amplitude1Unit,
                                                                 ViPReal64 amplitude2,
                                                                 ViPInt32 amplitude2Unit)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TArbitrary_DIMENSION    value           = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!DCOffset)
        return VI_ERROR_PARAMETER3;
    if (!DCOffsetUnit)
        return VI_ERROR_PARAMETER4;
    if (!amplitude1)
        return VI_ERROR_PARAMETER5;
    if (!amplitude1Unit)
        return VI_ERROR_PARAMETER6;
    if (!amplitude2)
        return VI_ERROR_PARAMETER7;
    if (!amplitude2Unit)
        return VI_ERROR_PARAMETER8;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_ARBITRARY_DIMENSION, channel, &value, sizeof(value)));

    if (instrPtr -> generatorMode == RSSIUP_GENERATOR_MODE_ANALOG) /* Analog generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_V;
        *amplitude1 = value.Amplitude1 / sqrt(2); /* Vp tp Vrms */
        *amplitude1Unit = RSSIUP_UNIT_V;
        *amplitude2 = value.Amplitude2 / sqrt(2); /* Vp to Vrms */
        *amplitude2Unit = RSSIUP_UNIT_V;
        }
    else /* Digital generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_FS;
        *amplitude1 = value.Amplitude1;
        *amplitude1Unit = RSSIUP_UNIT_FS;
        *amplitude2 = value.Amplitude2;
        *amplitude2Unit = RSSIUP_UNIT_FS;
        }

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Sine Burst Shape
 * Purpose:  This function sets frequency and time setings for sine burst
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionSineBurstShape (ViSession instrSession,
                                                             ViReal64 frequency,
                                                             ViInt32 frequencyUnit,
                                                             ViReal64 burstOnDelay,
                                                             ViInt32 burstOnDelayUnit,
                                                             ViReal64 burstOnTime,
                                                             ViInt32 burstOnTimeUnit,
                                                             ViReal64 burstOffTime,
                                                             ViInt32 burstOffTimeUnit,
                                                             ViInt32 signalType)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TBurst_SHAPE    value           = {0};

/*
    if (rssiup_invalidViReal64Range (frequency, , ))
        return VI_ERROR_PARAMETER2;
*/
    if (frequencyUnit != RSSIUP_UNIT_HZ)
        return VI_ERROR_PARAMETER3;
    if (rssiup_invalidViReal64Range (burstOnDelay, 0.0, 10000.0))
        return VI_ERROR_PARAMETER4;
    if (burstOnDelayUnit != RSSIUP_UNIT_S)
        return VI_ERROR_PARAMETER5;
    if (rssiup_invalidViReal64Range (burstOnTime, 0.0, 10000.0))
        return VI_ERROR_PARAMETER6;
    if (burstOnTimeUnit != RSSIUP_UNIT_S)
        return VI_ERROR_PARAMETER7;
    if (rssiup_invalidViReal64Range (burstOffTime, 0.0, 10000.0))
        return VI_ERROR_PARAMETER8;
    if (burstOffTimeUnit != RSSIUP_UNIT_S)
        return VI_ERROR_INSTR_PARAMETER9;

    DBL2FLT(frequency, value.GenFrequency);
    DBL2FLT(burstOnDelay, value.BurstOnDelay);
    DBL2FLT(burstOnTime, value.HighLevelTime);
    DBL2FLT(burstOffTime, value.LowLevelTime);

    CHECKERR (rssiup_param_to_val (SBurstSignalTypeDiscVals, signalType, &value.SignalType, VI_ERROR_INSTR_PARAMETER10));
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_BURST_SHAPE, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Sine Burst Shape
 * Purpose:  This function returns frequency and time setings for sine burst
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionSineBurstShape (ViSession instrSession,
                                                             ViPReal64 frequency,
                                                             ViPInt32 frequencyUnit,
                                                             ViPReal64 burstOnDelay,
                                                             ViPInt32 burstOnDelayUnit,
                                                             ViPReal64 burstOnTime,
                                                             ViPInt32 burstOnTimeUnit,
                                                             ViPReal64 burstOffTime,
                                                             ViPInt32 burstOffTimeUnit,
                                                             ViPInt32 signalType)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TBurst_SHAPE    value           = {0};

    if (!frequency)
        return VI_ERROR_PARAMETER2;
    if (!frequencyUnit)
        return VI_ERROR_PARAMETER3;
    if (!burstOnDelay)
        return VI_ERROR_PARAMETER4;
    if (!burstOnDelayUnit)
        return VI_ERROR_PARAMETER5;
    if (!burstOnTime)
        return VI_ERROR_PARAMETER6;
    if (!burstOnTimeUnit)
        return VI_ERROR_PARAMETER7;
    if (!burstOffTime)
        return VI_ERROR_PARAMETER8;
    if (!burstOffTimeUnit)
        return VI_ERROR_INSTR_PARAMETER9;
    if (!signalType)
        return VI_ERROR_INSTR_PARAMETER10;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_BURST_SHAPE, ChAB, &value, sizeof(value)));
    *frequency = value.GenFrequency;
    *frequencyUnit = RSSIUP_UNIT_HZ;
    *burstOnDelay = value.BurstOnDelay;
    *burstOnDelayUnit = RSSIUP_UNIT_S;
    *burstOnTime = value.HighLevelTime;
    *burstOnTimeUnit = RSSIUP_UNIT_S;
    *burstOffTime = value.LowLevelTime;
    *burstOffTimeUnit = RSSIUP_UNIT_S;
    CHECKERR (rssiup_val_to_param (SBurstSignalTypeDiscVals, signalType, &value.SignalType, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Sine Burst Dimension
 * Purpose:  This function sets amplitude and offset setings for sine burst
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionSineBurstDimension (ViSession instrSession,
                                                                 ViInt32 channel,
                                                                 ViReal64 DCOffset,
                                                                 ViInt32 DCOffsetUnit,
                                                                 ViReal64 amplitude1,
                                                                 ViInt32 amplitude1Unit,
                                                                 ViReal64 amplitude2,
                                                                 ViInt32 amplitude2Unit,
                                                                 ViReal64 lowLevelAmplitude,
                                                                 ViInt32 lowLevelAmplitudeUnit)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TBurst_DIMENSION    value           = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    /* DC Offset */
    switch (DCOffsetUnit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (DCOffset, -1.0, 1.0))
                return VI_ERROR_PARAMETER3;
            
            DBL2FLT(DCOffset, value.DCOffset);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (DCOffset, -10.61, 10.61))
                return VI_ERROR_PARAMETER3;

            DBL2FLT(DCOffset, value.DCOffset);
            break;
        default:
            return VI_ERROR_PARAMETER4;
        }
    
    /* Amplitude 1 */
    switch (amplitude1Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 1.0))
                return VI_ERROR_PARAMETER5;
            
            DBL2FLT(amplitude1, value.Amplitude1);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 7.5))
                return VI_ERROR_PARAMETER5;

            DBL2FLT(amplitude1, value.Amplitude1);
            /* Vrms to Vp */
            value.Amplitude1 *= sqrt(2);
            break;
        default:
            return VI_ERROR_PARAMETER6;
        }

    /* Amplitude 2 */
    switch (amplitude2Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 1.0))
                return VI_ERROR_PARAMETER7;
            
            DBL2FLT(amplitude2, value.Amplitude2);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 7.5))
                return VI_ERROR_PARAMETER7;

            DBL2FLT(amplitude2, value.Amplitude2);
            /* Vrms to Vp */
            value.Amplitude2 *= sqrt(2);
            break;
        default:
            return VI_ERROR_PARAMETER8;
        }

    /* Low Level Amplitude */
    switch (lowLevelAmplitudeUnit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (lowLevelAmplitude, 0.0, 1.0))
                return VI_ERROR_INSTR_PARAMETER9;
            
            DBL2FLT(lowLevelAmplitude, value.LowLevelAmpl);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (lowLevelAmplitude, 0.0, 7.5))
                return VI_ERROR_INSTR_PARAMETER9;

            DBL2FLT(lowLevelAmplitude, value.LowLevelAmpl);
            /* Vrms to Vp */
            value.LowLevelAmpl *= sqrt(2);
            break;
        default:
            return VI_ERROR_INSTR_PARAMETER10;
        }

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_BURST_DIMENSION, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Sine Burst Dimension
 * Purpose:  This function returns amplitude and offset setings for sine
 *           burst generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionSineBurstDimension (ViSession instrSession,
                                                                 ViInt32 channel,
                                                                 ViPReal64 DCOffset,
                                                                 ViPInt32 DCOffsetUnit,
                                                                 ViPReal64 amplitude1,
                                                                 ViPInt32 amplitude1Unit,
                                                                 ViPReal64 amplitude2,
                                                                 ViPInt32 amplitude2Unit,
                                                                 ViPReal64 lowLevelAmplitude,
                                                                 ViPInt32 lowLevelAmplitudeUnit)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TBurst_DIMENSION    value           = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!DCOffset)
        return VI_ERROR_PARAMETER3;
    if (!DCOffsetUnit)
        return VI_ERROR_PARAMETER4;
    if (!amplitude1)
        return VI_ERROR_PARAMETER5;
    if (!amplitude1Unit)
        return VI_ERROR_PARAMETER6;
    if (!amplitude2)
        return VI_ERROR_PARAMETER7;
    if (!amplitude2Unit)
        return VI_ERROR_PARAMETER8;
    if (!lowLevelAmplitude)
        return VI_ERROR_INSTR_PARAMETER9;
    if (!lowLevelAmplitudeUnit)
        return VI_ERROR_INSTR_PARAMETER9;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_BURST_DIMENSION, channel, &value, sizeof(value)));

    if (instrPtr -> generatorMode == RSSIUP_GENERATOR_MODE_ANALOG) /* Analog generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_V;
        *amplitude1 = value.Amplitude1 / sqrt(2); /* Vp tp Vrms */
        *amplitude1Unit = RSSIUP_UNIT_V;
        *amplitude2 = value.Amplitude2 / sqrt(2); /* Vp to Vrms */
        *amplitude2Unit = RSSIUP_UNIT_V;
        }
    else /* Digital generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_FS;
        *amplitude1 = value.Amplitude1;
        *amplitude1Unit = RSSIUP_UNIT_FS;
        *amplitude2 = value.Amplitude2;
        *amplitude2Unit = RSSIUP_UNIT_FS;
        }

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function Polarity Dimension
 * Purpose:  This function sets amplitude and offset parameters for polarity
 *           function.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionPolarityDimension (ViSession instrSession,
                                                                ViInt32 channel,
                                                                ViReal64 DCOffset,
                                                                ViInt32 DCOffsetUnit,
                                                                ViReal64 amplitude1,
                                                                ViInt32 amplitude1Unit,
                                                                ViReal64 amplitude2,
                                                                ViInt32 amplitude2Unit)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TPolarity_DIMENSION     value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    /* DC Offset */
    switch (DCOffsetUnit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (DCOffset, -1.0, 1.0))
                return VI_ERROR_PARAMETER3;
            
            DBL2FLT(DCOffset, value.DCOffset);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (DCOffset, -10.61, 10.61))
                return VI_ERROR_PARAMETER3;
            
            DBL2FLT(DCOffset, value.DCOffset);
            break;
        default:
            return VI_ERROR_PARAMETER4;
        }

    /* Amplitude 1 */
    switch (amplitude1Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 1.0))
                return VI_ERROR_PARAMETER5;

            DBL2FLT(amplitude1, value.Amplitude1);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude1, 0.0, 10.61))
                return VI_ERROR_PARAMETER5;

            DBL2FLT(amplitude1, value.Amplitude1);
            break;
        default:
            return VI_ERROR_PARAMETER6;
        }

    /* Amplitude 2 */
    switch (amplitude2Unit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 1.0))
                return VI_ERROR_PARAMETER7;
            
            DBL2FLT(amplitude2, value.Amplitude2);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (amplitude2, 0.0, 10.61))
                return VI_ERROR_PARAMETER7;

            DBL2FLT(amplitude2, value.Amplitude2);
            break;
        default:
            return VI_ERROR_PARAMETER8;
        }

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_POLARITY_DIMENSION, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function Polarity Dimension
 * Purpose:  This function returns amplitude and offset parameters for
 *           polarity function.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionPolarityDimension (ViSession instrSession,
                                                                ViInt32 channel,
                                                                ViPReal64 DCOffset,
                                                                ViPInt32 DCOffsetUnit,
                                                                ViPReal64 amplitude1,
                                                                ViPInt32 amplitude1Unit,
                                                                ViPReal64 amplitude2,
                                                                ViPInt32 amplitude2Unit)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TPolarity_DIMENSION     value           = {0};
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!DCOffset)
        return VI_ERROR_PARAMETER3;
    if (!DCOffsetUnit)
        return VI_ERROR_PARAMETER4;
    if (!amplitude1)
        return VI_ERROR_PARAMETER5;
    if (!amplitude1Unit)
        return VI_ERROR_PARAMETER6;
    if (!amplitude2)
        return VI_ERROR_PARAMETER7;
    if (!amplitude2Unit)
        return VI_ERROR_PARAMETER8;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_POLARITY_DIMENSION, channel, &value, sizeof(value)));

    if (instrPtr -> generatorMode == RSSIUP_GENERATOR_MODE_ANALOG) /* Analog generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_V;
        *amplitude1 = value.Amplitude1;
        *amplitude1Unit = RSSIUP_UNIT_V;
        *amplitude2 = value.Amplitude2;
        *amplitude2Unit = RSSIUP_UNIT_V;
        }
    else /* Digital generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_FS;
        *amplitude1 = value.Amplitude1;
        *amplitude1Unit = RSSIUP_UNIT_FS;
        *amplitude2 = value.Amplitude2;
        *amplitude2Unit = RSSIUP_UNIT_FS;
        }

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Global DC Offset
 * Purpose:  This function sets global DC offset for generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorGlobalDCOffset (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViReal64 DCOffset,
                                                     ViInt32 DCOffsetUnit)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TGlobDCOffset   value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    /* DC Offset */
    switch (DCOffsetUnit)
        {
        case RSSIUP_UNIT_FS:
            if (rssiup_invalidViReal64Range (DCOffset, -1.0, 1.0))
                return VI_ERROR_PARAMETER3;
            
            DBL2FLT(DCOffset, value.DCOffset);
            break;
        case RSSIUP_UNIT_V:
            if (rssiup_invalidViReal64Range (DCOffset, -10.61, 10.61))
                return VI_ERROR_PARAMETER3;

            DBL2FLT(DCOffset, value.DCOffset);
            break;
        default:
            return VI_ERROR_PARAMETER4;
        }

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_GlobDCOffset, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Global DC Offset
 * Purpose:  This function returns global DC offset for generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorGlobalDCOffset (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViPReal64 DCOffset,
                                                     ViPInt32 DCOffsetUnit)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TGlobDCOffset   value           = {0};
    pTStatusDataRanges  instrPtr    = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!DCOffset)
        return VI_ERROR_PARAMETER3;
    if (!DCOffsetUnit)
        return VI_ERROR_PARAMETER4;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_GlobDCOffset, channel, &value, sizeof(value)));

    if (instrPtr -> generatorMode == RSSIUP_GENERATOR_MODE_ANALOG) /* Analog generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_V;
        }
    else /* Digital generator */
        {
        *DCOffset = value.DCOffset;
        *DCOffsetUnit = RSSIUP_UNIT_FS;
        }

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function State
 * Purpose:  This function selects generator function to switch on or off.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionState (ViSession instrSession,
                                                    ViInt32 channel,
                                                    ViInt32 functionID,
                                                    ViBoolean functionState)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TGenFun     value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SGenFunIDDiscVals, functionID, &value.GenFunID, VI_ERROR_PARAMETER3));

    if (rssiup_invalidViBooleanRange (functionState))
        return VI_ERROR_PARAMETER4;

    if ((functionID == RSSIUP_GEN_FUNC_ALL) && (functionState == VI_TRUE))
        return RSSIUP_ERROR_SETTINGS_CONFLICT;

    value.FunctionStatus = (functionState == VI_TRUE) ? ON : OFF;
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_FUNCTION_ON, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function State
 * Purpose:  This function returns state of the selected generator function.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionState (ViSession instrSession,
                                                    ViInt32 channel,
                                                    ViInt32 functionID,
                                                    ViPBoolean functionState)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    ViUInt16        GenFunID        = 0;
    TGenDescription value           = {0};

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    if (functionID == RSSIUP_GEN_FUNC_ALL)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_param_to_val (SGenFunIDDiscVals, functionID, &GenFunID, VI_ERROR_PARAMETER3));

    if (!functionState)
        return VI_ERROR_PARAMETER4;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GEN_DESCRIPTION, ChAB, &value, sizeof(value)));
    *functionState = value.GenGenerally.FunctionIsOn[GenFunID][channel - 1];
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Device Selector
 * Purpose:  This function selects output device and sampling frequency of
 *           the generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorDeviceSelector (ViSession instrSession,
                                                     ViInt32 device)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViUInt16            value           = 0;
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    CHECKERR (rssiup_SetGeneratorFunctionState (instrSession, RSSIUP_CHAB, RSSIUP_GEN_FUNC_ALL, VI_FALSE));

    CHECKERR (rssiup_param_to_val (SGenDevSelectorDiscVals, device, &value, VI_ERROR_PARAMETER2));
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENHW_DEVICE_SELECTOR, ChAB, &value, sizeof(value)));

    /* --- */

    if ((value == dsA49) || (value == dsA98) || (value == dsA195))
        {
        instrPtr -> generatorMode = RSSIUP_GENERATOR_MODE_ANALOG;
        }
    else
        {
        instrPtr -> generatorMode = RSSIUP_GENERATOR_MODE_DIGITAL;
        }

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Device Selector
 * Purpose:  This function gets output device and sampling frequency of the
 *           generator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorDeviceSelector (ViSession instrSession,
                                                     ViPInt32 device)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViUInt16            value           = 0;
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!device)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENHW_DEVICE_SELECTOR, ChAB, &value, sizeof(value)));

    if ((value == dsA49) || (value == dsA98) || (value == dsA195))
        {
        instrPtr -> generatorMode = RSSIUP_GENERATOR_MODE_ANALOG;
        }
    else
        {
        instrPtr -> generatorMode = RSSIUP_GENERATOR_MODE_DIGITAL;
        }

    CHECKERR (rssiup_val_to_param (SGenDevSelectorDiscVals, device, &value, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Generator Output
 * Purpose:  This function sets state of the analog generator output.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalogGeneratorOutput (ViSession instrSession,
                                                   ViInt32 channel,
                                                   ViBoolean generatorOutput)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (rssiup_invalidViBooleanRange (generatorOutput))
        return VI_ERROR_PARAMETER3;

    value = (generatorOutput == VI_TRUE) ? ON : OFF;
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AGENHW_OUTPUT, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Generator Output
 * Purpose:  This function returns state of the analog generator output.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalogGeneratorOutput (ViSession instrSession,
                                                   ViInt32 channel,
                                                   ViPBoolean generatorOutput)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!generatorOutput)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AGENHW_OUTPUT, channel, &value, sizeof(value)));
    *generatorOutput = (value == ON) ? VI_TRUE : VI_FALSE;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Generator Float Ground
 * Purpose:  This function sets the analog generator generator ground.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalogGeneratorFloatGround (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViBoolean floatGround)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (rssiup_invalidViBooleanRange (floatGround))
        return VI_ERROR_PARAMETER3;

    value = (floatGround == VI_TRUE) ? ON : OFF;
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AGENHW_FLOAT_GND, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Generator Float Ground
 * Purpose:  This function returns the analog generator generator ground.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalogGeneratorFloatGround (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViPBoolean floatGround)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!floatGround)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AGENHW_FLOAT_GND, channel, &value, sizeof(value)));
    *floatGround = (value == ON) ? VI_TRUE : VI_FALSE;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Generator Range Dependency
 * Purpose:  This function sets whether to use the same range settings for
 *           both channels.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalogGeneratorRangeDependency (ViSession instrSession,
                                                            ViInt32 rangeDependency)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;

    if (rssiup_invalidViInt32Range (rangeDependency, 0, 1))
        return VI_ERROR_PARAMETER2;

    value = (rangeDependency == RSSIUP_RANGE_DEPENDENT) ? ON : OFF;
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AGENHW_RANGE_DEPENDENCY, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Generator Range Dependency
 * Purpose:  This function returns whether to use the same range settings for
 *           both channels.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalogGeneratorRangeDependency (ViSession instrSession,
                                                            ViPInt32 rangeDependency)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViUInt16    value           = 0;

    if (!rangeDependency)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AGENHW_RANGE_DEPENDENCY, ChAB, &value, sizeof(value)));
    *rangeDependency = (value == ON) ? RSSIUP_RANGE_DEPENDENT : RSSIUP_RANGE_INDEPENDENT;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Generator Range Number
 * Purpose:  This function sets analog generator range mode and range number.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_SetAnalogGeneratorRangeNumber (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViInt32 rangeMode,
                                                        ViInt32 rangeNumber)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TAGenRange  value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SAGenRangeModeDiscVals, rangeMode, &value.RangeMode, VI_ERROR_PARAMETER3));

    if (rssiup_invalidViInt32Range (rangeNumber, 0, 9))
        return VI_ERROR_PARAMETER4;

    value.RangeNum = rangeNumber;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AGENHW_RANGE_NUM, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Generator Range Number
 * Purpose:  This function returns analog generator range mode and range number.
 *****************************************************************************/
ViStatus /* _VI_FUNC */ rssiup_GetAnalogGeneratorRangeNumber (ViSession instrSession,
                                                        ViInt32 channel,
                                                        ViPInt32 rangeMode,
                                                        ViPInt32 rangeNumber)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TAGenRange  value           = {0};

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!rangeMode)
        return VI_ERROR_PARAMETER3;
    if (!rangeNumber)
        return VI_ERROR_PARAMETER4;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AGENHW_RANGE_NUM, channel, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAGenRangeModeDiscVals, rangeMode, &value.RangeMode, VI_ERROR_INV_RESPONSE));
    *rangeNumber = value.RangeNum;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Analog Generator Range Value
 * Purpose:  This function sets analog generator range mode and range value.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAnalogGeneratorRangeValue (ViSession instrSession,
                                                       ViInt32 channel,
                                                       ViInt32 rangeMode,
                                                       ViReal64 rangeValue,
                                                       ViInt32 unit)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TAGenRangeModeSetVolt   value           = {0};

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_param_to_val (SAGenRangeModeDiscVals, rangeMode, &value.Mode, VI_ERROR_PARAMETER3));

    if (rssiup_invalidViReal64Range (rangeValue, 0.0, 7.5))
        return VI_ERROR_PARAMETER4;
    if (unit != RSSIUP_UNIT_V)
        return VI_ERROR_PARAMETER5;

    DBL2FLT(rangeValue, value.RangeValue);
    value.RangeValue *= sqrt(2);    

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AGENHW_RANGE_VOLT, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Analog Generator Range
 * Purpose:  This function returns range mode, down limit and upper limit of
 *           the current range.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAnalogGeneratorRange (ViSession instrSession,
                                                  ViInt32 channel,
                                                  ViPInt32 rangeMode,
                                                  ViPReal64 lowerLimit,
                                                  ViPReal64 upperLimit)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    TAGenRangeModeGetVolt   value           = {0};

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!rangeMode)
        return VI_ERROR_PARAMETER3;
    if (!lowerLimit)
        return VI_ERROR_PARAMETER4;
    if (!upperLimit)
        return VI_ERROR_PARAMETER5;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_AGENHW_RANGE_VOLT, channel, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SAGenRangeModeDiscVals, rangeMode, &value.Mode, VI_ERROR_INV_RESPONSE));
    *lowerLimit = value.DnLimit / sqrt(2);
    *upperLimit = value.UpLimit / sqrt(2);
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Digital Generator Protocol
 * Purpose:  This function sets parameters for transmited DAI Protocol.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetDigitalGeneratorProtocol (ViSession instrSession,
                                                      /* ViInt32 channel, */
                                                      ViString channelStatus,
                                                      ViString userData,
                                                      ViInt32 validityBit)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TDGenDaiProtocol    value           = {0};
/*
    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
*/
    if (!channelStatus)
        return VI_ERROR_PARAMETER2;
    if (!userData)
        return VI_ERROR_PARAMETER3;

    memcpy (value.ChannelStatus, channelStatus, 24);
    memcpy (value.UserData, userData, 24);
    value.ValidityBit = (validityBit == RSSIUP_INVALID) ? 1 : 0; /* For module invalid = 1 */

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_DAIPROTOCOL, ChAB /* channel */, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Digital Generator Protocol
 * Purpose:  This function returns parameters for transmited DAI Protocol.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetDigitalGeneratorProtocol (ViSession instrSession,
                                                      ViInt32 channel,
                                                      ViChar _VI_FAR channelStatus[],
                                                      ViChar _VI_FAR userData[],
                                                      ViPInt32 validityBit)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    TDGenDaiProtocol    value           = {0};

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!channelStatus)
        return VI_ERROR_PARAMETER3;
    if (!userData)
        return VI_ERROR_PARAMETER4;
    if (!validityBit)
        return VI_ERROR_PARAMETER5;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENFUN_DAIPROTOCOL, channel, &value, sizeof(value)));

    memcpy (channelStatus, value.ChannelStatus, 24);
    memcpy (userData, value.UserData, 24);
    *validityBit = (value.ValidityBit == 1) ? RSSIUP_INVALID : RSSIUP_VALID; /* For module invalid = 1 */

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Digital Generator No of Bits
 * Purpose:  This function sets number of valid bits of DAI Transmitter.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetDigitalGeneratorNoofBits (ViSession instrSession,
                                                      /* ViInt32 channel, */
                                                      ViInt32 no_ofBits)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TDDevNoOfBits   value           = {0};
/*
    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
*/
    CHECKERR (rssiup_param_to_val (SDDevNoOfBitsDiscVals, no_ofBits, &value, VI_ERROR_PARAMETER3));

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_DGENHW_NUM_OF_BITS, ChAB /* channel */, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Digital Generator No of Bits
 * Purpose:  This function returns number of valid bits of DAI Transmitter.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetDigitalGeneratorNoofBits (ViSession instrSession,
                                                      /* ViInt32 channel, */
                                                      ViPInt32 no_ofBits)
{
    ViStatus        rssiup_status   = VI_SUCCESS;
    TDDevNoOfBits   value           = {0};
/*
    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
*/
    if (!no_ofBits)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_DGENHW_NUM_OF_BITS, ChA /* channel */, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SDDevNoOfBitsDiscVals, no_ofBits, &value, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Digital Generator Sampling Frequency Offset
 * Purpose:  This function sets Sampling Frequency Offset of DAI.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetDigitalGeneratorSamplingFrequencyOffset (ViSession instrSession,
                                                                     ViInt32 samplingFrequencyOffset)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViInt16     value           = 0;

    if (rssiup_invalidViInt32Range (samplingFrequencyOffset, -1000, 1000))
        return VI_ERROR_PARAMETER2;

    value = samplingFrequencyOffset;
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLHW_DAI_SAMPL_FREQ_OFFSET, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Digital Generator Sampling Frequency Offset
 * Purpose:  This function returns Sampling Frequency Offset of DAI.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetDigitalGeneratorSamplingFrequencyOffset (ViSession instrSession,
                                                                     ViPInt32 samplingFrequencyOffset)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViInt16     value           = 0;

    if (!samplingFrequencyOffset)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLHW_DAI_SAMPL_FREQ_OFFSET, ChA, &value, sizeof(value)));
    *samplingFrequencyOffset = value;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function RMS Sweep Frequency
 * Purpose:  This function sets frequency parameters for SinRmsSweep
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionRMSSweepFrequency (ViSession instrSession,
                                               ViReal64 startFrequency,
                                               ViReal64 stopFrequency,
                                               ViInt32 frequencySweepSpacing,
                                               ViInt32 frequencySweepSteps,
                                               ViInt32 frequencyStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinRmsSweep_NoChSet     value           = {0};
	TGetSinRmsSweep_NoChSet     get_value       = {0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViReal64            		get_startFrequency         = 0.0;
	//ViReal64            		get_stopFrequency          = 0.0;
	//ViInt32             		get_frequencySweepSpacing  = 0;
	//ViInt32             		get_frequencySweepSteps    = 0;
	//ViInt32             		get_frequencyStepDelay     = 0;
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
		
/*    
	if (rssiup_invalidViReal64Range (startFrequency, 1.0e-3, 88573.992))
        return VI_ERROR_PARAMETER2;
*/
/*
	if (rssiup_invalidViReal64Range (stopFrequency, 1.0e-3, 88573.992))
        return VI_ERROR_PARAMETER3;
*/
	if (rssiup_invalidViInt32Range (frequencySweepSpacing, RSSIUP_SPACING_NO, RSSIUP_SPACING_LOG))
        return VI_ERROR_PARAMETER4;
	if (rssiup_invalidViInt32Range (frequencySweepSteps, 1, 1999))
        return VI_ERROR_PARAMETER5;
	if (rssiup_invalidViInt32Range (frequencyStepDelay, 0, 65000))
        return VI_ERROR_PARAMETER6;
	
	/* NOT NEEDED
	// checking if the new sweep is running
	CHECKERR (rssiup_GetGeneratorFunctionRMSSweepFrequency (instrSession,
															&get_startFrequency,
															&get_stopFrequency,
															&get_frequencySweepSpacing,
															&get_frequencySweepSteps,
															&get_frequencyStepDelay));
	
	if((fabs (startFrequency - get_startFrequency) > 0.000001) ||
	   (fabs (stopFrequency - get_stopFrequency) > 0.000001) ||
	   (frequencySweepSpacing != get_frequencySweepSpacing) ||
	   (frequencySweepSteps != get_frequencySweepSteps) ||
	   (frequencyStepDelay != get_frequencyStepDelay))
		instrPtr->newSweep = VI_TRUE;
	*/
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRmsSweep_NoChSet, ChAB, &get_value, sizeof(get_value)));
    
	value.Sender = 0x07FE;
	
	DBL2FLT(startFrequency, value.fFr1Start);
	DBL2FLT(stopFrequency, value.fFr1End);
		
	CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing, &value.Fr1Spacing, VI_ERROR_PARAMETER4));
	
	DBL2FLT(startFrequency, value.fFr2Start /* startFrequency_2 */);
	DBL2FLT(stopFrequency, value.fFr2End /* stopFrequency_2 */);
		
	CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing /* frequencySweepSpacing_2 */, &value.Fr2Spacing, VI_ERROR_PARAMETER4));
	
	value.FrStepCnt = frequencySweepSteps;
	value.fPhase1 = 0.0 /* phase_1 */;
	value.fPhase2 = 0.0 /* phase_2 */;
	value.AmStepCnt = get_value.AmStepCnt;
	value.RefreshTime = 0 /*500 /* refreshTime*/;
	value.FrSweepRepeat = 1 /* sweepLoops */;
	value.FrStepPause = frequencyStepDelay;
	value.AmStepPause = get_value.AmStepPause;
	CHECKERR (rssiup_param_to_val (STCtrlStepDiscVals, RSSIUP_CTRL_STEP_CONTINUE /* sweepStepControl */, &value.StartCtrlStep, VI_ERROR_PARAMETER1));
	CHECKERR (rssiup_param_to_val (STAverageModeDiscVals, RSSIUP_AVER_MODE_OFF /* averageMode */, &value.AverageMode, VI_ERROR_PARAMETER1));
	
	value.AverageFactor = 1 /* averagedValues */;
    
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRmsSweep_NoChSet, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Get Generator Function RMS Sweep Frequency 
 * Purpose:  This function returns frequency parameters for SinRmsSweep
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionRMSSweepFrequency (ViSession instrSession,
                                               ViReal64 *startFrequency,
                                               ViReal64 *stopFrequency,
                                               ViInt32 *frequencySweepSpacing,
                                               ViInt32 *frequencySweepSteps,
                                               ViInt32 *frequencyStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TGetSinRmsSweep_NoChSet     value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (!startFrequency)
        return VI_ERROR_PARAMETER2;
    if (!stopFrequency)
        return VI_ERROR_PARAMETER3;
    if (!frequencySweepSpacing)
        return VI_ERROR_PARAMETER4;
    if (!frequencySweepSteps)
        return VI_ERROR_PARAMETER5;
    if (!frequencyStepDelay)
        return VI_ERROR_PARAMETER6;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRmsSweep_NoChSet, ChAB, &value, sizeof(value)));
    
	*startFrequency = value.fFr1Start;
	*stopFrequency = value.fFr1End;
		
	CHECKERR (rssiup_val_to_param (STFrSpacingDiscVals, &frequencySweepSpacing[0], &value.Fr1Spacing, VI_ERROR_INV_RESPONSE));
	
	*frequencySweepSteps = value.FrStepCnt;
	*frequencyStepDelay = value.FrStepPause;
	
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Set Generator Function RMS Sweep Amplitude
 * Purpose:  This function sets amplitude parameters for SinRmsSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionRMSSweepAmplitude (ViSession instrSession,
                                                      ViInt32 channel,
                                                      ViReal64 startAmplitude,
                                                      ViReal64 stopAmplitude,
                                                      ViInt32 amplitudeSweepSpacing,
                                                      ViReal64 measurementTime,
                                                      ViInt32 amplitudeSweepSteps,
                                                      ViInt32 amplitudeStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinRmsSweep_ChanSet     value           = {0};
	TCmdSinRmsSweep_NoChSet     no_ch_value     = {0};
	TGetSinRmsSweep_NoChSet     get_value       = {0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViReal64            		startAmplitudeA        = 0.0;
	//ViReal64            		stopAmplitudeA         = 0.0;
	//ViInt32             		amplitudeSweepSpacingA = 0;
	//ViReal64            		measurementTimeA       = 0.0;
	//ViInt32             		amplitudeSweepStepsA   = 0;
	//ViInt32             		amplitudeStepDelayA    = 0;
	//ViReal64            		startAmplitudeB        = 0.0;
	//ViReal64            		stopAmplitudeB         = 0.0;
	//ViInt32             		amplitudeSweepSpacingB = 0;
	//ViReal64            		measurementTimeB       = 0.0;
	//ViInt32             		amplitudeSweepStepsB   = 0;
	//ViInt32             		amplitudeStepDelayB    = 0;
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (rssiup_invalidViInt32Range (channel, RSSIUP_CHAB, RSSIUP_CHB))
        return VI_ERROR_PARAMETER2;
	if (rssiup_invalidViReal64Range (startAmplitude, 0.0, 10.61))
        return VI_ERROR_PARAMETER3;
	if (rssiup_invalidViReal64Range (stopAmplitude, 0.0, 10.61))
        return VI_ERROR_PARAMETER4;
	if (rssiup_invalidViInt32Range (amplitudeSweepSpacing, RSSIUP_SPACING_NO, RSSIUP_SPACING_INS_LOG))
        return VI_ERROR_PARAMETER5;
	if (rssiup_invalidViReal64Range (measurementTime, 1.0e-3, 1.0e4))
        return VI_ERROR_PARAMETER6;
	if (rssiup_invalidViInt32Range (amplitudeSweepSteps, 1, 1999))
        return VI_ERROR_PARAMETER7;
	if (rssiup_invalidViInt32Range (amplitudeStepDelay, 0, 65000))
        return VI_ERROR_PARAMETER8;
	
	/* NOT NEEDED
	// checking if the new sweep is running
	if ((channel == RSSIUP_CHAB) || (channel == RSSIUP_CHA))
	{
		CHECKERR (rssiup_GetGeneratorFunctionRMSSweepAmplitude (instrSession,
																RSSIUP_CHA,
																&startAmplitudeA,
																&stopAmplitudeA,
																&amplitudeSweepSpacingA,
																&measurementTimeA,
																&amplitudeSweepStepsA,
																&amplitudeStepDelayA));
	
		if((fabs (startAmplitude - startAmplitudeA) > 0.000001) ||
		   (fabs (stopAmplitude - stopAmplitudeA) > 0.000001) ||
		   (amplitudeSweepSpacing != amplitudeSweepSpacingA) ||
		   (fabs (measurementTime - measurementTimeA) > 0.000001) ||
		   (amplitudeSweepSteps != amplitudeSweepStepsA) ||
		   (amplitudeStepDelay != amplitudeStepDelayA))
			instrPtr->newSweep = VI_TRUE;
	}
	else
	{
		CHECKERR (rssiup_GetGeneratorFunctionRMSSweepAmplitude (instrSession,
																RSSIUP_CHB,
																&startAmplitudeB,
																&stopAmplitudeB,
																&amplitudeSweepSpacingB,
																&measurementTimeB,
																&amplitudeSweepStepsB,
																&amplitudeStepDelayB));
		
		if((fabs (startAmplitude - startAmplitudeB) > 0.000001) ||
		   (fabs (stopAmplitude - stopAmplitudeB) > 0.000001) ||
		   (amplitudeSweepSpacing != amplitudeSweepSpacingB) ||
		   (fabs (measurementTime - measurementTimeB) > 0.000001) ||
		   (amplitudeSweepSteps != amplitudeSweepStepsB) ||
		   (amplitudeStepDelay != amplitudeStepDelayB))
			instrPtr->newSweep = VI_TRUE;
	}	
	*/
	
	value.Sender = 0x07FE;
	
	value.fDCOffset = 0.0 /* DCOffset */;
    
	DBL2FLT(startAmplitude * sqrt(2)/2, value.fAm1Start);
	DBL2FLT(stopAmplitude * sqrt(2)/2, value.fAm1End);
		
	CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing, &value.fAm1Spacing, VI_ERROR_PARAMETER5));
	
	DBL2FLT(startAmplitude * sqrt(2)/2, value.fAm2Start /* startAmplitude_2 */);
    DBL2FLT(stopAmplitude * sqrt(2)/2, value.fAm2End /* stopAmplitude_2 */);
    
	CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing /* amplitudeSweepSpacing_2 */, &value.fAm2Spacing, VI_ERROR_PARAMETER5));
	
	DBL2FLT(measurementTime, value.fMeasTime);
	
	value.fTimeOut = 0.2 /* timeout */;
	
    if (2*measurementTime >= 0.2) 
		DBL2FLT(2*measurementTime, value.fTimeOut /* timeout */);
	
	CHECKERR (rssiup_param_to_val (STSynchroModeDiscVals, RSSIUP_SYNC_MODE_SYNCHRO /* synchroMode */, &value.SynchroMode, VI_ERROR_PARAMETER1));
	CHECKERR (rssiup_param_to_val (STSynchroSourcesDiscVals, RSSIUP_SYNC_SRC_SINE_GEN_A_RISING /* synchroSource */, &value.SynchroSource, VI_ERROR_PARAMETER1));
	CHECKERR (rssiup_param_to_val (STSynchroLevelModeDiscVals, RSSIUP_SYNC_LEVEL_MODE_AUTO /* synchroLevelMode */, &value.SynchroLevelMode, VI_ERROR_PARAMETER1));
	
	value.FixedLevel = 0.0 /* fixedLevel */;
    value.FixedHysteresis = 0.2 /* fixedHysteresis */;
    value.AutoHysteresis = 10.0 /* autoHysteresis */;
    value.SynchroFilterTau = 1.0 /* synchroFilterTau */;
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRmsSweep_ChanSet, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRmsSweep_NoChSet, ChAB, &get_value, sizeof(get_value)));
    
	no_ch_value.Sender = 0x07FE;
	
	no_ch_value.fFr1Start = get_value.fFr1Start;
	no_ch_value.fFr1End = get_value.fFr1End;
		
	no_ch_value.Fr1Spacing = get_value.Fr1Spacing;
	
	no_ch_value.fFr2Start = get_value.fFr2Start;
	no_ch_value.fFr2End = get_value.fFr2End;
		
	no_ch_value.Fr2Spacing = get_value.Fr2Spacing;
	
	no_ch_value.FrStepCnt = get_value.FrStepCnt;
	no_ch_value.fPhase1 = get_value.fPhase1;
	no_ch_value.fPhase2 = get_value.fPhase2;
	no_ch_value.RefreshTime = get_value.RefreshTime;
	no_ch_value.FrSweepRepeat = get_value.FrSweepRepeat;
	no_ch_value.FrStepPause = get_value.FrStepPause;
	no_ch_value.StartCtrlStep = get_value.StartCtrlStep;
	no_ch_value.AverageMode = get_value.AverageMode;
	
	no_ch_value.AverageFactor = get_value.AverageFactor;
    
	no_ch_value.AmStepCnt = amplitudeSweepSteps;
	no_ch_value.AmStepPause = amplitudeStepDelay;

	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRmsSweep_NoChSet, ChAB, &no_ch_value, sizeof(no_ch_value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
	
	return rssiup_status;    
}

/*****************************************************************************
 * Function: Get Generator Function RMS Sweep Amplitude 
 * Purpose:  This function returns amplitude parameters for SinRmsSweep
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionRMSSweepAmplitude (ViSession instrSession,
                                                      ViInt32 channel,
                                                      ViReal64 *startAmplitude,
                                                      ViReal64 *stopAmplitude,
                                                      ViInt32 *amplitudeSweepSpacing,
                                                      ViReal64 *measurementTime,
													  ViInt32 *amplitudeSweepSteps,
													  ViInt32 *amplitudeStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TGetSinRmsSweep_ChanSet     value           = {0};
	TGetSinRmsSweep_NoChSet     get_value       = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (rssiup_invalidViInt32Range (channel, RSSIUP_CHA, RSSIUP_CHB))
        return VI_ERROR_PARAMETER2;
	if (!startAmplitude)
        return VI_ERROR_PARAMETER3;
    if (!stopAmplitude)
        return VI_ERROR_PARAMETER4;
    if (!amplitudeSweepSpacing)
        return VI_ERROR_PARAMETER5;
    if (!measurementTime)
        return VI_ERROR_PARAMETER6;
    if (!amplitudeSweepSteps)
        return VI_ERROR_PARAMETER7;
	if (!amplitudeStepDelay)
        return VI_ERROR_PARAMETER8;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRmsSweep_ChanSet, channel, &value, sizeof(value)));
    
	*startAmplitude = value.fAm1Start * 2 / sqrt(2);
	*stopAmplitude = value.fAm1End * 2 / sqrt(2);
		
	CHECKERR (rssiup_val_to_param (STAmSpacingDiscVals, amplitudeSweepSpacing, &value.fAm1Spacing, VI_ERROR_INV_RESPONSE));
	
	*measurementTime = value.fMeasTime;
	
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRmsSweep_NoChSet, ChAB, &get_value, sizeof(get_value)));
    
	*amplitudeSweepSteps = get_value.AmStepCnt;
	*amplitudeStepDelay = get_value.AmStepPause;
    
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;     
}

/*****************************************************************************
 * Function: Set Generator Function RMS Selective Sweep Frequency
 * Purpose:  This function sets frequency parameters for
 *           SinRMSSelMuTskSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionRMSSelectiveSweepFrequency (ViSession instrSession,
                                                        ViReal64 startFrequency,
                                                        ViReal64 stopFrequency,
                                                        ViInt32 frequencySweepSpacing,
                                                        ViInt32 frequencySweepSteps,
                                                        ViInt32 frequencyStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinRSmSweep_NoChSet     set_value       = {0};
	TGetSinRSmSweep_NoChSet     get_value       = {0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViReal64            		get_startFrequency         = 0.0;
	//ViReal64            		get_stopFrequency          = 0.0;
	//ViInt32             		get_frequencySweepSpacing  = 0;
	//ViInt32             		get_frequencySweepSteps    = 0;
	//ViInt32             		get_frequencyStepDelay     = 0;
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
/*  
	if (rssiup_invalidViReal64Range (startFrequency, 1.0e-3, 88573.992))
        return VI_ERROR_PARAMETER2;
*/
/*	
	if (rssiup_invalidViReal64Range (stopFrequency, 1.0e-3, 88573.992))
        return VI_ERROR_PARAMETER3;
*/
	if (rssiup_invalidViInt32Range (frequencySweepSpacing, RSSIUP_SPACING_NO, RSSIUP_SPACING_LOG))
        return VI_ERROR_PARAMETER4;
	if (rssiup_invalidViInt32Range (frequencySweepSteps, 1, 1999))
        return VI_ERROR_PARAMETER5;
	if (rssiup_invalidViInt32Range (frequencyStepDelay, 0, 65000))
        return VI_ERROR_PARAMETER6;
	
	/* NOT NEEDED
	// checking if the new sweep is running
	CHECKERR (rssiup_GetGeneratorFunctionRMSSelectiveSweepFrequency (instrSession,
															&get_startFrequency,
															&get_stopFrequency,
															&get_frequencySweepSpacing,
															&get_frequencySweepSteps,
															&get_frequencyStepDelay));
	
	if((fabs (startFrequency - get_startFrequency) > 0.000001) ||
	   (fabs (stopFrequency - get_stopFrequency) > 0.000001) ||
	   (frequencySweepSpacing != get_frequencySweepSpacing) ||
	   (frequencySweepSteps != get_frequencySweepSteps) ||
	   (frequencyStepDelay != get_frequencyStepDelay))
		instrPtr->newSweep = VI_TRUE;
	*/
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_NoChSet, ChAB, &get_value, sizeof(get_value)));
    								
	set_value.Sender = 0x07FE;
	
	DBL2FLT(startFrequency, set_value.fFr1Start);
	DBL2FLT(stopFrequency, set_value.fFr1End);
		
	CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing, &set_value.Fr1Spacing, VI_ERROR_PARAMETER4));
	
	DBL2FLT(startFrequency, set_value.fFr2Start /* startFrequency_2 */);
	DBL2FLT(stopFrequency, set_value.fFr2End /* stopFrequency_2 */);
		
	CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing /* frequencySweepSpacing_2 */, &set_value.Fr2Spacing, VI_ERROR_PARAMETER4));
	
	set_value.FrStepCnt = frequencySweepSteps;
	set_value.fPhase1 = 0.0 /* phase_1 */;
	set_value.fPhase2 = 0.0 /* phase_2 */;
	set_value.AmStepCnt = get_value.AmStepCnt;
	set_value.RefreshTime = 0 /*500 /* refreshTime*/;
	set_value.FrSweepRepeat = 1 /* sweepLoops */;
	set_value.FrStepPause = frequencyStepDelay;
	set_value.AmStepPause = get_value.AmStepPause;
	CHECKERR (rssiup_param_to_val (STCtrlStepDiscVals, RSSIUP_CTRL_STEP_CONTINUE /* sweepStepControl */, &set_value.StartCtrlStep, VI_ERROR_PARAMETER1));
	
	set_value.wFilterOrder = 4;
	
	set_value.FilterBandwidthType = get_value.FilterBandwidthType /* FilterBandwidthType */;
	
	set_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth /* AbsoluteBandwidth */;
	
	set_value.RelativeBandwidth = get_value.RelativeBandwidth /* RelativeBandwidth */;
    
    CHECKERR (rssiup_param_to_val (STAutoFrqModeDiscVals, RSSIUP_FREQ_MODE_FIXED /* FrequencyMode */, &set_value.FrequencyMode, VI_ERROR_PARAMETER1));
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRSmSweep_NoChSet, ChAB, &set_value, sizeof(set_value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Set Generator Function RMS Selective Sweep Bandwidth 
 * Purpose:  This function sets bandwidth parameters for
 *           SinRMSSelMuTskSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionRMSSelectiveSweepBandwidth (ViSession instrSession,
                                                                ViInt32 filterBandwidthType,
                                                                ViReal64 filterBandwidth,
                                                                ViReal64 multipleOfCenterFrequency)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinRSmSweep_NoChSet     set_value       = {0};
	TGetSinRSmSweep_NoChSet     get_value       = {0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViInt32 					get_filterBandwidthType = 0;
	//ViReal64 					get_filterBandwidth = 0.0;
	//ViReal64 					get_multipleOfCenterFrequency = 0.0;
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (rssiup_invalidViInt32Range (filterBandwidthType, RSSIUP_FILTER_BWID_TYPE_CONST, RSSIUP_FILTER_BWID_TYPE_RELAT))
        return VI_ERROR_PARAMETER2;
/*
	if (rssiup_invalidViRea64Range (filterBandwidth, 10.0, 19531.2))
        return VI_ERROR_PARAMETER3;
*/
	if (rssiup_invalidViReal64Range (multipleOfCenterFrequency, 0.00001, 1.0))
        return VI_ERROR_PARAMETER4;
	
	/* NOT NEEDED
	// checking if the new sweep is running
	CHECKERR (rssiup_GetGeneratorFunctionRMSSelectiveSweepBandwidth (instrSession,
																&get_filterBandwidthType,
                                                                &get_filterBandwidth,
                                                                &get_multipleOfCenterFrequency));
	
	if((fabs (filterBandwidth - get_filterBandwidth) > 0.000001) ||
	   (fabs (multipleOfCenterFrequency - get_multipleOfCenterFrequency) > 0.000001) ||
	   (filterBandwidthType != get_filterBandwidthType))
		instrPtr->newSweep = VI_TRUE;
	*/
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_NoChSet, ChAB, &get_value, sizeof(get_value)));
    								
	set_value.Sender = 0x07FE;
	
	set_value.fFr1Start = get_value.fFr1Start;
	set_value.fFr1End = get_value.fFr1End;
		
	set_value.Fr1Spacing = get_value.Fr1Spacing;
	
	set_value.fFr2Start = get_value.fFr2Start;
	set_value.fFr2End = get_value.fFr2End;
		
	set_value.Fr2Spacing = get_value.Fr2Spacing;
	
	set_value.FrStepCnt = get_value.FrStepCnt;
	set_value.fPhase1 = 0.0;
	set_value.fPhase2 = 0.0;
	set_value.AmStepCnt = get_value.AmStepCnt;
	set_value.RefreshTime = 0 /*500*/;
	set_value.FrSweepRepeat = 1;
	set_value.FrStepPause = get_value.FrStepPause;
	set_value.AmStepPause = get_value.AmStepPause;
	CHECKERR (rssiup_param_to_val (STCtrlStepDiscVals, RSSIUP_CTRL_STEP_CONTINUE /* sweepStepControl */, &set_value.StartCtrlStep, VI_ERROR_PARAMETER1));
	
	set_value.wFilterOrder = 4;
	
	CHECKERR (rssiup_param_to_val (STFilterBandwidthTypeDiscVals, filterBandwidthType, &set_value.FilterBandwidthType, VI_ERROR_PARAMETER1));
	
	if (filterBandwidthType == RSSIUP_FILTER_BWID_TYPE_CONST)
	{
		DBL2FLT (filterBandwidth,set_value.AbsoluteBandwidth);
		set_value.RelativeBandwidth = get_value.RelativeBandwidth;
	}
	else	
	{
		DBL2FLT (multipleOfCenterFrequency,set_value.RelativeBandwidth);
		set_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth;
	}
    
    CHECKERR (rssiup_param_to_val (STAutoFrqModeDiscVals, RSSIUP_FREQ_MODE_FIXED /* FrequencyMode */, &set_value.FrequencyMode, VI_ERROR_PARAMETER1));
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRSmSweep_NoChSet, ChAB, &set_value, sizeof(set_value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator Function RMS Selective Sweep Frequency 
 * Purpose:  This function returns frequency parameters for
 *           SinRMSSelMuTskSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionRMSSelectiveSweepFrequency (ViSession instrSession,
                                                        ViReal64 *startFrequency,
                                                        ViReal64 *stopFrequency,
                                                        ViInt32 *frequencySweepSpacing,
                                                        ViInt32 *frequencySweepSteps,
                                                        ViInt32 *frequencyStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TGetSinRSmSweep_NoChSet     value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (!startFrequency)
        return VI_ERROR_PARAMETER2;
    if (!stopFrequency)
        return VI_ERROR_PARAMETER3;
    if (!frequencySweepSpacing)
        return VI_ERROR_PARAMETER4;
    if (!frequencySweepSteps)
        return VI_ERROR_PARAMETER5;
    if (!frequencyStepDelay)
        return VI_ERROR_PARAMETER6;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_NoChSet, ChAB, &value, sizeof(value)));
    
	*startFrequency = value.fFr1Start;
	*stopFrequency = value.fFr1End;
		
	CHECKERR (rssiup_val_to_param (STFrSpacingDiscVals, frequencySweepSpacing, &value.Fr1Spacing, VI_ERROR_INV_RESPONSE));
	
	*frequencySweepSteps = value.FrStepCnt;
	*frequencyStepDelay = value.FrStepPause;
	
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;     
}

/*****************************************************************************
 * Function: Get Generator Function RMS Selective Sweep Bandwidth
 * Purpose:  This function returns bandwidth parameters for
 *           SinRMSSelMuTskSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionRMSSelectiveSweepBandwidth (ViSession instrSession,
                                                                ViInt32 *filterBandwidthType,
                                                                ViReal64 *filterBandwidth,
                                                                ViReal64 *multipleOfCenterFrequency)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TGetSinRSmSweep_NoChSet     value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (!filterBandwidthType)
        return VI_ERROR_PARAMETER2;
    if (!filterBandwidth)
        return VI_ERROR_PARAMETER3;
    if (!multipleOfCenterFrequency)
        return VI_ERROR_PARAMETER4;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_NoChSet, ChAB, &value, sizeof(value)));
    
	CHECKERR (rssiup_val_to_param (STFilterBandwidthTypeDiscVals, filterBandwidthType, &value.FilterBandwidthType, VI_ERROR_INV_RESPONSE));
	
	*filterBandwidth = value.AbsoluteBandwidth;
	*multipleOfCenterFrequency = value.RelativeBandwidth;
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Get Generator Function RMS Selective Frequency Limits 
 * Purpose:  This function calculates the frequency limit values for fixed 
 *           frequency mode for certain bandwidth settings used in 
 *           SinRMSSelMuTskSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionRMSSelectiveFrequencyLimits (ViSession instrSession,
                                                                  ViInt32 filterBandwidthType,
                                                                  ViReal64 bandwidth,
                                                                  ViReal64 *lowerLimit,
                                                                  ViReal64 *upperLimit)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges          instrPtr        = {0};
	ViReal64					sample_frequency = 0.0;
	ViReal64                    gen_sample_freq = 0.0;
	ViReal64                    anl_sample_freq = 0.0;
	ViReal64                    fsArr[] = {48828.125,97656.250,195312.0,32000.0,44100.0,48000.0,96000.0,192000.0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	CHECKERR (rssiup_GetGeneratorSamplingFrequency (instrSession, &gen_sample_freq));
	
	anl_sample_freq = fsArr[instrPtr->AnlDescription.AnlGenerally.DevSelector];
	
	if(gen_sample_freq <= anl_sample_freq) 
		sample_frequency = gen_sample_freq;
	else
		sample_frequency = anl_sample_freq;

	if (filterBandwidthType == RSSIUP_FILTER_BWID_TYPE_CONST)
	{
		if (rssiup_invalidViReal64Range (bandwidth, 10.0, 0.1*sample_frequency))
        	return VI_ERROR_PARAMETER3;	
		
		*lowerLimit = 0.5 * bandwidth;
		
		if(*lowerLimit < 10.0) *lowerLimit = 10.0;
		
		*upperLimit = 0.4535 * sample_frequency - *lowerLimit;
	}
	else
	{
		if (rssiup_invalidViReal64Range (bandwidth, 0.00001, 1.0))
        	return VI_ERROR_PARAMETER3;
		
		*lowerLimit = 10 / ( 1 - bandwidth / 2 );
		
		*upperLimit = 0.4535 * sample_frequency / ( 1 + bandwidth / 2 );
	}
	
    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function RMS Selective Sweep Amplitude
 * Purpose:  This function sets amplitude parameters for SinRMSSelMuTskSweep 
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionRMSSelectiveSweepAmplitude (ViSession instrSession,
                                                               ViInt32 channel,
                                                               ViReal64 startAmplitude,
                                                               ViReal64 stopAmplitude,
                                                               ViInt32 amplitudeSweepSpacing,
															   ViInt32 amplitudeSweepSteps,
															   ViInt32 amplitudeStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinRSmSweep_ChanSet     set_value       = {0};
	TGetSinRSmSweep_NoChSet     get_value       = {0};
	TCmdSinRSmSweep_NoChSet     set_NoCh_value  = {0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViReal64            		startAmplitudeA        = 0.0;
	//ViReal64            		stopAmplitudeA         = 0.0;
	//ViInt32             		amplitudeSweepSpacingA = 0;
	//ViInt32             		amplitudeSweepStepsA   = 0;
	//ViInt32             		amplitudeStepDelayA    = 0;
	//ViReal64            		startAmplitudeB        = 0.0;
	//ViReal64            		stopAmplitudeB         = 0.0;
	//ViInt32             		amplitudeSweepSpacingB = 0;
	//ViInt32             		amplitudeSweepStepsB   = 0;
	//ViInt32             		amplitudeStepDelayB    = 0;
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (rssiup_invalidViInt32Range (channel, RSSIUP_CHAB, RSSIUP_CHB))
        return VI_ERROR_PARAMETER2;
	if (rssiup_invalidViReal64Range (startAmplitude, 0.0, 10.61))
        return VI_ERROR_PARAMETER3;
	if (rssiup_invalidViReal64Range (stopAmplitude, 0.0, 10.61))
        return VI_ERROR_PARAMETER4;
	if (rssiup_invalidViInt32Range (amplitudeSweepSpacing, RSSIUP_SPACING_NO, RSSIUP_SPACING_INS_LOG))
        return VI_ERROR_PARAMETER5;
	if (rssiup_invalidViInt32Range (amplitudeSweepSteps, 1, 1999))
        return VI_ERROR_PARAMETER6;
	if (rssiup_invalidViInt32Range (amplitudeStepDelay, 0, 65000))
        return VI_ERROR_PARAMETER7;
	
	/* NOT NEEDED
	// checking if the new sweep is running
	if ((channel == RSSIUP_CHAB) || (channel == RSSIUP_CHA))
	{
		CHECKERR (rssiup_GetGeneratorFunctionRMSSelectiveSweepAmplitude (instrSession,
																RSSIUP_CHA,
																&startAmplitudeA,
																&stopAmplitudeA,
																&amplitudeSweepSpacingA,
																&amplitudeSweepStepsA,
																&amplitudeStepDelayA));
	
		if((fabs (startAmplitude - startAmplitudeA) > 0.000001) ||
		   (fabs (stopAmplitude - stopAmplitudeA) > 0.000001) ||
		   (amplitudeSweepSpacing != amplitudeSweepSpacingA) ||
		   (amplitudeSweepSteps != amplitudeSweepStepsA) ||
		   (amplitudeStepDelay != amplitudeStepDelayA))
			instrPtr->newSweep = VI_TRUE;
	}
	else
	{
		CHECKERR (rssiup_GetGeneratorFunctionRMSSelectiveSweepAmplitude (instrSession,
																RSSIUP_CHB,
																&startAmplitudeB,
																&stopAmplitudeB,
																&amplitudeSweepSpacingB,
																&amplitudeSweepStepsB,
																&amplitudeStepDelayB));
		
		if((fabs (startAmplitude - startAmplitudeB) > 0.000001) ||
		   (fabs (stopAmplitude - stopAmplitudeB) > 0.000001) ||
		   (amplitudeSweepSpacing != amplitudeSweepSpacingB) ||
		   (amplitudeSweepSteps != amplitudeSweepStepsB) ||
		   (amplitudeStepDelay != amplitudeStepDelayB))
			instrPtr->newSweep = VI_TRUE;
	}	
	*/
	
	set_value.Sender = 0x07FE;
	
	set_value.fDCOffset = 0.0 /* DCOffset */;
    
	DBL2FLT(startAmplitude * sqrt(2)/2, set_value.fAm1Start);
	DBL2FLT(stopAmplitude * sqrt(2)/2, set_value.fAm1End);
		
	CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing, &set_value.fAm1Spacing, VI_ERROR_PARAMETER5));
	
	DBL2FLT(startAmplitude * sqrt(2)/2, set_value.fAm2Start /* startAmplitude_2 */);
    DBL2FLT(stopAmplitude * sqrt(2)/2, set_value.fAm2End /* stopAmplitude_2 */);
    
	CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing /* amplitudeSweepSpacing_2 */, &set_value.fAm2Spacing, VI_ERROR_PARAMETER5));
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_NoChSet, ChAB, &get_value, sizeof(get_value)));
    
	set_value.fFixFrStart = get_value.fFr1Start;
    set_value.fFixFrEnd = get_value.fFr1End;
    set_value.FixFrSpacing = get_value.Fr1Spacing;
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRSmSweep_ChanSet, channel, &set_value, sizeof(set_value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
	
	set_NoCh_value.Sender = 0x07FE;
	set_NoCh_value.fFr1Start = get_value.fFr1Start;
	set_NoCh_value.fFr1End = get_value.fFr1End;
	set_NoCh_value.Fr1Spacing = get_value.Fr1Spacing;
	set_NoCh_value.fFr2Start = get_value.fFr2Start;
	set_NoCh_value.fFr2End = get_value.fFr2End;
	set_NoCh_value.Fr2Spacing = get_value.Fr2Spacing;
	set_NoCh_value.FrStepCnt = get_value.FrStepCnt;
	set_NoCh_value.fPhase1 = get_value.fPhase1;
	set_NoCh_value.fPhase2 = get_value.fPhase2;
	set_NoCh_value.RefreshTime = get_value.RefreshTime;
	set_NoCh_value.FrSweepRepeat = get_value.FrSweepRepeat;
	set_NoCh_value.FrStepPause = get_value.FrStepPause;
	set_NoCh_value.StartCtrlStep = get_value.StartCtrlStep;
	set_NoCh_value.wFilterOrder = get_value.wFilterOrder;
	set_NoCh_value.FilterBandwidthType = get_value.FilterBandwidthType;
	set_NoCh_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth;
	set_NoCh_value.RelativeBandwidth = get_value.RelativeBandwidth;
    set_NoCh_value.FrequencyMode = get_value.FrequencyMode;

	set_NoCh_value.AmStepPause = amplitudeStepDelay;
	set_NoCh_value.AmStepCnt = amplitudeSweepSteps;

	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRSmSweep_NoChSet, ChAB, &set_NoCh_value, sizeof(set_NoCh_value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	
    return rssiup_status;    
}

/*****************************************************************************
 * Function: Get Generator Function RMS Selective Sweep Amplitude
 * Purpose:  This function returns amplitude parameters for SinRMSSelMuTskSweep 
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionRMSSelectiveSweepAmplitude (ViSession instrSession,
                                                               ViInt32 channel,
                                                               ViReal64 *startAmplitude,
                                                               ViReal64 *stopAmplitude,
                                                               ViInt32 *amplitudeSweepSpacing,
															   ViInt32 *amplitudeSweepSteps,
															   ViInt32 *amplitudeStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TGetSinRSmSweep_ChanSet     value           = {0};
	TGetSinRSmSweep_NoChSet     NoCh_value      = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (rssiup_invalidViInt32Range (channel, RSSIUP_CHA, RSSIUP_CHB))
        return VI_ERROR_PARAMETER2;
	if (!startAmplitude)
        return VI_ERROR_PARAMETER3;
    if (!stopAmplitude)
        return VI_ERROR_PARAMETER4;
    if (!amplitudeSweepSpacing)
        return VI_ERROR_PARAMETER5;
    if (!amplitudeSweepSteps)
        return VI_ERROR_PARAMETER6;
	if (!amplitudeStepDelay)
        return VI_ERROR_PARAMETER7;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_ChanSet, channel, &value, sizeof(value)));
    
	*startAmplitude = value.fAm1Start * 2 / sqrt(2);
	*stopAmplitude = value.fAm1End * 2 / sqrt(2);
		
	CHECKERR (rssiup_val_to_param (STAmSpacingDiscVals, &amplitudeSweepSpacing[0], &value.fAm1Spacing, VI_ERROR_INV_RESPONSE));
	
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_NoChSet, ChAB, &NoCh_value, sizeof(NoCh_value)));
    
	*amplitudeSweepSteps = NoCh_value.AmStepCnt;
	*amplitudeStepDelay = NoCh_value.AmStepPause;
    
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	
    return rssiup_status;    
}

/*****************************************************************************
 * Function: Set Generator All Parameters Channel RMS Selective Sweep 
 * Purpose:  This function sets channel parameters for SinRMSSelMuTskSweep 
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorAllParamChanRMSSelectiveSweep (ViSession instrSession,
                                                                    ViInt32 channel,
                                                                    ViReal64 DCOffset,
                                                                    ViReal64 startAmplitude[],
                                                                    ViReal64 stopAmplitude[],
                                                                    ViInt32 amplitudeSweepSpacing[],
                                                                    ViReal64 analyzerStartFrequency,
                                                                    ViReal64 analyzerStopFrequency,
                                                                    ViInt32 frequencySpacing)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinRSmSweep_AllPSet     set_value           = {0};
	TGetSinRSmSweep_AllPSet     get_value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViReal64 					get_DCOffset = 0;
	//ViReal64 					get_startAmplitude[2];
	//ViReal64 					get_stopAmplitude[2];
	//ViInt32 					get_amplitudeSweepSpacing[2];
	//ViReal64 					get_analyzerStartFrequency = 0.0;
	//ViReal64 					get_analyzerStopFrequency = 0.0;
	//ViInt32 					get_frequencySpacing = 0;
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (rssiup_invalidViInt32Range (channel, RSSIUP_CHA, RSSIUP_CHB))
        return VI_ERROR_PARAMETER2;
	if (rssiup_invalidViReal64Range (DCOffset, -10.61, 10.61))
        return VI_ERROR_PARAMETER3;
	if (rssiup_invalidViInt32Range (frequencySpacing, RSSIUP_SPACING_NO, RSSIUP_SPACING_LOG))
        return VI_ERROR_INSTR_PARAMETER9;

	if ((amplitudeSweepSpacing[0] == RSSIUP_SPACING_LIN) && (amplitudeSweepSpacing[1] == RSSIUP_SPACING_INS_LIN) ||
		(amplitudeSweepSpacing[0] == RSSIUP_SPACING_LOG) && (amplitudeSweepSpacing[1] == RSSIUP_SPACING_INS_LOG) ||
		(amplitudeSweepSpacing[1] == RSSIUP_SPACING_LIN) && (amplitudeSweepSpacing[0] == RSSIUP_SPACING_INS_LIN) ||
		(amplitudeSweepSpacing[1] == RSSIUP_SPACING_LOG) && (amplitudeSweepSpacing[0] == RSSIUP_SPACING_INS_LOG))
		return VI_ERROR_PARAMETER6;
    
	/* NOT NEEDED
	// checking if the new sweep is running
	if ((channel == RSSIUP_CHAB) || (channel == RSSIUP_CHA))
	{
		CHECKERR (rssiup_GetGeneratorAllParamChanRMSSelectiveSweep (instrSession,
																RSSIUP_CHA,
																&get_DCOffset,
																get_startAmplitude,
                                                                get_stopAmplitude,
                                                                get_amplitudeSweepSpacing,
                                                                &get_analyzerStartFrequency,
                                                                &get_analyzerStopFrequency,
                                                                &get_frequencySpacing));
	
		if((fabs (DCOffset - get_DCOffset) > 0.000001) ||
		   (fabs (startAmplitude[0] - get_startAmplitude[0]) > 0.000001) ||
		   (fabs (startAmplitude[1] - get_startAmplitude[1]) > 0.000001) ||
		   (fabs (stopAmplitude[0] != get_stopAmplitude[0]) > 0.000001) ||
		   (fabs (stopAmplitude[1] != get_stopAmplitude[1]) > 0.000001) ||
		   (amplitudeSweepSpacing[0] != get_amplitudeSweepSpacing[0]) ||
		   (amplitudeSweepSpacing[1] != get_amplitudeSweepSpacing[1]) ||
		   (fabs (analyzerStartFrequency != get_analyzerStartFrequency) > 0.000001) ||
		   (fabs (analyzerStopFrequency != get_analyzerStopFrequency) > 0.000001) ||
		   (frequencySpacing != get_frequencySpacing))
			instrPtr->newSweep = VI_TRUE;
	}
	else
	{
		CHECKERR (rssiup_GetGeneratorAllParamChanRMSSelectiveSweep (instrSession,
																RSSIUP_CHB,
																&get_DCOffset,
																get_startAmplitude,
                                                                get_stopAmplitude,
                                                                get_amplitudeSweepSpacing,
                                                                &get_analyzerStartFrequency,
                                                                &get_analyzerStopFrequency,
                                                                &get_frequencySpacing));
		
		if((fabs (DCOffset - get_DCOffset) > 0.000001) ||
		   (fabs (startAmplitude[0] - get_startAmplitude[0]) > 0.000001) ||
		   (fabs (startAmplitude[1] - get_startAmplitude[1]) > 0.000001) ||
		   (fabs (stopAmplitude[0] - get_stopAmplitude[0]) > 0.000001) ||
		   (fabs (stopAmplitude[1] - get_stopAmplitude[1]) > 0.000001) ||
		   (amplitudeSweepSpacing[0] != get_amplitudeSweepSpacing[0]) ||
		   (amplitudeSweepSpacing[1] != get_amplitudeSweepSpacing[1]) ||
		   (fabs (analyzerStartFrequency - get_analyzerStartFrequency) > 0.000001) ||
		   (fabs (analyzerStopFrequency - get_analyzerStopFrequency) > 0.000001) ||
		   (frequencySpacing != get_frequencySpacing))
			instrPtr->newSweep = VI_TRUE;
	}	
	*/
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_AllPSet, ChAB, &get_value, sizeof(get_value)));
    
	set_value.Sender = 0x07FE;
	
	if (channel == RSSIUP_CHA)
	{
		DBL2FLT (DCOffset, set_value.fDCOffsetA);
		DBL2FLT (startAmplitude[0] * sqrt(2)/2, set_value.fAm1StartA);
		DBL2FLT (stopAmplitude[0] * sqrt(2)/2, set_value.fAm1EndA);
	
		CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing[0], &set_value.fAm1SpacingA, VI_ERROR_PARAMETER6));
	
		DBL2FLT (startAmplitude[1] * sqrt(2)/2, set_value.fAm2StartA);
		DBL2FLT (stopAmplitude[1] * sqrt(2)/2, set_value.fAm2EndA);
	
		CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing[1], &set_value.fAm2SpacingA, VI_ERROR_PARAMETER6));
	
		DBL2FLT (analyzerStartFrequency, set_value.fFixFrStartA);
		DBL2FLT (analyzerStopFrequency, set_value.fFixFrEndA);
	
		CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySpacing, &set_value.FixFrSpacingA, VI_ERROR_PARAMETER6));
		
		set_value.fDCOffsetB = get_value.fDCOffsetB;
	    set_value.fAm1StartB = get_value.fAm1StartB;
	    set_value.fAm1EndB = get_value.fAm1EndB;
	    set_value.fAm1SpacingB = get_value.fAm1SpacingB;
	    set_value.fAm2StartB = get_value.fAm2StartB;
	    set_value.fAm2EndB = get_value.fAm2EndB;
	    set_value.fAm2SpacingB = get_value.fAm2SpacingB;
	    set_value.fFixFrStartB = get_value.fFixFrStartB;
	    set_value.fFixFrEndB = get_value.fFixFrEndB;
	    set_value.FixFrSpacingB = get_value.FixFrSpacingB;
	}
	else
	{
		DBL2FLT (DCOffset, set_value.fDCOffsetB);
		DBL2FLT (startAmplitude[0] * sqrt(2)/2, set_value.fAm1StartB);
		DBL2FLT (stopAmplitude[0] * sqrt(2)/2, set_value.fAm1EndB);
	
		CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing[0], &set_value.fAm1SpacingB, VI_ERROR_PARAMETER6));
	
		DBL2FLT (startAmplitude[1] * sqrt(2)/2, set_value.fAm2StartB);
		DBL2FLT (stopAmplitude[1] * sqrt(2)/2, set_value.fAm2EndB);
	
		CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing[1], &set_value.fAm2SpacingB, VI_ERROR_PARAMETER6));
	
		DBL2FLT (analyzerStartFrequency, set_value.fFixFrStartB);
		DBL2FLT (analyzerStopFrequency, set_value.fFixFrEndB);
	
		CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySpacing, &set_value.FixFrSpacingB, VI_ERROR_PARAMETER6));
		
		set_value.fDCOffsetB = get_value.fDCOffsetA;
	    set_value.fAm1StartB = get_value.fAm1StartA;
	    set_value.fAm1EndB = get_value.fAm1EndA;
	    set_value.fAm1SpacingB = get_value.fAm1SpacingA;
	    set_value.fAm2StartB = get_value.fAm2StartA;
	    set_value.fAm2EndB = get_value.fAm2EndA;
	    set_value.fAm2SpacingB = get_value.fAm2SpacingA;
	    set_value.fFixFrStartB = get_value.fFixFrStartA;
	    set_value.fFixFrEndB = get_value.fFixFrEndA;
	    set_value.FixFrSpacingB = get_value.FixFrSpacingA;
	}

	set_value.fFr1Start = get_value.fFr1Start;
    set_value.fFr1End = get_value.fFr1End;
    set_value.Fr1Spacing = get_value.Fr1Spacing;
    set_value.fFr2Start = get_value.fFr2Start;
    set_value.fFr2End = get_value.fFr2End;
    set_value.Fr2Spacing = get_value.Fr2Spacing;
    set_value.FrStepCnt = get_value.FrStepCnt;
    set_value.fPhase1 = get_value.fPhase1;
    set_value.fPhase2 = get_value.fPhase2;
    set_value.AmStepCnt = get_value.AmStepCnt;
    set_value.RefreshTime = get_value.RefreshTime;
    set_value.FrSweepRepeat = get_value.FrSweepRepeat;
    set_value.FrStepPause = get_value.FrStepPause;
    set_value.AmStepPause = get_value.AmStepPause;
    set_value.StartCtrlStep = get_value.StartCtrlStep;
    set_value.wFilterOrder = get_value.wFilterOrder;
    set_value.FilterBandwidthType = get_value.FilterBandwidthType;
    set_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth;
    set_value.RelativeBandwidth = get_value.RelativeBandwidth;
    set_value.FrequencyMode = get_value.FrequencyMode;	
	
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRSmSweep_AllPSet, ChAB, &set_value, sizeof(set_value)));
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Set Generator All Parameters RMS Selective Sweep 
 * Purpose:  This function sets non channel parameters for SinRMSSelMuTskSweep 
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorAllParamRMSSelectiveSweep (ViSession instrSession,
                                                                ViReal64 startFrequency[],
                                                                ViReal64 stopFrequency[],
                                                                ViInt32 frequencySweepSpacing[],
                                                                ViInt32 sweepSteps[],
                                                                ViInt32 stepDelay[],
                                                                ViReal64 generatorInitPhase[])
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinRSmSweep_AllPSet     set_value           = {0};
	TGetSinRSmSweep_AllPSet     get_value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViReal64 					get_startFrequency[2];
	//ViReal64		 			get_stopFrequency[2];
	//ViInt32 					get_frequencySweepSpacing[2];
	//ViInt32 					get_sweepSteps[2];
	//ViInt32 					get_stepDelay[2];
	//ViReal64 					get_generatorInitPhase[2];
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	/* NOT NEEDED
	CHECKERR (rssiup_SetGeneratorAllParamRMSSelectiveSweep (instrSession,
                                                            get_startFrequency,
                                                            get_stopFrequency,
                                                            get_frequencySweepSpacing,
                                                            get_sweepSteps,
                                                            get_stepDelay,
                                                            get_generatorInitPhase));
	
	if((fabs (startFrequency[0] - get_startFrequency[0]) > 0.000001) ||
	   (fabs (startFrequency[1] - get_startFrequency[1]) > 0.000001) ||
	   (fabs (stopFrequency[0] - get_stopFrequency[0]) > 0.000001) ||
	   (fabs (stopFrequency[1] - get_stopFrequency[1]) > 0.000001) ||
	   (frequencySweepSpacing[0] != get_frequencySweepSpacing[0]) ||
	   (frequencySweepSpacing[1] != get_frequencySweepSpacing[1]) ||
	   (sweepSteps[0] != get_sweepSteps[0]) ||
	   (sweepSteps[1] != get_sweepSteps[1]) ||
	   (stepDelay[0] != get_stepDelay[0]) ||
	   (stepDelay[1] != get_stepDelay[1]) ||
	   (fabs (generatorInitPhase[0] - get_generatorInitPhase[0]) > 0.000001) ||
	   (fabs (generatorInitPhase[1] - get_generatorInitPhase[1]) > 0.000001))
		instrPtr->newSweep = VI_TRUE;
	*/
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_AllPSet, ChAB, &get_value, sizeof(get_value)));
    
	set_value.Sender = 0x07FE;
	
	set_value.fDCOffsetA = get_value.fDCOffsetA;
    set_value.fAm1StartA = get_value.fAm1StartA;
    set_value.fAm1EndA = get_value.fAm1EndA;
    set_value.fAm1SpacingA = get_value.fAm1SpacingA;
    set_value.fAm2StartA = get_value.fAm2StartA;
    set_value.fAm2EndA = get_value.fAm2EndA;
    set_value.fAm2SpacingA = get_value.fAm2SpacingA;
    set_value.fFixFrStartA = get_value.fFixFrStartA;
    set_value.fFixFrEndA = get_value.fFixFrEndA;
    set_value.FixFrSpacingA = get_value.FixFrSpacingA;
	
	set_value.fDCOffsetB = get_value.fDCOffsetB;
    set_value.fAm1StartB = get_value.fAm1StartB;
    set_value.fAm1EndB = get_value.fAm1EndB;
    set_value.fAm1SpacingB = get_value.fAm1SpacingB;
    set_value.fAm2StartB = get_value.fAm2StartB;
    set_value.fAm2EndB = get_value.fAm2EndB;
    set_value.fAm2SpacingB = get_value.fAm2SpacingB;
    set_value.fFixFrStartB = get_value.fFixFrStartB;
    set_value.fFixFrEndB = get_value.fFixFrEndB;
    set_value.FixFrSpacingB = get_value.FixFrSpacingB;
		
	DBL2FLT (startFrequency[0], set_value.fFr1Start);
    DBL2FLT (stopFrequency[0], set_value.fFr1End);
    CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing[0], &set_value.Fr1Spacing, VI_ERROR_PARAMETER4));
	DBL2FLT (startFrequency[1], set_value.fFr2Start);
    DBL2FLT (stopFrequency[1], set_value.fFr2End);
    CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing[1], &set_value.Fr2Spacing, VI_ERROR_PARAMETER4));
    set_value.FrStepCnt = sweepSteps[0];
    DBL2FLT (generatorInitPhase[0], set_value.fPhase1);
    DBL2FLT (generatorInitPhase[1], set_value.fPhase2);
	set_value.AmStepCnt = sweepSteps[1];
    
	set_value.RefreshTime = get_value.RefreshTime;
    set_value.FrSweepRepeat = get_value.FrSweepRepeat;
    
	set_value.FrStepPause = stepDelay[0];
    set_value.AmStepPause = stepDelay[1];
    
	set_value.StartCtrlStep = get_value.StartCtrlStep;
    set_value.wFilterOrder = get_value.wFilterOrder;
    set_value.FilterBandwidthType = get_value.FilterBandwidthType;
    set_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth;
    set_value.RelativeBandwidth = get_value.RelativeBandwidth;
    set_value.FrequencyMode = get_value.FrequencyMode;	
	
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRSmSweep_AllPSet, ChAB, &set_value, sizeof(set_value)));
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Set Generator All Parameters RMS Selective Sweep Settings
 * Purpose:  This function sets additional non channel parameters for 
 *           SinRMSSelMuTskSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorAllParamRMSSelectiveSweepSettings (ViSession instrSession,
                                                                        ViInt32 resultsRefreshTime,
                                                                        ViInt32 numberOfSweepLoops,
                                                                        ViInt32 sweepStepControl,
                                                                        ViInt32 LPFilterOrder,
                                                                        ViInt32 filterBandwidthType,
                                                                        ViReal64 filterBandwidth,
                                                                        ViReal64 multipleOfCenterFrequency,
																		ViInt32 frequencyMode)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinRSmSweep_AllPSet     set_value           = {0};
	TGetSinRSmSweep_AllPSet     get_value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViInt32 					get_resultsRefreshTime = 0;
	//ViInt32 					get_numberOfSweepLoops = 0;
	//ViInt32 					get_sweepStepControl = 0;
	//ViInt32 					get_LPFilterOrder = 0;
	//ViInt32 					get_filterBandwidthType = 0;
	//ViReal64 					get_filterBandwidth = 0.0;
	//ViReal64 					get_multipleOfCenterFrequency = 0.0;
	//ViInt32 					get_frequencyMode = 0;
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (rssiup_invalidViInt32Range (resultsRefreshTime, 0, 65000))
        return VI_ERROR_PARAMETER2;
	if (rssiup_invalidViInt32Range (numberOfSweepLoops, 1, 1000))
        return VI_ERROR_PARAMETER3;
	if (rssiup_invalidViInt32Range (sweepStepControl, RSSIUP_CTRL_STEP_RESTART_SWEEPS, RSSIUP_CTRL_STEP_TO_END_OF_INS_LOOP))
        return VI_ERROR_PARAMETER4;
	if (rssiup_invalidViInt32Range (LPFilterOrder, 3, 12))
        return VI_ERROR_PARAMETER5;
	if (rssiup_invalidViInt32Range (filterBandwidthType, RSSIUP_FILTER_BWID_TYPE_CONST, RSSIUP_FILTER_BWID_TYPE_RELAT))
        return VI_ERROR_PARAMETER6;
/*
	if (rssiup_invalidViReal64Range (filterBandwidth, 10.0, 0.1*fs))
        return VI_ERROR_PARAMETER7;
*/
	if (rssiup_invalidViReal64Range (multipleOfCenterFrequency, 0.00001, 1.0))
        return VI_ERROR_PARAMETER8;
	if (rssiup_invalidViInt32Range (frequencyMode, RSSIUP_FREQ_MODE_AUTO, RSSIUP_FREQ_MODE_FIXED))
        return VI_ERROR_INSTR_PARAMETER9;

	/* NOT NEEDED
	CHECKERR (rssiup_GetGeneratorAllParamRMSSelectiveSweepSettings (instrSession,
                                                                    &get_resultsRefreshTime,
                                                                    &get_numberOfSweepLoops,
                                                                    &get_sweepStepControl,
                                                                    &get_LPFilterOrder,
                                                                    &get_filterBandwidthType,
                                                                    &get_filterBandwidth,
                                                                    &get_multipleOfCenterFrequency,
                                                                    &get_frequencyMode));
	
	if((resultsRefreshTime != get_resultsRefreshTime) ||
	   (numberOfSweepLoops != get_numberOfSweepLoops) ||
	   (sweepStepControl != get_sweepStepControl) ||
	   (LPFilterOrder != get_LPFilterOrder) ||
	   (filterBandwidthType != get_filterBandwidthType) ||
	   (fabs (filterBandwidth - get_filterBandwidth) > 0.000001) ||
	   (fabs (multipleOfCenterFrequency - get_multipleOfCenterFrequency) > 0.000001) ||
	   (frequencyMode != get_frequencyMode))
		instrPtr->newSweep = VI_TRUE;
	*/
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_AllPSet, ChAB, &get_value, sizeof(get_value)));
    
	set_value.Sender = 0x07FE;
	
	set_value.fDCOffsetA = get_value.fDCOffsetA;
    set_value.fAm1StartA = get_value.fAm1StartA;
    set_value.fAm1EndA = get_value.fAm1EndA;
    set_value.fAm1SpacingA = get_value.fAm1SpacingA;
    set_value.fAm2StartA = get_value.fAm2StartA;
    set_value.fAm2EndA = get_value.fAm2EndA;
    set_value.fAm2SpacingA = get_value.fAm2SpacingA;
    set_value.fFixFrStartA = get_value.fFixFrStartA;
    set_value.fFixFrEndA = get_value.fFixFrEndA;
    set_value.FixFrSpacingA = get_value.FixFrSpacingA;
	
	set_value.fDCOffsetB = get_value.fDCOffsetB;
    set_value.fAm1StartB = get_value.fAm1StartB;
    set_value.fAm1EndB = get_value.fAm1EndB;
    set_value.fAm1SpacingB = get_value.fAm1SpacingB;
    set_value.fAm2StartB = get_value.fAm2StartB;
    set_value.fAm2EndB = get_value.fAm2EndB;
    set_value.fAm2SpacingB = get_value.fAm2SpacingB;
    set_value.fFixFrStartB = get_value.fFixFrStartB;
    set_value.fFixFrEndB = get_value.fFixFrEndB;
    set_value.FixFrSpacingB = get_value.FixFrSpacingB;
		
	set_value.fFr1Start = get_value.fFr1Start;
    set_value.fFr1End = get_value.fFr1End;
    set_value.Fr1Spacing = get_value.Fr1Spacing;
    set_value.fFr2Start = get_value.fFr2Start;
    set_value.fFr2End = get_value.fFr2End;
    set_value.Fr2Spacing = get_value.Fr2Spacing;
    set_value.FrStepCnt = get_value.FrStepCnt;
    set_value.fPhase1 = get_value.fPhase1;
    set_value.fPhase2 = get_value.fPhase2;
    set_value.AmStepCnt = get_value.AmStepCnt;
	
    set_value.RefreshTime = resultsRefreshTime;
    set_value.FrSweepRepeat = numberOfSweepLoops;
    
	set_value.FrStepPause = get_value.FrStepPause;
    set_value.AmStepPause = get_value.AmStepPause;
    
	CHECKERR (rssiup_param_to_val (STCtrlStepDiscVals, sweepStepControl, &set_value.StartCtrlStep, VI_ERROR_PARAMETER4));
	
	set_value.wFilterOrder = LPFilterOrder;
    
	CHECKERR (rssiup_param_to_val (STFilterBandwidthTypeDiscVals, filterBandwidthType, &set_value.FilterBandwidthType, VI_ERROR_PARAMETER6));
	
	if (filterBandwidthType == RSSIUP_FILTER_BWID_TYPE_CONST)
	{
		DBL2FLT (filterBandwidth, set_value.AbsoluteBandwidth);
		set_value.RelativeBandwidth = get_value.RelativeBandwidth;
	}
	else
	{
    	DBL2FLT (multipleOfCenterFrequency, set_value.RelativeBandwidth);
		set_value.AbsoluteBandwidth = get_value.AbsoluteBandwidth;
	}
    
	CHECKERR (rssiup_param_to_val (STAutoFrqModeDiscVals, frequencyMode, &set_value.FrequencyMode, VI_ERROR_INSTR_PARAMETER9));
	
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinRSmSweep_AllPSet, ChAB, &set_value, sizeof(set_value)));
    
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Get Generator All Parameters Channel RMS Selective Sweep
 * Purpose:  This function returns channel parameters for SinRMSSelMuTskSweep 
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorAllParamChanRMSSelectiveSweep (ViSession instrSession,
                                                                    ViInt32 channel,
                                                                    ViReal64 *DCOffset,
                                                                    ViReal64 startAmplitude[],
                                                                    ViReal64 stopAmplitude[],
                                                                    ViInt32 amplitudeSweepSpacing[],
                                                                    ViReal64 *analyzerStartFrequency,
                                                                    ViReal64 *analyzerStopFrequency,
                                                                    ViInt32 *frequencySpacing)
{
    ViStatus    				rssiup_status   = VI_SUCCESS;
    TGetSinRSmSweep_AllPSet     value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (rssiup_invalidViInt32Range (channel, RSSIUP_CHA, RSSIUP_CHB))
        return VI_ERROR_PARAMETER2;
	if (!DCOffset)
        return VI_ERROR_PARAMETER3;
    if (!startAmplitude)
        return VI_ERROR_PARAMETER4;
    if (!stopAmplitude)
        return VI_ERROR_PARAMETER5;
    if (!amplitudeSweepSpacing)
        return VI_ERROR_PARAMETER6;
    if (!analyzerStartFrequency)
        return VI_ERROR_PARAMETER7;
    if (!analyzerStopFrequency)
        return VI_ERROR_PARAMETER8;
    if (!frequencySpacing)
        return VI_ERROR_INSTR_PARAMETER9;
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_AllPSet, ChAB, &value, sizeof(value)));
    
	if (channel == RSSIUP_CHA)
	{
		*DCOffset = value.fDCOffsetA;
		startAmplitude[0] = value.fAm1StartA * 2 / sqrt(2);
		stopAmplitude[0] = value.fAm1EndA * 2 / sqrt(2);
	
		CHECKERR (rssiup_val_to_param (STAmSpacingDiscVals, &amplitudeSweepSpacing[0], &value.fAm1SpacingA, VI_ERROR_INV_RESPONSE));
	
		startAmplitude[1] = value.fAm2StartA * 2 / sqrt(2);
		stopAmplitude[1] = value.fAm2EndA * 2 / sqrt(2);
	
		CHECKERR (rssiup_val_to_param (STAmSpacingDiscVals, &amplitudeSweepSpacing[1], &value.fAm2SpacingA, VI_ERROR_INV_RESPONSE));
	
		*analyzerStartFrequency = value.fFixFrStartA;
		*analyzerStopFrequency = value.fFixFrEndA;
	
		CHECKERR (rssiup_val_to_param (STFrSpacingDiscVals, frequencySpacing, &value.FixFrSpacingA, VI_ERROR_INV_RESPONSE));
	}
	else
	{
		*DCOffset = value.fDCOffsetB;
		startAmplitude[0] = value.fAm1StartB * 2 / sqrt(2);
		stopAmplitude[0] = value.fAm1EndB * 2 / sqrt(2);
	
		CHECKERR (rssiup_val_to_param (STAmSpacingDiscVals, &amplitudeSweepSpacing[0], &value.fAm1SpacingB, VI_ERROR_INV_RESPONSE));
	
		startAmplitude[1] = value.fAm2StartB * 2 / sqrt(2);
		stopAmplitude[1] = value.fAm2EndB * 2 / sqrt(2);
	
		CHECKERR (rssiup_val_to_param (STAmSpacingDiscVals, &amplitudeSweepSpacing[1], &value.fAm2SpacingB, VI_ERROR_INV_RESPONSE));
	
		*analyzerStartFrequency = value.fFixFrStartB;
		*analyzerStopFrequency = value.fFixFrEndB;
	
		CHECKERR (rssiup_val_to_param (STFrSpacingDiscVals, frequencySpacing, &value.FixFrSpacingB, VI_ERROR_INV_RESPONSE));
	}
	
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator All Parameters RMS Selective Sweep
 * Purpose:  This function returns non channel parameters for 
 *           SinRMSSelMuTskSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorAllParamRMSSelectiveSweep (ViSession instrSession,
                                                                ViReal64 startFrequency[],
                                                                ViReal64 stopFrequency[],
                                                                ViInt32 frequencySweepSpacing[],
                                                                ViInt32 sweepSteps[],
                                                                ViInt32 stepDelay[],
                                                                ViReal64 generatorInitPhase[])
{
    ViStatus  				  	rssiup_status   = VI_SUCCESS;
	TGetSinRSmSweep_AllPSet     value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (!startFrequency)
        return VI_ERROR_PARAMETER2;
    if (!stopFrequency)
        return VI_ERROR_PARAMETER3;
    if (!frequencySweepSpacing)
        return VI_ERROR_PARAMETER4;
    if (!sweepSteps)
        return VI_ERROR_PARAMETER5;
    if (!stepDelay)
        return VI_ERROR_PARAMETER6;
    if (!generatorInitPhase)
        return VI_ERROR_PARAMETER7;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_AllPSet, ChAB, &value, sizeof(value)));
    
	startFrequency[0] = value.fFr1Start;
    stopFrequency[0] = value.fFr1End;
    
	CHECKERR (rssiup_val_to_param (STFrSpacingDiscVals, &frequencySweepSpacing[0], &value.Fr1Spacing, VI_ERROR_INV_RESPONSE));
	
	startFrequency[1] = value.fFr2Start;
    stopFrequency[1] = value.fFr2End;
    
	CHECKERR (rssiup_val_to_param (STFrSpacingDiscVals, &frequencySweepSpacing[1], &value.Fr2Spacing, VI_ERROR_INV_RESPONSE));
    
	sweepSteps[0] = value.FrStepCnt;
    
	generatorInitPhase[0] = value.fPhase1;
    generatorInitPhase[1] = value.fPhase2;
	
	sweepSteps[1] = value.AmStepCnt;
    
	stepDelay[0] = value.FrStepPause;
    stepDelay[1] = value.AmStepPause;
    
    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Generator All Parameters RMS Selective Sweep Settings
 * Purpose:  This function returns additional non channel parameters for 
 *           SinRMSSelMuTskSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorAllParamRMSSelectiveSweepSettings (ViSession instrSession,
                                                                        ViInt32 *resultsRefreshTime,
                                                                        ViInt32 *numberOfSweepLoops,
                                                                        ViInt32 *sweepStepControl,
                                                                        ViInt32 *LPFilterOrder,
                                                                        ViInt32 *filterBandwidthType,
                                                                        ViReal64 *filterBandwidth,
                                                                        ViReal64 *multipleOfCenterFrequency,
                                                                        ViInt32 *frequencyMode)
{
    ViStatus    				rssiup_status   = VI_SUCCESS;
	TGetSinRSmSweep_AllPSet     value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (!resultsRefreshTime)
        return VI_ERROR_PARAMETER2;
    if (!numberOfSweepLoops)
        return VI_ERROR_PARAMETER3;
    if (!sweepStepControl)
        return VI_ERROR_PARAMETER4;
    if (!LPFilterOrder)
        return VI_ERROR_PARAMETER5;
    if (!filterBandwidthType)
        return VI_ERROR_PARAMETER6;
    if (!filterBandwidth)
        return VI_ERROR_PARAMETER7;
    if (!multipleOfCenterFrequency)
        return VI_ERROR_PARAMETER8;
    if (!frequencyMode)
        return VI_ERROR_INSTR_PARAMETER9;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinRSmSweep_AllPSet, ChAB, &value, sizeof(value)));
    
	*resultsRefreshTime = value.RefreshTime;
    *numberOfSweepLoops = value.FrSweepRepeat;
    
	CHECKERR (rssiup_val_to_param (STCtrlStepDiscVals, sweepStepControl, &value.StartCtrlStep, VI_ERROR_INV_RESPONSE));
	
	*LPFilterOrder = value.wFilterOrder;
    
	CHECKERR (rssiup_val_to_param (STFilterBandwidthTypeDiscVals, filterBandwidthType, &value.FilterBandwidthType, VI_ERROR_INV_RESPONSE));
	
	*filterBandwidth = value.AbsoluteBandwidth;
	*multipleOfCenterFrequency = value.RelativeBandwidth;
    
	CHECKERR (rssiup_val_to_param (STAutoFrqModeDiscVals, frequencyMode, &value.FrequencyMode, VI_ERROR_INV_RESPONSE));
	
    
    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Generator Function THD Sweep Frequency
 * Purpose:  This function sets frequency parameters for SinThdSweep 
 *           measurement
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionTHDSweepFrequency (ViSession instrSession,
                                               ViReal64 startFrequency,
                                               ViReal64 stopFrequency,
                                               ViInt32 frequencySweepSpacing,
                                               ViInt32 frequencySweepSteps,
                                               ViInt32 frequencyStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinThdSweep_NoChSet     value           = {0};
	TGetSinThdSweep_NoChSet     get_value       = {0};
	ViReal64					sample_frequency = 0.0;
	ViReal64                    fsArr[] = {48828.125,97656.250,195312.0,32000.0,44100.0,48000.0,96000.0,192000.0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViReal64            		get_startFrequency         = 0.0;
	//ViReal64            		get_stopFrequency          = 0.0;
	//ViInt32             		get_frequencySweepSpacing  = 0;
	//ViInt32             		get_frequencySweepSteps    = 0;
	//ViInt32             		get_frequencyStepDelay     = 0;
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (rssiup_invalidViInt32Range (frequencySweepSpacing, RSSIUP_SPACING_NO, RSSIUP_SPACING_LOG))
        return VI_ERROR_PARAMETER4;
	if (rssiup_invalidViInt32Range (frequencySweepSteps, 1, 1999))
        return VI_ERROR_PARAMETER5;
	if (rssiup_invalidViInt32Range (frequencyStepDelay, 0, 65000))
        return VI_ERROR_PARAMETER6;
	
	/* NOT NEEDED
	// checking if the new sweep is running
	CHECKERR (rssiup_GetGeneratorFunctionTHDSweepFrequency (instrSession,
															&get_startFrequency,
															&get_stopFrequency,
															&get_frequencySweepSpacing,
															&get_frequencySweepSteps,
															&get_frequencyStepDelay));
	
	if((fabs (startFrequency - get_startFrequency) > 0.000001) ||
	   (fabs (stopFrequency - get_stopFrequency) > 0.000001) ||
	   (frequencySweepSpacing != get_frequencySweepSpacing) ||
	   (frequencySweepSteps != get_frequencySweepSteps) ||
	   (frequencyStepDelay != get_frequencyStepDelay))
		instrPtr->newSweep = VI_TRUE;
	*/
	
	value.Sender = 0x07FE;
	
	DBL2FLT(startFrequency, value.fFr1Start);
	DBL2FLT(stopFrequency, value.fFr1End);
		
	CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing, &value.Fr1Spacing, VI_ERROR_PARAMETER4));
	
	DBL2FLT(startFrequency, value.fFr2Start /* startFrequency_2 */);
	DBL2FLT(stopFrequency, value.fFr2End /* stopFrequency_2 */);
		
	CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing /* frequencySweepSpacing_2 */, &value.Fr2Spacing, VI_ERROR_PARAMETER4));
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinThdSweep_NoChSet, ChAB, &get_value, sizeof(get_value)));
    
	value.FrStepCnt = frequencySweepSteps;
	value.fPhase1 = 0.0 /* phase_1 */;
	value.fPhase2 = 0.0 /* phase_2 */;
	value.AmStepCnt = get_value.AmStepCnt;
	value.RefreshTime = 0 /*500 /* refreshTime*/;
	value.FrSweepRepeat = 1 /* sweepLoops */;
	value.FrStepPause = frequencyStepDelay;
	value.AmStepPause = get_value.AmStepPause;
	
	CHECKERR (rssiup_param_to_val (STCtrlStepDiscVals, RSSIUP_CTRL_STEP_CONTINUE /* sweepStepControl */, &value.StartCtrlStep, VI_ERROR_PARAMETER1));
	
	CHECKERR (rssiup_param_to_val (STAutoFrqModeDiscVals, RSSIUP_FREQ_MODE_FIXED /* freqMode */, &value.FreqMode, VI_ERROR_PARAMETER1));
	
    DBL2FLT(startFrequency, value.FixFreqStart_A);
    DBL2FLT(stopFrequency, value.FixFreqEnd_A);
    CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing /* frequencySweepSpacing_2 */, &value.FrSpaceing_A, VI_ERROR_PARAMETER4));
	DBL2FLT(startFrequency, value.FixFreqStart_B);
    DBL2FLT(stopFrequency, value.FixFreqEnd_B);
    CHECKERR (rssiup_param_to_val (STFrSpacingDiscVals, frequencySweepSpacing /* frequencySweepSpacing_2 */, &value.FrSpaceing_B, VI_ERROR_PARAMETER4));
	
	CHECKERR (rssiup_param_to_val (SFilterBandwidthDiscVals, RSSIUP_FILTER_BWIDTH_WIDE /* filterBandwidth */, &value.FilterBandwidth, VI_ERROR_PARAMETER1));
	
	CHECKERR (rssiup_param_to_val (SMeasTimeDiscVals, RSSIUP_MEAS_TIME_FAST /* measurementTime */, &value.MeasTime, VI_ERROR_PARAMETER1));
	
	value.FrqLimitLo = 10.0;
	
	sample_frequency = fsArr[instrPtr->AnlDescription.AnlGenerally.DevSelector];
    value.FrqLimitHi = sample_frequency * 0.4535 - 10.0;
    
	value.MeasCharacter = 0; //get_value.MeasCharacter;
	
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinThdSweep_NoChSet, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Get Generator Function THD Sweep Frequency
 * Purpose:  This function returns frequency parameters for SinThdSweep 
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionTHDSweepFrequency (ViSession instrSession,
                                               ViReal64 *startFrequency,
                                               ViReal64 *stopFrequency,
                                               ViInt32 *frequencySweepSpacing,
                                               ViInt32 *frequencySweepSteps,
                                               ViInt32 *frequencyStepDelay)
{
    ViStatus    				rssiup_status   = VI_SUCCESS;
	TGetSinThdSweep_NoChSet     value           = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
	if (!startFrequency)
        return VI_ERROR_PARAMETER2;
    if (!stopFrequency)
        return VI_ERROR_PARAMETER3;
    if (!frequencySweepSpacing)
        return VI_ERROR_PARAMETER4;
    if (!frequencySweepSteps)
        return VI_ERROR_PARAMETER5;
    if (!frequencyStepDelay)
        return VI_ERROR_PARAMETER6;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinThdSweep_NoChSet, ChAB, &value, sizeof(value)));
	
	*startFrequency = value.fFr1Start;
    *stopFrequency = value.fFr1End;
    
	CHECKERR (rssiup_val_to_param (STFrSpacingDiscVals, frequencySweepSpacing, &value.Fr1Spacing, VI_ERROR_INV_RESPONSE));
    
    
	*frequencySweepSteps = value.FrStepCnt;
	*frequencyStepDelay = value.FrStepPause;
    
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	return rssiup_status;     
}

/*****************************************************************************
 * Function: Set Generator Function THD Sweep Amplitude
 * Purpose:  This function sets amplitude parameters for SinThdSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetGeneratorFunctionTHDSweepAmplitude (ViSession instrSession,
                                                      ViInt32 channel,
                                                      ViReal64 startAmplitude,
                                                      ViReal64 stopAmplitude,
                                                      ViInt32 amplitudeSweepSpacing,
													  ViInt32 amplitudeSweepSteps,
													  ViInt32 amplitudeStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TCmdSinThdSweep_ChanSet     value           = {0};
	TCmdSinThdSweep_NoChSet     set_value       = {0};
	TGetSinThdSweep_NoChSet     get_value       = {0};
	pTStatusDataRanges          instrPtr        = {0};
	//ViReal64            		startAmplitudeA        = 0.0;
	//ViReal64            		stopAmplitudeA         = 0.0;
	//ViInt32             		amplitudeSweepSpacingA = 0;
	//ViInt32             		amplitudeSweepStepsA   = 0;
	//ViInt32             		amplitudeStepDelayA    = 0;
	//ViReal64            		startAmplitudeB        = 0.0;
	//ViReal64            		stopAmplitudeB         = 0.0;
	//ViInt32             		amplitudeSweepSpacingB = 0;
	//ViInt32             		amplitudeSweepStepsB   = 0;
	//ViInt32             		amplitudeStepDelayB    = 0;
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (rssiup_invalidViInt32Range (channel, RSSIUP_CHAB, RSSIUP_CHB))
        return VI_ERROR_PARAMETER2;
	if (rssiup_invalidViReal64Range (startAmplitude, 0.0, 10.61))
        return VI_ERROR_PARAMETER3;
	if (rssiup_invalidViReal64Range (stopAmplitude, 0.0, 10.61))
        return VI_ERROR_PARAMETER4;
	if (rssiup_invalidViInt32Range (amplitudeSweepSpacing, RSSIUP_SPACING_NO, RSSIUP_SPACING_INS_LOG))
        return VI_ERROR_PARAMETER5;
	if (rssiup_invalidViInt32Range (amplitudeSweepSteps, 1, 1999))
        return VI_ERROR_PARAMETER6;
	if (rssiup_invalidViInt32Range (amplitudeStepDelay, 0, 65000))
        return VI_ERROR_PARAMETER7;
	
	/* NOT NEEDED
	// checking if the new sweep is running
	if ((channel == RSSIUP_CHAB) || (channel == RSSIUP_CHA))
	{
		CHECKERR (rssiup_GetGeneratorFunctionTHDSweepAmplitude (instrSession,
																RSSIUP_CHA,
																&startAmplitudeA,
																&stopAmplitudeA,
																&amplitudeSweepSpacingA,
																&amplitudeSweepStepsA,
																&amplitudeStepDelayA));
	
		if((fabs (startAmplitude - startAmplitudeA) > 0.000001) ||
		   (fabs (stopAmplitude - stopAmplitudeA) > 0.000001) ||
		   (amplitudeSweepSpacing != amplitudeSweepSpacingA) ||
		   (amplitudeSweepSteps != amplitudeSweepStepsA) ||
		   (amplitudeStepDelay != amplitudeStepDelayA))
			instrPtr->newSweep = VI_TRUE;
	}
	else
	{
		CHECKERR (rssiup_GetGeneratorFunctionTHDSweepAmplitude (instrSession,
																RSSIUP_CHB,
																&startAmplitudeB,
																&stopAmplitudeB,
																&amplitudeSweepSpacingB,
																&amplitudeSweepStepsB,
																&amplitudeStepDelayB));
		
		if((fabs (startAmplitude - startAmplitudeB) > 0.000001) ||
		   (fabs (stopAmplitude - stopAmplitudeB) > 0.000001) ||
		   (amplitudeSweepSpacing != amplitudeSweepSpacingB) ||
		   (amplitudeSweepSteps != amplitudeSweepStepsB) ||
		   (amplitudeStepDelay != amplitudeStepDelayB))
			instrPtr->newSweep = VI_TRUE;
	}	
	*/
	
	value.Sender = 0x07FE;
	
	value.fDCOffset = 0.0 /* DCOffset */;
    
	DBL2FLT(startAmplitude * sqrt(2)/2, value.fAm1Start);
	DBL2FLT(stopAmplitude * sqrt(2)/2, value.fAm1End);
		
	CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing, &value.fAm1Spacing, VI_ERROR_PARAMETER5));
	
	DBL2FLT(startAmplitude * sqrt(2)/2, value.fAm2Start /* startAmplitude_2 */);
    DBL2FLT(stopAmplitude * sqrt(2)/2, value.fAm2End /* stopAmplitude_2 */);
    
	CHECKERR (rssiup_param_to_val (STAmSpacingDiscVals, amplitudeSweepSpacing /* amplitudeSweepSpacing_2 */, &value.fAm2Spacing, VI_ERROR_PARAMETER5));
	
	CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinThdSweep_ChanSet, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
	
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinThdSweep_NoChSet, ChAB, &get_value, sizeof(get_value)));
    
	set_value.Sender = 0x07FE;
	
	set_value.fFr1Start = get_value.fFr1Start;
	set_value.fFr1End = get_value.fFr1End;
	set_value.Fr1Spacing = get_value.Fr1Spacing;
	set_value.fFr2Start = get_value.fFr2Start;
	set_value.fFr2End = get_value.fFr2End;
	set_value.Fr2Spacing = get_value.Fr2Spacing;
	set_value.FrStepCnt = get_value.FrStepCnt;
	set_value.fPhase1 = get_value.fPhase1;
	set_value.fPhase2 = get_value.fPhase2;
	set_value.RefreshTime = get_value.RefreshTime;
	set_value.FrSweepRepeat = get_value.FrSweepRepeat;
	set_value.FrStepPause = get_value.FrStepPause;
	
	set_value.AmStepCnt = amplitudeSweepSteps;
	set_value.AmStepPause = amplitudeStepDelay;
	
	set_value.StartCtrlStep = get_value.StartCtrlStep;
	set_value.FreqMode = get_value.FreqMode;
    set_value.FixFreqStart_A = get_value.FixFreqStart_A;
    set_value.FixFreqEnd_A = get_value.FixFreqEnd_A;
    set_value.FrSpaceing_A = get_value.FrSpaceing_A;
	set_value.FixFreqStart_B = get_value.FixFreqStart_B;
    set_value.FixFreqEnd_B = get_value.FixFreqEnd_B;
    set_value.FrSpaceing_B = get_value.FrSpaceing_B;
	set_value.FilterBandwidth = get_value.FilterBandwidth;
	set_value.MeasTime = get_value.MeasTime;
	set_value.FrqLimitLo = get_value.FrqLimitLo;
	set_value.FrqLimitHi = get_value.FrqLimitHi;
	set_value.MeasCharacter = get_value.MeasCharacter;
	
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_SinThdSweep_NoChSet, ChAB, &set_value, sizeof(set_value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));


    return rssiup_status;     
}

/*****************************************************************************
 * Function: Get Generator Function THD Sweep Amplitude
 * Purpose:  This function returns amplitude parameters for SinThdSweep measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetGeneratorFunctionTHDSweepAmplitude (ViSession instrSession,
                                                      ViInt32 channel,
                                                      ViReal64 *startAmplitude,
                                                      ViReal64 *stopAmplitude,
                                                      ViInt32 *amplitudeSweepSpacing,
													  ViInt32 *amplitudeSweepSteps,
													  ViInt32 *amplitudeStepDelay)
{
	ViStatus    				rssiup_status   = VI_SUCCESS;
    TGetSinThdSweep_ChanSet     value           = {0};
	TGetSinThdSweep_NoChSet     get_value       = {0};
	pTStatusDataRanges          instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
	if (instrPtr->fwVersion < 1.307) /* do only with FW versions higher than 1.307 */
		return RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC;
	
    if (rssiup_invalidViInt32Range (channel, RSSIUP_CHAB, RSSIUP_CHB))
        return VI_ERROR_PARAMETER2;
	if (!startAmplitude)
        return VI_ERROR_PARAMETER3;
    if (!stopAmplitude)
        return VI_ERROR_PARAMETER4;
    if (!amplitudeSweepSpacing)
        return VI_ERROR_PARAMETER5;
    if (!amplitudeSweepSteps)
        return VI_ERROR_PARAMETER6;
    if (!amplitudeStepDelay)
        return VI_ERROR_PARAMETER7;
    
	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinThdSweep_ChanSet, channel, &value, sizeof(value)));
    
	*startAmplitude = value.fAm1Start * 2 / sqrt(2);
	*stopAmplitude = value.fAm1End * 2 / sqrt(2);
		
	CHECKERR (rssiup_val_to_param (STAmSpacingDiscVals, amplitudeSweepSpacing, &value.fAm1Spacing, VI_ERROR_INV_RESPONSE));
	
	CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

	CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLFUN_SinThdSweep_NoChSet, ChAB, &get_value, sizeof(get_value)));
	
	*amplitudeSweepSteps = get_value.AmStepCnt;
    *amplitudeStepDelay = get_value.AmStepPause;

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;    
}

/*****************************************************************************
 * Function: Set Audio Monitor Output
 * Purpose:  This function sets state of the audio monitor outputs.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAudioMonitorOutput (ViSession instrSession,
                                                ViInt32 channel,
                                                ViBoolean monitorOutput)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViInt16     value           = 0;

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (rssiup_invalidViBooleanRange (monitorOutput))
        return VI_ERROR_PARAMETER3;

    value = (monitorOutput == VI_TRUE) ? ON : OFF;
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_MONHW_OUTPUT, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Audio Monitor Output
 * Purpose:  This function returns state of the audio monitor outputs.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAudioMonitorOutput (ViSession instrSession,
                                                ViInt32 channel,
                                                ViPBoolean monitorOutput)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViInt16     value           = 0;

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!monitorOutput)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_MONHW_OUTPUT, channel, &value, sizeof(value)));
    *monitorOutput = (value == ON) ? VI_TRUE : VI_FALSE;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Audio Monitor Source
 * Purpose:  This function sets audio monitor source.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAudioMonitorSource (ViSession instrSession,
                                                ViInt32 source)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViInt16     value           = 0;

    CHECKERR (rssiup_param_to_val (SDspMonSrcDiscVals, source, &value, VI_ERROR_PARAMETER2));
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_MONHW_SOURCE, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Audio Monitor Source
 * Purpose:  This function returns audio monitor source.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAudioMonitorSource (ViSession instrSession,
                                                ViPInt32 source)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViInt16     value           = 0;

    if (!source)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_MONHW_SOURCE, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_val_to_param (SDspMonSrcDiscVals, source, &value, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Audio Monitor Attenuation
 * Purpose:  This function sets audio monitor attenuation.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_SetAudioMonitorAttenuation (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViReal64 attenuation)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViInt16     value           = 0;

    if (!((channel == ChAB) || (channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (rssiup_invalidViReal64Range (attenuation, -63.5, 0.0))
        return VI_ERROR_PARAMETER3;

    value = 255 - fabs (attenuation) * 2;
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_MONHW_ATTENUATION, channel, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Audio Monitor Attenuation
 * Purpose:  This function returns audio monitor attenuation.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_GetAudioMonitorAttenuation (ViSession instrSession,
                                                     ViInt32 channel,
                                                     ViPReal64 attenuation)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViInt16     value           = 0;

    if (!((channel == ChA) || (channel == ChB)))
        return VI_ERROR_PARAMETER2;
    if (!attenuation)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_MONHW_ATTENUATION, channel, &value, sizeof(value)));
    *attenuation = (-1) * (255 - value) / 2.0;
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Configure Ref Oscillator
 * Purpose:  This function sets parameters of reference oscillator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_configureRefOscillator (ViSession instrSession,
                                                 ViBoolean state,
                                                 ViInt32 source,
                                                 ViInt32 frequency)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TRefOsc     value           = {0};

    if (rssiup_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;

    value.State = (state == VI_TRUE) ? ON : OFF;
    CHECKERR (rssiup_param_to_val (SRefOscSourceDiscVals, source, &value.Source, VI_ERROR_PARAMETER3));
    CHECKERR (rssiup_param_to_val (SRefOscExtFreqDiscVals, frequency, &value.ExtFreq, VI_ERROR_PARAMETER4));
    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_DEV_ROSC_SETTING, ChAB, &value, sizeof(value)));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Get Ref Oscillator Parameters
 * Purpose:  This function returns parameters of reference oscillator.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_getRefOscillatorParameters (ViSession instrSession,
                                                     ViPBoolean state,
                                                     ViPInt32 source,
                                                     ViPInt32 frequency)
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    TRefOsc     value           = {0};

    if (!state)
        return VI_ERROR_PARAMETER2;
    if (!source)
        return VI_ERROR_PARAMETER3;
    if (!frequency)
        return VI_ERROR_PARAMETER4;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_DEV_ROSC_SETTING, ChAB, &value, sizeof(value)));
    *state = (value.State == ON) ? VI_TRUE : VI_FALSE;  
    CHECKERR (rssiup_val_to_param (SRefOscSourceDiscVals, source, &value.Source, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_val_to_param (SRefOscExtFreqDiscVals, frequency, &value.ExtFreq, VI_ERROR_INV_RESPONSE));
    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}

/*****************************************************************************
 * Function: Set Time Out
 * Purpose:  Sets a minimum timeout value for driver I/O transactions in
 *           milliseconds. The timeout period may vary on computer platforms.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_setTimeOut(
    ViSession   instrSession,
    ViInt32     timeout
)
{
    return SiSetAttribute (instrSession, SI_ATTR_TMO_VALUE, timeout);
}

/*****************************************************************************
 * Function: Get Time Out
 * Purpose:  Returns the timeout value for driver I/O transactions in
 *           milliseconds.
 *
 *           The timeout period may vary on computer platforms.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_getTimeOut(
    ViSession   instrSession,
    ViPInt32    timeout
)
{
    return SiGetAttribute (instrSession, SI_ATTR_TMO_VALUE, timeout);
}

/*****************************************************************************
 * Function: Flush Error Queue
 * Purpose:  This function deletes content of error queue.
 *****************************************************************************/
ViStatus _VI_FUNC rssiup_flushErrorQueue (ViSession instrSession)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    /* Flush error queue */
    instrPtr -> errorCount = 0;
    memset (instrPtr -> errorQueue, 0, sizeof (instrPtr -> errorQueue[MAX_ERROR_QUEUE_LENGTH]));

    return rssiup_status;
}

/*****************************************************************************/
/*-------- INSERT USER-CALLABLE INSTRUMENT-DEPENDENT ROUTINES HERE ----------*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Warning Checking                                                */
/* Purpose:  This function enables (disables) warning checking. Warning      */
/*           checking is by default disabled.                                */
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_warningCheckState (ViSession instrSession,
                                   ViBoolean warningChecking)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};

    if (rssiup_invalidViBooleanRange (warningChecking))
       return VI_ERROR_PARAMETER2;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    instrPtr -> warningChecking = warningChecking;

    return rssiup_status;
}

/*===========================================================================*/
/* Function: State Checking                                                  */
/* Purpose:  This function enables (disables) error state checking (query the*/
/*           instrument's error subsystem).                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_errorCheckState (ViSession instrSession,
                                          ViBoolean stateChecking)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};

    if (rssiup_invalidViBooleanRange (stateChecking))
       return VI_ERROR_PARAMETER2;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_EVENT_HANDLING, stateChecking));

    instrPtr -> errorChecking = stateChecking;

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument. If the reset function      */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_reset (ViSession instrSession)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};

    /* --- Default Instrument Setup --- (mandatory!) --- */

    GOCHECKERR (rssiup_defaultInstrSetup (instrSession));
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    
#if 1 /*- Preset sequence used in MMI ---------------------------------------*/

    {
    TGenFun value = {0};

    value.GenFunID          = 0xFFFF;
    value.FunctionStatus    = 0x0000;
    value.Sender            = 0x07FE;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_FUNCTION_ON, ChAB, &value, sizeof(value)));

    /* Call also this function to properly update session structures
    CHECKERR (rssiup_SetGeneratorFunctionState (instrSession, RSSIUP_CHAB,
        RSSIUP_GEN_FUNC_ALL, VI_FALSE));
    */
    }

    {
    TAnlSwitchOnOff value = {0};

    value.AnlFunID              = 0xFFFF;
    value.FunctionStatus        = 0x0000;
    value.DigFilterOnOff_Unload = 0x0000;
    value.CntOfResults          = 0xFFFF;
    value.SenderMarker          = 0x07FE;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_FUNCTION_ON, ChAB, &value, sizeof(value)));

    /* Call also this function to properly update session structures
    CHECKERR (rssiup_SetAnalyzerFunctionState (instrSession, RSSIUP_CHAB,
        RSSIUP_ANL_FUNC_ALL, VI_FALSE, VI_FALSE));
    */
    }

    {
    TAGenOutput value = ON;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AGENHW_OUTPUT, ChAB, &value, sizeof(value)));
    }
	
	{
	TAnlMeasMode        value = ammContMeas;
	
	if (instrPtr->fwVersion - 1.2 > 0.00001) /* do only with FW versions higher than 1.2 */
		{
		CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_MEAS_MODE, ChAB, &value, sizeof(value)));
		}
	}

    {
    TGenDevSelector value = dsA49;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENHW_DEVICE_SELECTOR, ChAB, &value, sizeof(value)));
    }

    {
    TAGenRangeDependency value = OFF;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AGENHW_RANGE_DEPENDENCY, ChAB, &value, sizeof(value)));
    }

    {
    TAGenRangeModeSetVolt value = {0};

    value.Mode          = 0;
    value.RangeValue    = 10.0;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AGENHW_RANGE_VOLT, ChAB, &value, sizeof(value)));
    }

    {
    TAGenFloatGnd value = ON;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AGENHW_FLOAT_GND, ChAB, &value, sizeof(value)));
    }

    {
    TDDevNoOfBits value = nb24bits;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_DGENHW_NUM_OF_BITS, ChAB, &value, sizeof(value)));
    }

    {
    ViInt16 value = 0;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLHW_DAI_SAMPL_FREQ_OFFSET, ChAB, &value, sizeof(value)));
    }

    {
    TDGenDaiProtocol value =
        {
        /* ChannelStatus [24] */ 4, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        /* UserData[24] */       0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
        /* ValidityBit */        0x0000,
        /* Sender */             0x07FE
        };

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_GENFUN_DAIPROTOCOL, ChAB, &value, sizeof(value)));
    }

    {
    TAAnlInput value = aaiOn;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_INPUT, ChAB, &value, sizeof(value)));
    }

    {
    TAnlDevSelector value = dsA49;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLHW_DEVICE_SELECTOR, ChAB, &value, sizeof(value)));
    }

    {
    TAAnlCoupling value = aacAC;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_COUPLING, ChAB, &value, sizeof(value)));
    }

    {
    TAAnlRange value = {0};

    value.RangeMode = rtAuto;
    value.RangeNum  = 0;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_RANGE_NUM, ChAB, &value, sizeof(value)));
    }

    {
    TAAnlHPF value = ooON;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_AANLHW_DIGITAL_HPF, ChAB, &value, sizeof(value)));
    }

    {
    ViInt16 value = 0x0099;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_MONHW_ATTENUATION, ChAB, &value, sizeof(value)));
    }

    {
    ViInt16 value = 0x0003;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_MONHW_SOURCE, ChAB, &value, sizeof(value)));
    }

    {
    TCmdDigFilterSetting value = {0};

    value.FilterSection         = 0;
    value.FilterType            = ftNoFilter;
    value.CenterFreqForOctaves  = 0;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_DIGITALFILTER_SETTING, ChA, &value, sizeof(value)));
    }

    {
    TCmdDigFilterSetting value = {0};

    value.FilterSection         = 1;
    value.FilterType            = ftNoFilter;
    value.CenterFreqForOctaves  = 0;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_DIGITALFILTER_SETTING, ChA, &value, sizeof(value)));
    }

    {
    TCmdDigFilterSetting value = {0};

    value.FilterSection         = 2;
    value.FilterType            = ftNoFilter;
    value.CenterFreqForOctaves  = 0;

    CHECKERR (rssiup_DSI_Set (instrSession, DSI_CMD_ANLFUN_DIGITALFILTER_SETTING, ChA, &value, sizeof(value)));
    }

#else /*- Setting of all driver functions to default values -----------------*/

    /* --- UP 300 Initial Settings (same as after Power On) --- */

    GOCHECKERR (rssiup_SetAnalyzerFunctionState (instrSession, RSSIUP_CHAB,
        RSSIUP_ANL_FUNC_ALL, VI_FALSE, VI_FALSE));
    GOCHECKERR (rssiup_SetGeneratorFunctionState (instrSession, RSSIUP_CHAB,
        RSSIUP_GEN_FUNC_ALL, VI_FALSE));

    /* --- */

    GOCHECKERR (rssiup_configureRefOscillator (instrSession, VI_FALSE,
                                   RSSIUP_REF_OSCILLATOR_SOURCE_INT,
                                   RSSIUP_REF_OSCILLATOR_FREQ_10MHZ));

    /* --- Analyzer --- */

    GOCHECKERR (rssiup_SetAnalyzerDeviceSelector (instrSession, RSSIUP_ANL_A98));
    GOCHECKERR (rssiup_SetAnalogAnalyzerInput (instrSession, RSSIUP_CHAB, RSSIUP_ANL_INPUT_OFF));
    GOCHECKERR (rssiup_SetAnalogAnalyzerCoupling (instrSession, /* RSSIUP_CHAB, */ RSSIUP_ANL_COUPLING_DC));
    GOCHECKERR (rssiup_SetAnalogAnalyzerRangeNumber (instrSession, RSSIUP_CHAB,
                                                     RSSIUP_RANGE_MODE_AUTO, 7));
    /* GOCHECKERR (rssiup_SetAnalogAnalyzerHighPassFilter (instrSession, VI_FALSE)); */
    GOCHECKERR (rssiup_SetAnalogAnalyzerFloatGround (instrSession, RSSIUP_CHAB, VI_FALSE));

    GOCHECKERR (rssiup_SetAnalyzerFunctionPeakSettings (instrSession, 0.1));
    /* GOCHECKERR (rssiup_SetAnalyzerFunctionPeakAveraging (instrSession, RSSIUP_AVERAGING_MODE_OFF, 1)); */

    GOCHECKERR (rssiup_SetAnalyzerFunctionRMSDCSettings (instrSession, RSSIUP_CHAB,
                                                         0.1, 0.15,
                                                         RSSIUP_SYNC_MODE_SYNC,
                                                         RSSIUP_SYNC_SOURCE_SIGNAL_A_RISE));
    GOCHECKERR (rssiup_SetAnalyzerFunctionRMSDCAveraging (instrSession, RSSIUP_CHAB,
                                                          RSSIUP_AVERAGING_MODE_OFF,
                                                          1,
                                                          RSSIUP_AVERAGING_MODE_OFF,
                                                          1,
                                                          RSSIUP_AVERAGING_MODE_OFF,
                                                          1));

    GOCHECKERR (rssiup_SetAnalyzerFunctionQpeakSettings (instrSession, 3.0));
    GOCHECKERR (rssiup_AnalyzerFunctionQpeakReset (instrSession));

    GOCHECKERR (rssiup_SetAnalyzerFunctionRMSSelectiveSettings (instrSession, 0.1,
                                                                1.0e3,
                                                                RSSIUP_RMS_BANDWIDTH_30HZ));
    GOCHECKERR (rssiup_SetAnalyzerFunctionRMSSelectiveAveraging (instrSession,
                                                                 RSSIUP_AVERAGING_MODE_OFF,
                                                                 1));
    GOCHECKERR (rssiup_SetAnalyzerFunctionRMSSelectiveAveraging (instrSession,
                                                                 RSSIUP_AVERAGING_MODE_OFF,
                                                                 1));

    GOCHECKERR (rssiup_SetAnalyzerDigitalFilter (instrSession, RSSIUP_CHAB,
                                                 RSSIUP_DIGI_FILTER_SECTION_1,
                                                 RSSIUP_DIGI_FILTER_TYPE_NONE, 25.0));
    {
    ViInt32 number[] = {RSSIUP_USER_FILTER_1, RSSIUP_USER_FILTER_2, RSSIUP_USER_FILTER_3},
            filter[] = {RSSIUP_DIGI_FILTER_TYPE_USER_1, RSSIUP_DIGI_FILTER_TYPE_USER_2, RSSIUP_DIGI_FILTER_TYPE_USER_3},
            coefficients[26],
            idx = 0;

    memset (coefficients, 0, 26 * sizeof(coefficients[0]));

    for (idx = 0; idx < 3; idx++)
        {
        GOCHECKERR (rssiup_SetAnalyzerUserFilter (instrSession, number[idx], filter[idx],
                                                  1, 0.0, 26, coefficients));
        }
    }

    GOCHECKERR (rssiup_SetAnalyzerFunctionTHDNSettings (instrSession,
                                                        RSSIUP_MEAS_TIME_FAST,
                                                        RSSIUP_FREQ_MODE_AUTO,
                                                        1000.0, 1000.0, 10.0, 40.0e3));
    GOCHECKERR (rssiup_SetAnalyzerFunctionTHDNFFTSettings (instrSession, VI_FALSE,
                                                           RSSIUP_FFT_SIZE_1024,
                                                           RSSIUP_FFT_WINDOW_RIFE_VINCENT_1));

    GOCHECKERR (rssiup_SetAnalyzerFunctionPhaseSettings (instrSession,
                                                         RSSIUP_FREQ_MODE_AUTO,
                                                         1000.0,
                                                         RSSIUP_FREQ_MASTER_CHA));
    GOCHECKERR (rssiup_SetAnalyzerFunctionPhaseFFTSettings (instrSession, VI_FALSE,
                                                            VI_FALSE,
                                                            RSSIUP_FFT_SIZE_1024, 200,
                                                            400, 0, 10, 100));

    GOCHECKERR (rssiup_SetAnalyzerFunctionDFDSettings (instrSession,
                                                       RSSIUP_FREQ_MODE_FIXED, 1.0e3,
                                                       1.0e4, 1.0e3, 1.0e4));
    GOCHECKERR (rssiup_SetAnalyzerFunctionDFDFFTSettings (instrSession, VI_FALSE,
                                                          RSSIUP_FFT_SIZE_1024,
                                                          RSSIUP_FFT_WINDOW_RIFE_VINCENT_1));

    GOCHECKERR (rssiup_SetAnalyzerFunctionModDistSettings (instrSession,
                                                           RSSIUP_FREQ_MODE_FIXED,
                                                           1.0e3, 1.0e4, 1.0e3, 1.0e4));
    GOCHECKERR (rssiup_SetAnalyzerFunctionModDistFFTSettings (instrSession, VI_FALSE,
                                                              RSSIUP_FFT_SIZE_1024,
                                                              RSSIUP_FFT_WINDOW_RIFE_VINCENT_1));

    GOCHECKERR (rssiup_SetAnalyzerFunctionFFTSettings (instrSession, RSSIUP_CHAB,
                                                       VI_FALSE, RSSIUP_FFT_SIZE_1024,
                                                       RSSIUP_FFT_WINDOW_RECTANGULAR,
                                                       1.0, RSSIUP_FFT_ZOOM_FACTOR_0,
                                                       0.0, 200, 400, 0, 10, 100));
    GOCHECKERR (rssiup_SetAnalyzerFunctionFFTAveraging (instrSession, RSSIUP_CHAB,
                                                        RSSIUP_AVERAGING_MODE_OFF, 1));

    GOCHECKERR (rssiup_SetDigitalAnalyzerSampleRateSettings (instrSession, 0.1));
    GOCHECKERR (rssiup_SetDigitalAnalyzerSampleRateAveraging (instrSession,
                                                              RSSIUP_AVERAGING_MODE_OFF,
                                                              1));
    GOCHECKERR (rssiup_SetDigitalAnalyzerProtocol (instrSession,
                                                   RSSIUP_DAI_PROTOCOL_CH_STATUS, 0.1));
    GOCHECKERR (rssiup_SetDigitalAnalyzerInput (instrSession, RSSIUP_DAI_INPUT_BNC));
    GOCHECKERR (rssiup_SetDigitalAnalyzerNoofBits (instrSession, RSSIUP_CHAB,
                                                   RSSIUP_DAI_BITS_24));

    /* --- Generator --- */

    GOCHECKERR (rssiup_SetGeneratorDeviceSelector (instrSession, RSSIUP_GEN_A98));
    GOCHECKERR (rssiup_SetGeneratorGlobalDCOffset (instrSession, RSSIUP_CHAB, 0.0,
                                                   RSSIUP_UNIT_V));

    GOCHECKERR (rssiup_SetAnalogGeneratorOutput (instrSession, RSSIUP_CHAB, VI_FALSE));
    GOCHECKERR (rssiup_SetAnalogGeneratorRangeNumber (instrSession, RSSIUP_CHAB,
                                                      RSSIUP_RANGE_MODE_AUTO, 0));
    GOCHECKERR (rssiup_SetAnalogGeneratorFloatGround (instrSession, RSSIUP_CHAB, VI_FALSE));

    GOCHECKERR (rssiup_SetGeneratorFunctionSineShape (instrSession, 1.0e3,
                                                      RSSIUP_UNIT_HZ, 0.0,
                                                      RSSIUP_UNIT_DEG, 1.0e3,
                                                      RSSIUP_UNIT_HZ, 0.0,
                                                      RSSIUP_UNIT_DEG));
    GOCHECKERR (rssiup_SetGeneratorFunctionSineDimension (instrSession, RSSIUP_CHAB,
                                                          0.0, RSSIUP_UNIT_V, 0.2,
                                                          RSSIUP_UNIT_V, 0.0,
                                                          RSSIUP_UNIT_V));
    
    GOCHECKERR (rssiup_SetGeneratorFunctionNoiseShape (instrSession, RSSIUP_PDF_TRIANGULAR, 12));
    GOCHECKERR (rssiup_SetGeneratorFunctionNoiseDimension (instrSession, RSSIUP_CHAB,
                                                           0.0, RSSIUP_UNIT_V, 0.2,
                                                           RSSIUP_UNIT_V, 0.0,
                                                           RSSIUP_UNIT_V));

    {
        ViInt32     idx = 0,
                    multiple[17];
        ViReal64    phase[17],
                    amplitude[17];

        for (idx = 0; idx < 17; idx++)
            {
            multiple[idx] = 1;
            phase[idx] = 0.0;
            amplitude[idx] = 1.0;
            }
    
        GOCHECKERR (rssiup_SetGeneratorFunctionMultisineShape (instrSession, 17, multiple,
                                                               phase, amplitude, 10.0));
    }

    GOCHECKERR (rssiup_SetGeneratorFunctionMultisineDimension (instrSession,
                                                               RSSIUP_CHAB, 0.0,
                                                               RSSIUP_UNIT_V, 0.2,
                                                               RSSIUP_UNIT_V, 0.0,
                                                               RSSIUP_UNIT_V, 0.0));
    GOCHECKERR (rssiup_SetGeneratorFunctionArbitraryDimension (instrSession,
                                                               RSSIUP_CHAB, 0.0,
                                                               RSSIUP_UNIT_V, 0.2,
                                                               RSSIUP_UNIT_V, 0.0,
                                                               RSSIUP_UNIT_V));

    GOCHECKERR (rssiup_SetGeneratorFunctionSineBurstShape (instrSession, 1.0e3,
                                                           RSSIUP_UNIT_HZ, 3.0,
                                                           RSSIUP_UNIT_S, 0.002,
                                                           RSSIUP_UNIT_S, 0.003,
                                                           RSSIUP_UNIT_S,
                                                           RSSIUP_BURST_SIGNAL_SINGLE));

    GOCHECKERR (rssiup_SetGeneratorFunctionSineBurstDimension (instrSession,
                                                               RSSIUP_CHAB, 0.0,
                                                               RSSIUP_UNIT_V, 0.2,
                                                               RSSIUP_UNIT_V, 0.0,
                                                               RSSIUP_UNIT_V, 0.0,
                                                               RSSIUP_UNIT_V));

    GOCHECKERR (rssiup_SetGeneratorFunctionPolarityDimension (instrSession,
                                                              RSSIUP_CHAB, 0.0,
                                                              RSSIUP_UNIT_V, 0.2,
                                                              RSSIUP_UNIT_V, 0.0,
                                                              RSSIUP_UNIT_V));

    {
        ViChar  status[24],
                data[24];

        memset (status, 0, 24);
        memset (data, 0, 24);

        GOCHECKERR (rssiup_SetDigitalGeneratorProtocol (instrSession, status,
                                                        data, RSSIUP_VALID));
    }

    GOCHECKERR (rssiup_SetDigitalGeneratorNoofBits (instrSession, RSSIUP_DAI_BITS_24));
    
    /* --- Audio Monitor --- */

    GOCHECKERR (rssiup_SetAudioMonitorOutput (instrSession, RSSIUP_CHAB, VI_FALSE));
    GOCHECKERR (rssiup_SetAudioMonitorSource (instrSession, RSSIUP_MONITOR_SOURCE_NONE));
    GOCHECKERR (rssiup_SetAudioMonitorAttenuation (instrSession, RSSIUP_CHAB, 0.0));

#endif /*--------------------------------------------------------------------*/

    /* --- Reset is finished, check event queue for possible errors --- */

ERROR:

    if (rssiup_status == VI_SUCCESS)
        {
        /* Skip error checking for reset function */
        //CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));
        CHECKERR (SiFlushEventQueue(instrSession)); /* Flush event queue */
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_self_test (ViSession instrSession,
                                    ViPInt16 testResult,
                                    ViChar _VI_FAR testMessage[])
{
    ViStatus rssiup_status = VI_WARN_NSUP_SELF_TEST;

    //
    // Self-Test not supported
    //

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result. If the error query function is not supported by the */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_ERROR_QUERY.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_error_query (ViSession instrSession,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[])
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr -> errorCount == 0)
        {
        *errorCode = 0x0; /* No error. */
        if (errorMessage)
            sprintf (errorMessage, "No error.");
        }
    else
        {
        /* Error queue full? */
        if (instrPtr -> errorCount >= MAX_ERROR_QUEUE_LENGTH)
            return RSSIUP_ERROR_QUEUE_OVERFLOW;

        /* Retrieve error code and description */
        *errorCode = instrPtr -> errorQueue[instrPtr -> errorCount - 1].stringVal;
        if (errorMessage)
            sprintf (errorMessage, "%s", instrPtr -> errorQueue[instrPtr -> errorCount - 1].stringName);

        /* Decrease error counter */
        instrPtr -> errorCount--;
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_error_message (ViSession instrSession,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR errMessage[])
{
    ViStatus    rssiup_status   = VI_SUCCESS;
    ViInt16     i               = 0;

    static TStringValPair statusDescArray[] = {
        {VI_WARN_NSUP_ID_QUERY,         "WARNING: ID Query not supported"},
        {VI_WARN_NSUP_RESET,            "WARNING: Reset not supported"},
        {VI_WARN_NSUP_SELF_TEST,        "WARNING: Self-test not supported"},
        {VI_WARN_NSUP_ERROR_QUERY,      "WARNING: Error Query not supported"},
        {VI_WARN_NSUP_REV_QUERY,        "WARNING: Revision Query not supported"},
        {VI_ERROR_PARAMETER1,           "ERROR: Parameter 1 out of range"},
        {VI_ERROR_PARAMETER2,           "ERROR: Parameter 2 out of range"},
        {VI_ERROR_PARAMETER3,           "ERROR: Parameter 3 out of range"},
        {VI_ERROR_PARAMETER4,           "ERROR: Parameter 4 out of range"},
        {VI_ERROR_PARAMETER5,           "ERROR: Parameter 5 out of range"},
        {VI_ERROR_PARAMETER6,           "ERROR: Parameter 6 out of range"},
        {VI_ERROR_PARAMETER7,           "ERROR: Parameter 7 out of range"},
        {VI_ERROR_PARAMETER8,           "ERROR: Parameter 8 out of range"},
        {VI_ERROR_FAIL_ID_QUERY,        "ERROR: Identification query failed"},
        {VI_ERROR_INV_RESPONSE,         "ERROR: Interpreting instrument response"},
        {VI_ERROR_INSTR_FILE_OPEN,      "ERROR: Opening the specified file"},
        {VI_ERROR_INSTR_FILE_WRITE,     "ERROR: Writing to the specified file"},
        {VI_ERROR_INSTR_INTERPRETING_RESPONSE, "ERROR: Interpreting the instrument's response"},
        {VI_ERROR_INSTR_PARAMETER9 ,    "ERROR: Parameter 9 out of range"},
        {VI_ERROR_INSTR_PARAMETER10,    "ERROR: Parameter 10 out of range"},
        {VI_ERROR_INSTR_PARAMETER11,    "ERROR: Parameter 11 out of range"},
        {VI_ERROR_INSTR_PARAMETER12,    "ERROR: Parameter 12 out of range"},
        {VI_ERROR_INSTR_PARAMETER13,    "ERROR: Parameter 13 out of range"},
        {VI_ERROR_INSTR_PARAMETER14,    "ERROR: Parameter 14 out of range"},
        {VI_ERROR_INSTR_PARAMETER15,    "ERROR: Parameter 15 out of range"},

        /* Place user defined error codes here ... */

        {RSSIUP_ERROR_INSTRUMENT_ERROR,         "ERROR: Instrument status error."},
        {RSSIUP_ERROR_INVALID_CONFIGURATION,    "ERROR: Instrument configuration error."},
        {RSSIUP_ERROR_INSTRUMENT_OPTION,        "ERROR: Required instrument's option is not installed."},
        {RSSIUP_ERROR_INSTRUMENT_NSUP_MODEL,    "ERROR: Required instrument model is not connected."},
        {RSSIUP_ERROR_MEASUREMENT_ABORTED,      "ERROR: Current measurement has been aborted."},
        {RSSIUP_ERROR_INVALID_VALUE,            "ERROR: Invalid value (value out of range)."},
        {RSSIUP_ERROR_RNG_TAB_NOT_AVAIL,        "ERROR: Range table for selected register name is not available."},
        {RSSIUP_ERROR_NULL_POINTER_VALUE,       "ERROR: NULL pointer passed as parameter."},
        {RSSIUP_ERROR_QUEUE_OVERFLOW,           "ERROR: The error queue is overflowed."},
        {RSSIUP_ERROR_DATA_NOT_AVAILABLE,       "ERROR: Data not available."},
        {RSSIUP_ERROR_DATA_CORRUPTED,           "ERROR: Data are corrupted."},
        {RSSIUP_ERROR_SETTINGS_CONFLICT,        "ERROR: Settings conflict. Passed parameter does not match with the current instrument's settings."},
        {RSSIUP_ERROR_RESERVED,                 "ERROR: Function or parameter is for any reason reserved."},
        {RSSIUP_ERROR_OVER_LIMIT,               "ERROR: Passed value is over predefined limit."},
		{RSSIUP_ERROR_INSTRUMENT_NSUP_FUNC,     "ERROR: Function not available in this firmware."},

        /* Place user defined warnings here ... */

        {RSSIUP_WARNING_INSTRUMENT_WARNING,     "WARNING: Instrument warning message."},
        {RSSIUP_WARNING_CACHED_DATA,            "WARNING: Data are retrieved from cache."},

        {VI_NULL, VI_NULL}
    };

    /* Query SiControl library */
    rssiup_status = SiGetErrorString(statusCode, errMessage, 256);
    /* If SiControl library failed, try user defined codes */
    if (rssiup_status == SI_WARN_UNKNOWN_STATUS)
        {
        for (i = 0; statusDescArray[i].stringName; i++)
            {
            if (statusDescArray[i].stringVal == statusCode)
                {
                sprintf (errMessage, "%s", statusDescArray[i].stringName);
                return VI_SUCCESS;
                }
            }
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*           If the revision query function is not supported by the          */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_REV_QUERY.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_revision_query (ViSession instrSession,
                    ViChar _VI_FAR driverRev[], ViChar _VI_FAR instrRev[])
{
    ViStatus rssiup_status = VI_SUCCESS;

    struct {
        ViUInt16 MajorVersion;
        ViUInt16 MinorVersion;
    } SFirmwareVersion = {0};

    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, VI_FALSE));

    rssiup_status = SiGetRegister(instrSession, 0x1010, 0, &SFirmwareVersion, 4);

    SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, VI_TRUE);

    if (instrRev)
        sprintf (instrRev, "%u.%u", SFirmwareVersion.MajorVersion,
            SFirmwareVersion.MinorVersion);

    if (driverRev)
        sprintf (driverRev, "%s", RSSIUP_REVISION);

    /* Suppress positive (warning) code */
    rssiup_status = (rssiup_status < VI_SUCCESS) ? rssiup_status : VI_SUCCESS;

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rssiup_close (ViSession instrSession)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr != NULL)
        free (instrPtr);

    CHECKERR (SiCloseDevice (instrSession));
    CHECKERR (SiLibExit ());

    return rssiup_status;
}

/*****************************************************************************/
/*= UTILITY ROUTINES (Non-Exportable Functions) =============================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Boolean Value Out Of Range - ViBoolean                          */
/* Purpose:  This function checks a Boolean to see if it is equal to VI_TRUE */
/*           or VI_FALSE. If the value is out of range, the return value is  */
/*           VI_TRUE, otherwise the return value is VI_FALSE.                */
/*===========================================================================*/
ViBoolean rssiup_invalidViBooleanRange (ViBoolean val)
{
    return (ViBoolean)((val != VI_FALSE && val != VI_TRUE) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Long Signed Integer Value Out Of Range - ViInt32                */
/* Purpose:  This function checks a long signed integer value to see if it   */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViBoolean rssiup_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Real (Double) Value Out Of Range - ViReal64                     */
/* Purpose:  This function checks a real (double) value to see if it lies    */
/*           between a minimum and maximum value.  If the value is out of    */
/*           range, the return value is VI_TRUE, otherwise the return value  */
/*           is VI_FALSE.                                                    */
/*===========================================================================*/
ViBoolean rssiup_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Check String                                                    */
/* Purpose:  This function checks a string value to see if it is             */
/*           of a defined length and initialized.                            */
/*===========================================================================*/
ViBoolean rssiup_invalidViString (ViString val, ViUInt32 maxLength)
{
    if (val)
        return (ViBoolean)((strlen (val) > maxLength) ? VI_TRUE : VI_FALSE);

    return VI_TRUE;
}

/*===========================================================================*/
/* Function: Initialize Clean Up                                             */
/* Purpose:  This function is used only by the rssiup_init function.  When   */
/*           an error is detected this function is called to close the       */
/*           open resource manager and instrument object sessions and to     */
/*           set the instrSession that is returned from rssiup_init to       */
/*           VI_NULL.                                                        */
/*===========================================================================*/
ViStatus rssiup_initCleanUp (ViPSession openInstrSession,
                             ViStatus currentStatus)
{
    pTStatusDataRanges instrPtr = {0};

    if (SiGetAttribute (*openInstrSession, SI_ATTR_USER_DATA, &instrPtr) >= 0)
        if (instrPtr != NULL)
            free (instrPtr);

    SiCloseDevice (*openInstrSession);
    *openInstrSession = VI_NULL;

    return currentStatus;
}

/*===========================================================================*/
/* Function: Delay                                                           */
/* Purpose : With a call to rssiup_delay, the current program is suspended   */
/*           from execution for the number of seconds specified by the       */
/*           argument seconds. rssiup_delay is accurate to a millisecond.    */
/*           This function is platform independent.                          */
/*===========================================================================*/
void rssiup_delay (ViReal64 numberOfSeconds)
{
  clock_t StartTime = clock();

  while ((((double)(clock() - StartTime))/(double)CLOCKS_PER_SEC) < (numberOfSeconds));

  return;
}

/*===========================================================================*/
/* Function: Parameter to Value
/* Purpose : Translate public constant to the device specific value.
/*===========================================================================*/
ViStatus rssiup_param_to_val (TSDiscreteValue table[], ViInt32 parameter, void *value, ViStatus error_code)
{
    ViInt32 idx = 0;

    for (idx = 0; table[idx].opt; idx++)
        {
        if (table[idx].parameter == parameter)
            {
            switch (table[idx].type)
                {
                case I32:
                    *(ViInt32 *)value = table[idx].value;
                    break;
                case U32:
                    *(ViUInt32 *)value = table[idx].value;
                    break;
                case I16:
                    *(ViInt16 *)value = table[idx].value;
                    break;
                case U16: default:
                    *(ViUInt16 *)value = table[idx].value;
                    break;
                }
                return VI_SUCCESS;
                }
        }

    return error_code;
}

/*===========================================================================*/
/* Function: Value to Parameter
/* Purpose : Translate device specific value to the public constant.
/*===========================================================================*/
ViStatus rssiup_val_to_param (TSDiscreteValue table[], ViPInt32 parameter, void *value, ViStatus error_code)
{
    ViInt32 idx = 0;

    for (idx = 0; table[idx].opt; idx++)
        {
        switch (table[idx].type)
            {
            case I32:
                {
                ViInt32 new_value = *(ViPInt32)value;

                if (table[idx].value == new_value)
                    {
                    *parameter = table[idx].parameter;
                    return VI_SUCCESS;
                    }
                }
                break;
            case U32:
                {
                ViUInt32 new_value = *(ViPUInt32)value;

                if (table[idx].value == new_value)
                    {
                    *parameter = table[idx].parameter;
                    return VI_SUCCESS;
                    }
                }
                break;
            case I16:
                {
                ViInt16 new_value = *(ViPInt16)value;

                if (table[idx].value == new_value)
                    {
                    *parameter = table[idx].parameter;
                    return VI_SUCCESS;
                    }
                }
                break;
            case U16: default:
                {
                ViUInt16 new_value = *(ViPUInt16)value;

                if (table[idx].value == new_value)
                    {
                    *parameter = table[idx].parameter;
                    return VI_SUCCESS;
                    }
                }
                break;
            }
        }

    return error_code;
}

/*****************************************************************************/
/*----------- INSERT INSTRUMENT-DEPENDENT UTILITY ROUTINES HERE -------------*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Default Instrument Setup                                        */
/* Purpose:  This function sends a default setup to the instrument. This     */
/*           function is called by the rssiup_reset operation and by the     */
/*           rssiup_init function if the reset option has not been           */
/*           selected. This function is useful for configuring any           */
/*           instrument settings that are required by the rest of the        */
/*           instrument driver functions.                                    */
/*===========================================================================*/
ViStatus rssiup_defaultInstrSetup (ViSession instrSession)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges      instrPtr        = {0};
	ViInt32					idx				= 0;
	
    /* Determine if the structure has been initialized for the current       */
    /* Session and malloc if it has not.                                     */
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr == NULL)
        {
        instrPtr = malloc (sizeof (TStatusDataRanges));
        instrPtr = memset (instrPtr, 0, sizeof (TStatusDataRanges));
        }

    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_USER_DATA, (ViUInt32)instrPtr));

    /* Set default values for members of the session based data structure */
    instrPtr -> instrSession                = instrSession;
    instrPtr -> errorChecking               = VI_TRUE;
    instrPtr -> warningChecking             = VI_FALSE;
    strcpy (instrPtr -> instrDriverRevision, RSSIUP_REVISION);

    /* --- */
    instrPtr -> measMode                    = RSSIUP_MEAS_MODE_CONTINUOUS;
    instrPtr -> abortCurrentMeasurement     = VI_FALSE;
	instrPtr -> triggerSource				= RSSIUP_TRIGGER_SOURCE_IMMEDIATE;
	instrPtr -> cachedData                  = VI_FALSE;
	instrPtr -> fwVersion					= 0.0;
	instrPtr -> anlDiscSize 				= 0;
	instrPtr -> enabledMeasIdCnt 			= 0;
	//instrPtr -> oldTimeout					= 0.0;
	//instrPtr -> sampleCount					= 0;
	//instrPtr -> newSweep					= VI_TRUE;
	
	for (idx = 0; idx < ANLFUN_CNT; idx++)
	{
		instrPtr->enabledMeasId[idx] = 0;
		instrPtr->enabledMeasIdDataValid[idx] = OFF;
	}
	
    /* Enable flag for reading of results from device and DSP. */
    {
	    ViUInt16    		value 			= ON;
		ViUInt16			min_ver			= 0;
		ViUInt16			maj_ver			= 0;
		TAnlDescription     AnlDescription  = {0};
		
		struct {
	        ViUInt16 MajorVersion;
	        ViUInt16 MinorVersion;
	    } SFirmwareVersion = {0};

	    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, VI_FALSE));

	    rssiup_status = SiGetRegister(instrSession, 0x1010, 0, &SFirmwareVersion, 4);

	    SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, VI_TRUE);

		maj_ver = SFirmwareVersion.MajorVersion;
	    min_ver = SFirmwareVersion.MinorVersion;
		
		instrPtr->fwVersion = (ViReal32) maj_ver + (((ViReal32) min_ver) / 1000); 
		instrPtr->anlDiscSize = (instrPtr->fwVersion - 1.2 > 0.00001) ? sizeof (AnlDescription) : sizeof (AnlDescription) - 130;
		
	    if (instrPtr->fwVersion - 1.2 < 0.00001) /* do only with FW versions smaller than 1.2 */
		{
			CHECKERR (rssiup_DSI_Set (instrSession, ENABLE_RESULT_LOOP, ChAB, &value, sizeof (value)));
		    CHECKERR (rssiup_DSI_Set (instrSession, ENABLE_RESULTS_READING, ChAB, &value, sizeof (value)));
    	}
	}

    /* Analyzer */
    {
    ViUInt16    value = 0;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_ANLHW_DEVICE_SELECTOR, ChAB, &value, sizeof(value)));

    if ((value == dsA49) || (value == dsA98) || (value == dsA195))
        {
        instrPtr -> analyzerMode = RSSIUP_ANALYZER_MODE_ANALOG;
        }
    else
        {
        instrPtr -> analyzerMode = RSSIUP_ANALYZER_MODE_DIGITAL;
        }
    }

    /* Generator */
    {
    ViUInt16    value = 0;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENHW_DEVICE_SELECTOR, ChAB, &value, sizeof(value)));

    if ((value == dsA49) || (value == dsA98) || (value == dsA195))
        {
        instrPtr -> analyzerMode = RSSIUP_GENERATOR_MODE_ANALOG;
        }
    else
        {
        instrPtr -> analyzerMode = RSSIUP_GENERATOR_MODE_DIGITAL;
        }
    }
	
    /* Flush event queue */
    CHECKERR (SiFlushEventQueue(instrSession));

    /* Flush error queue */
    instrPtr -> errorCount = 0;
    memset (instrPtr -> errorQueue, 0, sizeof (instrPtr -> errorQueue[MAX_ERROR_QUEUE_LENGTH]));

    return rssiup_status;
}

/*=========================================================================*/
/* Function: Check Status                                                  */
/* Purpose:  This function checks status subsystem. All events waiting in  */
/*           the event queue are retrieved and checked for error occurence.*/
/*           As option is possible search for the specified event.         */
/*=========================================================================*/
ViStatus rssiup_checkStatus (ViSession instrSession, ViInt16 checkEvent,
                ViPBoolean checkEnventFound)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    /* Proceed when Error Checking is enabled */
    if (instrPtr -> errorChecking)
        {
        ViUInt16    oldErrorCount       = instrPtr -> errorCount;
        ViInt32     idx                 = 0,
                    idy                 = 0,
                    idz                 = 0;
        ViBoolean   warningFlag         = VI_TRUE; /* If VI_FALSE, error is detected */
        int         EventId             = 0;
        long        lParam              = 0;
        int         wParam              = 0;

        /* Set it to default (VI_FALSE = not event found) */
        if (checkEnventFound)
            *checkEnventFound = VI_FALSE;

        /* Search event queue for error events. Note that other events are discarted. */
        while ((rssiup_status = SiHandleEvent(instrSession, &EventId, &lParam, &wParam)) == VI_SUCCESS)
            {
            /* Is error queue full? */
            if (instrPtr -> errorCount >= MAX_ERROR_QUEUE_LENGTH)
                break;
            /* Try to associate appropriate error descriptions */
            switch (EventId)
                {
                case MSG_OSE_INTERNAL_ERROR:

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Operating system internal error (0x%X).", wParam);


                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;

                    break;

                case MSG_DEVICE_ERROR:
                    {
                    static TStringValPair error_message[] =
                    {
                        {0x8010, "An unimplemented feature was accessed."},
                        {0x8020, "Unknown GDI identifier."},
                        {0x8025, "Invalid channel index."},
                        {0x8030, "Identifier and size do not correspond"},
                        {0x8040, "Invalid buffer content"},
                        {0x8041, "Debug message buffer (get) overflow."},
                        {0x8042, "Debug message buffer (put) overflow."},
                        {0xA010, "Unexpected type of signal received."},
                        {0xA011, "Invalid control signal buffer down."},
                        {0xA012, "Invalid control signal buffer up."},
                        {0xA013, "Invalid control signal default."},
                        {0xA014, "Invalid bulk signal buffer down."},
                        {0xA015, "Invalid bulk signal buffer up."},
                        {0xA016, "Invalid bulk signal default."},
                        {0xA017, "Invalid interrupt signal buffer down."},
                        {0xA018, "Invalid interrupt signal buffer up."},
                        {0xA019, "Invalid interrupt signal default."},
                        {0xA01F, "Invalid flash signal."},
                        {0xA020, "Incoming bulk buffer is corrupt."},
                        {0xA030, "Unknown control request."},
                        {0xA040, "Corrupt control batch"},
                        {0xFEFA, "Bad fill interrupt signal buffer up."},
                        {0xFEFD, "Bad fill interrupt signal buffer down."},
                        {0xFEFB, "Test interrupt error."},
                        {0xC010, "USB unknown signal."},
                        {0xC011, "USB EP0 unknown transfer type."},
                        {0xC012, "USB control signal up is not free."},
                        {0xC013, "USB signal setup request reserved."},
                        {0xC014, "USB EP0 mismatch transfer type."},
                        {0xC015, "USB EP0 unknown transfer direction."},
                        {0xC016, "USB EP0 unknown transfer request."},
                        {0xC017, "USB signal setup unknown direction."},
                        {0xC018, "USB buffer down, signal pipe 0 is null."},
                        {0xC019, "USB buffer up, signal pipe 0 is null."},
                        {0xC01A, "USB warning EP0 different data size."},
                        {0xC01B, "USB buffer up signal pipe x is null."},
                        {0xC01C, "USB send signal buffer up to control default."},
                        {0xC01D, "USB buffer up unknown EP type."},
                        {0xC020, "USB signal buffer up control transfer request standard."},
                        {0xC021, "USB signal buffer up control transfer request type default."},
                        {0xC022, "USB signal buffer up control transfer request bad EP."},
                        {0xC023, "USB signal buffer up trasfer type default."},
                        {0xC024, "USB signal buffer down control transfer request standard."},
                        {0xC025, "USB signal buffer down control transfer request type default."},
                        {0xC026, "USB signal buffer down control transfer request bad EP."},
                        {0xC027, "USB signal buffer down trasfer type default."},
                        /* Last element */
                        {0, NULL}
                    };

                    if ((IGNORE_OS_INTERNAL_ERROR_0xC01B == VI_TRUE) && (wParam == 0xC01B))
                        break;

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    for (idx = 0; error_message[idx].stringName; idx++)
                        if (error_message[idx].stringVal == wParam)
                            break;

                    if (!error_message[idx].stringName)
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Operating system internal error (0x%X).", wParam);
                    else
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Operating system internal error (0x%X). %s", wParam, error_message[idx].stringName);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }
                    break;

                case MSG_USB_ENUMERATION_STATUS:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "USB Enumeration Status (detect: 0x%X, state: 0x%X).", lParam, wParam);

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_SELFTEST:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        static TStringValPair test_name[] =
                            {
                                {0x00000000, "Self-test"},
                                {0x00000001, "Self-test FLASH"},
                                {0x00000002, "Self-test RAM"},
                                {0x00000004, "Self-test CPLD"},
                                {0x00000008, "Self-test DSP"},
                                {0x00000010, "Self-test I2C"},
                                {0x00000400, "Self-test Analog Board Monitor"},
                                {0x00000800, "Self-test Generator Board Monitor"},
                                {0x00001000, "Self-test Digital Board Monitor"},
                                {0x00002000, "Self-test PLL Lock"},
                                {0x04000000, "Self-test Signal DCPass"},
                                {0x08000000, "Self-test Signal ACTest"},
                                {0x10000000, "Self-test Signal Top Frequency"},
                                {0x20000000, "Self-test Signal THD Test"},
                                {0x40000000, "Self-test Signal THDN Test"},
                                {0x80000000, "Self-test Signal Discharge"},
                                /* Last element */
                                {0, NULL}
                            };

                        static TStringValPair action[] =
                            {
                                {0, "started"},
                                {1, "ended"},
                                {2, "skipped"},
                                {3, "OK"},
                                {4, "BAD"},
                                {5, "fatal error"},
                                {6, "prepared to start"},
                                {7, "post settings"},
                                /* Last element */
                                {0, NULL}
                            };

                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idx = 0; test_name[idx].stringName; idx++)
                            if (test_name[idx].stringVal == lParam)
                                break;

                        for (idy = 0; action[idy].stringName; idy++)
                            if (action[idy].stringVal == wParam)
                                break;

                        {
                        ViChar  tmp_1[64],
                                tmp_2[64];

                        sprintf (tmp_1, "Test name: 0x%X,", lParam);
                        sprintf (tmp_2, "action: 0x%X", wParam);

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Self-test info messages during the procedure (%s %s).",
                            (test_name[idx].stringName) ? test_name[idx].stringName : tmp_1,
                            (action[idy].stringName) ? action[idy].stringName : tmp_2);
                        }

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_SELFCALIBRATION:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        int lo_lParam = (short)lParam,
                            hi_lParam = (short)(lParam >> 16);

                        static TStringValPair hi_range[] =
                            {
                                {0xFFFF, "No range"},
                                /* Last element */
                                {0, NULL}
                            };

                        static TStringValPair lo_calib_name[] =
                            {
                                {0x0001, "Self calibration analyzer"},
                                {0x0002, "Self calibration generator"},
                                {0x0003, "Self calib analyzer & generator"},
                                /* Last element */
                                {0, NULL}
                            };

                        static TStringValPair action[] =
                            {
                                {0, "error"},
                                {1, "OK"},
                                {3, "started"},
                                {4, "range out of limit in ChA"},
                                {5, "range out of limit in ChB"},
                                {6, "remembered HW setting and stopped functions"},
                                {7, "set back HW setting and restored functions"},
                                {8, "offset calibration done"},
                                /* Last element */
                                {0, NULL}
                            };

                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idx = 0; hi_range[idx].stringName; idx++)
                            if (hi_range[idx].stringVal == hi_lParam)
                                break;

                        for (idy = 0; lo_calib_name[idy].stringName; idy++)
                            if (lo_calib_name[idy].stringVal == lo_lParam)
                                break;

                        for (idz = 0; action[idz].stringName; idz++)
                            if (action[idz].stringVal == wParam)
                                break;

                        {
                        ViChar  tmp_1[64],
                                tmp_2[64],
                                tmp_3[64];

                        sprintf (tmp_1, "Range: %d,", hi_lParam);
                        sprintf (tmp_2, "cal name: 0x%X,", lo_lParam);
                        sprintf (tmp_3, "action: %ld", wParam);

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Self calibration info messages during the procedure (%s %s %s).",
                            (hi_range[idx].stringName) ? hi_range[idx].stringName : tmp_1,
                            (lo_calib_name[idy].stringName) ? lo_calib_name[idy].stringName : tmp_2,
                            (action[idz].stringName) ? action[idz].stringName : tmp_3);
                        }

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_BOOT_STATUS:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        static TStringValPair mask[] =
                            {
                                {0x00000001, "BD HW version"},
                                {0x00000002, "PLL is locked"},
                                {0x00000004, "Reference oscillator init"},
                                {0x00000008, "DSP boot"},
                                {0x00000010, "FPGA boot"},
                                {0x00000020, "I2C init"},
                                {0x00000040, "analyzer supervisor init"},
                                {0x00000080, "generator supervisor init"},
                                {0x00000100, "digital supervisor init"},
                                {0x00000200, "DSP tasks init"},
                                {0x00000400, "baugruppen data all blocks load"},
                                /* Last element */
                                {0, NULL}
                            };

                        static TStringValPair action[] =
                            {
                                {14, " OK"},
                                {15, " BAD"},
                                /* Last element */
                                {0, NULL}
                            };

                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idx = 0; mask[idx].stringName; idx++)
                            if (mask[idx].stringVal == lParam)
                                break;

                        for (idy = 0; action[idy].stringName; idy++)
                            if (action[idy].stringVal == wParam)
                                break;

                        {
                        ViChar  tmp_1[64],
                                tmp_2[64];

                        sprintf (tmp_1, "mask: 0x%X,", lParam);
                        sprintf (tmp_2, "action: %ld", wParam);
                        
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Boot status info messages during the procedure (%s %s).",
                            (mask[idx].stringName) ? mask[idx].stringName : tmp_1,
                            (action[idy].stringName) ? action[idy].stringName : tmp_2);
                        }

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_BAUGRUPPENDATA_ACTION:

                    {
                    int lo_lParam = (short)lParam,
                        hi_lParam = (short)(lParam >> 16);
            
                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Baugruppen data action (Block ID: 0x%X, action: %ld, result: %d).",
                        hi_lParam, wParam, lo_lParam);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }

                    break;

                case MSG_DEVICE_STATUS:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Device status: %s.", ((short)lParam) == 0) ? "Idle" : "Busy";

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_NOT_IMPLEMENTED_ID:

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "An unimplemented DSP task 0x%X was accessed.", wParam);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;

                    break;

                case MSG_INVALID_REQUEST_ID:

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Unknown GDI identifier 0x%X was requested.", wParam);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;

                    break;

                case MSG_INVALID_CHANNEL:

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Invalid channel index (Request ID: 0x%X, channel: %d).", wParam, lParam);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    
                    break;

                case MSG_INVALID_SIZE:

                    {
                    int lo_lParam = (short)lParam,
                        hi_lParam = (short)(lParam >> 16);

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Incorrect size of data in request (Request ID: 0x%X, sent size: %d, correct size: %d).",
                        wParam, lo_lParam, hi_lParam);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }

                    break;

                case MSG_DSPTASK:
                case MSG_ANALYZER_DSP_TASK:
                case MSG_GENERATOR_DSP_TASK:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        static TStringValPair task_id[] =
                            {
                                {0x0101,        "Load input data"},
                                {MEAS_PEAK,     "Peak value measurement"},
                                {0x0104,        "Digital filter"},
                                {MEAS_RMSSEL,   "RMS selective"},
                                {MEAS_QPEAK,    "QPeak"},
                                {0x010C,        "THDN ChA"},
                                {0x010D,        "THDN ChB"},
                                {0x010E,        "RMS average frequency"},
                                {0x010F,        "Polarity"},
                                {0x0201,        "Single sine"},
                                {0x0202,        "Store output data"},
                                {0x0204,        "Arbitrary waveform"},
                                {0x0205,        "Multisine waveform"},
                                {0x0206,        "Sine burst"},
                                {0x0207,        "Noise"},
                                {0x0208,        "Sine burst 2"},
                                {0x031D,        "Audio monitor"},
                                {0x0350,        "THDpmN"},
                                {0x0351,        "PhaseMuTsk"},
                                {0x0352,        "DFDMuTsk"},
                                {0x0353,        "ModDist"},
                                {0x0354,        "FFTMuTsk"},
                                {0x0355,        "RMSSelMuTsk"},
                                {0x0401,        "Sampling frequency"},
                                {0x0402,        "DAI protocol"},
                                /* Last element */
                                {0, NULL}
                            };

                        static TStringValPair what[] =
                            {
                                {TASK_ERROR,                                    "task error"},
                                {TASK_OK,                                       "task ok"},
                                {TASK_BAD_STATUS,                               "task bad status"},
                                {TASK_HANDSHAKE,                                "task handshake"},
                                {TASK_ALREADY,                                  "task already"},
                                {TASK_INT_MEM,                                  "task int memory"},
                                {TASK_EXT_MEM,                                  "task ext memory"},
                                {TASK_MISMATCH,                                 "task mismatch"},
                                {TASK_REPAIR,                                   "task repair"},
                                {DSP_TASK_LOAD,                                 "DSP task load"},
                                {DSP_TASK_INIT,                                 "DSP task init"},
                                {DSP_TASK_REINIT,                               "DSP task reinit"},
                                {DSP_TASK_STOP,                                 "DSP task stop"},
                                {DSP_TASK_UNLOAD,                               "DSP task unload"},
                                {DSP_TASK_SETPARAM,                             "DSP task setparam"},
                                {DSP_TASK_INCLUDE,                              "DSP task include"},
                                {DSP_TASK_FREE,                                 "DSP task free"},
                                {DSP_TASK_CONNECT,                              "DSP task connect"},
                                {DSP_TASK_DISCONNECT,                           "DSP task disconnect"},
                                {DSP_TASK_RESULT,                               "DSP task result"},
                                {DSP_TASK_DELETE_FROM_INIT_TABLE,               "DSP task delete from init table"},
                                {DSP_TASK_ADD_TO_INIT_TABLE,                    "DSP task add to init table"},
                                {(DSP_TASK_LOAD | TASK_OK),                     "was successfully loaded"},
                                {(DSP_TASK_INIT | TASK_OK),                     "was successfully initiated"},
                                {(DSP_TASK_REINIT | TASK_OK),                   "was successfully reinitiated"},
                                {(DSP_TASK_STOP | TASK_OK),                     "was successfully stopped"},
                                {(DSP_TASK_UNLOAD | TASK_OK),                   "was successfully unloaded"},
                                {(DSP_TASK_SETPARAM | TASK_OK),                 "was successfully setparameter"},
                                {(DSP_TASK_INCLUDE | TASK_OK),                  "was successfully included"},
                                {(DSP_TASK_FREE | TASK_OK),                     "was successfully freed"},
                                {(DSP_TASK_CONNECT | TASK_OK),                  "was successfully connected"},
                                {(DSP_TASK_DISCONNECT | TASK_OK),               "was successfully disconnected"},
                                {(DSP_TASK_RESULT | TASK_OK),                   "was successfully read result but with timeout"},
                                {(DSP_TASK_DELETE_FROM_INIT_TABLE | TASK_OK),   "was successfully deleted from init table"},
                                {(DSP_TASK_ADD_TO_INIT_TABLE | TASK_OK),        "was successfully added to init table"},
                                {(DSP_TASK_LOAD | TASK_ERROR),                  "cannot load"},
                                {(DSP_TASK_INIT | TASK_ERROR),                  "cannot init"},
                                {(DSP_TASK_REINIT | TASK_ERROR),                "cannot reinit"},
                                {(DSP_TASK_STOP | TASK_ERROR),                  "cannot stop"},
                                {(DSP_TASK_UNLOAD | TASK_ERROR),                "cannot unload"},
                                {(DSP_TASK_SETPARAM | TASK_ERROR),              "cannot set parameter"},
                                {(DSP_TASK_INCLUDE | TASK_ERROR),               "cannot include"},
                                {(DSP_TASK_FREE | TASK_ERROR),                  "cannot free"},
                                {(DSP_TASK_CONNECT | TASK_ERROR),               "cannot connect"},
                                {(DSP_TASK_DISCONNECT | TASK_ERROR),            "cannot disconnect"},
                                {(DSP_TASK_RESULT | TASK_ERROR),                "cannot read DSP task result"},
                                {(DSP_TASK_DELETE_FROM_INIT_TABLE | TASK_ERROR),    "cannot delete fro init table"},
                                {(DSP_TASK_ADD_TO_INIT_TABLE | TASK_ERROR),     "cannot add to init table"},
                                {(DSP_TASK_LOAD | TASK_BAD_STATUS),             "cannot load for bad task status"},
                                {(DSP_TASK_INIT | TASK_BAD_STATUS),             "cannot init for bad task status"},
                                {(DSP_TASK_REINIT | TASK_BAD_STATUS),           "cannot reinit for bad task status"},
                                {(DSP_TASK_STOP | TASK_BAD_STATUS),             "cannot stop for bad task status"},
                                {(DSP_TASK_UNLOAD | TASK_BAD_STATUS),           "cannot unload for bad task status"},
                                {(DSP_TASK_INCLUDE | TASK_BAD_STATUS),          "cannot include for bad task status"},
                                {(DSP_TASK_FREE | TASK_BAD_STATUS),             "cannot free for bad task status"},
                                {(DSP_TASK_CONNECT | TASK_ALREADY),             "cannot connect because task already connected to other task"},
                                {(DSP_TASK_DISCONNECT | TASK_ALREADY),          "cannot disconnect because task is already disconnected"},
                                {(DSP_TASK_DISCONNECT | TASK_REPAIR),           "warning in disconnect & connect mismatch was repaired"},
                                {(DSP_TASK_DISCONNECT | TASK_MISMATCH),         "cannot disconect because task is last line"},
                                {(DSP_TASK_DELETE_FROM_INIT_TABLE | TASK_BAD_STATUS),   "cannot delete from init table for bad status"},
                                {(DSP_TASK_ADD_TO_INIT_TABLE | TASK_BAD_STATUS),        "cannot add to init table for bad status"},
                                {(DSP_TASK_ADD_TO_INIT_TABLE | TASK_ALREADY),   "cannot add to init table because there already in not space"},
                                {(DSP_TASK_RESULT | TASK_BAD_STATUS),           "cannot read DSP task result, count of results is zero"},
                                {(DSP_TASK_RESULT | TASK_ALREADY),              "cannot read DSP task result, no result available"},
                                {(DSP_TASK_RESULT | TASK_INT_MEM),              "cannot read DSP task result from internal memory"},
                                {(DSP_TASK_RESULT | TASK_EXT_MEM),              "cannot read DSP task result from external memory"},
                                {(DSP_TASK_RESULT | TASK_HANDSHAKE),            "cannot read DSP task result, no handshake"},
                                /* Last element */
                                {0, NULL}
                            };

                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idx = 0; task_id[idx].stringName; idx++)
                            if (task_id[idx].stringVal == lParam)
                                break;

                        for (idy = 0; what[idy].stringName; idy++)
                            if (what[idy].stringVal == wParam)
                                break;

                        switch (EventId)
                            {
                            case MSG_DSPTASK:
                                {
                                ViChar  tmp_1[64],
                                        tmp_2[64];

                                sprintf (tmp_1, "Task ID: 0x%X,", lParam);
                                sprintf (tmp_2, "what: 0x%X", wParam);
                        
                                sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                                    "Common change of DSP task state (%s %s).",
                                    (task_id[idx].stringName) ? task_id[idx].stringName : tmp_1,
                                    (what[idy].stringName) ? what[idy].stringName : tmp_2);
                                }
                                break;
                            case MSG_ANALYZER_DSP_TASK:
                                {
                                ViChar  tmp_1[64],
                                        tmp_2[64],
                                        tmp_3[64];

                                int lo_lParam = (short)lParam,
                                    hi_lParam = (short)(lParam >> 16);

                                sprintf (tmp_1, "Task ID (source): 0x%X,", hi_lParam);
                                sprintf (tmp_2, "task ID (destination): 0x%X,", lo_lParam);
                                sprintf (tmp_3, "what: 0x%X", wParam);

                                for (idx = 0; task_id[idx].stringName; idx++)
                                    if (task_id[idx].stringVal == hi_lParam)
                                        break;

                                for (idz = 0; task_id[idz].stringName; idz++)
                                    if (task_id[idz].stringVal == lo_lParam)
                                        break;

                                sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                                    "Change of analyzer's task connection (%s -> %s %s).",
                                    (task_id[idx].stringName) ? task_id[idx].stringName : tmp_1,
                                    (task_id[idz].stringName) ? task_id[idz].stringName : tmp_2,
                                    (what[idy].stringName) ? what[idy].stringName : tmp_3);
                                }
                            case MSG_GENERATOR_DSP_TASK:
                            default:
                                {
                                ViChar  tmp_1[64],
                                        tmp_2[64],
                                        tmp_3[64];

                                int lo_lParam = (short)lParam,
                                    hi_lParam = (short)(lParam >> 16);

                                sprintf (tmp_1, "Task ID (last): 0x%X,", hi_lParam);
                                sprintf (tmp_2, "task ID (new): 0x%X,", lo_lParam);
                                sprintf (tmp_3, "what: 0x%X", wParam);

                                for (idx = 0; task_id[idx].stringName; idx++)
                                    if (task_id[idx].stringVal == hi_lParam)
                                        break;

                                for (idz = 0; task_id[idz].stringName; idz++)
                                    if (task_id[idz].stringVal == lo_lParam)
                                        break;

                                sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                                    "Change of generator's task connection (%s -> %s %s).",
                                    (task_id[idx].stringName) ? task_id[idx].stringName : tmp_1,
                                    (task_id[idz].stringName) ? task_id[idz].stringName : tmp_2,
                                    (what[idy].stringName) ? what[idy].stringName : tmp_3);
                                }
                                break;
                            }

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_INVALID_PRECONDITION:

                    {
                    static TStringValPair precondition[] =
                        {
                            {0x0001, "Single sine"},
                            {0x0002, "Digital filter"},
                            {0x0003, "Any anlyzer function"},
                            {0x0004, "Any generator function"},
                            /* Last element */
                            {0, NULL}
                        };

                    static TStringValPair what[] =
                        {
                            {0x0001, "unrunning task for synchro setting"},
                            {0x0002, "over BiQuad"},
                            {0x0003, "is running"},
                            {0x0004, "anlyzer function crossing"},
                            /* Last element */
                            {0, NULL}
                        };

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    for (idx = 0; precondition[idx].stringName; idx++)
                        if (precondition[idx].stringVal == lParam)
                            break;

                    for (idy = 0; what[idy].stringName; idy++)
                        if (what[idy].stringVal == wParam)
                            break;

                    {
                    ViChar  tmp_1[64],
                            tmp_2[64];

                    sprintf (tmp_1, "Precondition: 0x%X,", lParam);
                    sprintf (tmp_2, "what: 0x%X", wParam);

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Invalid precondition, settings conflict (%s %s).",
                        (precondition[idx].stringName) ? precondition[idx].stringName : tmp_1,
                        (what[idy].stringName) ? what[idy].stringName : tmp_2);
                    }

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }

                    break;

                case MSG_GENERATOR_RANGE_SET:
                
                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Set range on generator (Range: %ld, Channel: %d).",
                            lParam, wParam);

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_GENERATOR_AMPLITUDE:
                case MSG_GENERATOR_AMPLITUDE_NO_CHANNEL:
                case MSG_GENERATOR_AMPLITUDE_CHANNEL_B:
                case MSG_GENERATOR_AMPLITUDE_CHANNEL_A:
                case MSG_GENERATOR_AMPLITUDE_CHANNEL_AB:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        static TStringValPair message[] =
                            {
                                {MSG_GENERATOR_AMPLITUDE, ""},
                                {MSG_GENERATOR_AMPLITUDE_NO_CHANNEL, "no channel "},
                                {MSG_GENERATOR_AMPLITUDE_CHANNEL_B, "ChB "},
                                {MSG_GENERATOR_AMPLITUDE_CHANNEL_A, "ChA "},
                                {MSG_GENERATOR_AMPLITUDE_CHANNEL_AB, "ChAB "},
                                /* Last element */
                                {0, NULL}
                            };

                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idx = 0; message[idx].stringName; idx++)
                            if (message[idx].stringVal == EventId)
                                break;

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Generator change of amplitude %s(0x%X, 0x%X).",
                            (message[idx].stringName) ? message[idx].stringName : "",
                            lParam, wParam);

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_ANALYZER_BAD_STATUS:
                case MSG_ANALYZER_BAD_PARAMETER:

                    {
                    static TStringValPair status[] =
                        {
                            { 0, "stoped"},
                            { 1, "running"},
                            {-1, "changing"},
                            {-2, "error"},
                            /* Last element */
                            {0, NULL}
                        };

                    static TStringValPair function[] =
                        {
                            {0x0040, "Wave, measurement times"},
                            {0x0041, "Wave, waveform settings"},
                            {0x0042, "Wave, oversampling mode"},
                            {0x0043, "Wave, postfilter trigger setting"},
                            {0x0044, "Wave, data reduction setting"},
                            {0x0050, "Peak"},
                            {0x0051, "Peak, setting"},
                            {0x0052, "Peak, averanging"},
                            {0x0060, "QPeak"},
                            {0x0061, "QPeak, setting"},
                            {0x0070, "Polarity"},
                            {0x0080, "RMSSel"},
                            {0x0081, "RMSSel, setting"},
                            {0x0082, "RMSSel, averanging"},
                            {0x0088, "RMSSel Multitask"},
                            {0x0089, "RMSSel Multitask, channel setting"},
                            {0x008A, "RMSSel Multitask, non channel setting"},
                            {0x008B, "RMSSel Multitask, all params"},
                            {0x0090, "RMSDC"},
                            {0x0092, "RMSDC, meas times and wideband setting"},
                            {0x0093, "RMSDC, averaging"},
                            {0x00A0, "Synchro Source"},
                            {0x00B0, "THDN"},
                            {0x00B1, "THDN, meas times"},
                            {0x00B2, "THDN, setting"},
                            {0x00B3, "THDN, averaging"},
                            {0x00B4, "THDN, setting center frequency"},
                            {0x00B5, "THDN, copy filter coefficients"},
                            {0x00D0, "THDpmN"},
                            {0x00D1, "THDpmN, setting"},
                            {0x00E0, "PhaseMuTsk"},
                            {0x00E1, "PhaseMuTsk, setting"},
                            {0x00F0, "DFDMuTsk"},
                            {0x00F1, "DFDMuTsk, setting"},
                            {0x0100, "ModDist"},
                            {0x0101, "ModDist, setting"},
                            {0x0110, "Digital Filter"},
                            {0x0111, "Digital Filter, setting"},
                            {0x0120, "User Filter"},
                            {0x0121, "User Filter, setting"},
                            {0x0130, "Digital Loopback"},
                            {0x0131, "Digital Loopback, setting"},
                            {0x0140, "FFTMuTsk"},
                            {0x0141, "FFTMuTsk, setting"},
                            {0x0150, "Sampl Frequency"},
                            {0x0151, "Sampl Frequency, setting"},
                            {0x0152, "Sampl Frequency, averaging"},
                            {0x0160, "DAI Protocol"},
                            {0x0161, "DAI Protocol, setting"},
							{0x0170, "Analyzer Sweep RMS"},
							{0x0171, "Analyzer Sweep RMS Meas Times And Wideband Setting"},
							{0x0172, "Analyzer Sweep RMS Averaging"},
							{0x0173, "Analyzer Sin RMS Sweep Sweep Set"},
							{0x0174, "Analyzer Sin RMS Sweep Gen Set"},
							{0x0175, "Analyzer Sin RMS Sweep Anl Chan Set"},
							{0x0176, "Analyzer Sin RMS Sweep Anl No Ch Set"},
							{0x0190, "Analyzer Sweep THD"},
							{0x0191, "Analyzer Sweep THD Setting"},
							{0x0193, "Analyzer Sin THD Sweep Sweep Set"},
							{0x0194, "Analyzer Sin THD Sweep Gen Set"},
							{0x0195, "Analyzer Sin THD Sweep Anl Chan Set"},
							{0x0196, "Analyzer Sin THD Sweep Anl No Ch Set"},
							{0x0210, "Analyzer Sweep RMS Selective"},
							{0x0211, "Analyzer Sweep RMS Selective No Ch Setting"},
							{0x0212, "Analyzer Sweep RMS Selective Chan Setting"},
							{0x0213, "Analyzer Sin RMS Selective Sweep Sweep Set"},
							{0x0214, "Analyzer Sin RMS Selective Sweep Gen Set"},
							{0x0215, "Analyzer Sin RMS Selective Sweep Anl Chan Set"},
							{0x0216, "Analyzer Sin RMS Selective Sweep Anl No Ch Set"},
                            /* Last element */
                            {0, NULL}
                        };

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    for (idx = 0; status[idx].stringName; idx++)
                        if (status[idx].stringVal == lParam)
                            break;

                    for (idy = 0; function[idy].stringName; idy++)
                        if (function[idy].stringVal == wParam)
                            break;

                    {
                    ViChar  tmp_1[64],
                            tmp_2[64];

                    sprintf (tmp_1, "Status: %ld,", lParam);
                    sprintf (tmp_2, "function: 0x%X", wParam);
                    
                    if (EventId == MSG_ANALYZER_BAD_STATUS)
                        {
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Bad status of analyzer function (%s is %s).",
                            (function[idy].stringName) ? function[idy].stringName : tmp_2,
                            (status[idx].stringName) ? status[idx].stringName : tmp_1);
                        }
                    else /* MSG_ANALYZER_BAD_PARAMETER */
                        {
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Parameter in analyzer setting command is out of limits (%s).",
                            (function[idy].stringName) ? function[idy].stringName : tmp_2);
                        }
                    }

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }

                    break;

                case MSG_INVALID_VALUE:

                    {
                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Invalid buffer content (lParam: 0x%X, wParam: 0x%X).",
                        lParam, wParam);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }
                    
                    break;

                case MSG_INVALID_COMMAND:

                    {
                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Unknown GDI identifier (lParam: 0x%X, wParam: 0x%X).",
                        lParam, wParam);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }
                    
                    break;

                case MSG_INVALID_RANGE:

                    {
                    ViChar  tmp_1[64];

                    static TStringValPair parameter[] =
                        {
                            {1, "parameter value out of range"},
                            {2, "generator max amplitude out of range"},
                            {3, "analyzer function ID out of range"},
                            /* Last element */
                            {0, NULL}
                        };

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    for (idx = 0; parameter[idx].stringName; idx++)
                        if (parameter[idx].stringVal == lParam)
                            break;

                    sprintf (tmp_1, "parameter: %ld", lParam);

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Invalid range (Request ID: 0x%X, %s).",
                        wParam, (parameter[idx].stringName) ? parameter[idx].stringName : tmp_1);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }
                    
                    break;

                case MSG_UNKNOW_NAME:

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Unknown name of generator  function (Request ID: 0x%X).", wParam);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    
                    break;

                case MSG_INVALID_DSP_TASK:

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Invalid DSP task control command (Task ID: 0x%X, service cmd: 0x%X).",
                        lParam, wParam);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    
                    break;
                
                case MSG_GENERATOR_ERROR:

                    {
                    ViChar  tmp_1[64];

                    static TStringValPair parameter[] =
                        {
                            {4, "not started"},
                            {5, "not stopped"},
                            /* Last element */
                            {0, NULL}
                        };

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    for (idx = 0; parameter[idx].stringName; idx++)
                        if (parameter[idx].stringVal == lParam)
                            break;

                    sprintf (tmp_1, "parameter: %ld", lParam);

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Internal error at generator switch on/off function (Request ID: 0x%X, %s).",
                        wParam, (parameter[idx].stringName) ? parameter[idx].stringName : tmp_1);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }
                    
                    break;
                
                case MSG_SYSTEM_ERROR:

                    {
                    ViChar  tmp_1[64];

                    static TStringValPair parameter[] =
                        {
                            {1, "float point trap"},
                            {2, "division by zero"},
                            {3, "access to odd addr"},
                            {4, "stack underflow"},
                            {5, "stack overflow"},
                            {6, "error queue overflow"},
                            /* Last element */
                            {0, NULL}
                        };

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    for (idx = 0; parameter[idx].stringName; idx++)
                        if (parameter[idx].stringVal == wParam)
                            break;

                    sprintf (tmp_1, "parameter: %ld", wParam);

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Internal system error (Trap code or queue size: %ld, %s).",
                        lParam, (parameter[idx].stringName) ? parameter[idx].stringName : tmp_1);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }
                    
                    break;

                case MSG_ANALYZER_RANGE_SET:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Set range on analyzer (Range: %ld, Channel: %d).",
                            lParam, wParam);

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;
                    
                case MSG_PLL_LOCK:
                
                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "PLL is unlocked (System ticks: %ld).", lParam);

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_INTERRUPT_EVENT:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Interrupt event from external source %s.", (wParam == 1) ? "EXT1" : "EXT0");

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_ANALYZER_OVERDETECTOR:
                case MSG_GENERATOR_OVERDETECTOR:

#if IGNORE_MSG_DIGITAL_BOARD_OVERDETECTOR != VI_TRUE

                case MSG_DIGITAL_BOARD_OVERDETECTOR:

#endif
                    {
                    static TStringValPair source[] =
                        {
                            {0x0001, "Temperature"},
                            {0x0002, "Over temperature ChA"},
                            {0x0004, "Over temperature ChB"},
                            {0x0008, "Voltage +/-15V"},
                            {0x0010, "Voltage +5V"},
                            {0x0020, "Voltage analog +/-5V or digital +5.5V"},
                            {0x0040, "Voltage analog +/-3.3V or digital 1.8V"},
                            {0x0080, "Voltage GND"},
                            {0x0100, "Overload ChA"},
                            {0x0200, "Overload ChB"},
                            {0x0400, "Voltage -5.5V"},
                            {0x0800, "Voltage -15V"},
                            {0x1000, "Voltage +15V"},
                            {0x2000, "Voltage generator output"},
                            {0x4000, "Voltage generator PLL"},
                            {0x8000, "Voltage generator reference"},
                            /* Last element */
                            {0, NULL}
                        };

                    static TStringValPair event[] =
                        {
                            {0x0, "emergence"},
                            {0x1, "internal timeout exceeded"},
                            /* Last element */
                            {0, NULL}
                        };

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    for (idx = 0; source[idx].stringName; idx++)
                        if (source[idx].stringVal == lParam)
                            break;

                    for (idy = 0; event[idy].stringName; idy++)
                        if (event[idy].stringVal == wParam)
                            break;

                    {
                    ViChar  tmp_1[64],
                            tmp_2[64],
                            board[64];

                    switch (EventId)
                        {
                        case MSG_ANALYZER_OVERDETECTOR:
                            sprintf (board, "analyzer");
                            break;
                        case MSG_GENERATOR_OVERDETECTOR:
                            sprintf (board, "generator");
                            break;
                        case MSG_DIGITAL_BOARD_OVERDETECTOR:
                        default:
                            sprintf (board, "digital");
                            break;
                        }

                    sprintf (tmp_1, "Source: 0x%X,", lParam);
                    sprintf (tmp_2, "event: 0x%X", wParam);

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Error emergence on supervisor measurement on the %s board (%s %s).", board,
                        (source[idx].stringName) ? source[idx].stringName : tmp_1,
                        (event[idy].stringName) ? event[idy].stringName : tmp_2);
                    }

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }

                    break;

                case MSG_CENTRAL_DEBUGGING_TRAP:

                    {
                    static TStringValPair exception[] =
                        {
                            {MSG_CENTRAL_DEBUGGING_TRAP_BUFFER_POOL,    "Buffer pool"},
                            {MSG_CENTRAL_DEBUGGING_TRAP_FPGA,           "FPGA"},
                            {MSG_CENTRAL_DEBUGGING_TRAP_I2C,            "I2C"},
                            {MSG_CENTRAL_DEBUGGING_TRAP_DEVICE,         "Device"},
                            {MSG_CENTRAL_DEBUGGING_TRAP_BUFFER_DSP,     "DSP"},
                            {MSG_CENTRAL_DEBUGGING_TRAP_ANL_FUNCTION,   "Analyzer function"},
                            {MSG_CENTRAL_DEBUGGING_TRAP_MSG_BUFFER,     "GDI message buffer"},
                            /* Last element */
                            {0, NULL}
                        };

                    static TStringErrorPair what_exception[32];
                    
                    memset (what_exception, 0, 32 * sizeof (what_exception[0]));
                    
                    switch (wParam)
                        {
                        case MSG_CENTRAL_DEBUGGING_TRAP_BUFFER_POOL:
                            what_exception[0].stringVal = 1;
                            strcpy (what_exception[0].stringName, "locked");
                            what_exception[1].stringVal = 2;
                            strcpy (what_exception[1].stringName, "big size of data");
                            what_exception[2].stringVal = 3;
                            strcpy (what_exception[2].stringName, "different task name");
                            what_exception[3].stringVal = 4;
                            strcpy (what_exception[3].stringName, "write to transmitting");
                            what_exception[4].stringVal = 5;
                            strcpy (what_exception[4].stringName, "read zero size");
                            what_exception[5].stringVal = 6;
                            strcpy (what_exception[5].stringName, "read empty");
                            what_exception[6].stringVal = 7;
                            strcpy (what_exception[6].stringName, "bad size for read");
                            what_exception[7].stringVal = 8;
                            strcpy (what_exception[7].stringName, "unknown function ID");
                            what_exception[8].stringVal = 9;
                            strcpy (what_exception[8].stringName, "DWA is null");
                            what_exception[9].stringVal = 10;
                            strcpy (what_exception[9].stringName, "test");
                            what_exception[10].stringVal = 11;
                            strcpy (what_exception[10].stringName, "bad status put");
                            what_exception[11].stringVal = 12;
                            strcpy (what_exception[11].stringName, "bad status get");
                            break;
                        case MSG_CENTRAL_DEBUGGING_TRAP_FPGA:
                        case MSG_CENTRAL_DEBUGGING_TRAP_I2C:
                        case MSG_CENTRAL_DEBUGGING_TRAP_DEVICE:
                        case MSG_CENTRAL_DEBUGGING_TRAP_MSG_BUFFER:
                            what_exception[0].stringVal = 1;
                            strcpy (what_exception[0].stringName, "locked");
                            break;
                        case MSG_CENTRAL_DEBUGGING_TRAP_BUFFER_DSP:
                            what_exception[0].stringVal = 1;
                            strcpy (what_exception[0].stringName, "locked");
                            what_exception[1].stringVal = 6;
                            strcpy (what_exception[1].stringName, "reading under ext memory");
                            what_exception[2].stringVal = 7;
                            strcpy (what_exception[2].stringName, "reading over ext memory");
                            what_exception[3].stringVal = 8;
                            strcpy (what_exception[3].stringName, "writing under ext memory");
                            what_exception[4].stringVal = 9;
                            strcpy (what_exception[4].stringName, "writing over ext memory");
                            what_exception[5].stringVal = 10;
                            strcpy (what_exception[5].stringName, "reading outside DSP memory");
                            what_exception[6].stringVal = 11;
                            strcpy (what_exception[6].stringName, "writing outside DSP memory");
                            what_exception[7].stringVal = 20;
                            strcpy (what_exception[7].stringName, "give me arbiter timeout");
                            what_exception[8].stringVal = 21;
                            strcpy (what_exception[8].stringName, "transfer is done timeout");
                            what_exception[9].stringVal = 22;
                            strcpy (what_exception[9].stringName, "DMA end error 1");
                            what_exception[10].stringVal = 23;
                            strcpy (what_exception[10].stringName, "DMA end error 2");
                            what_exception[11].stringVal = 24;
                            strcpy (what_exception[11].stringName, "transfer is done IEN error");
                            break;
                        case MSG_CENTRAL_DEBUGGING_TRAP_ANL_FUNCTION:
                            what_exception[0].stringVal = 20;
                            strcpy (what_exception[0].stringName, "THDpmN mismatch Res N");
                            what_exception[1].stringVal = 21;
                            strcpy (what_exception[1].stringName, "THDpmN mismatch Res 1");
                            what_exception[2].stringVal = 22;
                            strcpy (what_exception[2].stringName, "THDpmN mismatch Res 2");
                            what_exception[3].stringVal = 23;
                            strcpy (what_exception[3].stringName, "THDpmN mismatch Res 3");
                            what_exception[4].stringVal = 24;
                            strcpy (what_exception[4].stringName, "THDpmN mismatch Res 4");
                            what_exception[5].stringVal = 30;
                            strcpy (what_exception[5].stringName, "DFDMuTsk mismatch Res N");
                            what_exception[6].stringVal = 31;
                            strcpy (what_exception[6].stringName, "DFDMuTsk mismatch Res 1");
                            what_exception[7].stringVal = 32;
                            strcpy (what_exception[7].stringName, "DFDMuTsk mismatch Res 2");
                            what_exception[8].stringVal = 33;
                            strcpy (what_exception[8].stringName, "DFDMuTsk mismatch Res 3");
                            what_exception[9].stringVal = 34;
                            strcpy (what_exception[9].stringName, "DFDMuTsk mismatch Res 4");
                            what_exception[10].stringVal = 40;
                            strcpy (what_exception[10].stringName, "ModDistMuTsk mismatch Res N");
                            what_exception[11].stringVal = 41;
                            strcpy (what_exception[11].stringName, "ModDistMuTsk mismatch Res 1");
                            what_exception[12].stringVal = 42;
                            strcpy (what_exception[12].stringName, "ModDistMuTsk mismatch Res 2");
                            what_exception[13].stringVal = 43;
                            strcpy (what_exception[13].stringName, "ModDistMuTsk mismatch Res 3");
                            what_exception[14].stringVal = 44;
                            strcpy (what_exception[14].stringName, "ModDistMuTsk mismatch Res 4");
                            what_exception[15].stringVal = 50;
                            strcpy (what_exception[15].stringName, "PhaseMuTsk mismatch Res N");
                            what_exception[16].stringVal = 51;
                            strcpy (what_exception[16].stringName, "PhaseMuTsk mismatch Res 1");
                            what_exception[17].stringVal = 52;
                            strcpy (what_exception[17].stringName, "PhaseMuTsk mismatch Res 2");
                            what_exception[18].stringVal = 53;
                            strcpy (what_exception[18].stringName, "PhaseMuTsk mismatch Res 3");
                            what_exception[19].stringVal = 54;
                            strcpy (what_exception[19].stringName, "PhaseMuTsk mismatch Res 4");
                            what_exception[20].stringVal = 60;
                            strcpy (what_exception[20].stringName, "FFTMuTsk mismatch Res N");
                            what_exception[21].stringVal = 61;
                            strcpy (what_exception[21].stringName, "FFTMuTsk mismatchRes 1");
                            what_exception[22].stringVal = 62;
                            strcpy (what_exception[22].stringName, "FFTMuTsk mismatch Res 2");
                            what_exception[23].stringVal = 63;
                            strcpy (what_exception[23].stringName, "FFTMuTsk mismatch Res 3");
                            what_exception[24].stringVal = 64;
                            strcpy (what_exception[24].stringName, "FFTMuTsk mismatch Res 4");
                            break;
                        default:
                            break;
                        }

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    for (idx = 0; exception[idx].stringName; idx++)
                        if (exception[idx].stringVal == wParam)
                            break;

                    for (idy = 0; what_exception[idy].stringVal > 0; idy++)
                        if (what_exception[idy].stringVal == lParam)
                            break;

                    {
                    ViChar  tmp_1[64],
                            tmp_2[64];

                    sprintf (tmp_1, "wParam: 0x%X", wParam);
                    sprintf (tmp_2, "lParam: 0x%X,", lParam);
                    
                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Central debugging trap, progrem exception (%s %s).",
                        (exception[idx].stringName) ? exception[idx].stringName : tmp_1,
                        (strlen (what_exception[idy].stringName)) ? what_exception[idy].stringName : tmp_2);
                    }

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }

                    break;
                
                case MSG_FLUSH_BUFFER_POOL:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        static TStringValPair function[] =
                            {
                                {MEAS_PEAK,                     "Peak"},
                                {MEAS_QPEAK,                    "QPeak"},
                                {MEAS_RMSSEL,                   "RMS selective"},
                                {MEAS_DAI_SAMPLING_FREQUENCY,   "Sampling frequency"},
                                {MEAS_DAI_PROTOCOL,             "DAI protocol"},
                                {MEAS_RMSDC,                    "RMS"},
                                {0x210C,                        "THDN ChA"},
                                {0x210D,                        "THDN ChB"},
                                {0x2108,                        "Waveform dual"},
                                {0x2301,                        "Wave data red ChA"},
                                {0x2314,                        "Wave data red ChB"},
                                {0x210F,                        "Polarity"},
                                {MEAS_THDN,                     "THDpmN"},
                                {MEAS_THDN_POST_FFT,            "THDpmN FFT"},
                                {MEAS_THDN_REDUCED_FFT,         "THDpmN data red"},
                                {MEAS_PHASE,                    "PhaseMuTsk"},
                                {MEAS_PHASE_POST_FFT,           "PhaseMuTsk FFT"},
                                {MEAS_PHASE_REDUCED_FFT,        "PhaseMuTsk data red"},
                                {MEAS_DFD,                      "DFDMuTsk"},
                                {MEAS_DFD_POST_FFT,             "DFDMuTsk FFT"},
                                {MEAS_DFD_REDUCED_FFT,          "DFDMuTsk data red"},
                                {MEAS_MOD_DIST,                 "ModDist"},
                                {MEAS_MOD_DIST_POST_FFT,        "ModDist FFT"},
                                {MEAS_MOD_DIST_REDUCED_FFT,     "ModDist data red"},
                                {0x3354,                        "FFTMuTsk"},
                                {MEAS_FFT,                      "FFTMuTsk FFT"},
                                {MEAS_FFT_REDUCED,              "FFTMuTsk data red"},
                                {MEAS_RMSSEL_MUTSK,             "RMSSelMuTsk"},
                                {MEAS_RMSSEL_MUTSK_FFT,         "RMSSelMuTsk FFT"},
                                {MEAS_RMSSEL_MUTSK_REDUCED_FFT,	"RMSSelMuTsk data red"},
                                {MEAS_RMS_SELECTIVE_SWEEP,		"Sin RSm Sweep"},
                                {MEAS_THD_SWEEP,				"Sin Thd Sweep"},
                                {MEAS_RMS_SWEEP,				"Sin Rms Sweep"},
                                /* Last element */
                                {0, NULL}
                            };

                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idx = 0; function[idx].stringName; idx++)
                            if (function[idx].stringVal == lParam)
                                break;

                        {
                        ViChar  tmp_1[64];
                        
                        sprintf (tmp_1, "Function ID: %ld", lParam);
                        
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Cleaning the respective part in buffer pool (%s, %d).",
                            (function[idx].stringName) ? function[idx].stringName : tmp_1, wParam);
                        }

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_ANALYZER_OVERRANGE:
                
                    {
                    ViChar  tmp_1[64];

                    static TStringValPair parameter[] =
                        {
                            {1, "ChA"},
                            {2, "ChB"},
                            {3, "ChAB"},
                            /* Last element */
                            {0, NULL}
                        };

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    for (idx = 0; parameter[idx].stringName; idx++)
                        if (parameter[idx].stringVal == lParam)
                            break;

                    sprintf (tmp_1, "Channel: %ld", lParam);

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Analyzer input overrange (%s).",
                        (parameter[idx].stringName) ? parameter[idx].stringName : tmp_1);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;
                    }
                    
                    break;

                case MSG_FPGA_ARBITER:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        ViChar  tmp_1[64];

                        static TStringValPair parameter[] =
                            {
                                {1, "timeout not ready"},
                                {2, "timeout is running"},
                                /* Last element */
                                {0, NULL}
                            };

                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idx = 0; parameter[idx].stringName; idx++)
                            if (parameter[idx].stringVal == lParam)
                                break;

                        sprintf (tmp_1, "lParam: 0x%X, wParam: 0x%X", lParam, wParam);

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Bus arbiter DMA handling (%s).",
                            (parameter[idx].stringName) ? parameter[idx].stringName : tmp_1);

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }
                    
                    break;

                case MSG_SWEEP_EVENTS:
					{
                        int lo_lParam = (short)lParam,
                            hi_lParam = (short)(lParam >> 16);
						
						static TStringValPair errors_reason[] =
						{
							{0,  "Nil"},
							{1,  "Unknown Signal 1"},
							{2,  "Unknown Command 1"},
							{3,  "Unknown Function Name"},
							{4,  "Can't On"},
							{5,  "Can't Do Out Step"},
							{6,  "Can't Do In Step"},
							{7,  "Invalid Function Name"},
							{8,  "Can't Off"},
							{9,  "Can't Off And Send Back"},
							{10, "Unknown Command 2"},
							{11, "Unknown Signal 2"},
							{61, "Can't Do In Step 1"},
							{62, "Can't Do In Step 2"},
							{63, "Can't Do In Step 3"},
							/* Last element */
                            {0, NULL}
						};
						
						static TStringValPair what[] = 
						{
							{0x0170,  "Analyzer Sweep Rms"},
							{0x0171,  "Analyzer Sweep Rms Meas Times And Wideband Setting"},
							{0x0172,  "Analyzer Sweep Rms Averaging"},
							{0x0173,  "Analyzer Sin Rms Sweep Sweep Set"},
							{0x0174,  "Analyzer Sin Rms Sweep Gen Set"},
							{0x0175,  "Analyzer Sin Rms Sweep Anl Chan Set"},
							{0x0176,  "Analyzer Sin Rms Sweep Anl No Ch Set"},
							{0x0190,  "Analyzer Sweep Thd"},
							{0x0191,  "Analyzer Sweep Thd Setting"},
							{0x0193,  "Analyzer Sin Thd Sweep Sweep Set"},
							{0x0194,  "Analyzer Sin Thd Sweep Gen Set"},
							{0x0195,  "Analyzer Sin Thd Sweep Anl Chan Set"},
							{0x0196,  "Analyzer Sin Thd Sweep Anl No Ch Set"},
							{0x0210,  "Analyzer Sweep RSm"},
							{0x0211,  "Analyzer Sweep RSm No Ch Setting"},
							{0x0212,  "Analyzer Sweep RSm Chan Setting"},
							{0x0213,  "Analyzer Sin RSm Sweep Sweep Set"},
							{0x0214,  "Analyzer Sin RSm Sweep Gen Set"},
							{0x0215,  "Analyzer Sin RSm Sweep Anl Chan Set"},
							{0x0216,  "Analyzer Sin RSm Sweep Anl No Ch Set"},
							/* Last element */
                            {0, NULL}
						};
						
						if (hi_lParam == 0x0177)
						{
							instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        	for (idx = 0; what[idx].stringName; idx++)
	                            if (what[idx].stringVal == wParam)
	                                break;

	                        for (idy = 0; errors_reason[idy].stringName; idy++)
	                            if (errors_reason[idy].stringVal == lo_lParam)
	                                break;

                        	{
	                        ViChar  tmp_1[64],
	                                tmp_2[64];

	                        sprintf (tmp_1, "%ld", lo_lParam);
	                        sprintf (tmp_2, "0x%X", wParam);
	                        
	                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
	                            "Sweep Error: %s, in: %s.",
	                            (errors_reason[idy].stringName) ? errors_reason[idy].stringName : tmp_1,
	                            (what[idx].stringName) ? what[idx].stringName : tmp_2);
	                        }
							instrPtr -> errorCount++;
                        	warningFlag = VI_FALSE;
						}
						else
						{
							/* Proceed only when warnigs are enabled */
                    		if (instrPtr -> warningChecking == VI_TRUE)
                    		{
								static TStringValPair message[] =
	                            {
	                                {0x0178, "Sweep Init"},
	                                {0x0179, "Sweep Stopped"},
	                                {0x017A, "Sweep Started"},
	                                {0x017B, "Sweep Set Parameters"},
	                                /* Last element */
	                                {0, NULL}
	                            };

		                        static TStringErrorPair message_detail[2];

		                        memset (message_detail, 0, 2 * sizeof (message_detail[0]));

		                        switch (lo_lParam)
								{
									case 0x0178:
										{
											message_detail[0].stringVal = 0;
	                                		strcpy (message_detail[0].stringName, "Unknown");
	                                		message_detail[1].stringVal = 1;
	                                		strcpy (message_detail[1].stringName, "Sin RMS Sweep");
										}
										break;
									case 0x0179:
									case 0x017A:
										{
											message_detail[0].stringVal = 0;
	                                		strcpy (message_detail[0].stringName, "HS_NAK");
	                                		message_detail[1].stringVal = 1;
	                                		strcpy (message_detail[1].stringName, "HS_ACK");
										}
										break;
									case 0x017B:
									default:
										break;
								}
							
								instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

	                        	for (idx = 0; message_detail[idx].stringName; idx++)
		                            if (message_detail[idx].stringVal == hi_lParam)
		                                break;

		                        for (idy = 0; message[idy].stringName; idy++)
		                            if (message[idy].stringVal == lo_lParam)
		                                break;
							
								for (idx = 0; what[idz].stringName; idx++)
		                            if (what[idz].stringVal == wParam)
		                                break;

	                        	{
		                        ViChar  tmp_1[64],
		                                tmp_2[64],
										tmp_3[64];

		                        sprintf (tmp_1, "%ld", hi_lParam);
		                        sprintf (tmp_2, "0x%X", lo_lParam);
		                        sprintf (tmp_3, "0x%X", wParam);
	                        
		                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
		                            "Sweep Message: %s, %s, in: %s.",
		                            (message_detail[idx].stringName) ? message_detail[idx].stringName : tmp_1,
		                            (message[idy].stringName) ? message[idy].stringName : tmp_2,
									(what[idz].stringName) ? what[idz].stringName : tmp_3);
		                        }
								instrPtr -> errorCount++;
								/* warningFlag is not changed here */
							}
							else
							{
								warningFlag = VI_FALSE;
								/* Warnings are dumped */
							}
						}
                    }
					break;
					
				case MSG_INVALID_TRIG_STATE:
					{
                        int lo_lParam = (short)lParam,
                            hi_lParam = (short)(lParam >> 16);

                        static TStringValPair bad_right_state[] =
                        {
                            {0x0000, "unknown"},
							{0x0001, "idle"},
							{0x0002, "wait for trigger"},
							{0x0003, "measurement"},
							{0x0004, "idle or wait for trigger"},
							{0x0005, "idle or measurement"},
							{0x0006, "wait for trigger or measurement"},
                            /* Last element */
                            {0, NULL}
                        };

                        static TStringValPair function[] =
                        {
                            {0x0050, "Peak"},
                            {0x0060, "Quasi peak"},
                            {0x0070, "Polarity"},
                            {0x0080, "RMS Selective"},
                            {0x0088, "RMS Selective Multitask"},
                            {0x0090, "RMS DC"},
                            {0x00D0, "THD"},
                            {0x00E0, "Phase"},
                            {0x00F0, "DFD"},
							{0x0100, "Mod Dist"},
							{0x0140, "FFT"},
							{0x0150, "Sample Frequency"},
							{0x0160, "DAI Protocol"},
							{0x0170, "Analyzer Sweep RMS"},
							{0x0171, "Analyzer Sweep RMS Meas Times And Wideband Setting"},
							{0x0172, "Analyzer Sweep RMS Averaging"},
							{0x0173, "Analyzer Sin RMS Sweep Sweep Set"},
							{0x0174, "Analyzer Sin RMS Sweep Gen Set"},
							{0x0175, "Analyzer Sin RMS Sweep Anl Chan Set"},
							{0x0176, "Analyzer Sin RMS Sweep Anl No Ch Set"},
							{0x0190, "Analyzer Sweep THD"},
							{0x0191, "Analyzer Sweep THD Setting"},
							{0x0193, "Analyzer Sin THD Sweep Sweep Set"},
							{0x0194, "Analyzer Sin THD Sweep Gen Set"},
							{0x0195, "Analyzer Sin THD Sweep Anl Chan Set"},
							{0x0196, "Analyzer Sin THD Sweep Anl No Ch Set"},
							{0x0210, "Analyzer Sweep RMS Selective"},
							{0x0211, "Analyzer Sweep RMS Selective No Ch Setting"},
							{0x0212, "Analyzer Sweep RMS Selective Chan Setting"},
							{0x0213, "Analyzer Sin RMS Selective Sweep Sweep Set"},
							{0x0214, "Analyzer Sin RMS Selective Sweep Gen Set"},
							{0x0215, "Analyzer Sin RMS Selective Sweep Anl Chan Set"},
							{0x0216, "Analyzer Sin RMS Selective Sweep Anl No Ch Set"},
                            /* Last element */
                            {0, NULL}
                        };

                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idx = 0; bad_right_state[idx].stringName; idx++)
                            if (bad_right_state[idx].stringVal == hi_lParam)
                                break;

                        for (idy = 0; bad_right_state[idy].stringName; idy++)
                            if (bad_right_state[idy].stringVal == lo_lParam)
                                break;

                        for (idz = 0; function[idz].stringName; idz++)
                            if (function[idz].stringVal == wParam)
                                break;

                        {
                        ViChar  tmp_1[64],
                                tmp_2[64],
                                tmp_3[64];

                        sprintf (tmp_1, "0x%X", hi_lParam);
                        sprintf (tmp_2, "0x%X", lo_lParam);
                        sprintf (tmp_3, "0x%X", wParam);

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Invalid trigger state - bad state: %s, right state: %s, function: %s.",
                            (bad_right_state[idx].stringName) ? bad_right_state[idx].stringName : tmp_1,
                            (bad_right_state[idy].stringName) ? bad_right_state[idy].stringName : tmp_2,
                            (function[idz].stringName) ? function[idz].stringName : tmp_3);
                        }

                        instrPtr -> errorCount++;
                        warningFlag = VI_FALSE;
                    }
					break;
					
				case MSG_OPERATION_COMPLETE:
/*					{
						int lo_lParam = (short)lParam,
                        	hi_lParam = (short)(lParam >> 16);

	                    static TStringValPair function[] =
                        {
                            {0x0050, "Peak"},
                            {0x0060, "Quasi peak"},
                            {0x0070, "Polarity"},
                            {0x0080, "RMS Selective"},
                            {0x0090, "RMS DC"},
                            {0x00D0, "THD"},
                            {0x00E0, "Phase"},
                            {0x00F0, "DFD"},
							{0x0100, "Mod Dist"},
							{0x0140, "FFT"},
							{0x0150, "Sample Frequency"},
							{0x0160, "DAI Protocol"},
                            /* Last element */
/*                            {0, NULL}
                        };
						
						instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

						for (idx = 0; function[idx].stringName; idx++)
                            if (function[idx].stringVal == wParam)
                                break;
							
                        {
	                        ViChar  tmp[64];

	                        sprintf (tmp, "0x%X", wParam);
						
							sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
		                        "Operation Complete (Request ID: %s, Sender: %d, Result Number: %d).",
		                        (function[idx].stringName) ? function[idx].stringName : tmp, lo_lParam, hi_lParam);
						}
						instrPtr -> errorCount++;
                        warningFlag = VI_FALSE;
					}
*/
					{
						static TIntValPair function[] =
                        {
                            {0x0050, afPeak},
                            {0x0060, afQPeak},
                            {0x0070, afPolarity},
                            {0x0080, afRMSSel},
                            {0x0088, afRMSSelMuTsk},
                            {0x0090, afRMSDC},
                            {0x00D0, afTHDpmN},
                            {0x00E0, afPhaseMuTsk},
                            {0x00F0, afDFDMuTsk},
							{0x0100, afModDist},
							{0x0140, afFFTMuTsk},
							{0x0150, afDAISamplRate},
							{0x0160, afDAIProtocol},
							{0x0175, afSinRmsSweep},
							{0x0195, afSinThdSweep},
							{0x0215, afSinRSmSweep},
                            /* Last element */
                            {0, NULL}
                        };
						
						for (idx = 0; function[idx].intName; idx++)
                            if (function[idx].intVal == wParam)
                                break;
							
						instrPtr->enabledMeasIdDataValid[function[idx].intName] = ON;
					}
					break;
				case MSG_INVALID_MEAS_MODE:
					{
                        static TStringValPair right_mode[] =
                        {
                            {0, "Continuous Measurement"},
							{1, "Triggered Measurement"},
							/* Last element */
                            {0, NULL}
                        };

                        
                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idz = 0; right_mode[idz].stringName; idz++)
                            if (right_mode[idz].stringVal == wParam)
                                break;

                        {
                        ViChar  tmp_1[64];

                        sprintf (tmp_1, "%ld", wParam);

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        	"Invalid measurement mode - right mode: %s).",
                        	(right_mode[idz].stringName) ? right_mode[idz].stringName : tmp_1);
                        }

                        instrPtr -> errorCount++;
                        warningFlag = VI_FALSE;
                    }
					break;
					
				case MSG_DAI_MESSAGE:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        static TStringValPair input[] =
                            {
                                {0x1, "I2S signal not presented"},
                                {0x2, "Receiver error (CS8416)"},
                                /* Last element */
                                {0, NULL}
                            };

                        static TStringErrorPair error[5];

                        memset (error, 0, 5 * sizeof (error[0]));

                        switch (lParam)
                            {
                            case 0x1:
                                error[0].stringVal = 0x1;
                                strcpy (error[0].stringName, "SCLK clock not presented");
                                error[1].stringVal = 0x2;
                                strcpy (error[1].stringName, "FS clock not presented");
                                break;
                            case 0x2:
                                error[0].stringVal = 0x10;
                                strcpy (error[0].stringName, "PLL unlock");
                                error[1].stringVal = 0x2;
                                strcpy (error[1].stringName, "bi-phase error");
                                error[2].stringVal = 0x1;
                                strcpy (error[2].stringName, "parity error");
                                error[3].stringVal = 0x11;
                                strcpy (error[3].stringName, "PLL unlock + parity error");
                                error[4].stringVal = 0x3;
                                strcpy (error[4].stringName, "bi-phase error + parity error");
                                break;
                            default:
                                break;
                            }

                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        for (idx = 0; input[idx].stringName; idx++)
                            if (input[idx].stringVal == lParam)
                                break;

                        for (idy = 0; error[idy].stringVal > 0; idy++)
                            if (error[idy].stringVal == wParam)
                                break;

                        {
                        ViChar  tmp_1[64],
                                tmp_2[64];

                        sprintf (tmp_1, "Input: 0x%X", lParam);
                        sprintf (tmp_2, "error: 0x%X", wParam);

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "DAI status message (%s, %s).",
                            (input[idx].stringName) ? input[idx].stringName : tmp_1,
                            (strlen (error[idy].stringName)) ? error[idy].stringName : tmp_2);
                        }

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */ /* warningFlag = VI_FALSE; */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                case MSG_DATA:

                    /* Proceed only when warnigs are enabled */
                    if (instrPtr -> warningChecking == VI_TRUE)
                        {
                        instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Send data on Irpt channel for events (lParam: 0x%X, wParam: 0x%X).",
                            lParam, wParam);

                        instrPtr -> errorCount++;
                        /* warningFlag is not changed here */
                        }
                    else
                        {
                        /* Warnings are dumped */
                        warningFlag = VI_FALSE;
                        }

                    break;

                default:
                    /* Check for the specified event */
                    if (EventId == checkEvent)
                        if (checkEnventFound)
                            *checkEnventFound = VI_TRUE;
                }

            /* Zeroing event data */
            EventId = 0x0; lParam = 0x0; wParam = 0x0;
            }

        /* If any error has been detected, return error/warning code */
        if (instrPtr -> errorCount > oldErrorCount)
            rssiup_status = (warningFlag) ?
                RSSIUP_WARNING_INSTRUMENT_WARNING :
                RSSIUP_ERROR_INSTRUMENT_ERROR;
        else
            rssiup_status = VI_SUCCESS;
        }

    return rssiup_status;
}

/*=========================================================================*/
/* Function: DSI Set                                                       */
/* Purpose:  This function sets value of the specified register structure. */
/*=========================================================================*/
ViStatus rssiup_DSI_Set (ViSession instrSession, ViInt32 regId, ViInt32 channel, void *value, ViInt32 size)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges      instrPtr        = {0};

    if (!value)
        return RSSIUP_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (SiSetRegister(instrSession, regId, channel, value, size));

    return rssiup_status;
}

/*=========================================================================*/
/* Function: DSI Get                                                       */
/* Purpose:  This function gets value of the specified register structure. */
/*=========================================================================*/
ViStatus rssiup_DSI_Get (ViSession instrSession, ViInt32 regId, ViInt32 channel, void *value, ViInt32 size)
{
    ViStatus                rssiup_status   = VI_SUCCESS;
    pTStatusDataRanges      instrPtr        = {0};
    ViBoolean               handshake       = VI_FALSE;

    if (!value)
        return RSSIUP_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    /* This instrument does not provides handshake acknowledge in case of getting value */
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, &handshake));
    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, VI_FALSE));

    rssiup_status = SiGetRegister(instrSession, regId, channel, value, size);

    SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, handshake);

    CHECKERR (rssiup_status);

    /* Suppress positive (warning) code */
    rssiup_status = (rssiup_status < VI_SUCCESS) ? rssiup_status : VI_SUCCESS;

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Wait for Device State                                           */
/* Purpose:  This function waits until the defined device state or timeout   */
/*           associated with the session is reached.                         */
/*===========================================================================*/
ViStatus rssiup_waitForDeviceState (ViSession instrSession, ViInt32 deviceState)
{
    ViStatus rssiup_status  = VI_SUCCESS;
    ViInt32  status         = 0;
    ViUInt32 timeout        = 0;
    ViUInt32 consumed       = 0;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_TMO_VALUE, &timeout));

    while ((status = SiGetStatus(instrSession)) != deviceState)
        {
        /* Wait for at least 5 milisecond */
        rssiup_delay (0.005);
        /* Increase consumed time counter */
        consumed += 5;
        /* Exit when timeout elapsed */
        if (consumed >= timeout)
            return SI_ERROR_TMO;
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Read Analyzer Function Data
/* Purpose:  This function reads analyzer function data.
/*===========================================================================*/
ViStatus rssiup_readAnalyzerFunctionData (ViSession instrSession,
                                          TAnlFunFrameHeader *frame,
                                          void *data)
{
    ViStatus            rssiup_status       = VI_SUCCESS;
    ViInt32             retCount            = 0;
    ViBoolean           gdi_acknowledge     = VI_TRUE;
    ViChar              *buffer;
    ViUInt16            *p2header;
    pTStatusDataRanges  instrPtr            = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, &gdi_acknowledge));
    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, VI_FALSE));

    /* Prepare data buffer */
    buffer = malloc (BUFFER_SIZE);
    buffer = memset (buffer, 0, BUFFER_SIZE);

    /* Read Analyzer Function Data */
    if ((retCount = SiReadData (instrSession, CLASS_ID_UP300_ANL_FUN, buffer, BUFFER_SIZE)) < VI_SUCCESS)
        {
        free (buffer);
        return RSSIUP_ERROR_DATA_NOT_AVAILABLE;
        }

    if ((retCount < sizeof (TAnlFunFrameHeader)) || 
        (retCount > BUFFER_SIZE))
        {
        free (buffer);
        return RSSIUP_ERROR_DATA_CORRUPTED;
        }

    /* Assign header values */
    p2header = (ViUInt16 *)buffer;

    frame->FrSz         = (ViUInt16)*p2header++; /* Frame Size (Bytes = FrSz * 4) */
    frame->ClassID      = (ViUInt16)*p2header++; /* Class ID ... number of functions per frame */

    retCount -= sizeof (TAnlFunFrameHeader);

    /* Copy analyzer function data */
    memcpy (data, buffer + sizeof (TAnlFunFrameHeader), retCount);

    /* Do the cleanup */
    free (buffer);

    SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_GDI_ACKNOWLEDGE, gdi_acknowledge);

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Handle Analyzer Function Data
/* Purpose:  This function handles analyzer function data. Retrieves complete
/*           data set for enabled measurements.
/*===========================================================================*/
ViStatus rssiup_handleAnalyzerFunctionData (ViSession instrSession,
                                            ViInt32 measId[],
                                            ViInt32 noMeasId)
{
    ViStatus            rssiup_status       = VI_SUCCESS;
    ViChar              buffer[BUFFER_SIZE];
    TAnlFunData         function[ANLFUN_CNT];
    ViChar              *p2buffer;
    ViUInt16            *p2header;
    TAnlFunDataHeader   header              = {0};
    TAnlFunFrameHeader  frame               = {0};
    pTStatusDataRanges  instrPtr            = {0};
    ViUInt32            timeout             = 0;
    ViInt32             collectedIds        = 0;
    ViInt32             frameFuns           = 0;    
    ViInt32             idx                 = 0;
    clock_t             start_time          = clock();

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (instrPtr -> abortCurrentMeasurement == VI_TRUE)
        {
        instrPtr -> abortCurrentMeasurement = VI_FALSE;

        return RSSIUP_ERROR_MEASUREMENT_ABORTED;
        }

    if (instrPtr -> measMode == RSSIUP_MEAS_MODE_IDLE)
        return RSSIUP_ERROR_DATA_NOT_AVAILABLE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_TMO_VALUE, &timeout));

    /* Setup data collect info structure */
    memset (function, 0, ANLFUN_CNT * sizeof (function[0]));
    
    for (idx = 0; idx < noMeasId; idx++)
        {
        /* Exception (handle with care!): Two blocks are combined in one measurement Id block. */
        if (idx > 0)
            {
            if (((measId[idx-1] == MEAS_THDN_POST_FFT) && (measId[idx] == MEAS_THDN)) || 
                ((measId[idx-1] == MEAS_DFD_POST_FFT) && (measId[idx] == MEAS_DFD)))
                {
                noMeasId--;
                break;
                }
            }

        /* --- */
        
        function[idx].FunID     = measId[idx];
        function[idx].completed = VI_FALSE;
        function[idx].data      = NULL;
        function[idx].p2data    = NULL;
        function[idx].size      = 0;
        }

    /* Collect all requested data sets */
    while (collectedIds < noMeasId)
        {
        /* Retrieve measurement results */
        GOCHECKERR (rssiup_readAnalyzerFunctionData (instrSession, &frame, buffer));

        p2buffer = buffer;
#if 0
            frame.FrSz          /* Frame Size (Bytes = FrSz * 4) */
            frame.ClassID       /* Class ID ... number of functions per frame */

            RSSIUP_WARNING_CACHED_DATA ... TODO in single meas mode ...
#endif
        frameFuns = frame.ClassID; /* Class ID ... number of functions per frame */

        /* Retrieve complete data set for enabled measurements */
        while (frameFuns > 0)
            {
            /* Assign header values */
            p2header = (ViUInt16 *)p2buffer;

            header.FunSz    = (ViUInt16)*p2header++; /* Function Size (Bytes = FunSz * 4) */
            header.FunID    = (ViUInt16)*p2header++; /* Function identificator */
            header.PartyID  = (ViUInt16)*p2header++; /* Party identificator */
            header.ResCnt   = (ViUInt16)*p2header++; /* Result counter */
            header.FunDtSz  = (ViUInt16)*p2header++; /* Function Data Size (Bytes = FunDtSz * 4) */
            header.Marker   = (ViUInt16)*p2header++; /* Sender Marker */
            header.PartyMax = (ViUInt16)*p2header++; /* Party Max (for N parts is PartyMax = N-1 and PartyID is 0,1,...,N-2,N-3) */
            header.ChnCnt   = (ViUInt16)*p2header;   /* Change counter */
																										  
            /* Pointer to data */
            p2buffer += sizeof (TAnlFunDataHeader);

            /* Count & complete collected Ids */
            for (idx = 0; idx < noMeasId; idx++)
                if (function[idx].FunID == header.FunID)
                    if (function[idx].completed == VI_FALSE)
                        {
                        if (header.PartyID == 0)
                            {
                            /* Initialize temporary data storage */
                            function[idx].data = malloc (4 * header.FunDtSz);
                            memset (function[idx].data, 0, 4 * header.FunDtSz);
                            function[idx].p2data = function[idx].data;
                            function[idx].size = 4 * header.FunDtSz;
                            }
                        if (function[idx].p2data) // Not NULL?
                            {
                            if (header.PartyID <= header.PartyMax)
                                {
                                memcpy (function[idx].p2data, p2buffer, 4 * header.FunSz - sizeof (TAnlFunDataHeader));
                                function[idx].p2data += (4 * header.FunSz - sizeof (TAnlFunDataHeader));
                                
                                if (header.PartyID == header.PartyMax)
                                    {
                                    function[idx].completed = VI_TRUE;
                                    collectedIds++;
                                    }
                                }
                            }
                        }

            /* Exit when timeout elapsed */
            if ((((double)(clock() - start_time))/(double)CLOCKS_PER_SEC) > (timeout / 1000))
                {
                rssiup_status = SI_ERROR_TMO;

                goto ERROR;
                }

            /* Exit when measurement is aborted */
            if (instrPtr -> abortCurrentMeasurement == VI_TRUE)
                {
                instrPtr -> abortCurrentMeasurement = VI_FALSE;

                rssiup_status = RSSIUP_ERROR_MEASUREMENT_ABORTED;

                goto ERROR;
                }

            /* Decrement number of functions in frame */
            frameFuns--;

            /* Shift pointer in buffer to next function, if any */
            if (frameFuns > 0)
                p2buffer += (4 * header.FunSz - sizeof (TAnlFunDataHeader));

            } // end of while

        } // end of while (collectedIds < noMeasId)

    /* Parse data and store result to the session variables */
    for (idx = 0; idx < noMeasId; idx++)
        {
        GOCHECKERR (rssiup_parseAnalyzerFunctionData (instrSession, function[idx].FunID,
            function[idx].data, function[idx].size));
        }

ERROR:

    for (idx = 0; idx < noMeasId; idx++)
        if (function[idx].data)
            free (function[idx].data);

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Parse Analyzer Function Data
/* Purpose:  This function parses analyzer function data and stores them to
/*           the session variables.
/*===========================================================================*/
ViStatus rssiup_parseAnalyzerFunctionData (ViSession instrSession,
                                           ViInt32 FunID,
                                           ViChar *buffer,
                                           ViUInt16 size)
{
    ViStatus            rssiup_status       = VI_SUCCESS;
    pTStatusDataRanges  instrPtr            = {0};
    ViChar              *p2buffer           = buffer;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    /* Only known data packages are taken into consideration */
    switch (FunID)
        {
        case MEAS_PEAK:
            {
            ViReal32    *p2data;

            p2data = (ViReal32 *)buffer;

            instrPtr -> AnlMeasPeak.PeakMax_A = *p2data++;
            instrPtr -> AnlMeasPeak.PeakMin_A = *p2data++;
            instrPtr -> AnlMeasPeak.PeakMax_B = *p2data++;
            instrPtr -> AnlMeasPeak.PeakMin_B = *p2data;

            break;
            }
        case MEAS_QPEAK:
            {
            ViReal32    *p2data;

            p2data = (ViReal32 *)buffer;

            instrPtr -> AnlMeasQpeak.QuasiPeakMax_A             = *p2data++;
            instrPtr -> AnlMeasQpeak.QuasiPeakMin_A             = *p2data++;
            instrPtr -> AnlMeasQpeak.QuasiPeakCurrentValue_A    = *p2data++;
            instrPtr -> AnlMeasQpeak.QuasiPeakMax_B             = *p2data++;
            instrPtr -> AnlMeasQpeak.QuasiPeakMin_B             = *p2data++;
            instrPtr -> AnlMeasQpeak.QuasiPeakCurrentValue_B    = *p2data;
            }
            break;
        case MEAS_RMSDC:
            {
            ViUInt16    i = 0;
            ViUInt32    *p2U32;
            ViReal32    *p2F32;

            p2U32 = (ViUInt32 *)buffer;
            p2F32 = (ViReal32 *)buffer;

            instrPtr -> AnlMeasRMSDC.AsynchroIndication_A   = p2U32[i++];
            instrPtr -> AnlMeasRMSDC.Valid_A                = p2U32[i++];
            instrPtr -> AnlMeasRMSDC.DC_A                   = p2F32[i++];
            instrPtr -> AnlMeasRMSDC.SqrRMS_A               = p2F32[i++];
            instrPtr -> AnlMeasRMSDC.Frequency_A            = p2F32[i++];
            instrPtr -> AnlMeasRMSDC.AsynchroIndication_B   = p2U32[i++];
            instrPtr -> AnlMeasRMSDC.Valid_B                = p2U32[i++];
            instrPtr -> AnlMeasRMSDC.DC_B                   = p2F32[i++];
            instrPtr -> AnlMeasRMSDC.SqrRMS_B               = p2F32[i++];
            instrPtr -> AnlMeasRMSDC.Frequency_B            = p2F32[i];
            }
            break;
        case MEAS_RMSSEL:
            {
            ViUInt16    i = 0;
            ViUInt32    *p2U32;
            ViReal32    *p2F32;

            p2U32 = (ViUInt32 *)buffer;
            p2F32 = (ViReal32 *)buffer;

            instrPtr -> AnlMeasRMSSel.SqrRMSValue_A     = p2F32[i++];
            instrPtr -> AnlMeasRMSSel.SqrRMSValue_B     = p2F32[i++];
            instrPtr -> AnlMeasRMSSel.Valid             = p2U32[i];
			}
            break;
        case MEAS_RMSSEL_MUTSK_FFT:
        	{
			ViUInt16    i   = 0;
            ViUInt32    *p2U32;
            ViInt32     *p2S32;
            ViReal32    *p2F32;
			ViInt32		temp1, temp2;
		
			/* this section checks the channels - START */
			TFFTResHeader   header = {0};

            p2buffer = buffer;
        
            /* Check how many channels is in the data and which one is the first */
            memcpy (&header, p2buffer, sizeof (TFFTResHeader));
            instrPtr -> FFTChannelRunning[0] = VI_FALSE;
            instrPtr -> FFTChannelRunning[1] = VI_FALSE;

            if (header.ChnlMode & 0x80000000) // Bit 31: 1 = ChA, 0 = ChB
                {
                /* ChA */
                instrPtr -> FFTChannelRunning[0] = VI_TRUE;

                /* Two channels? */
                if (size > (2 * (temp1 = sizeof (TFFTResHeader) + header.NOSL * (temp2 = sizeof (ViReal32)))))
                    {
                    /* ChB */
                    instrPtr -> FFTChannelRunning[1] = VI_TRUE;
                    }
                }
            else
                {
                /* Only ChB, ChA is Off */
                instrPtr -> FFTChannelRunning[0] = VI_FALSE;
                instrPtr -> FFTChannelRunning[1] = VI_TRUE;
                }
		
			/* this section checks the channels - END */
		
			/* this section handles Post FFT - START */
			/* ChA */
            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                memcpy (&instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_A, p2buffer,
                    sizeof (TFFTResHeader));

                p2buffer += sizeof (TFFTResHeader);

                memset (instrPtr -> AnlMeasRMSSelMuTskPostFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                memcpy (instrPtr -> AnlMeasRMSSelMuTskPostFFT.SpLines_A, p2buffer, instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_A.NOSL * sizeof (ViReal32));

                p2buffer += instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_A.NOSL * sizeof (ViReal32);
                }
            else
                {
                memset (&instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_A, 0, sizeof (TFFTResHeader));
                memset (instrPtr -> AnlMeasRMSSelMuTskPostFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                }

            /* ChB */
            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                {
                memcpy (&instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_B, p2buffer, sizeof (TFFTResHeader));

                p2buffer += sizeof (TFFTResHeader);

                memset (instrPtr -> AnlMeasRMSSelMuTskPostFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                memcpy (instrPtr -> AnlMeasRMSSelMuTskPostFFT.SpLines_B, p2buffer, instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_B.NOSL * sizeof (ViReal32));

                p2buffer += instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_B.NOSL * sizeof (ViReal32);
                }
            else
                {
                memset (&instrPtr -> AnlMeasRMSSelMuTskPostFFT.Header_B, 0, sizeof (TFFTResHeader));
                memset (instrPtr -> AnlMeasRMSSelMuTskPostFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                }
			/* this section handles Post FFT - END */
		
			/* this section handles RMS SEL MUTSK data - START */
		
			p2U32 = (ViUInt32 *)p2buffer;
            p2S32 = (ViInt32 *)p2buffer;
            p2F32 = (ViReal32 *)p2buffer;

            instrPtr -> AnlMeasRMSSelMuTsk.Marker1_FFTFreq         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker2_FFTFreq         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker1_A_Value         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker2_A_Value         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker1_B_Value         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker2_B_Value         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Tag                     = p2U32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.AutoTuneLocked_A        = p2S32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Frequency_A             = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.RMS_A                   = p2F32[i++];

            instrPtr -> AnlMeasRMSSelMuTsk.AutoTuneLocked_B        = p2S32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Frequency_B             = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.RMS_B                   = p2F32[i++];
            
			/* this section handles RMS SEL MUTSK data - END */
			}	
			break;	

        case MEAS_RMSSEL_MUTSK:
            {
            ViUInt16    i   = 0;
            ViUInt32    *p2U32;
            ViInt32     *p2S32;
            ViReal32    *p2F32;

            p2U32 = (ViUInt32 *)p2buffer;
            p2S32 = (ViInt32 *)p2buffer;
            p2F32 = (ViReal32 *)p2buffer;

            instrPtr -> AnlMeasRMSSelMuTsk.Marker1_FFTFreq         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker2_FFTFreq         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker1_A_Value         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker2_A_Value         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker1_B_Value         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Marker2_B_Value         = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Tag                     = p2U32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.AutoTuneLocked_A        = p2S32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Frequency_A             = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.RMS_A                   = p2F32[i++];

            instrPtr -> AnlMeasRMSSelMuTsk.AutoTuneLocked_B        = p2S32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.Frequency_B             = p2F32[i++];
            instrPtr -> AnlMeasRMSSelMuTsk.RMS_B                   = p2F32[i++];
            }
            break;
        case MEAS_RMSSEL_MUTSK_REDUCED_FFT:
            {
            ViChar          *p2buffer;

            p2buffer = buffer;

            memcpy (&instrPtr -> AnlMeasRMSSelMuTskReducedFFT.HeaderMax, p2buffer,
                sizeof (TFFTResHeader));

            p2buffer += sizeof (TFFTResHeader);

            memset (instrPtr -> AnlMeasRMSSelMuTskReducedFFT.SLmax, 0, FFT_DISPLAY_SIZE_MAX * sizeof (ViReal32));
            memcpy (instrPtr -> AnlMeasRMSSelMuTskReducedFFT.SLmax, p2buffer, instrPtr -> AnlMeasRMSSelMuTskReducedFFT.HeaderMax.NOSL * sizeof (ViReal32));
            }
            break;
        case MEAS_THDN_POST_FFT:
            {
				ViUInt16    i   = 0,
	                        idx = 0;
	            ViUInt32    *p2U32;
	            ViInt32     *p2S32;
	            ViReal32    *p2F32;
				ViInt32		temp1, temp2;
			
				/* this section checks the channels - START */
				TFFTResHeader   header = {0};

	            p2buffer = buffer;
            
	            /* Check how many channels is in the data and which one is the first */
	            memcpy (&header, p2buffer, sizeof (TFFTResHeader));
	            instrPtr -> FFTChannelRunning[0] = VI_FALSE;
	            instrPtr -> FFTChannelRunning[1] = VI_FALSE;

	            if (header.ChnlMode & 0x80000000) // Bit 31: 1 = ChA, 0 = ChB
	                {
	                /* ChA */
	                instrPtr -> FFTChannelRunning[0] = VI_TRUE;

	                /* Two channels? */
	                if (size > (2 * (temp1 = sizeof (TFFTResHeader) + header.NOSL * (temp2 = sizeof (ViReal32)))))
	                    {
	                    /* ChB */
	                    instrPtr -> FFTChannelRunning[1] = VI_TRUE;
	                    }
	                }
	            else
	                {
	                /* Only ChB, ChA is Off */
	                instrPtr -> FFTChannelRunning[0] = VI_FALSE;
	                instrPtr -> FFTChannelRunning[1] = VI_TRUE;
	                }
			
				/* this section checks the channels - END */
			
				/* this section handles Post FFT - START */
				/* ChA */
	            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	                {
	                memcpy (&instrPtr -> AnlMeasTHDNPostFFT.Header_A, p2buffer,
	                    sizeof (TFFTResHeader));

	                p2buffer += sizeof (TFFTResHeader);

	                memset (instrPtr -> AnlMeasTHDNPostFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
	                memcpy (instrPtr -> AnlMeasTHDNPostFFT.SpLines_A, p2buffer, instrPtr -> AnlMeasTHDNPostFFT.Header_A.NOSL * sizeof (ViReal32));

	                p2buffer += instrPtr -> AnlMeasTHDNPostFFT.Header_A.NOSL * sizeof (ViReal32);
	                }
	            else
	                {
	                memset (&instrPtr -> AnlMeasTHDNPostFFT.Header_A, 0, sizeof (TFFTResHeader));
	                memset (instrPtr -> AnlMeasTHDNPostFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
	                }

	            /* ChB */
	            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	                {
	                memcpy (&instrPtr -> AnlMeasTHDNPostFFT.Header_B, p2buffer, sizeof (TFFTResHeader));

	                p2buffer += sizeof (TFFTResHeader);

	                memset (instrPtr -> AnlMeasTHDNPostFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
	                memcpy (instrPtr -> AnlMeasTHDNPostFFT.SpLines_B, p2buffer, instrPtr -> AnlMeasTHDNPostFFT.Header_B.NOSL * sizeof (ViReal32));

	                p2buffer += instrPtr -> AnlMeasTHDNPostFFT.Header_B.NOSL * sizeof (ViReal32);
	                }
	            else
	                {
	                memset (&instrPtr -> AnlMeasTHDNPostFFT.Header_B, 0, sizeof (TFFTResHeader));
	                memset (instrPtr -> AnlMeasTHDNPostFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
	                }
				/* this section handles Post FFT - END */
			
				/* this section handles THDN data - START */
			
				p2U32 = (ViUInt32 *)p2buffer;
	            p2S32 = (ViInt32 *)p2buffer;
	            p2F32 = (ViReal32 *)p2buffer;

	            instrPtr -> AnlMeasTHDN.Marker1_FFTFreq         = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.Marker2_FFTFreq         = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.Marker1_A_Value         = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.Marker2_A_Value         = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.Marker1_B_Value         = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.Marker2_B_Value         = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.Tag                     = p2U32[i++];
	            instrPtr -> AnlMeasTHDN.AutoTuneLocked_A        = p2S32[i++];
	            instrPtr -> AnlMeasTHDN.Frequency_A             = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.TotalRMS_A_THDN         = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.Noise_A_THDN            = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.TotalRMS_A_THDN_NonFund = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.TotalRMS_A_THD          = p2F32[i++];

	            for (idx = 0; idx < 10; idx++)
	                instrPtr -> AnlMeasTHDN.Harmonic_A[idx]     = p2F32[i++];

	            instrPtr -> AnlMeasTHDN.AutoTuneLocked_B        = p2S32[i++];
	            instrPtr -> AnlMeasTHDN.Frequency_B             = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.TotalRMS_B_THDN         = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.Noise_B_THDN            = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.TotalRMS_B_THDN_NonFund = p2F32[i++];
	            instrPtr -> AnlMeasTHDN.TotalRMS_B_THD          = p2F32[i++];

	            for (idx = 0; idx < 10; idx++)
	                instrPtr -> AnlMeasTHDN.Harmonic_B[idx]     = p2F32[i++];
				/* this section handles THDN data - END */
			}	
			break;	

/* original data storing - START */
/*			{
			p2buffer = buffer;

            memcpy (&instrPtr -> AnlMeasTHDNPostFFT.Header, p2buffer,
                sizeof (TFFTResHeader));

            p2buffer += sizeof (TFFTResHeader);

            memset (instrPtr -> AnlMeasTHDNPostFFT.SpLines, 0, FFT_NOSL_MAX * sizeof (ViReal32));
            memcpy (instrPtr -> AnlMeasTHDNPostFFT.SpLines, p2buffer, instrPtr -> AnlMeasTHDNPostFFT.Header.NOSL * sizeof (ViReal32));
            /* Shift data pointer to the right position */
/*            p2buffer = buffer + 2 * (instrPtr -> AnlMeasTHDNPostFFT.Header.NOSL * sizeof (ViReal32) + sizeof (TFFTResHeader));
            }
            /* There is appended data for MEAS_THDN, skip break */
/* original data storing - END */
			
        case MEAS_THDN:
            {
            ViUInt16    i   = 0,
                        idx = 0;
            ViUInt32    *p2U32;
            ViInt32     *p2S32;
            ViReal32    *p2F32;

            p2U32 = (ViUInt32 *)p2buffer;
            p2S32 = (ViInt32 *)p2buffer;
            p2F32 = (ViReal32 *)p2buffer;

            instrPtr -> AnlMeasTHDN.Marker1_FFTFreq         = p2F32[i++];
            instrPtr -> AnlMeasTHDN.Marker2_FFTFreq         = p2F32[i++];
            instrPtr -> AnlMeasTHDN.Marker1_A_Value         = p2F32[i++];
            instrPtr -> AnlMeasTHDN.Marker2_A_Value         = p2F32[i++];
            instrPtr -> AnlMeasTHDN.Marker1_B_Value         = p2F32[i++];
            instrPtr -> AnlMeasTHDN.Marker2_B_Value         = p2F32[i++];
            instrPtr -> AnlMeasTHDN.Tag                     = p2U32[i++];
            instrPtr -> AnlMeasTHDN.AutoTuneLocked_A        = p2S32[i++];
            instrPtr -> AnlMeasTHDN.Frequency_A             = p2F32[i++];
            instrPtr -> AnlMeasTHDN.TotalRMS_A_THDN         = p2F32[i++];
            instrPtr -> AnlMeasTHDN.Noise_A_THDN            = p2F32[i++];
            instrPtr -> AnlMeasTHDN.TotalRMS_A_THDN_NonFund = p2F32[i++];
            instrPtr -> AnlMeasTHDN.TotalRMS_A_THD          = p2F32[i++];

            for (idx = 0; idx < 10; idx++)
                instrPtr -> AnlMeasTHDN.Harmonic_A[idx]     = p2F32[i++];

            instrPtr -> AnlMeasTHDN.AutoTuneLocked_B        = p2S32[i++];
            instrPtr -> AnlMeasTHDN.Frequency_B             = p2F32[i++];
            instrPtr -> AnlMeasTHDN.TotalRMS_B_THDN         = p2F32[i++];
            instrPtr -> AnlMeasTHDN.Noise_B_THDN            = p2F32[i++];
            instrPtr -> AnlMeasTHDN.TotalRMS_B_THDN_NonFund = p2F32[i++];
            instrPtr -> AnlMeasTHDN.TotalRMS_B_THD          = p2F32[i++];

            for (idx = 0; idx < 10; idx++)
                instrPtr -> AnlMeasTHDN.Harmonic_B[idx]     = p2F32[i++];
            }
            break;
        case MEAS_THDN_REDUCED_FFT:
            {
            ViChar          *p2buffer;

            p2buffer = buffer;

            memcpy (&instrPtr -> AnlMeasTHDNReducedFFT.HeaderMax, p2buffer,
                sizeof (TFFTResHeader));

            p2buffer += sizeof (TFFTResHeader);

            memset (instrPtr -> AnlMeasTHDNReducedFFT.SLmax, 0, FFT_DISPLAY_SIZE_MAX * sizeof (ViReal32));
            memcpy (instrPtr -> AnlMeasTHDNReducedFFT.SLmax, p2buffer, instrPtr -> AnlMeasTHDNReducedFFT.HeaderMax.NOSL * sizeof (ViReal32));
            }
            break;
        case MEAS_PHASE:
            {
            ViUInt16    i   = 0;
            ViUInt32    *p2U32;
            ViInt32     *p2S32;
            ViReal32    *p2F32;

            p2U32 = (ViUInt32 *)buffer;
            p2S32 = (ViInt32 *)buffer;
            p2F32 = (ViReal32 *)buffer;

            instrPtr -> AnlMeasPhase.Marker1_FFTFrequency    = p2F32[i++];
            instrPtr -> AnlMeasPhase.Marker2_FFTFrequency    = p2F32[i++];
            instrPtr -> AnlMeasPhase.Marker1_Value_A         = p2F32[i++];
            instrPtr -> AnlMeasPhase.Marker2_Value_A         = p2F32[i++];
            instrPtr -> AnlMeasPhase.Marker1_Value_B         = p2F32[i++];
            instrPtr -> AnlMeasPhase.Marker2_Value_B         = p2F32[i++];
            instrPtr -> AnlMeasPhase.Reserved                = p2U32[i++];
            instrPtr -> AnlMeasPhase.AutotuneLocked          = p2S32[i++];
            instrPtr -> AnlMeasPhase.Master                  = p2S32[i++];
            instrPtr -> AnlMeasPhase.PhaseDifference         = p2F32[i++];
            instrPtr -> AnlMeasPhase.Frequency               = p2F32[i++];
            }
            break;
        case MEAS_PHASE_POST_FFT:
            {
            p2buffer = buffer;

            memcpy (&instrPtr -> AnlMeasPhasePostFFT.Header, p2buffer,
                sizeof (TFFTResHeader));

            p2buffer += sizeof (TFFTResHeader);

            memset (instrPtr -> AnlMeasPhasePostFFT.SpLines, 0, FFT_NOSL_MAX * sizeof (ViReal32));
            memcpy (instrPtr -> AnlMeasPhasePostFFT.SpLines, p2buffer, instrPtr -> AnlMeasPhasePostFFT.Header.NOSL * sizeof (ViReal32));
            }
            break;
        case MEAS_PHASE_REDUCED_FFT:
            {
            p2buffer = buffer;

            memcpy (&instrPtr -> AnlMeasPhaseReducedFFT.HeaderMax, p2buffer,
                sizeof (TFFTResHeader));

            p2buffer += sizeof (TFFTResHeader);

            memset (instrPtr -> AnlMeasPhaseReducedFFT.SLmax, 0, FFT_DISPLAY_SIZE_MAX * sizeof (ViReal32));
            memcpy (instrPtr -> AnlMeasPhaseReducedFFT.SLmax, p2buffer, instrPtr -> AnlMeasPhaseReducedFFT.HeaderMax.NOSL * sizeof (ViReal32));
            }
            break;
        case MEAS_DFD:
            {
            ViUInt16    i   = 0,
                        idx = 0;
            ViUInt32    *p2U32;
            ViInt32     *p2S32;
            ViReal32    *p2F32;

            p2U32 = (ViUInt32 *)buffer;
            p2S32 = (ViInt32 *)buffer;
            p2F32 = (ViReal32 *)buffer;

            instrPtr -> AnlMeasDFD.Marker1_FFTFrequency    = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker2_FFTFrequency    = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker1_Value_A         = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker2_Value_A         = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker1_Value_B         = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker2_Value_B         = p2F32[i++];
            instrPtr -> AnlMeasDFD.Reserved                = p2U32[i++];
            instrPtr -> AnlMeasDFD.AutotuneLocked_A        = p2S32[i++];

            for (idx = 0; idx < 5; idx++)
                instrPtr -> AnlMeasDFD.Frequencies_A[idx]  = p2F32[i++];

            for (idx = 0; idx < 5; idx++)
                instrPtr -> AnlMeasDFD.RMSValues_A[idx]    = p2F32[i++];

            instrPtr -> AnlMeasDFD.AutotuneLocked_B        = p2S32[i++];
            
            for (idx = 0; idx < 5; idx++)
                instrPtr -> AnlMeasDFD.Frequencies_B[idx]  = p2F32[i++];

            for (idx = 0; idx < 5; idx++)
                instrPtr -> AnlMeasDFD.RMSValues_B[idx]    = p2F32[i++];
            }
            break;
        case MEAS_DFD_POST_FFT:
            {
			/* this section was added - START */
			ViUInt16    i   = 0,
                        idx = 0;
            ViUInt32    *p2U32;
            ViInt32     *p2S32;
            ViReal32    *p2F32;
			/* this section was added - END */
			
			/* this section checks the channels - START */
			TFFTResHeader   header = {0};

            p2buffer = buffer;
            
            /* Check how many channels is in the data and which one is the first */
            memcpy (&header, p2buffer, sizeof (TFFTResHeader));
            instrPtr -> FFTChannelRunning[0] = VI_FALSE;
            instrPtr -> FFTChannelRunning[1] = VI_FALSE;

            if (header.ChnlMode & 0x80000000) // Bit 31: 1 = ChA, 0 = ChB
                {
                /* ChA */
                instrPtr -> FFTChannelRunning[0] = VI_TRUE;

                /* Two channels? */
                if (size > (2 * (sizeof (TFFTResHeader) + header.NOSL * (sizeof (ViReal32)))))
                    {
                    /* ChB */
                    instrPtr -> FFTChannelRunning[1] = VI_TRUE;
                    }
                }
            else
                {
                /* Only ChB, ChA is Off */
                instrPtr -> FFTChannelRunning[0] = VI_FALSE;
                instrPtr -> FFTChannelRunning[1] = VI_TRUE;
                }
			
			/* this section checks the channels - END */
			
/* this is the original section <<< to be left out >>> - START 
			p2buffer = buffer;			 
			
            memcpy (&instrPtr -> AnlMeasDFDPostFFT.Header_A, p2buffer,
                sizeof (TFFTResHeader));

            p2buffer += sizeof (TFFTResHeader);

            memset (instrPtr -> AnlMeasDFDPostFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
            memcpy (instrPtr -> AnlMeasDFDPostFFT.SpLines_A, p2buffer, instrPtr -> AnlMeasDFDPostFFT.Header_A.NOSL * sizeof (ViReal32));
/* this is the original section - END */
			
			/* this section handles Post FFT - START */
			/* ChA */
            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                memcpy (&instrPtr -> AnlMeasDFDPostFFT.Header_A, p2buffer,
                    sizeof (TFFTResHeader));

                p2buffer += sizeof (TFFTResHeader);

                memset (instrPtr -> AnlMeasDFDPostFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                memcpy (instrPtr -> AnlMeasDFDPostFFT.SpLines_A, p2buffer, instrPtr -> AnlMeasDFDPostFFT.Header_A.NOSL * sizeof (ViReal32));

                p2buffer += instrPtr -> AnlMeasDFDPostFFT.Header_A.NOSL * sizeof (ViReal32);
                }
            else
                {
                memset (&instrPtr -> AnlMeasDFDPostFFT.Header_A, 0, sizeof (TFFTResHeader));
                memset (instrPtr -> AnlMeasDFDPostFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                }

            /* ChB */
            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                {
                memcpy (&instrPtr -> AnlMeasDFDPostFFT.Header_B, p2buffer, sizeof (TFFTResHeader));

                p2buffer += sizeof (TFFTResHeader);

                memset (instrPtr -> AnlMeasDFDPostFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                memcpy (instrPtr -> AnlMeasDFDPostFFT.SpLines_B, p2buffer, instrPtr -> AnlMeasDFDPostFFT.Header_B.NOSL * sizeof (ViReal32));

                p2buffer += instrPtr -> AnlMeasDFDPostFFT.Header_B.NOSL * sizeof (ViReal32);
                }
            else
                {
                memset (&instrPtr -> AnlMeasDFDPostFFT.Header_B, 0, sizeof (TFFTResHeader));
                memset (instrPtr -> AnlMeasDFDPostFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                }
			/* this section handles Post FFT - END */
			
			/* this section handles DFD data - START */
			
			p2U32 = (ViUInt32 *) p2buffer;
            p2S32 = (ViInt32 *) p2buffer;
            p2F32 = (ViReal32 *) p2buffer;

            instrPtr -> AnlMeasDFD.Marker1_FFTFrequency    = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker2_FFTFrequency    = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker1_Value_A         = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker2_Value_A         = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker1_Value_B         = p2F32[i++];
            instrPtr -> AnlMeasDFD.Marker2_Value_B         = p2F32[i++];
            instrPtr -> AnlMeasDFD.Reserved                = p2U32[i++];
            instrPtr -> AnlMeasDFD.AutotuneLocked_A        = p2S32[i++];

            for (idx = 0; idx < 5; idx++)
                instrPtr -> AnlMeasDFD.Frequencies_A[idx]  = p2F32[i++];

            for (idx = 0; idx < 5; idx++)
                instrPtr -> AnlMeasDFD.RMSValues_A[idx]    = p2F32[i++];

            instrPtr -> AnlMeasDFD.AutotuneLocked_B        = p2S32[i++];
            
            for (idx = 0; idx < 5; idx++)
                instrPtr -> AnlMeasDFD.Frequencies_B[idx]  = p2F32[i++];

            for (idx = 0; idx < 5; idx++)
                instrPtr -> AnlMeasDFD.RMSValues_B[idx]    = p2F32[i++];
			/* this section handles DFD data - END */
			}
            break;
        case MEAS_DFD_REDUCED_FFT:
            {
            p2buffer = buffer;

            memcpy (&instrPtr -> AnlMeasDFDReducedFFT.HeaderMax, p2buffer,
                sizeof (TFFTResHeader));

            p2buffer += sizeof (TFFTResHeader);

            memset (instrPtr -> AnlMeasDFDReducedFFT.SLmax, 0, FFT_DISPLAY_SIZE_MAX * sizeof (ViReal32));
            memcpy (instrPtr -> AnlMeasDFDReducedFFT.SLmax, p2buffer, instrPtr -> AnlMeasDFDReducedFFT.HeaderMax.NOSL * sizeof (ViReal32));
            }
            break;
        case MEAS_MOD_DIST:
            {
            ViUInt16    i   = 0,
                        idx = 0;
            ViUInt32    *p2U32;
            ViInt32     *p2S32;
            ViReal32    *p2F32;

            p2U32 = (ViUInt32 *)buffer;
            p2S32 = (ViInt32 *)buffer;
            p2F32 = (ViReal32 *)buffer;

            instrPtr -> AnlMeasModDist.Marker1_FFTFrequency    = p2F32[i++];
            instrPtr -> AnlMeasModDist.Marker2_FFTFrequency    = p2F32[i++];
            instrPtr -> AnlMeasModDist.Marker1_Value_A         = p2F32[i++];
            instrPtr -> AnlMeasModDist.Marker2_Value_A         = p2F32[i++];
            instrPtr -> AnlMeasModDist.Marker1_Value_B         = p2F32[i++];
            instrPtr -> AnlMeasModDist.Marker2_Value_B         = p2F32[i++];
            instrPtr -> AnlMeasModDist.Reserved                = p2U32[i++];
            instrPtr -> AnlMeasModDist.AutotuneLocked_A        = p2S32[i++];

            for (idx = 0; idx < 6; idx++)
                instrPtr -> AnlMeasModDist.Frequencies_A[idx]  = p2F32[i++];

            for (idx = 0; idx < 6; idx++)
                instrPtr -> AnlMeasModDist.RMSValues_A[idx]    = p2F32[i++];

            instrPtr -> AnlMeasModDist.AutotuneLocked_B        = p2S32[i++];
            
            for (idx = 0; idx < 6; idx++)
                instrPtr -> AnlMeasModDist.Frequencies_B[idx]  = p2F32[i++];

            for (idx = 0; idx < 6; idx++)
                instrPtr -> AnlMeasModDist.RMSValues_B[idx]    = p2F32[i++];
            }
            break;
        case MEAS_MOD_DIST_POST_FFT:
			{
				ViUInt16    i   = 0,
	                        idx = 0;
	            ViUInt32    *p2U32;
	            ViInt32     *p2S32;
	            ViReal32    *p2F32;
				
				/* this section checks the channels - START */
				TFFTResHeader   header = {0};

	            p2buffer = buffer;
            
	            /* Check how many channels is in the data and which one is the first */
	            memcpy (&header, p2buffer, sizeof (TFFTResHeader));
	            instrPtr -> FFTChannelRunning[0] = VI_FALSE;
	            instrPtr -> FFTChannelRunning[1] = VI_FALSE;

	            if (header.ChnlMode & 0x80000000) // Bit 31: 1 = ChA, 0 = ChB
	                {
	                /* ChA */
	                instrPtr -> FFTChannelRunning[0] = VI_TRUE;

	                /* Two channels? */
	                if (size > (2 * (sizeof (TFFTResHeader) + header.NOSL * (sizeof (ViReal32)))))
	                    {
	                    /* ChB */
	                    instrPtr -> FFTChannelRunning[1] = VI_TRUE;
	                    }
	                }
	            else
	                {
	                /* Only ChB, ChA is Off */
	                instrPtr -> FFTChannelRunning[0] = VI_FALSE;
	                instrPtr -> FFTChannelRunning[1] = VI_TRUE;
	                }
			
				/* this section checks the channels - END */
			
				/* this section handles Post FFT - START */
				/* ChA */
	            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
	                {
	                memcpy (&instrPtr -> AnlMeasModDistPostFFT.Header_A, p2buffer,
	                    sizeof (TFFTResHeader));

	                p2buffer += sizeof (TFFTResHeader);

	                memset (instrPtr -> AnlMeasModDistPostFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
	                memcpy (instrPtr -> AnlMeasModDistPostFFT.SpLines_A, p2buffer, instrPtr -> AnlMeasModDistPostFFT.Header_A.NOSL * sizeof (ViReal32));

	                p2buffer += instrPtr -> AnlMeasModDistPostFFT.Header_A.NOSL * sizeof (ViReal32);
	                }
	            else
	                {
	                memset (&instrPtr -> AnlMeasModDistPostFFT.Header_A, 0, sizeof (TFFTResHeader));
	                memset (instrPtr -> AnlMeasModDistPostFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
	                }

	            /* ChB */
	            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
	                {
	                memcpy (&instrPtr -> AnlMeasModDistPostFFT.Header_B, p2buffer, sizeof (TFFTResHeader));

	                p2buffer += sizeof (TFFTResHeader);

	                memset (instrPtr -> AnlMeasModDistPostFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
	                memcpy (instrPtr -> AnlMeasModDistPostFFT.SpLines_B, p2buffer, instrPtr -> AnlMeasModDistPostFFT.Header_B.NOSL * sizeof (ViReal32));

	                p2buffer += instrPtr -> AnlMeasModDistPostFFT.Header_B.NOSL * sizeof (ViReal32);
	                }
	            else
	                {
	                memset (&instrPtr -> AnlMeasModDistPostFFT.Header_B, 0, sizeof (TFFTResHeader));
	                memset (instrPtr -> AnlMeasModDistPostFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
	                }
				/* this section handles Post FFT - END */
			
				/* this section handles MOD DIST data - START */
				p2U32 = (ViUInt32 *)p2buffer;
	            p2S32 = (ViInt32 *)p2buffer;
	            p2F32 = (ViReal32 *)p2buffer;

	            instrPtr -> AnlMeasModDist.Marker1_FFTFrequency    = p2F32[i++];
	            instrPtr -> AnlMeasModDist.Marker2_FFTFrequency    = p2F32[i++];
	            instrPtr -> AnlMeasModDist.Marker1_Value_A         = p2F32[i++];
	            instrPtr -> AnlMeasModDist.Marker2_Value_A         = p2F32[i++];
	            instrPtr -> AnlMeasModDist.Marker1_Value_B         = p2F32[i++];
	            instrPtr -> AnlMeasModDist.Marker2_Value_B         = p2F32[i++];
	            instrPtr -> AnlMeasModDist.Reserved                = p2U32[i++];
	            instrPtr -> AnlMeasModDist.AutotuneLocked_A        = p2S32[i++];

	            for (idx = 0; idx < 6; idx++)
	                instrPtr -> AnlMeasModDist.Frequencies_A[idx]  = p2F32[i++];

	            for (idx = 0; idx < 6; idx++)
	                instrPtr -> AnlMeasModDist.RMSValues_A[idx]    = p2F32[i++];

	            instrPtr -> AnlMeasModDist.AutotuneLocked_B        = p2S32[i++];
            
	            for (idx = 0; idx < 6; idx++)
	                instrPtr -> AnlMeasModDist.Frequencies_B[idx]  = p2F32[i++];

	            for (idx = 0; idx < 6; idx++)
	                instrPtr -> AnlMeasModDist.RMSValues_B[idx]    = p2F32[i++];
				/* this section handles MOD DIST data - END */
			}	
			break;
/* original data storing - START */            
/*			{
            p2buffer = buffer;

            memcpy (&instrPtr -> AnlMeasModDistPostFFT.Header, p2buffer,
                sizeof (TFFTResHeader));

            p2buffer += sizeof (TFFTResHeader);

            memset (instrPtr -> AnlMeasModDistPostFFT.SpLines, 0, FFT_NOSL_MAX * sizeof (ViReal32));
            memcpy (instrPtr -> AnlMeasModDistPostFFT.SpLines, p2buffer, instrPtr -> AnlMeasModDistPostFFT.Header.NOSL * sizeof (ViReal32));
            }
            break;
/* original data storing - END*/			
			
        case MEAS_MOD_DIST_REDUCED_FFT:
            {
            p2buffer = buffer;

            memcpy (&instrPtr -> AnlMeasModDistReducedFFT.HeaderMax, p2buffer,
                sizeof (TFFTResHeader));

            p2buffer += sizeof (TFFTResHeader);

            memset (instrPtr -> AnlMeasModDistReducedFFT.SLmax, 0, FFT_DISPLAY_SIZE_MAX * sizeof (ViReal32));
            memcpy (instrPtr -> AnlMeasModDistReducedFFT.SLmax, p2buffer, instrPtr -> AnlMeasModDistReducedFFT.HeaderMax.NOSL * sizeof (ViReal32));
            }
            break;
        case MEAS_FFT:
        case MEAS_FFT_REDUCED:
            {
            ViUInt16        i = 0;
            ViUInt32        *p2U32;
            ViReal32        *p2F32;

            TFFTResHeader   header = {0};

            p2buffer = buffer;
            
            /* Check how many channels is in the data and which one is the first */
            memcpy (&header, p2buffer, sizeof (TFFTResHeader));
            instrPtr -> FFTChannelRunning[0] = VI_FALSE;
            instrPtr -> FFTChannelRunning[1] = VI_FALSE;

            if (header.ChnlMode & 0x80000000) // Bit 31: 1 = ChA, 0 = ChB
                {
                /* ChA */
                instrPtr -> FFTChannelRunning[0] = VI_TRUE;

                /* Two channels? */
                if (size > (2 * (sizeof (TFFTResHeader) + header.NOSL * sizeof (ViReal32))))
                    {
                    /* ChB */
                    instrPtr -> FFTChannelRunning[1] = VI_TRUE;
                    }
                }
            else
                {
                /* Only ChB, ChA is Off */
                instrPtr -> FFTChannelRunning[0] = VI_FALSE;
                instrPtr -> FFTChannelRunning[1] = VI_TRUE;
                }

            /* ChA */
            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                memcpy (&instrPtr -> AnlMeasFFT.Header_A, p2buffer,
                    sizeof (TFFTResHeader));

                p2buffer += sizeof (TFFTResHeader);

                memset (instrPtr -> AnlMeasFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                memcpy (instrPtr -> AnlMeasFFT.SpLines_A, p2buffer, instrPtr -> AnlMeasFFT.Header_A.NOSL * sizeof (ViReal32));

                p2buffer += instrPtr -> AnlMeasFFT.Header_A.NOSL * sizeof (ViReal32);
                }
            else
                {
                memset (&instrPtr -> AnlMeasFFT.Header_A, 0, sizeof (TFFTResHeader));
                memset (instrPtr -> AnlMeasFFT.SpLines_A, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                }

            /* ChB */
            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                {
                memcpy (&instrPtr -> AnlMeasFFT.Header_B, p2buffer, sizeof (TFFTResHeader));

                p2buffer += sizeof (TFFTResHeader);

                memset (instrPtr -> AnlMeasFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                memcpy (instrPtr -> AnlMeasFFT.SpLines_B, p2buffer, instrPtr -> AnlMeasFFT.Header_B.NOSL * sizeof (ViReal32));

                p2buffer += instrPtr -> AnlMeasFFT.Header_B.NOSL * sizeof (ViReal32);
                }
            else
                {
                memset (&instrPtr -> AnlMeasFFT.Header_B, 0, sizeof (TFFTResHeader));
                memset (instrPtr -> AnlMeasFFT.SpLines_B, 0, FFT_NOSL_MAX * sizeof (ViReal32));
                }

            p2U32 = (ViUInt32 *)p2buffer;
            p2F32 = (ViReal32 *)p2buffer;
            i = 0;
            
            instrPtr -> AnlMeasFFT.Marker1_FFTFrequency = p2F32[i++];
            instrPtr -> AnlMeasFFT.Marker2_FFTFrequency = p2F32[i++];
            instrPtr -> AnlMeasFFT.Marker1_Value_A      = p2F32[i++];
            instrPtr -> AnlMeasFFT.Marker2_Value_A      = p2F32[i++];
            instrPtr -> AnlMeasFFT.Marker1_Value_B      = p2F32[i++];
            instrPtr -> AnlMeasFFT.Marker2_Value_B      = p2F32[i++];
            instrPtr -> AnlMeasFFT.TaskTag              = p2U32[i];
            }
            break;

#if 0 // MEAS_FFT_REDUCED is currently handle the same way as MEAS_FFT

        case MEAS_FFT_REDUCED:
            {
            ViUInt16        i = 0;
            ViUInt32        *p2U32;
            ViReal32        *p2F32;
            TFFTResHeader   header = {0};

            p2buffer = buffer;
            
            /* Check how many channels is in the data and which one is the first */
            memcpy (&header, p2buffer, sizeof (TFFTResHeader));
            instrPtr -> FFTChannelRunning[0] = VI_FALSE;
            instrPtr -> FFTChannelRunning[1] = VI_FALSE;

            if (header.ChnlMode & 0x80000000) // Bit 31: 1 = ChA, 0 = ChB
                {
                /* ChA */
                instrPtr -> FFTChannelRunning[0] = VI_TRUE;

                /* Two channels? */
                if (size > (2 * (sizeof (TFFTResHeader) + header.NOSL * sizeof (ViReal32))))
                    {
                    /* ChB */
                    instrPtr -> FFTChannelRunning[1] = VI_TRUE;
                    }
                }
            else
                {
                /* Only ChB, ChA is Off */
                instrPtr -> FFTChannelRunning[0] = VI_FALSE;
                instrPtr -> FFTChannelRunning[1] = VI_TRUE;
                }

            /* ChA ... min values are not currently used */
            if (instrPtr -> FFTChannelRunning[0] == VI_TRUE)
                {
                memcpy (&instrPtr -> AnlMeasFFTReduced.Header_A_max, p2buffer,
                    sizeof (TFFTResHeader));

                p2buffer += sizeof (TFFTResHeader);

                memset (instrPtr -> AnlMeasFFTReduced.SpLnMax_A_max, 0, FFT_DISPLAY_SIZE_MAX * sizeof (ViReal32));
                memcpy (instrPtr -> AnlMeasFFTReduced.SpLnMax_A_max, p2buffer, instrPtr -> AnlMeasFFTReduced.Header_A_max.NOSL * sizeof (ViReal32));

                p2buffer += instrPtr -> AnlMeasFFTReduced.Header_A_max.NOSL * sizeof (ViReal32);
                }
            else
                {
                memset (&instrPtr -> AnlMeasFFTReduced.Header_A_max, 0, sizeof (TFFTResHeader));
                memset (instrPtr -> AnlMeasFFTReduced.SpLnMax_A_max, 0, FFT_DISPLAY_SIZE_MAX * sizeof (ViReal32));
                }

            /* ChB ... min values are not currently used */
            if (instrPtr -> FFTChannelRunning[1] == VI_TRUE)
                {
                memcpy (&instrPtr -> AnlMeasFFTReduced.Header_B_max, p2buffer, sizeof (TFFTResHeader));

                p2buffer += sizeof (TFFTResHeader);

                memset (instrPtr -> AnlMeasFFTReduced.SpLnMax_B_max, 0, FFT_DISPLAY_SIZE_MAX * sizeof (ViReal32));
                memcpy (instrPtr -> AnlMeasFFTReduced.SpLnMax_B_max, p2buffer, instrPtr -> AnlMeasFFTReduced.Header_B_max.NOSL * sizeof (ViReal32));

                p2buffer += instrPtr -> AnlMeasFFTReduced.Header_B_max.NOSL * sizeof (ViReal32);
                }
            else
                {
                memset (&instrPtr -> AnlMeasFFTReduced.Header_B_max, 0, sizeof (TFFTResHeader));
                memset (instrPtr -> AnlMeasFFTReduced.SpLnMax_B_max, 0, FFT_DISPLAY_SIZE_MAX * sizeof (ViReal32));
                }

            p2U32 = (ViUInt32 *)p2buffer;
            p2F32 = (ViReal32 *)p2buffer;
            i = 0;

            instrPtr -> AnlMeasFFTReduced.Marker1_FFTFrequency = p2F32[i++];
            instrPtr -> AnlMeasFFTReduced.Marker2_FFTFrequency = p2F32[i++];
            instrPtr -> AnlMeasFFTReduced.Marker1_Value_A      = p2F32[i++];
            instrPtr -> AnlMeasFFTReduced.Marker2_Value_A      = p2F32[i++];
            instrPtr -> AnlMeasFFTReduced.Marker1_Value_B      = p2F32[i++];
            instrPtr -> AnlMeasFFTReduced.Marker2_Value_B      = p2F32[i++];
            instrPtr -> AnlMeasFFTReduced.TaskTag              = p2U32[i];

            break;
            }

#endif // MEAS_FFT_REDUCED

        case MEAS_DAI_SAMPLING_FREQUENCY:
            {
            ViReal32    *p2data;

            p2data = (ViReal32 *)buffer;

            instrPtr -> AnlMeasDAISamplingFrequency.DAISamplFreq = *p2data;

            break;
            }
        case MEAS_DAI_PROTOCOL:
            {
            ViChar      *p2data;
            ViUInt16    *p2short;

            p2data = (ViChar *)buffer;

            memcpy (instrPtr -> AnlMeasDAIProtocol.ChannelStatusA, p2data, 24);
            p2data += 24;
            memcpy (instrPtr -> AnlMeasDAIProtocol.ChannelStatusB, p2data, 24);
            p2data += 24;

            p2short = (ViUInt16 *)p2data;
            instrPtr -> AnlMeasDAIProtocol.ReceiveError = *p2short;

            break;
            }
		case MEAS_RMS_SWEEP:
			{
			ViUInt16    i   = 0;
            ViUInt32    *p2U32;
            ViInt16     *p2S16;
            ViUInt16    *p2U16;
            ViReal32    *p2F32;
			
			p2U32 = (ViUInt32 *)buffer;
            p2S16 = (ViInt16 *)buffer;
            p2U16 = (ViUInt16 *)buffer;
            p2F32 = (ViReal32 *)buffer;

            instrPtr->AnlMeasRMSSweep.bAmSweepInside  = p2S16[0];	
			instrPtr->AnlMeasRMSSweep.wAmSweepRepCnt  = p2U16[1];
			instrPtr->AnlMeasRMSSweep.wFrSweepRepCnt  = p2U16[2];
			instrPtr->AnlMeasRMSSweep.wSampleCount    = p2U16[3];
			instrPtr->AnlMeasRMSSweep.wFrSwStep       = p2U16[4];
			instrPtr->AnlMeasRMSSweep.wFrSwStCnt      = p2U16[5];
			instrPtr->AnlMeasRMSSweep.Fr1spacing      = p2U16[6];
			instrPtr->AnlMeasRMSSweep.Fr2spacing      = p2U16[7];
			instrPtr->AnlMeasRMSSweep.fiFr1start      = p2F32[4];
			instrPtr->AnlMeasRMSSweep.fiFr1end        = p2F32[5];
			instrPtr->AnlMeasRMSSweep.fiFr2start      = p2F32[6];
			instrPtr->AnlMeasRMSSweep.fiFr2end        = p2F32[7];
			instrPtr->AnlMeasRMSSweep.fiActualFr1     = p2F32[8];
			instrPtr->AnlMeasRMSSweep.fiActualFr2     = p2F32[9];
			instrPtr->AnlMeasRMSSweep.wAmSwStep       = p2U16[20];
			instrPtr->AnlMeasRMSSweep.wAmSwStCnt      = p2U16[21];
			instrPtr->AnlMeasRMSSweep.Am1spacing[0]   = p2U16[22];
			instrPtr->AnlMeasRMSSweep.Am1spacing[1]   = p2U16[23];
			instrPtr->AnlMeasRMSSweep.Am2spacing[0]   = p2U16[24];
			instrPtr->AnlMeasRMSSweep.Am2spacing[1]   = p2U16[25];
			instrPtr->AnlMeasRMSSweep.fiAm1start[0]   = p2F32[13];
			instrPtr->AnlMeasRMSSweep.fiAm1start[1]   = p2F32[14];
			instrPtr->AnlMeasRMSSweep.fiAm1end[0]     = p2F32[15];
			instrPtr->AnlMeasRMSSweep.fiAm1end[1]     = p2F32[16];
			instrPtr->AnlMeasRMSSweep.fiAm2start[0]   = p2F32[17];
			instrPtr->AnlMeasRMSSweep.fiAm2start[1]   = p2F32[18];
			instrPtr->AnlMeasRMSSweep.fiAm2end[0]     = p2F32[19];
			instrPtr->AnlMeasRMSSweep.fiAm2end[1]     = p2F32[20];
			instrPtr->AnlMeasRMSSweep.fiActualAm1[0]  = p2F32[21];
			instrPtr->AnlMeasRMSSweep.fiActualAm1[1]  = p2F32[22];
			instrPtr->AnlMeasRMSSweep.fiActualAm2[0]  = p2F32[23];
			instrPtr->AnlMeasRMSSweep.fiActualAm2[1]  = p2F32[24];
			instrPtr->AnlMeasRMSSweep.wStartSwCnt     = p2U16[50];
			instrPtr->AnlMeasRMSSweep.ReasonOfSending = p2S16[51];
			instrPtr->AnlMeasRMSSweep.Reserve[0]      = p2U32[26];
			instrPtr->AnlMeasRMSSweep.Reserve[1]      = p2U32[27];
			
			memset (instrPtr->AnlMeasRMSSweep.Sample, 0, 4 * RMS_SWEEP_MAX_SAMPLES * sizeof (ViReal32));
            //memcpy (instrPtr->AnlMeasRMSSweep.Sample, p2buffer, instrPtr->AnlMeasRMSSweep.wSampleCount * sizeof (ViReal32));

			for (i = 0; i < instrPtr->AnlMeasRMSSweep.wSampleCount; i++)
			{
				instrPtr->AnlMeasRMSSweep.Sample[i].fiFr1AmA = p2F32[28+i*4];
				instrPtr->AnlMeasRMSSweep.Sample[i].fiFr2AmB = p2F32[28+1+i*4];
				instrPtr->AnlMeasRMSSweep.Sample[i].fiRmsA   = p2F32[28+2+i*4];
				instrPtr->AnlMeasRMSSweep.Sample[i].fiRmsB   = p2F32[28+3+i*4];
			}
			
			break;
			}
			
		case MEAS_RMS_SELECTIVE_SWEEP:
			{
			ViUInt16    i   = 0;
            ViUInt32    *p2U32;
            ViInt16     *p2S16;
            ViUInt16    *p2U16;
            ViReal32    *p2F32;
			ViInt32     *p2S32;
			
			p2buffer = buffer;
            p2U32 = (ViUInt32 *)buffer;
            p2S16 = (ViInt16 *)buffer;
            p2U16 = (ViUInt16 *)buffer;
            p2F32 = (ViReal32 *)buffer;
			p2S32 = (ViInt32 *)buffer;
            
            instrPtr->AnlMeasRMSSelectiveSweep.bAmSweepInside  = p2S16[0];	
			instrPtr->AnlMeasRMSSelectiveSweep.wAmSweepRepCnt  = p2U16[1];
			instrPtr->AnlMeasRMSSelectiveSweep.wFrSweepRepCnt  = p2U16[2];
			instrPtr->AnlMeasRMSSelectiveSweep.wSampleCount    = p2U16[3];
			instrPtr->AnlMeasRMSSelectiveSweep.wFrSwStep       = p2U16[4];
			instrPtr->AnlMeasRMSSelectiveSweep.wFrSwStCnt      = p2U16[5];
			instrPtr->AnlMeasRMSSelectiveSweep.FrGen1spacing   = p2U16[6];
			instrPtr->AnlMeasRMSSelectiveSweep.FrGen2spacing   = p2U16[7];
			instrPtr->AnlMeasRMSSelectiveSweep.FrAnlAspacing   = p2U16[8];
			instrPtr->AnlMeasRMSSelectiveSweep.FrAnlBspacing   = p2U16[9];
			instrPtr->AnlMeasRMSSelectiveSweep.fiFrGen1start   = p2F32[5];
			instrPtr->AnlMeasRMSSelectiveSweep.fiFrGen1end     = p2F32[6];
			instrPtr->AnlMeasRMSSelectiveSweep.fiFrGen2start   = p2F32[7];
			instrPtr->AnlMeasRMSSelectiveSweep.fiFrGen2end     = p2F32[8];
			instrPtr->AnlMeasRMSSelectiveSweep.fiFrAnlAstart   = p2F32[9];
			instrPtr->AnlMeasRMSSelectiveSweep.fiFrAnlAend     = p2F32[10];
			instrPtr->AnlMeasRMSSelectiveSweep.fiFrAnlBstart   = p2F32[11];
			instrPtr->AnlMeasRMSSelectiveSweep.fiFrAnlBend     = p2F32[12];
			instrPtr->AnlMeasRMSSelectiveSweep.fiActualFrGen1  = p2F32[13];
			instrPtr->AnlMeasRMSSelectiveSweep.fiActualFrGen2  = p2F32[14];
			instrPtr->AnlMeasRMSSelectiveSweep.fiActualFrAnlA  = p2F32[15];
			instrPtr->AnlMeasRMSSelectiveSweep.fiActualFrAnlB  = p2F32[16];
			instrPtr->AnlMeasRMSSelectiveSweep.wAmSwStep       = p2U16[34];
			instrPtr->AnlMeasRMSSelectiveSweep.wAmSwStCnt      = p2U16[35];
			instrPtr->AnlMeasRMSSelectiveSweep.Am1spacing[0]   = p2U16[36];
			instrPtr->AnlMeasRMSSelectiveSweep.Am1spacing[1]   = p2U16[37];
			instrPtr->AnlMeasRMSSelectiveSweep.Am2spacing[0]   = p2U16[38];
			instrPtr->AnlMeasRMSSelectiveSweep.Am2spacing[1]   = p2U16[39];
			instrPtr->AnlMeasRMSSelectiveSweep.fiAm1start[0]   = p2F32[20];
			instrPtr->AnlMeasRMSSelectiveSweep.fiAm1start[1]   = p2F32[21];
			instrPtr->AnlMeasRMSSelectiveSweep.fiAm1end[0]     = p2F32[22];
			instrPtr->AnlMeasRMSSelectiveSweep.fiAm1end[1]     = p2F32[23];
			instrPtr->AnlMeasRMSSelectiveSweep.fiAm2start[0]   = p2F32[24];
			instrPtr->AnlMeasRMSSelectiveSweep.fiAm2start[1]   = p2F32[25];
			instrPtr->AnlMeasRMSSelectiveSweep.fiAm2end[0]     = p2F32[26];
			instrPtr->AnlMeasRMSSelectiveSweep.fiAm2end[1]     = p2F32[27];
			instrPtr->AnlMeasRMSSelectiveSweep.fiActualAm1[0]  = p2F32[28];
			instrPtr->AnlMeasRMSSelectiveSweep.fiActualAm1[1]  = p2F32[29];
			instrPtr->AnlMeasRMSSelectiveSweep.fiActualAm2[0]  = p2F32[30];
			instrPtr->AnlMeasRMSSelectiveSweep.fiActualAm2[1]  = p2F32[31];
			instrPtr->AnlMeasRMSSelectiveSweep.wStartSwCnt     = p2U16[64];
			instrPtr->AnlMeasRMSSelectiveSweep.ReasonOfSending = p2S16[65];
			instrPtr->AnlMeasRMSSelectiveSweep.dwRSmReserve[0] = p2U32[33];
			instrPtr->AnlMeasRMSSelectiveSweep.dwRSmReserve[1] = p2U32[34];
			instrPtr->AnlMeasRMSSelectiveSweep.dwRSmReserve[2] = p2U32[35];
			instrPtr->AnlMeasRMSSelectiveSweep.dwFrameReserve[0] = p2U32[36];
			instrPtr->AnlMeasRMSSelectiveSweep.dwFrameReserve[1] = p2U32[37];
			instrPtr->AnlMeasRMSSelectiveSweep.dwFrameReserve[2] = p2U32[38];
			instrPtr->AnlMeasRMSSelectiveSweep.dwFrameReserve[3] = p2U32[39];
			
			memset (instrPtr->AnlMeasRMSSelectiveSweep.Sample, 0, 10 * RMS_SEL_SWEEP_MAX_SAMPLES * sizeof (ViReal32));
            //memcpy (instrPtr->AnlMeasRMSSelectiveSweep.Sample, p2buffer, instrPtr->AnlMeasRMSSelectiveSweep.wSampleCount * sizeof (ViReal32));

			for (i = 0; i < instrPtr->AnlMeasRMSSelectiveSweep.wSampleCount; i++)
			{
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFr1AmA             = p2F32[40+i*10];
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFr2AmB             = p2F32[40+1+i*10];
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFrAAnl             = p2F32[40+2+i*10];
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].fiFrBAnl             = p2F32[40+3+i*10];
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmA.iAutoTuneLocked = p2S32[40+4+i*10];
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmA.fiFrequency     = p2F32[40+5+i*10];
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmA.fiRMS           = p2F32[40+6+i*10];
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmB.iAutoTuneLocked = p2S32[40+7+i*10];
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmB.fiFrequency     = p2F32[40+8+i*10];
				instrPtr->AnlMeasRMSSelectiveSweep.Sample[i].RSmB.fiRMS           = p2F32[40+9+i*10];
			}
			break;
			}
			
		case MEAS_THD_SWEEP:
			{
			ViUInt16    i   = 0;
            ViUInt16    idx = 0;
            ViUInt32    *p2U32;
            ViInt16     *p2S16;
            ViUInt16    *p2U16;
            ViReal32    *p2F32;
			ViInt32     *p2S32;
			
			p2buffer = buffer;
            p2U32 = (ViUInt32 *)buffer;
            p2S16 = (ViInt16 *)buffer;
            p2U16 = (ViUInt16 *)buffer;
            p2F32 = (ViReal32 *)buffer;
			p2S32 = (ViInt32 *)buffer;

            instrPtr->AnlMeasTHDSweep.bAmSweepInside  = p2S16[0];	
			instrPtr->AnlMeasTHDSweep.wAmSweepRepCnt  = p2U16[1];
			instrPtr->AnlMeasTHDSweep.wFrSweepRepCnt  = p2U16[2];
			instrPtr->AnlMeasTHDSweep.wSampleCount    = p2U16[3];
			instrPtr->AnlMeasTHDSweep.wFrSwStep       = p2U16[4];
			instrPtr->AnlMeasTHDSweep.wFrSwStCnt      = p2U16[5];
			instrPtr->AnlMeasTHDSweep.FrGen1spacing   = p2U16[6];
			instrPtr->AnlMeasTHDSweep.FrGen2spacing   = p2U16[7];
			instrPtr->AnlMeasTHDSweep.FrAnlAspacing   = p2U16[8];
			instrPtr->AnlMeasTHDSweep.FrAnlBspacing   = p2U16[9];
			instrPtr->AnlMeasTHDSweep.fiFrGen1start   = p2F32[5];
			instrPtr->AnlMeasTHDSweep.fiFrGen1end     = p2F32[6];
			instrPtr->AnlMeasTHDSweep.fiFrGen2start   = p2F32[7];
			instrPtr->AnlMeasTHDSweep.fiFrGen2end     = p2F32[8];
			instrPtr->AnlMeasTHDSweep.fiFrAnlAstart   = p2F32[9];
			instrPtr->AnlMeasTHDSweep.fiFrAnlAend     = p2F32[10];
			instrPtr->AnlMeasTHDSweep.fiFrAnlBstart   = p2F32[11];
			instrPtr->AnlMeasTHDSweep.fiFrAnlBend     = p2F32[12];
			instrPtr->AnlMeasTHDSweep.fiActualFrGen1  = p2F32[13];
			instrPtr->AnlMeasTHDSweep.fiActualFrGen2  = p2F32[14];
			instrPtr->AnlMeasTHDSweep.fiActualFrAnlA  = p2F32[15];
			instrPtr->AnlMeasTHDSweep.fiActualFrAnlB  = p2F32[16];
			instrPtr->AnlMeasTHDSweep.wAmSwStep       = p2U16[34];
			instrPtr->AnlMeasTHDSweep.wAmSwStCnt      = p2U16[35];
			instrPtr->AnlMeasTHDSweep.Am1spacing[0]   = p2U16[36];
			instrPtr->AnlMeasTHDSweep.Am1spacing[1]   = p2U16[37];
			instrPtr->AnlMeasTHDSweep.Am2spacing[0]   = p2U16[38];
			instrPtr->AnlMeasTHDSweep.Am2spacing[1]   = p2U16[39];
			instrPtr->AnlMeasTHDSweep.fiAm1start[0]   = p2F32[20];
			instrPtr->AnlMeasTHDSweep.fiAm1start[1]   = p2F32[21];
			instrPtr->AnlMeasTHDSweep.fiAm1end[0]     = p2F32[22];
			instrPtr->AnlMeasTHDSweep.fiAm1end[1]     = p2F32[23];
			instrPtr->AnlMeasTHDSweep.fiAm2start[0]   = p2F32[24];
			instrPtr->AnlMeasTHDSweep.fiAm2start[1]   = p2F32[25];
			instrPtr->AnlMeasTHDSweep.fiAm2end[0]     = p2F32[26];
			instrPtr->AnlMeasTHDSweep.fiAm2end[1]     = p2F32[27];
			instrPtr->AnlMeasTHDSweep.fiActualAm1[0]  = p2F32[28];
			instrPtr->AnlMeasTHDSweep.fiActualAm1[1]  = p2F32[29];
			instrPtr->AnlMeasTHDSweep.fiActualAm2[0]  = p2F32[30];
			instrPtr->AnlMeasTHDSweep.fiActualAm2[1]  = p2F32[31];
			instrPtr->AnlMeasTHDSweep.wStartSwCnt     = p2U16[64];
			instrPtr->AnlMeasTHDSweep.ReasonOfSending = p2S16[65];
			instrPtr->AnlMeasTHDSweep.dwRSmReserve[0] = p2U32[33];
			instrPtr->AnlMeasTHDSweep.dwRSmReserve[1] = p2U32[34];
			instrPtr->AnlMeasTHDSweep.dwRSmReserve[2] = p2U32[35];
			instrPtr->AnlMeasTHDSweep.dwFrameReserve[0] = p2U32[36];
			instrPtr->AnlMeasTHDSweep.dwFrameReserve[1] = p2U32[37];
			instrPtr->AnlMeasTHDSweep.dwFrameReserve[2] = p2U32[38];
			instrPtr->AnlMeasTHDSweep.dwFrameReserve[3] = p2U32[39];
			
			memset (instrPtr->AnlMeasTHDSweep.Sample, 0, 40 * THD_SWEEP_MAX_SAMPLES * sizeof (ViReal32));
            //memcpy (instrPtr->AnlMeasTHDSweep.Sample, p2buffer, instrPtr->AnlMeasTHDSweep.wSampleCount * sizeof (ViReal32));

			for (i = 0; i < instrPtr->AnlMeasTHDSweep.wSampleCount; i++)
			{
				instrPtr->AnlMeasTHDSweep.Sample[i].fiFr1AmA                   = p2F32[40+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].fiFr2AmB                   = p2F32[40+1+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].fiFrAAnl                   = p2F32[40+2+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].fiFrBAnl                   = p2F32[40+3+i*40];
				
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.AutoTuneLocked        = p2S32[40+4+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.Frequency             = p2F32[40+5+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.TotalRMS_THDN         = p2F32[40+6+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.Noise_THDN            = p2F32[40+7+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.TotalRMS_THDN_NonFund = p2F32[40+8+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.TotalRMS_THD          = p2F32[40+9+i*40];	
				
				for (idx = 0; idx < 10; idx++)
				{
					instrPtr->AnlMeasTHDSweep.Sample[i].ThdA.Harmonic[idx]     = p2F32[40+10 + idx + i*40];
				}
				
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.AutoTuneLocked        = p2S32[40+20+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.Frequency             = p2F32[40+21+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.TotalRMS_THDN         = p2F32[40+22+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.Noise_THDN            = p2F32[40+23+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.TotalRMS_THDN_NonFund = p2F32[40+24+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.TotalRMS_THD          = p2F32[40+25+i*40];	
	
				for (idx = 0; idx < 10; idx++)
				{
					instrPtr->AnlMeasTHDSweep.Sample[i].ThdB.Harmonic[idx]     = p2F32[40+26 + idx + i*40];
				}
				
				instrPtr->AnlMeasTHDSweep.Sample[i].fiSampleResrve[0]          = p2F32[40+36+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].fiSampleResrve[1]          = p2F32[40+37+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].fiSampleResrve[2]          = p2F32[40+38+i*40];
				instrPtr->AnlMeasTHDSweep.Sample[i].fiSampleResrve[3]          = p2F32[40+39+i*40];
			}
			
			break;
			}
			
        default:
            /* Wait if it is necessary */
            rssiup_delay (0.005);
        }

    return rssiup_status;
}

/*===========================================================================*/
/* Function: Coerce to nearest in structure                                  */
/* Purpose:  This function is used to coerce entered value to the nearest    */
/*           value from the discreete table.                                 */
/*===========================================================================*/
void rssiup_coerceToNearestMixedValPair (void *table, ViPReal64 value, ViPInt16 index)
{
    TSMixedValPair *p2table = table;

    *index = 0;

    while ((*value > p2table -> value) && (fabs (p2table -> value) > NUMERIC_PRECISION))
        {
        *(++p2table);
        (*index)++;
        }

    if ((*value > NUMERIC_PRECISION) && (*index > 0))
        {
        if (fabs ((*value - ((--p2table) -> value)) / 2) < fabs ((*value - ((++p2table) -> value)) / 2))
            {
            *value = ((--p2table) -> value);
            (*index)--;
            }
        else
            {
            *value = p2table -> value;
            }
        }
    else
        {
        *value = p2table -> value;
        *index = 0;
        }

    return;
}

/*===========================================================================*/
/* Function: Float to Double
/* Purpose:  Copy float values to double values.
/*===========================================================================*/
void rssiup_float_to_double(ViReal64 *target, ViReal32 *source, ViUInt16 values)
{
   ViUInt16 idx         = 0;
   ViReal32 *p2source   = source;
   ViReal64 *p2target   = target;

   for (idx = 0; idx < values; idx++)
      *p2target++ = (ViReal64)*p2source++;

   return;
}

/*===========================================================================*/
/* Function: Recalculate FFT Measurement
/* Purpose:  This function recalculates raw FFT to the exportable values.
/*===========================================================================*/
void rssiup_recalculateFFTMeasurement (TFFTResHeader fftResponseHeader,
                                       ViReal64 spectralLines[],
                                       ViInt32 analyzerMode)
{
/* --- FFT Header ---

      0 - Function ID copied from parameters.
      1 - FFT size: 1024, 2048, 4096, 8192 or 16384
      2 - Number of valid spectral lines.
      3 - Shift of frequency axis.
      4 - Averaging Mode:
            0 - Exponencial
            1 - Normal
      5 - Number of measurements incoming to the averaging.
      6 - Averaging Quotient (type cast it to ViReal32).
      7 - Reserved
      8 - Reserved
      9 - Sampling frequency in Hz (type cast it to ViReal32).
      10 - Window Size; Block size within original FFT spectrum.
      11 - Display Size; Size of display in pixels.
      12 - Reserved
      13 - Reserved
      14 - Reserved
      15 - Channel Mode:
             Bit 31: 1 = Channel A
                     0 = Channel B
             Bit 30: 1 = Maximum
                     0 = Minimum

*/

    ViReal32   *Q       = &fftResponseHeader.AverQuotient;
    ViUInt32    FFTsize = fftResponseHeader.FFTSize,
                N       = fftResponseHeader.AverCount,
                noLines = fftResponseHeader.NOSL,
                i       = 0;

    if (fftResponseHeader.AverMode == 1) /* Normal averaging */
        {
        for (i = 0; i < noLines; i++)
            {
            spectralLines[i] = sqrt (spectralLines[i] / N) / FFTsize;

            if (analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL)
                spectralLines[i] *= sqrt (2.0);
            }
        }
    else /* == 0) ... Exponencial averaging */
        {
        for (i = 0; i < noLines; i++)
            {
            spectralLines[i] = sqrt (spectralLines[i] * (1.0 - *Q)) / FFTsize;

            if (analyzerMode == RSSIUP_ANALYZER_MODE_DIGITAL)
                spectralLines[i] *= sqrt (2.0);
            }
        }

    return;
}

/*===========================================================================*/
/* Function: Get Generator Sampling Frequency
/* Purpose:  Returns actual generator sampling frequency.
/*===========================================================================*/
ViStatus rssiup_GetGeneratorSamplingFrequency (ViSession instrSession, ViPReal64 samplingFrequency)
{
    ViStatus            rssiup_status   = VI_SUCCESS;
    ViUInt16            value           = 0;
    pTStatusDataRanges  instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    if (!samplingFrequency)
        return VI_ERROR_PARAMETER2;

    CHECKERR (rssiup_DSI_Get (instrSession, DSI_GET_GENHW_DEVICE_SELECTOR, ChAB, &value, sizeof(value)));

    /* Sampling frequencies are hardcoded */
    switch (value)
        {
        case dsA49:
            *samplingFrequency = 48828.125; /* Analog */
            break;
        case dsA98:
            *samplingFrequency = 97656.250; /* Analog */
            break;
        case dsA195:
            *samplingFrequency = 195312.500; /* Analog */
            break;
        case dsD32:
            *samplingFrequency = 32000; /* Digital */
            break;
        case dsD44:
            *samplingFrequency = 44100; /* Digital */
            break;
        case dsD48:
            *samplingFrequency = 48000; /* Digital */
            break;
        case dsD96:
            *samplingFrequency = 96000; /* Digital */
            break;
        case dsD192:
            *samplingFrequency = 192000; /* Digital */
            break;
        default:
            return VI_ERROR_INV_RESPONSE;
        }

    CHECKERR (rssiup_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiup_status;
}
/*===========================================================================*/
/* Function: Coerce to nearest                                               */
/* Purpose:  This function is used to coerce entered value to the nearest    */
/*           value from the discreete table. Data are in ascending order!    */
/*===========================================================================*/
void rssiup_coerceToNearest (void *table, ViPReal64 value, ViPInt16 index)
{
    ViReal64 *p2table = table;

    *index = 0;

    while ((*value > *p2table) && (fabs (*p2table) > NUMERIC_PRECISION))
        {
        *(++p2table);
        (*index)++;
        }

    if ((*value > NUMERIC_PRECISION) && (*index > 0))
        {
        if (fabs ((*value - *(--p2table)) / 2) < fabs ((*value - *(++p2table)) / 2))
            {
            *value = *(--p2table);
            (*index)--;
            }
        else
            {
            *value = *p2table;
            }
        }
    else
        {
        *value = *p2table;
        *index = 0;
        }

    return;
}

/*===========================================================================*/
/* Function: Clear Analyzer Function Results                                 */
/* Purpose:  This function is used to clear all cached data before new       */
/*           measurement data are returned.                                  */
/*===========================================================================*/
ViStatus rssiup_clearAnalyzerFunctionResults (ViSession instrSession)
{
	ViStatus            rssiup_status   = VI_SUCCESS;
    ViInt32				i;
	pTStatusDataRanges  instrPtr        = {0};
	
	CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKSESSION (instrSession);

    instrPtr->AnlMeasPeak.PeakMax_A = 0.0;
	instrPtr->AnlMeasPeak.PeakMin_A = 0.0;
	instrPtr->AnlMeasPeak.PeakMax_B = 0.0;       
	instrPtr->AnlMeasPeak.PeakMin_B = 0.0;

	instrPtr->AnlMeasRMSDC.AsynchroIndication_A  = 0;
	instrPtr->AnlMeasRMSDC.Valid_A = 0;
	instrPtr->AnlMeasRMSDC.DC_A = 0.0;
	instrPtr->AnlMeasRMSDC.SqrRMS_A = 0.0;
	instrPtr->AnlMeasRMSDC.Frequency_A = 0.0;
	instrPtr->AnlMeasRMSDC.AsynchroIndication_B = 0;
	instrPtr->AnlMeasRMSDC.Valid_B = 0;
	instrPtr->AnlMeasRMSDC.DC_B = 0.0;
	instrPtr->AnlMeasRMSDC.SqrRMS_B = 0.0; 
	instrPtr->AnlMeasRMSDC.Frequency_B = 0.0;

	instrPtr->AnlMeasQpeak.QuasiPeakMax_A = 0.0;
	instrPtr->AnlMeasQpeak.QuasiPeakMin_A = 0.0;
	instrPtr->AnlMeasQpeak.QuasiPeakCurrentValue_A = 0.0;
	instrPtr->AnlMeasQpeak.QuasiPeakMax_B = 0.0;
	instrPtr->AnlMeasQpeak.QuasiPeakMin_B = 0.0;
	instrPtr->AnlMeasQpeak.QuasiPeakCurrentValue_B = 0.0;

	instrPtr->AnlMeasRMSSel.SqrRMSValue_A = 0.0;
	instrPtr->AnlMeasRMSSel.SqrRMSValue_B = 0.0;
	instrPtr->AnlMeasRMSSel.Valid = 0;

	instrPtr->AnlMeasTHDN.Marker1_FFTFreq = 0.0;
	instrPtr->AnlMeasTHDN.Marker2_FFTFreq = 0.0;
	instrPtr->AnlMeasTHDN.Marker1_A_Value = 0.0;
	instrPtr->AnlMeasTHDN.Marker2_A_Value = 0.0;
	instrPtr->AnlMeasTHDN.Marker1_B_Value = 0.0;
	instrPtr->AnlMeasTHDN.Marker2_B_Value = 0.0;
	instrPtr->AnlMeasTHDN.Tag = 0;
	instrPtr->AnlMeasTHDN.AutoTuneLocked_A = 0;
	instrPtr->AnlMeasTHDN.Frequency_A = 0.0;
	instrPtr->AnlMeasTHDN.TotalRMS_A_THDN = 0.0;
	instrPtr->AnlMeasTHDN.Noise_A_THDN = 0.0;
	instrPtr->AnlMeasTHDN.TotalRMS_A_THDN_NonFund = 0.0;
	instrPtr->AnlMeasTHDN.TotalRMS_A_THD = 0.0;
	instrPtr->AnlMeasTHDN.AutoTuneLocked_B = 0;
	instrPtr->AnlMeasTHDN.Frequency_B = 0.0;
	instrPtr->AnlMeasTHDN.TotalRMS_B_THDN = 0.0;
	instrPtr->AnlMeasTHDN.Noise_B_THDN = 0.0;
	instrPtr->AnlMeasTHDN.TotalRMS_B_THDN_NonFund = 0.0;
	instrPtr->AnlMeasTHDN.TotalRMS_B_THD = 0.0;

	instrPtr->AnlMeasTHDNPostFFT.Header_A.FunId = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.FFTSize = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.NOSL = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.SptrOffset = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.AverMode = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.AverCount = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.AverQuotient = 0.0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.ZoomFactor = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.ZoomOffset = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.SamplFreq = 0.0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.WindowSize = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.DisplaySize = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.Reserved_1 = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.Reserved_2 = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.Reserved_3 = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_A.ChnlMode = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.FunId = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.FFTSize = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.NOSL = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.SptrOffset = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.AverMode = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.AverCount = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.AverQuotient = 0.0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.ZoomFactor = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.ZoomOffset = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.SamplFreq = 0.0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.WindowSize = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.DisplaySize = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.Reserved_1 = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.Reserved_2 = 0;
	instrPtr->AnlMeasTHDNPostFFT.Header_B.Reserved_3 = 0;

	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.FunId = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.FFTSize = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.NOSL = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.SptrOffset = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.AverMode = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.AverCount = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.AverQuotient = 0.0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.ZoomFactor = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.ZoomOffset = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.SamplFreq = 0.0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.WindowSize = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.DisplaySize = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.Reserved_1 = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.Reserved_2 = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.Reserved_3 = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMax.ChnlMode = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.FunId = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.FFTSize = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.NOSL = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.SptrOffset = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.AverMode = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.AverCount = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.AverQuotient = 0.0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.ZoomFactor = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.ZoomOffset = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.SamplFreq = 0.0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.WindowSize = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.DisplaySize = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.Reserved_1 = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.Reserved_2 = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.Reserved_3 = 0;
	instrPtr->AnlMeasTHDNReducedFFT.HeaderMin.ChnlMode = 0;

	instrPtr->AnlMeasPhase.Marker1_FFTFrequency = 0.0;
	instrPtr->AnlMeasPhase.Marker2_FFTFrequency = 0.0;
	instrPtr->AnlMeasPhase.Marker1_Value_A = 0.0;
	instrPtr->AnlMeasPhase.Marker2_Value_A = 0.0;
	instrPtr->AnlMeasPhase.Marker1_Value_B = 0.0;
	instrPtr->AnlMeasPhase.Marker2_Value_B = 0.0;
	instrPtr->AnlMeasPhase.Reserved = 0;
	instrPtr->AnlMeasPhase.AutotuneLocked = 0;
	instrPtr->AnlMeasPhase.Master = 0;
	instrPtr->AnlMeasPhase.PhaseDifference = 0.0;
	instrPtr->AnlMeasPhase.Frequency = 0.0;

	instrPtr->AnlMeasPhasePostFFT.Header.FunId = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.FFTSize = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.NOSL = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.SptrOffset = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.AverMode = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.AverCount = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.AverQuotient = 0.0;
	instrPtr->AnlMeasPhasePostFFT.Header.ZoomFactor = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.ZoomOffset = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.SamplFreq = 0.0;
	instrPtr->AnlMeasPhasePostFFT.Header.WindowSize = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.DisplaySize = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.Reserved_1 = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.Reserved_2 = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.Reserved_3 = 0;
	instrPtr->AnlMeasPhasePostFFT.Header.ChnlMode = 0;

	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.FunId = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.FFTSize = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.NOSL = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.SptrOffset = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.AverMode = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.AverCount = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.AverQuotient = 0.0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.ZoomFactor = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.ZoomOffset = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.SamplFreq = 0.0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.WindowSize = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.DisplaySize = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.Reserved_1 = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.Reserved_2 = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.Reserved_3 = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMax.ChnlMode = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.FunId = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.FFTSize = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.NOSL = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.SptrOffset = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.AverMode = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.AverCount = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.AverQuotient = 0.0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.ZoomFactor = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.ZoomOffset = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.SamplFreq = 0.0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.WindowSize = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.DisplaySize = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.Reserved_1 = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.Reserved_2 = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.Reserved_3 = 0;
	instrPtr->AnlMeasPhaseReducedFFT.HeaderMin.ChnlMode = 0;

	instrPtr->AnlMeasDFD.Marker1_FFTFrequency = 0.0;
	instrPtr->AnlMeasDFD.Marker2_FFTFrequency = 0.0;
	instrPtr->AnlMeasDFD.Marker1_Value_A = 0.0;
	instrPtr->AnlMeasDFD.Marker2_Value_A = 0.0;
	instrPtr->AnlMeasDFD.Marker1_Value_B = 0.0;
	instrPtr->AnlMeasDFD.Marker2_Value_B = 0.0;
	instrPtr->AnlMeasDFD.Reserved = 0;
	instrPtr->AnlMeasDFD.AutotuneLocked_A = 0;
	instrPtr->AnlMeasDFD.AutotuneLocked_B = 0;

	instrPtr->AnlMeasDFDPostFFT.Header_A.FunId = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.FFTSize = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.NOSL = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.SptrOffset = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.AverMode = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.AverCount = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.AverQuotient = 0.0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.ZoomFactor = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.ZoomOffset = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.SamplFreq = 0.0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.WindowSize = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.DisplaySize = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.Reserved_1 = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.Reserved_2 = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.Reserved_3 = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_A.ChnlMode = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.FunId = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.FFTSize = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.NOSL = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.SptrOffset = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.AverMode = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.AverCount = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.AverQuotient = 0.0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.ZoomFactor = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.ZoomOffset = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.SamplFreq = 0.0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.WindowSize = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.DisplaySize = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.Reserved_1 = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.Reserved_2 = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.Reserved_3 = 0;
	instrPtr->AnlMeasDFDPostFFT.Header_B.ChnlMode = 0;

	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.FunId = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.FFTSize = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.NOSL = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.SptrOffset = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.AverMode = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.AverCount = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.AverQuotient = 0.0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.ZoomFactor = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.ZoomOffset = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.SamplFreq = 0.0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.WindowSize = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.DisplaySize = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.Reserved_1 = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.Reserved_2 = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.Reserved_3 = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMax.ChnlMode = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.FunId = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.FFTSize = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.NOSL = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.SptrOffset = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.AverMode = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.AverCount = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.AverQuotient = 0.0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.ZoomFactor = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.ZoomOffset = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.SamplFreq = 0.0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.WindowSize = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.DisplaySize = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.Reserved_1 = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.Reserved_2 = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.Reserved_3 = 0;
	instrPtr->AnlMeasDFDReducedFFT.HeaderMin.ChnlMode = 0;

	instrPtr->AnlMeasModDist.Marker1_FFTFrequency = 0.0;
	instrPtr->AnlMeasModDist.Marker2_FFTFrequency = 0.0;
	instrPtr->AnlMeasModDist.Marker1_Value_A = 0.0;
	instrPtr->AnlMeasModDist.Marker2_Value_A = 0.0;
	instrPtr->AnlMeasModDist.Marker1_Value_B = 0.0;
	instrPtr->AnlMeasModDist.Marker2_Value_B = 0.0;
	instrPtr->AnlMeasModDist.Reserved = 0;
	instrPtr->AnlMeasModDist.AutotuneLocked_A = 0;
	instrPtr->AnlMeasModDist.AutotuneLocked_B = 0;

	instrPtr->AnlMeasModDistPostFFT.Header_A.FunId = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.FFTSize = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.NOSL = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.SptrOffset = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.AverMode = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.AverCount = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.AverQuotient = 0.0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.ZoomFactor = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.ZoomOffset = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.SamplFreq = 0.0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.WindowSize = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.DisplaySize = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.Reserved_1 = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.Reserved_2 = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.Reserved_3 = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_A.ChnlMode = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.FunId = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.FFTSize = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.NOSL = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.SptrOffset = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.AverMode = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.AverCount = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.AverQuotient = 0.0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.ZoomFactor = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.ZoomOffset = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.SamplFreq = 0.0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.WindowSize = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.DisplaySize = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.Reserved_1 = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.Reserved_2 = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.Reserved_3 = 0;
	instrPtr->AnlMeasModDistPostFFT.Header_B.ChnlMode = 0;

	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.FunId = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.FFTSize = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.NOSL = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.SptrOffset = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.AverMode = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.AverCount = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.AverQuotient = 0.0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.ZoomFactor = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.ZoomOffset = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.SamplFreq = 0.0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.WindowSize = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.DisplaySize = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.Reserved_1 = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.Reserved_2 = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.Reserved_3 = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMax.ChnlMode = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.FunId = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.FFTSize = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.NOSL = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.SptrOffset = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.AverMode = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.AverCount = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.AverQuotient = 0.0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.ZoomFactor = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.ZoomOffset = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.SamplFreq = 0.0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.WindowSize = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.DisplaySize = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.Reserved_1 = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.Reserved_2 = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.Reserved_3 = 0;
	instrPtr->AnlMeasModDistReducedFFT.HeaderMin.ChnlMode = 0;

	instrPtr->AnlMeasFFT.Header_A.FunId = 0;
	instrPtr->AnlMeasFFT.Header_A.FFTSize = 0;
	instrPtr->AnlMeasFFT.Header_A.NOSL = 0;
	instrPtr->AnlMeasFFT.Header_A.SptrOffset = 0;
	instrPtr->AnlMeasFFT.Header_A.AverMode = 0;
	instrPtr->AnlMeasFFT.Header_A.AverCount = 0;
	instrPtr->AnlMeasFFT.Header_A.AverQuotient = 0.0;
	instrPtr->AnlMeasFFT.Header_A.ZoomFactor = 0;
	instrPtr->AnlMeasFFT.Header_A.ZoomOffset = 0;
	instrPtr->AnlMeasFFT.Header_A.SamplFreq = 0.0;
	instrPtr->AnlMeasFFT.Header_A.WindowSize = 0;
	instrPtr->AnlMeasFFT.Header_A.DisplaySize = 0;
	instrPtr->AnlMeasFFT.Header_A.Reserved_1 = 0;
	instrPtr->AnlMeasFFT.Header_A.Reserved_2 = 0;
	instrPtr->AnlMeasFFT.Header_A.Reserved_3 = 0;
	instrPtr->AnlMeasFFT.Header_A.ChnlMode = 0;  
	instrPtr->AnlMeasFFT.Header_B.FunId = 0;
	instrPtr->AnlMeasFFT.Header_B.FFTSize = 0;
	instrPtr->AnlMeasFFT.Header_B.NOSL = 0;
	instrPtr->AnlMeasFFT.Header_B.SptrOffset = 0;
	instrPtr->AnlMeasFFT.Header_B.AverMode = 0;
	instrPtr->AnlMeasFFT.Header_B.AverCount = 0;
	instrPtr->AnlMeasFFT.Header_B.AverQuotient = 0.0;
	instrPtr->AnlMeasFFT.Header_B.ZoomFactor = 0;
	instrPtr->AnlMeasFFT.Header_B.ZoomOffset = 0;
	instrPtr->AnlMeasFFT.Header_B.SamplFreq = 0.0;
	instrPtr->AnlMeasFFT.Header_B.WindowSize = 0;
	instrPtr->AnlMeasFFT.Header_B.DisplaySize = 0;
	instrPtr->AnlMeasFFT.Header_B.Reserved_1 = 0;
	instrPtr->AnlMeasFFT.Header_B.Reserved_2 = 0;
	instrPtr->AnlMeasFFT.Header_B.Reserved_3 = 0;
	instrPtr->AnlMeasFFT.Header_B.ChnlMode = 0;   

	instrPtr->AnlMeasFFT.Marker1_FFTFrequency = 0.0;
	instrPtr->AnlMeasFFT.Marker2_FFTFrequency = 0.0;
	instrPtr->AnlMeasFFT.Marker1_Value_A = 0.0;
	instrPtr->AnlMeasFFT.Marker2_Value_A = 0.0;
	instrPtr->AnlMeasFFT.Marker1_Value_B = 0.0;
	instrPtr->AnlMeasFFT.Marker2_Value_B = 0.0;
	instrPtr->AnlMeasFFT.TaskTag = 0;

	instrPtr->AnlMeasFFTReduced.Header_A_max.FunId = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.FFTSize = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.NOSL = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.SptrOffset = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.AverMode = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.AverCount = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.AverQuotient = 0.0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.ZoomFactor = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.ZoomOffset = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.SamplFreq = 0.0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.WindowSize = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.DisplaySize = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.Reserved_1 = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.Reserved_2 = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.Reserved_3 = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_max.ChnlMode = 0; 
	instrPtr->AnlMeasFFTReduced.Header_A_min.FunId = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.FFTSize = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.NOSL = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.SptrOffset = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.AverMode = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.AverCount = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.AverQuotient = 0.0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.ZoomFactor = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.ZoomOffset = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.SamplFreq = 0.0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.WindowSize = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.DisplaySize = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.Reserved_1 = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.Reserved_2 = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.Reserved_3 = 0;
	instrPtr->AnlMeasFFTReduced.Header_A_min.ChnlMode = 0;  
	instrPtr->AnlMeasFFTReduced.Header_B_max.FunId = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.FFTSize = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.NOSL = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.SptrOffset = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.AverMode = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.AverCount = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.AverQuotient = 0.0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.ZoomFactor = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.ZoomOffset = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.SamplFreq = 0.0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.WindowSize = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.DisplaySize = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.Reserved_1 = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.Reserved_2 = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.Reserved_3 = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_max.ChnlMode = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.FunId = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.FFTSize = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.NOSL = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.SptrOffset = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.AverMode = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.AverCount = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.AverQuotient = 0.0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.ZoomFactor = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.ZoomOffset = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.SamplFreq = 0.0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.WindowSize = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.DisplaySize = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.Reserved_1 = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.Reserved_2 = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.Reserved_3 = 0;
	instrPtr->AnlMeasFFTReduced.Header_B_min.ChnlMode = 0;

	instrPtr->AnlMeasFFTReduced.Marker1_FFTFrequency = 0.0;
	instrPtr->AnlMeasFFTReduced.Marker2_FFTFrequency = 0.0;
	instrPtr->AnlMeasFFTReduced.Marker1_Value_A = 0.0;
	instrPtr->AnlMeasFFTReduced.Marker2_Value_A = 0.0;
	instrPtr->AnlMeasFFTReduced.Marker1_Value_B = 0.0;
	instrPtr->AnlMeasFFTReduced.Marker2_Value_B = 0.0;
	instrPtr->AnlMeasFFTReduced.TaskTag = 0;

	instrPtr->AnlMeasDAISamplingFrequency.DAISamplFreq = 0.0;

	instrPtr->AnlMeasDAIProtocol.ReceiveError = 0;
	instrPtr->AnlMeasDAIProtocol.ChannelStatusA[23] = '\0';
	instrPtr->AnlMeasDAIProtocol.ChannelStatusB[23] = '\0';
	  
	for (i = 0; i< 10; i++)
	{
		instrPtr->AnlMeasTHDN.Harmonic_A[i] = 0.0;
		instrPtr->AnlMeasTHDN.Harmonic_B[i] = 0.0;
	}

	for (i = 0; i < 5; i++)
	{
		instrPtr->AnlMeasDFD.Frequencies_A[i] = 0.0;
		instrPtr->AnlMeasDFD.RMSValues_A[i] = 0.0;
		instrPtr->AnlMeasDFD.Frequencies_B[i] = 0.0;
		instrPtr->AnlMeasDFD.RMSValues_B[i] = 0.0;
	}  

	for (i = 0; i < 6; i++)
	{
		instrPtr->AnlMeasModDist.Frequencies_A[i] = 0.0;
		instrPtr->AnlMeasModDist.RMSValues_A[i] = 0.0;
		instrPtr->AnlMeasModDist.Frequencies_B[i] = 0.0;
		instrPtr->AnlMeasModDist.RMSValues_B[i] = 0.0;
	}  

	for (i = 0; i < 310; i++)
	{
		instrPtr->AnlMeasTHDNReducedFFT.SLmax[i] = 0.0;
		instrPtr->AnlMeasTHDNReducedFFT.SLmin[i] = 0.0;
		instrPtr->AnlMeasPhaseReducedFFT.SLmax[i] = 0.0;
		instrPtr->AnlMeasPhaseReducedFFT.SLmin[i] = 0.0;
		instrPtr->AnlMeasDFDReducedFFT.SLmax[i] = 0.0;
		instrPtr->AnlMeasDFDReducedFFT.SLmin[i] = 0.0;
		instrPtr->AnlMeasModDistReducedFFT.SLmax[i] = 0.0;
		instrPtr->AnlMeasModDistReducedFFT.SLmin[i] = 0.0;
		instrPtr->AnlMeasFFTReduced.SpLnMax_A_max[i] = 0.0;
		instrPtr->AnlMeasFFTReduced.SpLnMin_A_min[i] = 0.0;
		instrPtr->AnlMeasFFTReduced.SpLnMax_B_max[i] = 0.0;
		instrPtr->AnlMeasFFTReduced.SpLnMin_B_min[i] = 0.0;
	}  

	for (i = 0; i < 7430; i++)
	{
		instrPtr->AnlMeasTHDNPostFFT.SpLines_A[i] = 0.0;
		instrPtr->AnlMeasTHDNPostFFT.SpLines_B[i] = 0.0;
		instrPtr->AnlMeasPhasePostFFT.SpLines[i] = 0;
		instrPtr->AnlMeasDFDPostFFT.SpLines_A[i] = 0.0;
		instrPtr->AnlMeasDFDPostFFT.SpLines_B[i] = 0.0;
		instrPtr->AnlMeasModDistPostFFT.SpLines_A[i] = 0.0;
		instrPtr->AnlMeasModDistPostFFT.SpLines_B[i] = 0.0;
		instrPtr->AnlMeasFFT.SpLines_A[i] = 0.0;    
		instrPtr->AnlMeasFFT.SpLines_B[i] = 0.0;
	}
	
	return rssiup_status;
}

/*****************************************************************************/
/*=== END INSTRUMENT DRIVER SOURCE CODE =====================================*/
/*****************************************************************************/
